Class: Aws::QuickSight::Types::AccessControlConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The access control settings for a knowledge base. Use this structure to enable or disable document-level access control lists (ACLs) that filter query results based on the permissions from the source data connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_acl_enabledBoolean

Specifies whether ACLs are enabled for the knowledge base.

This setting works together with the data source connector's ACL crawling. To enforce document-level access control end to end, set isACLEnabled to true and enable ACL crawling on the connector. For example, for an Amazon S3 data source, set accessControlConfiguration.crawlAcl to true in the connector template. For more information, see KbTemplateConfiguration. Enabling only one of the two settings does not produce a fully ACL-enforced knowledge base.

Returns:

  • (Boolean)


57
58
59
60
61
# File 'lib/aws-sdk-quicksight/types.rb', line 57

class AccessControlConfiguration < Struct.new(
  :is_acl_enabled)
  SENSITIVE = []
  include Aws::Structure
end