Class: Aws::QuickSight::Types::ActionConnector
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ActionConnector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Contains detailed information about an action connector, including its configuration, status, and enabled actions.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#action_connector_id ⇒ String
The unique identifier of the action connector.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the action connector.
-
#authentication_config ⇒ Types::ReadAuthConfig
The authentication configuration used to connect to the external service.
-
#created_time ⇒ Time
The timestamp when the action connector was created.
-
#description ⇒ String
The description of the action connector.
-
#enabled_actions ⇒ Array<String>
The list of actions that are enabled for this connector.
-
#error ⇒ Types::ActionConnectorError
Error information if the action connector is in an error state.
-
#last_updated_time ⇒ Time
The date and time when the action connector was last updated.
-
#name ⇒ String
The name of the action connector.
-
#status ⇒ String
The current status of the action connector.
-
#type ⇒ String
The type of action connector.
-
#vpc_connection_arn ⇒ String
The ARN of the VPC connection used for secure connectivity to the external service.
Instance Attribute Details
#action_connector_id ⇒ String
The unique identifier of the action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#authentication_config ⇒ Types::ReadAuthConfig
The authentication configuration used to connect to the external service.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the action connector was created.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#enabled_actions ⇒ Array<String>
The list of actions that are enabled for this connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#error ⇒ Types::ActionConnectorError
Error information if the action connector is in an error state.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_time ⇒ Time
The date and time when the action connector was last updated.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The current status of the action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#type ⇒ String
The type of action connector.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#vpc_connection_arn ⇒ String
The ARN of the VPC connection used for secure connectivity to the external service.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-quicksight/types.rb', line 262 class ActionConnector < Struct.new( :arn, :action_connector_id, :type, :name, :created_time, :last_updated_time, :status, :error, :description, :authentication_config, :enabled_actions, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |