Class: Aws::QuickSight::Types::Agent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An agent resource in Amazon QuickSight that provides AI-powered conversational experiences.

Constant Summary collapse

SENSITIVE =
[:starter_prompts, :welcome_message]

Instance Attribute Summary collapse

Instance Attribute Details

#action_connectorsArray<String>

The Amazon Resource Names (ARNs) of the action connectors attached to the agent.

Returns:

  • (Array<String>)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#agent_idString

The unique identifier for the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#agent_lifecycleString

The lifecycle state of the agent. Valid values are ‘PREVIEW` and `PUBLISHED`.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#agent_statusString

The status of the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#created_atTime

The date and time that the agent was created.

Returns:

  • (Time)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#creatorString

The identity of the user who created the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#custom_prompt_interfaceTypes::CustomPromptInterface

The custom prompt interface configuration for the agent.



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#descriptionString

A description of the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#error_messageString

An error message associated with the agent, if applicable.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#icon_idString

The icon identifier for the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#nameString

The name of the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#spacesArray<String>

The Amazon Resource Names (ARNs) of the spaces attached to the agent.

Returns:

  • (Array<String>)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#starter_promptsArray<String>

A list of starter prompts that are displayed to users when they begin interacting with the agent.

Returns:

  • (Array<String>)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#updated_atTime

The date and time that the agent was last updated.

Returns:

  • (Time)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end

#welcome_messageString

The welcome message that is displayed when a user starts a conversation with the agent.

Returns:

  • (String)


482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/aws-sdk-quicksight/types.rb', line 482

class Agent < Struct.new(
  :spaces,
  :action_connectors,
  :description,
  :icon_id,
  :name,
  :starter_prompts,
  :welcome_message,
  :arn,
  :agent_id,
  :agent_lifecycle,
  :agent_status,
  :created_at,
  :creator,
  :custom_prompt_interface,
  :error_message,
  :updated_at)
  SENSITIVE = [:starter_prompts, :welcome_message]
  include Aws::Structure
end