Class: Aws::QuickSight::Types::AgentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A summary of an agent, including its identifier, name, and metadata.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_idString

The unique identifier for the agent.

Returns:

  • (String)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the agent.

Returns:

  • (String)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the agent was created.

Returns:

  • (Time)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the agent.

Returns:

  • (String)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#icon_idString

The icon identifier for the agent.

Returns:

  • (String)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the agent.

Returns:

  • (String)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the agent was last updated.

Returns:

  • (Time)


559
560
561
562
563
564
565
566
567
568
569
# File 'lib/aws-sdk-quicksight/types.rb', line 559

class AgentSummary < Struct.new(
  :arn,
  :agent_id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :icon_id)
  SENSITIVE = []
  include Aws::Structure
end