Class: Aws::QuickSight::Types::AggregateOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AggregateOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that groups rows by specified columns and applies aggregation functions to calculate summary values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregations ⇒ Array<Types::Aggregation>
The list of aggregation functions to apply to the grouped data, such as
SUM,COUNT, orAVERAGE. -
#alias ⇒ String
Alias for this operation.
-
#group_by_column_names ⇒ Array<String>
The list of column names to group by when performing the aggregation.
-
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the aggregation.
Instance Attribute Details
#aggregations ⇒ Array<Types::Aggregation>
The list of aggregation functions to apply to the grouped data, such
as SUM, COUNT, or AVERAGE.
651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-quicksight/types.rb', line 651 class AggregateOperation < Struct.new( :alias, :source, :group_by_column_names, :aggregations) SENSITIVE = [] include Aws::Structure end |
#alias ⇒ String
Alias for this operation.
651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-quicksight/types.rb', line 651 class AggregateOperation < Struct.new( :alias, :source, :group_by_column_names, :aggregations) SENSITIVE = [] include Aws::Structure end |
#group_by_column_names ⇒ Array<String>
The list of column names to group by when performing the aggregation. Rows with the same values in these columns will be grouped together.
651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-quicksight/types.rb', line 651 class AggregateOperation < Struct.new( :alias, :source, :group_by_column_names, :aggregations) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the aggregation.
651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-quicksight/types.rb', line 651 class AggregateOperation < Struct.new( :alias, :source, :group_by_column_names, :aggregations) SENSITIVE = [] include Aws::Structure end |