Class: Aws::QuickSight::Types::Aggregation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::Aggregation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Defines an aggregation function to be applied to grouped data, creating a new column with the calculated result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_function ⇒ Types::DataPrepAggregationFunction
The aggregation function to apply, such as ‘SUM`, `COUNT`, `AVERAGE`, `MIN`, `MAX`.
-
#new_column_id ⇒ String
A unique identifier for the new column that will contain the aggregated values.
-
#new_column_name ⇒ String
The name for the new column that will contain the aggregated values.
Instance Attribute Details
#aggregation_function ⇒ Types::DataPrepAggregationFunction
The aggregation function to apply, such as ‘SUM`, `COUNT`, `AVERAGE`, `MIN`, `MAX`
476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-quicksight/types.rb', line 476 class Aggregation < Struct.new( :aggregation_function, :new_column_name, :new_column_id) SENSITIVE = [] include Aws::Structure end |
#new_column_id ⇒ String
A unique identifier for the new column that will contain the aggregated values.
476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-quicksight/types.rb', line 476 class Aggregation < Struct.new( :aggregation_function, :new_column_name, :new_column_id) SENSITIVE = [] include Aws::Structure end |
#new_column_name ⇒ String
The name for the new column that will contain the aggregated values.
476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-quicksight/types.rb', line 476 class Aggregation < Struct.new( :aggregation_function, :new_column_name, :new_column_id) SENSITIVE = [] include Aws::Structure end |