Class: Aws::QuickSight::Types::AmazonQInQuickSightDashboardConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A collection of Amazon Q feature configurations in an embedded Quick Sight dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#executive_summaryTypes::ExecutiveSummaryConfigurations

A generated executive summary of an embedded Quick Sight dashboard.



677
678
679
680
681
# File 'lib/aws-sdk-quicksight/types.rb', line 677

class AmazonQInQuickSightDashboardConfigurations < Struct.new(
  :executive_summary)
  SENSITIVE = []
  include Aws::Structure
end