Class: Aws::QuickSight::Types::AnalysisSourceTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The source template of an analysis.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the source template of an analysis.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
# File 'lib/aws-sdk-quicksight/types.rb', line 1174

class AnalysisSourceTemplate < Struct.new(
  :data_set_references,
  :topic_references,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_referencesArray<Types::DataSetReference>

The dataset references of the source template of an analysis.

Returns:



1174
1175
1176
1177
1178
1179
1180
# File 'lib/aws-sdk-quicksight/types.rb', line 1174

class AnalysisSourceTemplate < Struct.new(
  :data_set_references,
  :topic_references,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#topic_referencesArray<Types::TopicReference>

The topic references of the source template of an analysis.

Returns:



1174
1175
1176
1177
1178
1179
1180
# File 'lib/aws-sdk-quicksight/types.rb', line 1174

class AnalysisSourceTemplate < Struct.new(
  :data_set_references,
  :topic_references,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end