Class: Aws::QuickSight::Types::AnonymousUserDashboardVisualEmbeddingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AnonymousUserDashboardVisualEmbeddingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The experience that you are embedding. You can use this object to generate a url that embeds a visual into your application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#initial_dashboard_visual_id ⇒ Types::DashboardVisualId
The visual ID for the visual that you want the user to see.
Instance Attribute Details
#initial_dashboard_visual_id ⇒ Types::DashboardVisualId
The visual ID for the visual that you want the user to see. This ID is included in the output URL. When the URL in response is accessed, Amazon Quick Sight renders this visual.
The Amazon Resource Name (ARN) of the dashboard that the visual belongs to must be included in the ‘AuthorizedResourceArns` parameter. Otherwise, the request will fail with `InvalidParameterValueException`.
1130 1131 1132 1133 1134 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1130 class AnonymousUserDashboardVisualEmbeddingConfiguration < Struct.new( :initial_dashboard_visual_id) SENSITIVE = [] include Aws::Structure end |