Class: Aws::QuickSight::Types::AnonymousUserGenerativeQnAEmbeddingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The settings that you want to use for the Generative Q&A experience.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#initial_topic_idString

The Quick Sight Q topic ID of the new reader experience topic that you want the anonymous user to see first. This ID is included in the output URL. When the URL in response is accessed, Quick Sight renders the Generative Q&A experience with this new reader experience topic pre selected.

The Amazon Resource Name (ARN) of this Q new reader experience topic must be included in the ‘AuthorizedResourceArns` parameter. Otherwise, the request fails with an `InvalidParameterValueException` error.

Returns:

  • (String)


1187
1188
1189
1190
1191
# File 'lib/aws-sdk-quicksight/types.rb', line 1187

class AnonymousUserGenerativeQnAEmbeddingConfiguration < Struct.new(
  :initial_topic_id)
  SENSITIVE = []
  include Aws::Structure
end