Class: Aws::QuickSight::Types::AnonymousUserQSearchBarEmbeddingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The settings that you want to use with the Q search bar.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#initial_topic_idString

The Quick Sight Q topic ID of the legacy topic that you want the anonymous user to see first. This ID is included in the output URL. When the URL in response is accessed, Quick Sight renders the Q search bar with this legacy topic pre-selected.

The Amazon Resource Name (ARN) of this Q legacy topic must be included in the AuthorizedResourceArns parameter. Otherwise, the request fails with an InvalidParameterValueException error.

Returns:

  • (String)


1388
1389
1390
1391
1392
# File 'lib/aws-sdk-quicksight/types.rb', line 1388

class AnonymousUserQSearchBarEmbeddingConfiguration < Struct.new(
  :initial_topic_id)
  SENSITIVE = []
  include Aws::Structure
end