Class: Aws::QuickSight::Types::AssetBundleCloudFormationOverridePropertyConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An optional collection of CloudFormation property configurations that control how the export job is generated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysesArray<Types::AssetBundleExportJobAnalysisOverrideProperties>

An optional list of structures that control how Analysis resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#dashboardsArray<Types::AssetBundleExportJobDashboardOverrideProperties>

An optional list of structures that control how Dashboard resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#data_setsArray<Types::AssetBundleExportJobDataSetOverrideProperties>

An optional list of structures that control how DataSet resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#data_sourcesArray<Types::AssetBundleExportJobDataSourceOverrideProperties>

An optional list of structures that control how DataSource resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#foldersArray<Types::AssetBundleExportJobFolderOverrideProperties>

An optional list of structures that controls how Folder resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_schedulesArray<Types::AssetBundleExportJobRefreshScheduleOverrideProperties>

An optional list of structures that control how RefreshSchedule resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id_override_configurationTypes::AssetBundleExportJobResourceIdOverrideConfiguration

An optional list of structures that control how resource IDs are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#themesArray<Types::AssetBundleExportJobThemeOverrideProperties>

An optional list of structures that control how Theme resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#topics_v2Array<Types::AssetBundleExportJobTopicV2OverrideProperties>

An optional list of structures that controls how Topic resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_connectionsArray<Types::AssetBundleExportJobVPCConnectionOverrideProperties>

An optional list of structures that control how VPCConnection resources are parameterized in the returned CloudFormation template.



1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-quicksight/types.rb', line 1772

class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new(
  :resource_id_override_configuration,
  :vpc_connections,
  :refresh_schedules,
  :data_sources,
  :data_sets,
  :themes,
  :analyses,
  :dashboards,
  :folders,
  :topics_v2)
  SENSITIVE = []
  include Aws::Structure
end