Class: Aws::QuickSight::Types::AssetBundleExportJobAnalysisOverrideProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleExportJobAnalysisOverrideProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Controls how a specific Analysis resource is parameterized in the
returned CloudFormation template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the specific
Analysisresource whose override properties are configured in this structure. -
#properties ⇒ Array<String>
A list of
Analysisresource properties to generate variables for in the returned CloudFormation template.
Instance Attribute Details
#arn ⇒ String
The ARN of the specific Analysis resource whose override
properties are configured in this structure.
1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1623 class AssetBundleExportJobAnalysisOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Array<String>
A list of Analysis resource properties to generate variables for
in the returned CloudFormation template.
1623 1624 1625 1626 1627 1628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1623 class AssetBundleExportJobAnalysisOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |