Class: Aws::QuickSight::Types::AssetBundleExportJobDataSetOverrideProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleExportJobDataSetOverrideProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Controls how a specific DataSet resource is parameterized in the
returned CloudFormation template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the specific
DataSetresource whose override properties are configured in this structure. -
#properties ⇒ Array<String>
A list of
DataSetresource properties to generate variables for in the returned CloudFormation template.
Instance Attribute Details
#arn ⇒ String
The ARN of the specific DataSet resource whose override properties
are configured in this structure.
1667 1668 1669 1670 1671 1672 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1667 class AssetBundleExportJobDataSetOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Array<String>
A list of DataSet resource properties to generate variables for in
the returned CloudFormation template.
1667 1668 1669 1670 1671 1672 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1667 class AssetBundleExportJobDataSetOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |