Class: Aws::QuickSight::Types::AssetBundleExportJobRefreshScheduleOverrideProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Controls how a specific RefreshSchedule resource is parameterized in the returned CloudFormation template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the specific RefreshSchedule resource whose override properties are configured in this structure.

Returns:

  • (String)


1936
1937
1938
1939
1940
1941
# File 'lib/aws-sdk-quicksight/types.rb', line 1936

class AssetBundleExportJobRefreshScheduleOverrideProperties < Struct.new(
  :arn,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesArray<String>

A list of RefreshSchedule resource properties to generate variables for in the returned CloudFormation template.

Returns:

  • (Array<String>)


1936
1937
1938
1939
1940
1941
# File 'lib/aws-sdk-quicksight/types.rb', line 1936

class AssetBundleExportJobRefreshScheduleOverrideProperties < Struct.new(
  :arn,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end