Class: Aws::QuickSight::Types::AssetBundleExportJobThemeOverrideProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleExportJobThemeOverrideProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Controls how a specific Theme resource is parameterized in the
returned CloudFormation template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the specific
Themeresource whose override properties are configured in this structure. -
#properties ⇒ Array<String>
A list of
Themeresource properties to generate variables for in the returned CloudFormation template.
Instance Attribute Details
#arn ⇒ String
The ARN of the specific Theme resource whose override properties
are configured in this structure.
1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1849 class AssetBundleExportJobThemeOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Array<String>
A list of Theme resource properties to generate variables for in
the returned CloudFormation template.
1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1849 class AssetBundleExportJobThemeOverrideProperties < Struct.new( :arn, :properties) SENSITIVE = [] include Aws::Structure end |