Class: Aws::QuickSight::Types::AssetBundleImportJobOverrideParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportJobOverrideParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A list of overrides that modify the asset bundle resource configuration before the resource is imported.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analyses ⇒ Array<Types::AssetBundleImportJobAnalysisOverrideParameters>
A list of overrides for any
Analysisresources that are present in the asset bundle that is imported. -
#dashboards ⇒ Array<Types::AssetBundleImportJobDashboardOverrideParameters>
A list of overrides for any
Dashboardresources that are present in the asset bundle that is imported. -
#data_sets ⇒ Array<Types::AssetBundleImportJobDataSetOverrideParameters>
A list of overrides for any
DataSetresources that are present in the asset bundle that is imported. -
#data_sources ⇒ Array<Types::AssetBundleImportJobDataSourceOverrideParameters>
A list of overrides for any
DataSourceresources that are present in the asset bundle that is imported. -
#folders ⇒ Array<Types::AssetBundleImportJobFolderOverrideParameters>
A list of overrides for any
Folderresources that are present in the asset bundle that is imported. -
#refresh_schedules ⇒ Array<Types::AssetBundleImportJobRefreshScheduleOverrideParameters>
A list of overrides for any
RefreshScheduleresources that are present in the asset bundle that is imported. -
#resource_id_override_configuration ⇒ Types::AssetBundleImportJobResourceIdOverrideConfiguration
An optional structure that configures resource ID overrides to be applied within the import job.
-
#themes ⇒ Array<Types::AssetBundleImportJobThemeOverrideParameters>
A list of overrides for any
Themeresources that are present in the asset bundle that is imported. -
#topics_v2 ⇒ Array<Types::AssetBundleImportJobTopicV2OverrideParameters>
A list of overrides for any
Topicresources that are present in the asset bundle that is imported. -
#vpc_connections ⇒ Array<Types::AssetBundleImportJobVPCConnectionOverrideParameters>
A list of overrides for any
VPCConnectionresources that are present in the asset bundle that is imported.
Instance Attribute Details
#analyses ⇒ Array<Types::AssetBundleImportJobAnalysisOverrideParameters>
A list of overrides for any Analysis resources that are present in
the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#dashboards ⇒ Array<Types::AssetBundleImportJobDashboardOverrideParameters>
A list of overrides for any Dashboard resources that are present
in the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#data_sets ⇒ Array<Types::AssetBundleImportJobDataSetOverrideParameters>
A list of overrides for any DataSet resources that are present in
the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Array<Types::AssetBundleImportJobDataSourceOverrideParameters>
A list of overrides for any DataSource resources that are present
in the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#folders ⇒ Array<Types::AssetBundleImportJobFolderOverrideParameters>
A list of overrides for any Folder resources that are present in
the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#refresh_schedules ⇒ Array<Types::AssetBundleImportJobRefreshScheduleOverrideParameters>
A list of overrides for any RefreshSchedule resources that are
present in the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#resource_id_override_configuration ⇒ Types::AssetBundleImportJobResourceIdOverrideConfiguration
An optional structure that configures resource ID overrides to be applied within the import job.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#themes ⇒ Array<Types::AssetBundleImportJobThemeOverrideParameters>
A list of overrides for any Theme resources that are present in
the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#topics_v2 ⇒ Array<Types::AssetBundleImportJobTopicV2OverrideParameters>
A list of overrides for any Topic resources that are present in
the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |
#vpc_connections ⇒ Array<Types::AssetBundleImportJobVPCConnectionOverrideParameters>
A list of overrides for any VPCConnection resources that are
present in the asset bundle that is imported.
2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2592 class AssetBundleImportJobOverrideParameters < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders, :topics_v2) SENSITIVE = [] include Aws::Structure end |