Class: Aws::QuickSight::Types::AssetBundleImportSourceDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A description of the import source that you provide at the start of an import job. This value is set to either Body or S3Uri, depending on how the StartAssetBundleImportJobRequest is configured.

Constant Summary collapse

SENSITIVE =
[:body]

Instance Attribute Summary collapse

Instance Attribute Details

#bodyString

An HTTPS download URL for the provided asset bundle that you optionally provided at the start of the import job. This URL is valid for five minutes after issuance. Call DescribeAssetBundleExportJob again for a fresh URL if needed. The downloaded asset bundle is a .qs zip file.

Returns:

  • (String)


3085
3086
3087
3088
3089
3090
# File 'lib/aws-sdk-quicksight/types.rb', line 3085

class AssetBundleImportSourceDescription < Struct.new(
  :body,
  :s3_uri)
  SENSITIVE = [:body]
  include Aws::Structure
end

#s3_uriString

The Amazon S3 URI that you provided at the start of the import job.

Returns:

  • (String)


3085
3086
3087
3088
3089
3090
# File 'lib/aws-sdk-quicksight/types.rb', line 3085

class AssetBundleImportSourceDescription < Struct.new(
  :body,
  :s3_uri)
  SENSITIVE = [:body]
  include Aws::Structure
end