Class: Aws::QuickSight::Types::BatchCreateTopicReviewedAnswerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchCreateTopicReviewedAnswerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invalid_answers ⇒ Array<Types::InvalidTopicReviewedAnswer>
The definition of Answers that are invalid and not created.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#succeeded_answers ⇒ Array<Types::SucceededTopicReviewedAnswer>
The definition of Answers that are successfully created.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to create.
Instance Attribute Details
#invalid_answers ⇒ Array<Types::InvalidTopicReviewedAnswer>
The definition of Answers that are invalid and not created.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#succeeded_answers ⇒ Array<Types::SucceededTopicReviewedAnswer>
The definition of Answers that are successfully created.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4138 class BatchCreateTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :status, :request_id) SENSITIVE = [] include Aws::Structure end |