Class: Aws::QuickSight::Types::BatchDeleteKnowledgeBaseFailure
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchDeleteKnowledgeBaseFailure
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Information about a knowledge base that failed to be deleted in a batch operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code for the deletion failure.
-
#error_message ⇒ String
The error message for the deletion failure.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that failed to be deleted.
Instance Attribute Details
#error_code ⇒ String
The error code for the deletion failure.
3875 3876 3877 3878 3879 3880 3881 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3875 class BatchDeleteKnowledgeBaseFailure < Struct.new( :knowledge_base_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message for the deletion failure.
3875 3876 3877 3878 3879 3880 3881 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3875 class BatchDeleteKnowledgeBaseFailure < Struct.new( :knowledge_base_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that failed to be deleted.
3875 3876 3877 3878 3879 3880 3881 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3875 class BatchDeleteKnowledgeBaseFailure < Struct.new( :knowledge_base_id, :error_code, :error_message) SENSITIVE = [] include Aws::Structure end |