Class: Aws::QuickSight::Types::BatchDeleteKnowledgeBaseResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchDeleteKnowledgeBaseResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deleted ⇒ Array<Types::BatchDeleteKnowledgeBaseSuccess>
A list of knowledge bases that were successfully deleted.
-
#errors ⇒ Array<Types::BatchDeleteKnowledgeBaseFailure>
A list of knowledge bases that failed to be deleted.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#deleted ⇒ Array<Types::BatchDeleteKnowledgeBaseSuccess>
A list of knowledge bases that were successfully deleted.
3919 3920 3921 3922 3923 3924 3925 3926 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3919 class BatchDeleteKnowledgeBaseResponse < Struct.new( :deleted, :errors, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::BatchDeleteKnowledgeBaseFailure>
A list of knowledge bases that failed to be deleted.
3919 3920 3921 3922 3923 3924 3925 3926 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3919 class BatchDeleteKnowledgeBaseResponse < Struct.new( :deleted, :errors, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
3919 3920 3921 3922 3923 3924 3925 3926 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3919 class BatchDeleteKnowledgeBaseResponse < Struct.new( :deleted, :errors, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
3919 3920 3921 3922 3923 3924 3925 3926 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3919 class BatchDeleteKnowledgeBaseResponse < Struct.new( :deleted, :errors, :request_id, :status) SENSITIVE = [] include Aws::Structure end |