Class: Aws::QuickSight::Types::BatchDeleteKnowledgeBaseSuccess
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchDeleteKnowledgeBaseSuccess
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Information about a knowledge base that was successfully deleted in a batch operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_arn ⇒ String
The ARN of the successfully deleted knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier of the successfully deleted knowledge base.
Instance Attribute Details
#knowledge_base_arn ⇒ String
The ARN of the successfully deleted knowledge base.
3941 3942 3943 3944 3945 3946 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3941 class BatchDeleteKnowledgeBaseSuccess < Struct.new( :knowledge_base_id, :knowledge_base_arn) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the successfully deleted knowledge base.
3941 3942 3943 3944 3945 3946 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3941 class BatchDeleteKnowledgeBaseSuccess < Struct.new( :knowledge_base_id, :knowledge_base_arn) SENSITIVE = [] include Aws::Structure end |