Class: Aws::QuickSight::Types::BorderStyle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The display options for tile borders for visuals.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#colorString

The option to add color for tile borders for visuals.

Returns:

  • (String)


4004
4005
4006
4007
4008
4009
4010
# File 'lib/aws-sdk-quicksight/types.rb', line 4004

class BorderStyle < Struct.new(
  :color,
  :show,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#showBoolean

The option to enable display of borders for visuals.

Returns:

  • (Boolean)


4004
4005
4006
4007
4008
4009
4010
# File 'lib/aws-sdk-quicksight/types.rb', line 4004

class BorderStyle < Struct.new(
  :color,
  :show,
  :width)
  SENSITIVE = []
  include Aws::Structure
end

#widthString

The option to set the width of tile borders for visuals.

Returns:

  • (String)


4004
4005
4006
4007
4008
4009
4010
# File 'lib/aws-sdk-quicksight/types.rb', line 4004

class BorderStyle < Struct.new(
  :color,
  :show,
  :width)
  SENSITIVE = []
  include Aws::Structure
end