Class: Aws::QuickSight::Types::CalculatedField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The calculated field of an analysis.

Constant Summary collapse

SENSITIVE =
[:expression]

Instance Attribute Summary collapse

Instance Attribute Details

#data_set_identifierString

The data set that is used in this calculated field.

Returns:

  • (String)


4800
4801
4802
4803
4804
4805
4806
4807
# File 'lib/aws-sdk-quicksight/types.rb', line 4800

class CalculatedField < Struct.new(
  :data_set_identifier,
  :topic_identifier,
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end

#expressionString

The expression of the calculated field.

Returns:

  • (String)


4800
4801
4802
4803
4804
4805
4806
4807
# File 'lib/aws-sdk-quicksight/types.rb', line 4800

class CalculatedField < Struct.new(
  :data_set_identifier,
  :topic_identifier,
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end

#nameString

The name of the calculated field.

Returns:

  • (String)


4800
4801
4802
4803
4804
4805
4806
4807
# File 'lib/aws-sdk-quicksight/types.rb', line 4800

class CalculatedField < Struct.new(
  :data_set_identifier,
  :topic_identifier,
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end

#topic_identifierString

The topic that is used in this calculated field.

Returns:

  • (String)


4800
4801
4802
4803
4804
4805
4806
4807
# File 'lib/aws-sdk-quicksight/types.rb', line 4800

class CalculatedField < Struct.new(
  :data_set_identifier,
  :topic_identifier,
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end