Class: Aws::QuickSight::Types::CastColumnTypesOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CastColumnTypesOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that changes the data types of one or more columns in the dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for this operation.
-
#cast_column_type_operations ⇒ Array<Types::CastColumnTypeOperation>
The list of column type casting operations to perform.
-
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the type casting.
Instance Attribute Details
#alias ⇒ String
Alias for this operation.
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5786 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |
#cast_column_type_operations ⇒ Array<Types::CastColumnTypeOperation>
The list of column type casting operations to perform.
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5786 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the type casting.
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5786 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |