Class: Aws::QuickSight::Types::ClientCredentialsGrantDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Configuration details for OAuth2 client credentials grant flow, including client ID, client secret, token endpoint, and optional scopes.

Constant Summary collapse

SENSITIVE =
[:client_secret]

Instance Attribute Summary collapse

Instance Attribute Details

#client_idString

The client identifier issued to the client during the registration process with the authorization server.

Returns:

  • (String)


6049
6050
6051
6052
6053
6054
6055
# File 'lib/aws-sdk-quicksight/types.rb', line 6049

class ClientCredentialsGrantDetails < Struct.new(
  :client_id,
  :client_secret,
  :token_endpoint)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#client_secretString

The client secret issued to the client during the registration process with the authorization server.

Returns:

  • (String)


6049
6050
6051
6052
6053
6054
6055
# File 'lib/aws-sdk-quicksight/types.rb', line 6049

class ClientCredentialsGrantDetails < Struct.new(
  :client_id,
  :client_secret,
  :token_endpoint)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end

#token_endpointString

The authorization server endpoint used to obtain access tokens via the client credentials grant flow.

Returns:

  • (String)


6049
6050
6051
6052
6053
6054
6055
# File 'lib/aws-sdk-quicksight/types.rb', line 6049

class ClientCredentialsGrantDetails < Struct.new(
  :client_id,
  :client_secret,
  :token_endpoint)
  SENSITIVE = [:client_secret]
  include Aws::Structure
end