Class: Aws::QuickSight::Types::ColumnSemanticType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The semantic type information for a column in the new data preparation experience.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#geographical_roleString

The geographical role of the column in the new data preparation experience.

Returns:

  • (String)


7527
7528
7529
7530
7531
# File 'lib/aws-sdk-quicksight/types.rb', line 7527

class ColumnSemanticType < Struct.new(
  :geographical_role)
  SENSITIVE = []
  include Aws::Structure
end