Class: Aws::QuickSight::Types::ColumnToUnpivot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies a column to be unpivoted, transforming it from a column into rows with associated values.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_nameString

The name of the column to unpivot from the source data.

Returns:

  • (String)


5488
5489
5490
5491
5492
5493
# File 'lib/aws-sdk-quicksight/types.rb', line 5488

class ColumnToUnpivot < Struct.new(
  :column_name,
  :new_value)
  SENSITIVE = []
  include Aws::Structure
end

#new_valueString

The value to assign to this column in the unpivoted result, typically the column name or a descriptive label.

Returns:

  • (String)


5488
5489
5490
5491
5492
5493
# File 'lib/aws-sdk-quicksight/types.rb', line 5488

class ColumnToUnpivot < Struct.new(
  :column_name,
  :new_value)
  SENSITIVE = []
  include Aws::Structure
end