Class: Aws::QuickSight::Types::ComboChartDefaultSeriesSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The options that determine the default presentation of all series in ‘ComboChartVisual`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#border_settingsTypes::BorderSettings

Border settings for all bar series in the visual.



7038
7039
7040
7041
7042
7043
7044
7045
# File 'lib/aws-sdk-quicksight/types.rb', line 7038

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#decal_settingsTypes::DecalSettings

Decal settings for all series in the visual.



7038
7039
7040
7041
7042
7043
7044
7045
# File 'lib/aws-sdk-quicksight/types.rb', line 7038

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#line_style_settingsTypes::LineChartLineStyleSettings

Line styles options for all line series in the visual.



7038
7039
7040
7041
7042
7043
7044
7045
# File 'lib/aws-sdk-quicksight/types.rb', line 7038

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#marker_style_settingsTypes::LineChartMarkerStyleSettings

Marker styles options for all line series in the visual.



7038
7039
7040
7041
7042
7043
7044
7045
# File 'lib/aws-sdk-quicksight/types.rb', line 7038

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end