Class: Aws::QuickSight::Types::ComboChartVisual

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A combo chart.

The ComboChartVisual includes stacked bar combo charts and clustered bar combo charts

For more information, see Using combo charts in the Amazon Quick Suite User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::VisualCustomAction>

The list of custom actions that are configured for a visual.

Returns:



8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#chart_configurationTypes::ComboChartConfiguration

The configuration settings of the visual.



8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#column_hierarchiesArray<Types::ColumnHierarchy>

The column hierarchy that is used during drill-downs and drill-ups.

Returns:



8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#subtitleTypes::VisualSubtitleLabelOptions

The subtitle that is displayed on the visual.



8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#titleTypes::VisualTitleLabelOptions

The title that is displayed on the visual.



8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_content_alt_textString

The alt text for the visual.

Returns:

  • (String)


8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_idString

The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

Returns:

  • (String)


8275
8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/aws-sdk-quicksight/types.rb', line 8275

class ComboChartVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :column_hierarchies,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end