Class: Aws::QuickSight::Types::CreateAccountSubscriptionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_nameString

The name of your Amazon Quick Sight account. This name is unique over all of Amazon Web Services, and it appears only when users sign in. You can’t change ‘AccountName` value after the Amazon Quick Sight account is created.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#active_directory_nameString

The name of your Active Directory. This field is required if ‘ACTIVE_DIRECTORY` is the selected authentication method of the new Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#admin_groupArray<String>

The admin group associated with your Active Directory or IAM Identity Center account. Either this field or the ‘AdminProGroup` field is required if `ACTIVE_DIRECTORY` or `IAM_IDENTITY_CENTER` is the selected authentication method of the new Quick Sight account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#admin_pro_groupArray<String>

The admin pro group associated with your Active Directory or IAM Identity Center account. Either this field or the ‘AdminGroup` field is required if `ACTIVE_DIRECTORY` or `IAM_IDENTITY_CENTER` is the selected authentication method of the new Quick Sight account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_methodString

The method that you want to use to authenticate your Quick Sight account.

If you choose ‘ACTIVE_DIRECTORY`, provide an `ActiveDirectoryName` and an `AdminGroup` associated with your Active Directory.

If you choose ‘IAM_IDENTITY_CENTER`, provide an `AdminGroup` associated with your IAM Identity Center account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#author_groupArray<String>

The author group associated with your Active Directory or IAM Identity Center account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#author_pro_groupArray<String>

The author pro group associated with your Active Directory or IAM Identity Center account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The Amazon Web Services account ID of the account that you’re using to create your Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#contact_numberString

A 10-digit phone number for the author of the Amazon Quick Sight account to use for future communications. This field is required if ‘ENTERPPRISE_AND_Q` is the selected edition of the new Amazon Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#directory_idString

The ID of the Active Directory that is associated with your Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#editionString

The edition of Amazon Quick Sight that you want your account to have. Currently, you can choose from ‘ENTERPRISE` or `ENTERPRISE_AND_Q`.

If you choose ‘ENTERPRISE_AND_Q`, the following parameters are required:

  • ‘FirstName`

  • ‘LastName`

  • ‘EmailAddress`

  • ‘ContactNumber`

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#email_addressString

The email address of the author of the Amazon Quick Sight account to use for future communications. This field is required if ‘ENTERPPRISE_AND_Q` is the selected edition of the new Amazon Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#first_nameString

The first name of the author of the Amazon Quick Sight account to use for future communications. This field is required if ‘ENTERPPRISE_AND_Q` is the selected edition of the new Amazon Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_identity_center_instance_arnString

The Amazon Resource Name (ARN) for the IAM Identity Center instance.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#last_nameString

The last name of the author of the Amazon Quick Sight account to use for future communications. This field is required if ‘ENTERPPRISE_AND_Q` is the selected edition of the new Amazon Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#notification_emailString

The email address that you want Quick Sight to send notifications to regarding your Quick Sight account or Quick Sight subscription.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#reader_groupArray<String>

The reader group associated with your Active Directory or IAM Identity Center account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#reader_pro_groupArray<String>

The reader pro group associated with your Active Directory or IAM Identity Center account.

For more information about using IAM Identity Center in Amazon Quick Sight, see [Using IAM Identity Center with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide. For more information about using Active Directory in Amazon Quick Sight, see [Using Active Directory with Amazon Quick Sight Enterprise Edition] in the Amazon Quick Sight User Guide.

[1]: docs.aws.amazon.com/quicksight/latest/user/sec-identity-management-identity-center.html [2]: docs.aws.amazon.com/quicksight/latest/user/aws-directory-service.html

Returns:

  • (Array<String>)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end

#realmString

The realm of the Active Directory that is associated with your Quick Sight account. This field is required if ‘ACTIVE_DIRECTORY` is the selected authentication method of the new Quick Sight account.

Returns:

  • (String)


8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/aws-sdk-quicksight/types.rb', line 8013

class CreateAccountSubscriptionRequest < Struct.new(
  :edition,
  :authentication_method,
  :aws_account_id,
  :account_name,
  :notification_email,
  :active_directory_name,
  :realm,
  :directory_id,
  :admin_group,
  :author_group,
  :reader_group,
  :admin_pro_group,
  :author_pro_group,
  :reader_pro_group,
  :first_name,
  :last_name,
  :email_address,
  :contact_number,
  :iam_identity_center_instance_arn)
  SENSITIVE = []
  include Aws::Structure
end