Class: Aws::QuickSight::Types::CreateAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:starter_prompts, :welcome_message, :custom_prompt_input]
Instance Attribute Summary collapse
-
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
-
#agent_id ⇒ String
A unique identifier for the agent.
-
#agent_lifecycle ⇒ String
The lifecycle state of the agent.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
-
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
-
#description ⇒ String
A description of the agent.
-
#icon_id ⇒ String
The icon identifier for the agent.
-
#name ⇒ String
The name of the agent.
-
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
-
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
-
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
Instance Attribute Details
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#agent_id ⇒ String
A unique identifier for the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#agent_lifecycle ⇒ String
The lifecycle state of the agent. Valid values are PREVIEW and
PUBLISHED.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#description ⇒ String
A description of the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#icon_id ⇒ String
The icon identifier for the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#name ⇒ String
The name of the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
9308 9309 9310 9311 9312 9313 9314 9315 9316 9317 9318 9319 9320 9321 9322 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9308 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |