Class: Aws::QuickSight::Types::CreateAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID for the analysis that you're creating.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you are creating an analysis.
-
#definition ⇒ Types::AnalysisDefinition
The definition of an analysis.
-
#folder_arns ⇒ Array<String>
When you create the analysis, Amazon Quick Sight adds the analysis to these folders.
-
#name ⇒ String
A descriptive name for the analysis that you're creating.
-
#parameters ⇒ Types::Parameters
The parameter names and override values that you want to use.
-
#permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the principals and the resource-level permissions on an analysis.
-
#source_entity ⇒ Types::AnalysisSourceEntity
A source entity to use for the analysis that you're creating.
-
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
-
#theme_arn ⇒ String
The ARN for the theme to apply to the analysis that you're creating.
-
#validation_strategy ⇒ Types::ValidationStrategy
The option to relax the validation needed to create an analysis with definition objects.
Instance Attribute Details
#analysis_id ⇒ String
The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you are creating an analysis.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ Types::AnalysisDefinition
The definition of an analysis.
A definition is the data model of all features in a Dashboard, Template, or Analysis.
Either a SourceEntity or a Definition must be provided in order
for the request to be valid.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#folder_arns ⇒ Array<String>
When you create the analysis, Amazon Quick Sight adds the analysis to these folders.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon Quick Sight console.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::Parameters
The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the principals and the resource-level
permissions on an analysis. You can use the Permissions structure
to grant permissions by providing a list of Identity and Access
Management (IAM) action information for each principal listed by
Amazon Resource Name (ARN).
To specify no permissions, omit Permissions.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#source_entity ⇒ Types::AnalysisSourceEntity
A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets or topics.
Either a SourceEntity or a Definition must be provided in order
for the request to be valid.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#theme_arn ⇒ String
The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon Quick Sight console, make sure that you have access to it.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |
#validation_strategy ⇒ Types::ValidationStrategy
The option to relax the validation needed to create an analysis with definition objects. This skips the validation step for specific errors.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9430 class CreateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :permissions, :source_entity, :theme_arn, :tags, :definition, :validation_strategy, :folder_arns) SENSITIVE = [] include Aws::Structure end |