Class: Aws::QuickSight::Types::CreateApprovalPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<String>

The list of governed actions that trigger the approval workflow.

Returns:

  • (Array<String>)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#applicable_toTypes::ApplicableTo

The scoping configuration that determines who the approval policy applies to.

Returns:



9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#approval_groupsArray<String>

The list of group ARNs whose members can approve requests.

Returns:

  • (Array<String>)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#asset_typesArray<String>

The list of asset types that the approval policy applies to.

Returns:

  • (Array<String>)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the approval policy.

Returns:

  • (String)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the approval policy.

Returns:

  • (String)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#policy_idString

The unique identifier to assign to the approval policy. You cannot change this value after you create the policy.

Returns:

  • (String)


9510
9511
9512
9513
9514
9515
9516
9517
9518
9519
9520
# File 'lib/aws-sdk-quicksight/types.rb', line 9510

class CreateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end