Class: Aws::QuickSight::Types::CreateDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:credentials]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#credentials ⇒ Types::DataSourceCredentials
The credentials Amazon Quick Sight that uses to connect to your underlying source.
-
#data_source_id ⇒ String
An ID for the data source.
-
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Amazon Quick Sight uses to connect to your underlying source.
-
#folder_arns ⇒ Array<String>
When you create the data source, Amazon Quick Sight adds the data source to these folders.
-
#name ⇒ String
A display name for the data source.
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the data source.
-
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Amazon Quick Sight connects to your underlying source.
-
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
-
#type ⇒ String
The type of the data source.
-
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
Use this parameter only when you want Amazon Quick Sight to use a VPC connection when connecting to your underlying source.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#credentials ⇒ Types::DataSourceCredentials
The credentials Amazon Quick Sight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#data_source_id ⇒ String
An ID for the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Amazon Quick Sight uses to connect to your underlying source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#folder_arns ⇒ Array<String>
When you create the data source, Amazon Quick Sight adds the data source to these folders.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#name ⇒ String
A display name for the data source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the data source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Amazon Quick Sight connects to your underlying source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#type ⇒ String
The type of the data source. To return a list of all data sources,
use ListDataSources.
Use AMAZON_ELASTICSEARCH for Amazon OpenSearch Service.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
Use this parameter only when you want Amazon Quick Sight to use a VPC connection when connecting to your underlying source.
8981 8982 8983 8984 8985 8986 8987 8988 8989 8990 8991 8992 8993 8994 8995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8981 class CreateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :type, :data_source_parameters, :credentials, :permissions, :vpc_connection_properties, :ssl_properties, :tags, :folder_arns) SENSITIVE = [:credentials] include Aws::Structure end |