Class: Aws::QuickSight::Types::CreateFolderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateFolderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account where you want to create the folder.
-
#folder_id ⇒ String
The ID of the folder.
-
#folder_type ⇒ String
The type of folder.
-
#name ⇒ String
The name of the folder.
-
#parent_folder_arn ⇒ String
The Amazon Resource Name (ARN) for the parent folder.
-
#permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the principals and the resource-level permissions of a folder.
-
#sharing_model ⇒ String
An optional parameter that determines the sharing scope of the folder.
-
#tags ⇒ Array<Types::Tag>
Tags for the folder.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account where you want to create the folder.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#folder_id ⇒ String
The ID of the folder.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#folder_type ⇒ String
The type of folder. By default, folderType is SHARED.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the folder.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#parent_folder_arn ⇒ String
The Amazon Resource Name (ARN) for the parent folder.
ParentFolderArn can be null. An empty parentFolderArn creates a
root-level folder.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the principals and the resource-level permissions of a folder.
To specify no permissions, omit Permissions.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#sharing_model ⇒ String
An optional parameter that determines the sharing scope of the
folder. The default value for this parameter is ACCOUNT.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags for the folder.
9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9171 class CreateFolderRequest < Struct.new( :aws_account_id, :folder_id, :name, :folder_type, :parent_folder_arn, :permissions, :tags, :sharing_model) SENSITIVE = [] include Aws::Structure end |