Class: Aws::QuickSight::Types::CreateIngestionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateIngestionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#data_set_id ⇒ String
The ID of the dataset used in the ingestion.
-
#ingestion_id ⇒ String
An ID for the ingestion.
-
#ingestion_type ⇒ String
The type of ingestion that you want to create.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
9271 9272 9273 9274 9275 9276 9277 9278 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9271 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID of the dataset used in the ingestion.
9271 9272 9273 9274 9275 9276 9277 9278 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9271 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#ingestion_id ⇒ String
An ID for the ingestion.
9271 9272 9273 9274 9275 9276 9277 9278 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9271 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#ingestion_type ⇒ String
The type of ingestion that you want to create.
9271 9272 9273 9274 9275 9276 9277 9278 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9271 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |