Class: Aws::QuickSight::Types::CreateLimitsProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The ID of the Amazon Web Services account that contains the limits profile.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
# File 'lib/aws-sdk-quicksight/types.rb', line 10834

class CreateLimitsProfileRequest < Struct.new(
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
# File 'lib/aws-sdk-quicksight/types.rb', line 10834

class CreateLimitsProfileRequest < Struct.new(
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the limits profile.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
# File 'lib/aws-sdk-quicksight/types.rb', line 10834

class CreateLimitsProfileRequest < Struct.new(
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

A display name for the limits profile.

Returns:

  • (String)


10834
10835
10836
10837
10838
10839
10840
10841
10842
# File 'lib/aws-sdk-quicksight/types.rb', line 10834

class CreateLimitsProfileRequest < Struct.new(
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_limitsHash<String,Types::ProfileLimitValue>

A map of resource types to their limit values for this profile.

Returns:



10834
10835
10836
10837
10838
10839
10840
10841
10842
# File 'lib/aws-sdk-quicksight/types.rb', line 10834

class CreateLimitsProfileRequest < Struct.new(
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end