Class: Aws::QuickSight::Types::CreateNamespaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateNamespaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Quick Sight namespace you created.
-
#capacity_region ⇒ String
The Amazon Web Services Region; that you want to use for the free SPICE capacity for the new namespace.
-
#creation_status ⇒ String
The status of the creation of the namespace.
-
#identity_store ⇒ String
Specifies the type of your user identity directory.
-
#name ⇒ String
The name of the new namespace that you created.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The ARN of the Quick Sight namespace you created.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#capacity_region ⇒ String
The Amazon Web Services Region; that you want to use for the free SPICE capacity for the new namespace. This is set to the region that you run CreateNamespace in.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#creation_status ⇒ String
The status of the creation of the namespace. This is an asynchronous
process. A status of CREATED means that your namespace is ready to
use. If an error occurs, it indicates if the process is retryable
or non-retryable. In the case of a non-retryable error, refer to
the error message for follow-up tasks.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#identity_store ⇒ String
Specifies the type of your user identity directory. Currently, this
supports users with an identity type of QUICKSIGHT.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new namespace that you created.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9654 class CreateNamespaceResponse < Struct.new( :arn, :name, :capacity_region, :creation_status, :identity_store, :request_id, :status) SENSITIVE = [] include Aws::Structure end |