Class: Aws::QuickSight::Types::CreateSpaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


9617
9618
9619
9620
9621
9622
9623
9624
# File 'lib/aws-sdk-quicksight/types.rb', line 9617

class CreateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description of the space.

Returns:

  • (String)


9617
9618
9619
9620
9621
9622
9623
9624
# File 'lib/aws-sdk-quicksight/types.rb', line 9617

class CreateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

A display name for the space.

Returns:

  • (String)


9617
9618
9619
9620
9621
9622
9623
9624
# File 'lib/aws-sdk-quicksight/types.rb', line 9617

class CreateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#space_idString

The ID of the space. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


9617
9618
9619
9620
9621
9622
9623
9624
# File 'lib/aws-sdk-quicksight/types.rb', line 9617

class CreateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end