Class: Aws::QuickSight::Types::CreateThemeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateThemeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to store the new theme.
-
#base_theme_id ⇒ String
The ID of the theme that a custom theme will inherit from.
-
#configuration ⇒ Types::ThemeConfiguration
The theme configuration, which contains the theme display properties.
-
#name ⇒ String
A display name for the theme.
-
#permissions ⇒ Array<Types::ResourcePermission>
A valid grouping of resource permissions to apply to the new theme.
-
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
-
#theme_id ⇒ String
An ID for the theme that you want to create.
-
#version_description ⇒ String
A description of the first version of the theme that you're creating.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to store the new theme.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#base_theme_id ⇒ String
The ID of the theme that a custom theme will inherit from. All
themes inherit from one of the starting themes defined by Amazon
Quick Sight. For a list of the starting themes, use ListThemes or
choose Themes from within an analysis.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::ThemeConfiguration
The theme configuration, which contains the theme display properties.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A display name for the theme.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A valid grouping of resource permissions to apply to the new theme.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#theme_id ⇒ String
An ID for the theme that you want to create. The theme ID is unique per Amazon Web Services Region in each Amazon Web Services account.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |
#version_description ⇒ String
A description of the first version of the theme that you're
creating. Every time UpdateTheme is called, a new version is
created. Each version of the theme has a description of the version
in the VersionDescription field.
11469 11470 11471 11472 11473 11474 11475 11476 11477 11478 11479 11480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11469 class CreateThemeRequest < Struct.new( :aws_account_id, :theme_id, :name, :base_theme_id, :version_description, :configuration, :permissions, :tags) SENSITIVE = [] include Aws::Structure end |