Class: Aws::QuickSight::Types::CreateTopicResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID for the topic that you want to create.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
11649 11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11649 class CreateTopicResponse < Struct.new( :arn, :topic_id, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
11649 11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11649 class CreateTopicResponse < Struct.new( :arn, :topic_id, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
11649 11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11649 class CreateTopicResponse < Struct.new( :arn, :topic_id, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
11649 11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11649 class CreateTopicResponse < Struct.new( :arn, :topic_id, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
11649 11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11649 class CreateTopicResponse < Struct.new( :arn, :topic_id, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |