Class: Aws::QuickSight::Types::CreateTopicV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that you want to create a topic in.

Returns:

  • (String)


11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#custom_instructionsTypes::CustomInstructions

Instructions that provide additional guidance and context for response generation.



11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#folder_arnsArray<String>

The Amazon Resource Names (ARNs) of the folders that you want the topic to reside in.

Returns:

  • (Array<String>)


11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Contains a map of the key-value pairs for the resource tag or tags that are assigned to the topic.

Returns:



11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#topicTypes::TopicV2Details

The definition of a topic to create.



11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


11729
11730
11731
11732
11733
11734
11735
11736
11737
11738
# File 'lib/aws-sdk-quicksight/types.rb', line 11729

class CreateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :tags,
  :folder_arns,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end