Class: Aws::QuickSight::Types::CreateTopicV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID for the topic that you want to create.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
11759 11760 11761 11762 11763 11764 11765 11766 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11759 class CreateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
11759 11760 11761 11762 11763 11764 11765 11766 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11759 class CreateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
11759 11760 11761 11762 11763 11764 11765 11766 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11759 class CreateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
11759 11760 11761 11762 11763 11764 11765 11766 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11759 class CreateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |