Class: Aws::QuickSight::Types::CredentialPair

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The combination of user name and password that are used as credentials.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alternate_data_source_parametersArray<Types::DataSourceParameters>

A set of alternate data source parameters that you want to share for these credentials. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the DataSourceParameters structure that's in the request with the structures in the AlternateDataSourceParameters allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the AlternateDataSourceParameters list is null, the DataSourceParameters originally used with these Credentials is automatically allowed.

Returns:



10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-quicksight/types.rb', line 10568

class CredentialPair < Struct.new(
  :username,
  :password,
  :alternate_data_source_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#passwordString

Password.

Returns:

  • (String)


10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-quicksight/types.rb', line 10568

class CredentialPair < Struct.new(
  :username,
  :password,
  :alternate_data_source_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#usernameString

User name.

Returns:

  • (String)


10568
10569
10570
10571
10572
10573
10574
# File 'lib/aws-sdk-quicksight/types.rb', line 10568

class CredentialPair < Struct.new(
  :username,
  :password,
  :alternate_data_source_parameters)
  SENSITIVE = []
  include Aws::Structure
end