Class: Aws::QuickSight::Types::CustomContentVisual

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A visual that contains custom content.

For more information, see Using custom visual content in the Amazon Quick Suite User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::VisualCustomAction>

The list of custom actions that are configured for a visual.

Returns:



11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#chart_configurationTypes::CustomContentConfiguration

The configuration of a CustomContentVisual.



11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_identifierString

The dataset that is used to create the custom content visual. You can't create a visual without a dataset or a topic.

Returns:

  • (String)


11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#subtitleTypes::VisualSubtitleLabelOptions

The subtitle that is displayed on the visual.



11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#titleTypes::VisualTitleLabelOptions

The title that is displayed on the visual.



11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#topic_identifierString

The topic that is used in the custom content visual. You can't create a visual without a dataset or a topic.

Returns:

  • (String)


11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_content_alt_textString

The alt text for the visual.

Returns:

  • (String)


11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_idString

The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

Returns:

  • (String)


11614
11615
11616
11617
11618
11619
11620
11621
11622
11623
11624
11625
# File 'lib/aws-sdk-quicksight/types.rb', line 11614

class CustomContentVisual < Struct.new(
  :visual_id,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :data_set_identifier,
  :topic_identifier,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end