Class: Aws::QuickSight::Types::CustomInstruction
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CustomInstruction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A custom instruction that provides guidance on how the dataset should be consumed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inline_custom_instruction ⇒ Types::InlineCustomInstruction
An inline custom instruction containing text and optional uploaded document metadata.
Instance Attribute Details
#inline_custom_instruction ⇒ Types::InlineCustomInstruction
An inline custom instruction containing text and optional uploaded document metadata.
10243 10244 10245 10246 10247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10243 class CustomInstruction < Struct.new( :inline_custom_instruction) SENSITIVE = [] include Aws::Structure end |