Class: Aws::QuickSight::Types::CustomPromptInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Note:

CustomPromptInput is a union - when making an API calls you must set exactly one of the members.

The custom prompt input for an agent. This is a union type that can be either an existing prompt profile or new prompt parameters.

Direct Known Subclasses

ExistingPrompt, NewPrompt, Unknown

Defined Under Namespace

Classes: ExistingPrompt, NewPrompt, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#existing_promptTypes::CustomPromptProfile

An existing custom prompt profile to use for the agent.



10740
10741
10742
10743
10744
10745
10746
10747
10748
10749
10750
10751
# File 'lib/aws-sdk-quicksight/types.rb', line 10740

class CustomPromptInput < Struct.new(
  :existing_prompt,
  :new_prompt,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExistingPrompt < CustomPromptInput; end
  class NewPrompt < CustomPromptInput; end
  class Unknown < CustomPromptInput; end
end

#new_promptTypes::CustomPromptInputParameters

New custom prompt parameters to configure for the agent.



10740
10741
10742
10743
10744
10745
10746
10747
10748
10749
10750
10751
# File 'lib/aws-sdk-quicksight/types.rb', line 10740

class CustomPromptInput < Struct.new(
  :existing_prompt,
  :new_prompt,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ExistingPrompt < CustomPromptInput; end
  class NewPrompt < CustomPromptInput; end
  class Unknown < CustomPromptInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10740
10741
10742
# File 'lib/aws-sdk-quicksight/types.rb', line 10740

def unknown
  @unknown
end