Class: Aws::QuickSight::Types::DashboardSourceTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DashboardSourceTemplate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Dashboard source template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
-
#data_set_references ⇒ Array<Types::DataSetReference>
Dataset references.
-
#topic_references ⇒ Array<Types::TopicReference>
The topic references for the source template of a dashboard.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
12340 12341 12342 12343 12344 12345 12346 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12340 class DashboardSourceTemplate < Struct.new( :data_set_references, :topic_references, :arn) SENSITIVE = [] include Aws::Structure end |
#data_set_references ⇒ Array<Types::DataSetReference>
Dataset references.
12340 12341 12342 12343 12344 12345 12346 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12340 class DashboardSourceTemplate < Struct.new( :data_set_references, :topic_references, :arn) SENSITIVE = [] include Aws::Structure end |
#topic_references ⇒ Array<Types::TopicReference>
The topic references for the source template of a dashboard.
12340 12341 12342 12343 12344 12345 12346 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12340 class DashboardSourceTemplate < Struct.new( :data_set_references, :topic_references, :arn) SENSITIVE = [] include Aws::Structure end |