Class: Aws::QuickSight::Types::DataColorPalette

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The theme colors that are used for data colors in charts. The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ‘#`, for example #37BFF5.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#colorsArray<String>

The hexadecimal codes for the colors.

Returns:

  • (Array<String>)


9634
9635
9636
9637
9638
9639
9640
# File 'lib/aws-sdk-quicksight/types.rb', line 9634

class DataColorPalette < Struct.new(
  :colors,
  :min_max_gradient,
  :empty_fill_color)
  SENSITIVE = []
  include Aws::Structure
end

#empty_fill_colorString

The hexadecimal code of a color that applies to charts where a lack of data is highlighted.

Returns:

  • (String)


9634
9635
9636
9637
9638
9639
9640
# File 'lib/aws-sdk-quicksight/types.rb', line 9634

class DataColorPalette < Struct.new(
  :colors,
  :min_max_gradient,
  :empty_fill_color)
  SENSITIVE = []
  include Aws::Structure
end

#min_max_gradientArray<String>

The minimum and maximum hexadecimal codes that describe a color gradient.

Returns:

  • (Array<String>)


9634
9635
9636
9637
9638
9639
9640
# File 'lib/aws-sdk-quicksight/types.rb', line 9634

class DataColorPalette < Struct.new(
  :colors,
  :min_max_gradient,
  :empty_fill_color)
  SENSITIVE = []
  include Aws::Structure
end