Class: Aws::QuickSight::Types::DataFieldBarSeriesItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataFieldBarSeriesItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The data field series item configuration of a ‘BarChartVisual`.
Constant Summary collapse
- SENSITIVE =
[:field_value]
Instance Attribute Summary collapse
-
#field_id ⇒ String
Field ID of the field that you are setting the series configuration for.
-
#field_value ⇒ String
Field value of the field that you are setting the series configuration for.
-
#settings ⇒ Types::BarChartSeriesSettings
Options that determine the presentation of bar series associated to the field.
Instance Attribute Details
#field_id ⇒ String
Field ID of the field that you are setting the series configuration for.
9895 9896 9897 9898 9899 9900 9901 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9895 class DataFieldBarSeriesItem < Struct.new( :field_id, :field_value, :settings) SENSITIVE = [:field_value] include Aws::Structure end |
#field_value ⇒ String
Field value of the field that you are setting the series configuration for.
9895 9896 9897 9898 9899 9900 9901 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9895 class DataFieldBarSeriesItem < Struct.new( :field_id, :field_value, :settings) SENSITIVE = [:field_value] include Aws::Structure end |
#settings ⇒ Types::BarChartSeriesSettings
Options that determine the presentation of bar series associated to the field.
9895 9896 9897 9898 9899 9900 9901 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9895 class DataFieldBarSeriesItem < Struct.new( :field_id, :field_value, :settings) SENSITIVE = [:field_value] include Aws::Structure end |