Class: Aws::QuickSight::Types::DataFieldComboSeriesItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The data field series item configuration of a ‘ComboChartVisual`.

Constant Summary collapse

SENSITIVE =
[:field_value]

Instance Attribute Summary collapse

Instance Attribute Details

#field_idString

Field ID of the field that you are setting the series configuration for.

Returns:

  • (String)


10918
10919
10920
10921
10922
10923
10924
# File 'lib/aws-sdk-quicksight/types.rb', line 10918

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end

#field_valueString

Field value of the field that you are setting the series configuration for.

Returns:

  • (String)


10918
10919
10920
10921
10922
10923
10924
# File 'lib/aws-sdk-quicksight/types.rb', line 10918

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end

#settingsTypes::ComboChartSeriesSettings

Options that determine the presentation of series associated to the field.



10918
10919
10920
10921
10922
10923
10924
# File 'lib/aws-sdk-quicksight/types.rb', line 10918

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end