Class: Aws::QuickSight::Types::DataPrepAggregationFunction
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataPrepAggregationFunction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Defines the type of aggregation function to apply to data during data preparation, supporting simple and list aggregations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#list_aggregation ⇒ Types::DataPrepListAggregationFunction
A list aggregation function that concatenates values from multiple rows into a single delimited string.
-
#simple_aggregation ⇒ Types::DataPrepSimpleAggregationFunction
A simple aggregation function such as ‘SUM`, `COUNT`, `AVERAGE`, `MIN`, `MAX`, `MEDIAN`, `VARIANCE`, or `STANDARD_DEVIATION`.
Instance Attribute Details
#list_aggregation ⇒ Types::DataPrepListAggregationFunction
A list aggregation function that concatenates values from multiple rows into a single delimited string.
11236 11237 11238 11239 11240 11241 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11236 class DataPrepAggregationFunction < Struct.new( :simple_aggregation, :list_aggregation) SENSITIVE = [] include Aws::Structure end |
#simple_aggregation ⇒ Types::DataPrepSimpleAggregationFunction
A simple aggregation function such as ‘SUM`, `COUNT`, `AVERAGE`, `MIN`, `MAX`, `MEDIAN`, `VARIANCE`, or `STANDARD_DEVIATION`.
11236 11237 11238 11239 11240 11241 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11236 class DataPrepAggregationFunction < Struct.new( :simple_aggregation, :list_aggregation) SENSITIVE = [] include Aws::Structure end |