Class: Aws::QuickSight::Types::DataPrepConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Configuration for data preparation operations, defining the complete pipeline from source tables through transformations to destination tables.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_table_mapHash<String,Types::DestinationTable>

A map of destination tables that receive the final prepared data.

Returns:



10266
10267
10268
10269
10270
10271
10272
# File 'lib/aws-sdk-quicksight/types.rb', line 10266

class DataPrepConfiguration < Struct.new(
  :source_table_map,
  :transform_step_map,
  :destination_table_map)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_mapHash<String,Types::SourceTable>

A map of source tables that provide information about underlying sources.

Returns:



10266
10267
10268
10269
10270
10271
10272
# File 'lib/aws-sdk-quicksight/types.rb', line 10266

class DataPrepConfiguration < Struct.new(
  :source_table_map,
  :transform_step_map,
  :destination_table_map)
  SENSITIVE = []
  include Aws::Structure
end

#transform_step_mapHash<String,Types::TransformStep>

A map of transformation steps that process the data.

Returns:



10266
10267
10268
10269
10270
10271
10272
# File 'lib/aws-sdk-quicksight/types.rb', line 10266

class DataPrepConfiguration < Struct.new(
  :source_table_map,
  :transform_step_map,
  :destination_table_map)
  SENSITIVE = []
  include Aws::Structure
end