Class: Aws::QuickSight::Types::DataPrepListAggregationFunction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An aggregation function that concatenates values from multiple rows into a single string with a specified separator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#distinctBoolean

Whether to include only distinct values in the concatenated result, removing duplicates.

Returns:

  • (Boolean)


10004
10005
10006
10007
10008
10009
10010
# File 'lib/aws-sdk-quicksight/types.rb', line 10004

class DataPrepListAggregationFunction < Struct.new(
  :input_column_name,
  :separator,
  :distinct)
  SENSITIVE = []
  include Aws::Structure
end

#input_column_nameString

The name of the column containing values to be concatenated.

Returns:

  • (String)


10004
10005
10006
10007
10008
10009
10010
# File 'lib/aws-sdk-quicksight/types.rb', line 10004

class DataPrepListAggregationFunction < Struct.new(
  :input_column_name,
  :separator,
  :distinct)
  SENSITIVE = []
  include Aws::Structure
end

#separatorString

The string used to separate values in the concatenated result.

Returns:

  • (String)


10004
10005
10006
10007
10008
10009
10010
# File 'lib/aws-sdk-quicksight/types.rb', line 10004

class DataPrepListAggregationFunction < Struct.new(
  :input_column_name,
  :separator,
  :distinct)
  SENSITIVE = []
  include Aws::Structure
end