Class: Aws::QuickSight::Types::DataSetSemanticMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Semantic metadata for a dataset, including a description and custom instructions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_instructionsArray<Types::CustomInstruction>

A list of custom instructions that guide how the dataset should be consumed.

Returns:



12976
12977
12978
12979
12980
12981
# File 'lib/aws-sdk-quicksight/types.rb', line 12976

class DataSetSemanticMetadata < Struct.new(
  :description,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionTypes::DataSetSemanticDescription

A description of the dataset.



12976
12977
12978
12979
12980
12981
# File 'lib/aws-sdk-quicksight/types.rb', line 12976

class DataSetSemanticMetadata < Struct.new(
  :description,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end