Class: Aws::QuickSight::Types::DataSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The structure of a data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alternate_data_source_parametersArray<Types::DataSourceParameters>

A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the DataSourceParameters structure that's in the request with the structures in the AlternateDataSourceParameters allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the AlternateDataSourceParameters list is null, the Credentials originally used with this DataSourceParameters are automatically allowed.

Returns:



13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the data source.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time that this data source was created.

Returns:

  • (Time)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#credential_statusString

The credential verification status of the data source. Valid values include:

  • CONNECTED – Credential validation succeeded.

  • AUTH_FAILED – Credential validation failed.

  • NOT_VERIFIED – Credential validation has not been performed.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The ID of the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_parametersTypes::DataSourceParameters

The parameters that Quick Sight uses to connect to your underlying source. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.



13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoTypes::DataSourceErrorInfo

Error information from the last update or the creation of the data source.



13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_credential_verified_atTime

The time that the credentials were last verified.

Returns:

  • (Time)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The last time that this data source was updated.

Returns:

  • (Time)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A display name for the data source.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#ssl_propertiesTypes::SslProperties

Secure Socket Layer (SSL) properties that apply when Quick Sight connects to your underlying source.



13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The HTTP status of the request.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the data source. This type indicates which database engine the data source connects to.

Returns:

  • (String)


13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_connection_propertiesTypes::VpcConnectionProperties

The VPC connection information. You need to use this parameter only when you want Quick Sight to use a VPC connection when connecting to your underlying source.



13214
13215
13216
13217
13218
13219
13220
13221
13222
13223
13224
13225
13226
13227
13228
13229
13230
13231
13232
# File 'lib/aws-sdk-quicksight/types.rb', line 13214

class DataSource < Struct.new(
  :arn,
  :data_source_id,
  :name,
  :type,
  :status,
  :created_time,
  :last_updated_time,
  :data_source_parameters,
  :alternate_data_source_parameters,
  :vpc_connection_properties,
  :ssl_properties,
  :error_info,
  :secret_arn,
  :credential_status,
  :last_credential_verified_at)
  SENSITIVE = []
  include Aws::Structure
end