Class: Aws::QuickSight::Types::DataSourceCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Data source credentials. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_source_arnString

The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ‘CopySourceArn` is not null, the credential pair from the data source in the ARN is used as the credentials for the `DataSourceCredentials` structure.



10860
10861
10862
10863
10864
10865
10866
10867
# File 'lib/aws-sdk-quicksight/types.rb', line 10860

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :web_proxy_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#credential_pairTypes::CredentialPair

Credential pair. For more information, see ‘ CredentialPair `.



10860
10861
10862
10863
10864
10865
10866
10867
# File 'lib/aws-sdk-quicksight/types.rb', line 10860

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :web_proxy_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.



10860
10861
10862
10863
10864
10865
10866
10867
# File 'lib/aws-sdk-quicksight/types.rb', line 10860

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :web_proxy_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#web_proxy_credentialsTypes::WebProxyCredentials

The credentials for connecting through a web proxy server.



10860
10861
10862
10863
10864
10865
10866
10867
# File 'lib/aws-sdk-quicksight/types.rb', line 10860

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :web_proxy_credentials)
  SENSITIVE = []
  include Aws::Structure
end