Class: Aws::QuickSight::Types::DefaultPaginatedLayoutConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DefaultPaginatedLayoutConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the default settings for a paginated layout configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#section_based ⇒ Types::DefaultSectionBasedLayoutConfiguration
The options that determine the default settings for a section-based layout configuration.
Instance Attribute Details
#section_based ⇒ Types::DefaultSectionBasedLayoutConfiguration
The options that determine the default settings for a section-based layout configuration.
13490 13491 13492 13493 13494 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13490 class DefaultPaginatedLayoutConfiguration < Struct.new( :section_based) SENSITIVE = [] include Aws::Structure end |