Class: Aws::QuickSight::Types::DeleteAccountCustomizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAccountCustomizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to delete Quick Sight customizations from.
-
#namespace ⇒ String
The Quick Sight namespace that you’re deleting the customizations from.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to delete Quick Sight customizations from.
12630 12631 12632 12633 12634 12635 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12630 class DeleteAccountCustomizationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick Sight namespace that you’re deleting the customizations from.
12630 12631 12632 12633 12634 12635 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12630 class DeleteAccountCustomizationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |