Class: Aws::QuickSight::Types::DeleteAccountSubscriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAccountSubscriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID of the account that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID of the account that you want to delete.
16199 16200 16201 16202 16203 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16199 class DeleteAccountSubscriptionRequest < Struct.new( :aws_account_id) SENSITIVE = [] include Aws::Structure end |