Class: Aws::QuickSight::Types::DeleteAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier for the agent to delete.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier for the agent to delete.
14587 14588 14589 14590 14591 14592 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14587 class DeleteAgentRequest < Struct.new( :agent_id, :aws_account_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
14587 14588 14589 14590 14591 14592 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14587 class DeleteAgentRequest < Struct.new( :agent_id, :aws_account_id) SENSITIVE = [] include Aws::Structure end |