Class: Aws::QuickSight::Types::DeleteAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The ID of the analysis that you're deleting.

Returns:

  • (String)


14988
14989
14990
14991
14992
14993
14994
14995
# File 'lib/aws-sdk-quicksight/types.rb', line 14988

class DeleteAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :recovery_window_in_days,
  :force_delete_without_recovery)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account where you want to delete an analysis.

Returns:

  • (String)


14988
14989
14990
14991
14992
14993
14994
14995
# File 'lib/aws-sdk-quicksight/types.rb', line 14988

class DeleteAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :recovery_window_in_days,
  :force_delete_without_recovery)
  SENSITIVE = []
  include Aws::Structure
end

#force_delete_without_recoveryBoolean

This option defaults to the value NoForceDeleteWithoutRecovery. To immediately delete the analysis, add the ForceDeleteWithoutRecovery option. You can't restore an analysis after it's deleted.

Returns:

  • (Boolean)


14988
14989
14990
14991
14992
14993
14994
14995
# File 'lib/aws-sdk-quicksight/types.rb', line 14988

class DeleteAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :recovery_window_in_days,
  :force_delete_without_recovery)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_window_in_daysInteger

A value that specifies the number of days that Amazon Quick Sight waits before it deletes the analysis. You can't use this parameter with the ForceDeleteWithoutRecovery option in the same API call. The default value is 30.

Returns:

  • (Integer)


14988
14989
14990
14991
14992
14993
14994
14995
# File 'lib/aws-sdk-quicksight/types.rb', line 14988

class DeleteAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :recovery_window_in_days,
  :force_delete_without_recovery)
  SENSITIVE = []
  include Aws::Structure
end