Class: Aws::QuickSight::Types::DeleteAnalysisResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAnalysisResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the deleted analysis.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the deleted analysis.
-
#deletion_time ⇒ Time
The date and time that the analysis is scheduled to be deleted.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the deleted analysis.
14662 14663 14664 14665 14666 14667 14668 14669 14670 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14662 class DeleteAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :deletion_time, :request_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the deleted analysis.
14662 14663 14664 14665 14666 14667 14668 14669 14670 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14662 class DeleteAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :deletion_time, :request_id) SENSITIVE = [] include Aws::Structure end |
#deletion_time ⇒ Time
The date and time that the analysis is scheduled to be deleted.
14662 14663 14664 14665 14666 14667 14668 14669 14670 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14662 class DeleteAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :deletion_time, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
14662 14663 14664 14665 14666 14667 14668 14669 14670 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14662 class DeleteAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :deletion_time, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
14662 14663 14664 14665 14666 14667 14668 14669 14670 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14662 class DeleteAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :deletion_time, :request_id) SENSITIVE = [] include Aws::Structure end |