Class: Aws::QuickSight::Types::DeleteAppRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_idString

The ID of the app that you want to delete.

Returns:

  • (String)


16372
16373
16374
16375
16376
16377
# File 'lib/aws-sdk-quicksight/types.rb', line 16372

class DeleteAppRequest < Struct.new(
  :aws_account_id,
  :app_id)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the app.

Returns:

  • (String)


16372
16373
16374
16375
16376
16377
# File 'lib/aws-sdk-quicksight/types.rb', line 16372

class DeleteAppRequest < Struct.new(
  :aws_account_id,
  :app_id)
  SENSITIVE = []
  include Aws::Structure
end