Class: Aws::QuickSight::Types::DeleteApprovalPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteApprovalPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_id ⇒ String
The unique identifier of the approval policy to delete.
Instance Attribute Details
#policy_id ⇒ String
The unique identifier of the approval policy to delete.
16397 16398 16399 16400 16401 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16397 class DeleteApprovalPolicyRequest < Struct.new( :policy_id) SENSITIVE = [] include Aws::Structure end |