Class: Aws::QuickSight::Types::DeleteDlpSettingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteDlpSettingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the DLP setting that you want to delete.
-
#dlp_setting_id ⇒ String
The ID of the DLP setting that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the DLP setting that you want to delete.
16729 16730 16731 16732 16733 16734 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16729 class DeleteDlpSettingRequest < Struct.new( :aws_account_id, :dlp_setting_id) SENSITIVE = [] include Aws::Structure end |
#dlp_setting_id ⇒ String
The ID of the DLP setting that you want to delete.
16729 16730 16731 16732 16733 16734 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16729 class DeleteDlpSettingRequest < Struct.new( :aws_account_id, :dlp_setting_id) SENSITIVE = [] include Aws::Structure end |