Class: Aws::QuickSight::Types::DeleteFlowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteFlowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are deleting.
-
#flow_id ⇒ String
The unique identifier of the flow to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are deleting.
14994 14995 14996 14997 14998 14999 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14994 class DeleteFlowRequest < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow to delete.
14994 14995 14996 14997 14998 14999 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14994 class DeleteFlowRequest < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |