Class: Aws::QuickSight::Types::DeleteFolderMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteFolderMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the folder.
-
#folder_id ⇒ String
The Folder ID.
-
#member_id ⇒ String
The ID of the asset that you want to delete.
-
#member_type ⇒ String
The member type of the asset that you want to delete from a folder.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the folder.
16197 16198 16199 16200 16201 16202 16203 16204 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16197 class DeleteFolderMembershipRequest < Struct.new( :aws_account_id, :folder_id, :member_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#folder_id ⇒ String
The Folder ID.
16197 16198 16199 16200 16201 16202 16203 16204 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16197 class DeleteFolderMembershipRequest < Struct.new( :aws_account_id, :folder_id, :member_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#member_id ⇒ String
The ID of the asset that you want to delete.
16197 16198 16199 16200 16201 16202 16203 16204 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16197 class DeleteFolderMembershipRequest < Struct.new( :aws_account_id, :folder_id, :member_id, :member_type) SENSITIVE = [] include Aws::Structure end |
#member_type ⇒ String
The member type of the asset that you want to delete from a folder.
16197 16198 16199 16200 16201 16202 16203 16204 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16197 class DeleteFolderMembershipRequest < Struct.new( :aws_account_id, :folder_id, :member_id, :member_type) SENSITIVE = [] include Aws::Structure end |