Class: Aws::QuickSight::Types::DeleteGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#group_name ⇒ String
The name of the group that you want to delete.
-
#namespace ⇒ String
The namespace of the group that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
12862 12863 12864 12865 12866 12867 12868 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12862 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to delete.
12862 12863 12864 12865 12866 12867 12868 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12862 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the group that you want to delete.
12862 12863 12864 12865 12866 12867 12868 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12862 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |