Class: Aws::QuickSight::Types::DeleteKnowledgeBaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteKnowledgeBaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
15413 15414 15415 15416 15417 15418 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15413 class DeleteKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
15413 15414 15415 15416 15417 15418 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15413 class DeleteKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |