Class: Aws::QuickSight::Types::DeleteNamespaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteNamespaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to delete the Quick Sight namespace from.
-
#namespace ⇒ String
The namespace that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to delete the Quick Sight namespace from.
15286 15287 15288 15289 15290 15291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15286 class DeleteNamespaceRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that you want to delete.
15286 15287 15288 15289 15290 15291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15286 class DeleteNamespaceRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |