Class: Aws::QuickSight::Types::DeleteRoleMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteRoleMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#member_name ⇒ String
The name of the group.
-
#namespace ⇒ String
The namespace that contains the role.
-
#role ⇒ String
The role that you want to remove permissions from.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
17317 17318 17319 17320 17321 17322 17323 17324 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17317 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The name of the group.
17317 17318 17319 17320 17321 17322 17323 17324 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17317 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that contains the role.
17317 17318 17319 17320 17321 17322 17323 17324 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17317 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role that you want to remove permissions from.
17317 17318 17319 17320 17321 17322 17323 17324 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17317 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |