Class: Aws::QuickSight::Types::DeleteSpaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


15503
15504
15505
15506
15507
15508
# File 'lib/aws-sdk-quicksight/types.rb', line 15503

class DeleteSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id)
  SENSITIVE = []
  include Aws::Structure
end

#space_idString

The ID of the space that you want to delete.

Returns:

  • (String)


15503
15504
15505
15506
15507
15508
# File 'lib/aws-sdk-quicksight/types.rb', line 15503

class DeleteSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id)
  SENSITIVE = []
  include Aws::Structure
end