Class: Aws::QuickSight::Types::DeleteTopicResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteTopicResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID of the topic that you want to delete.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17695 class DeleteTopicResponse < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17695 class DeleteTopicResponse < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17695 class DeleteTopicResponse < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17695 class DeleteTopicResponse < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |