Class: Aws::QuickSight::Types::DeleteTopicV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteTopicV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID of the topic that you want to delete.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
17742 17743 17744 17745 17746 17747 17748 17749 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17742 class DeleteTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17742 17743 17744 17745 17746 17747 17748 17749 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17742 class DeleteTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
17742 17743 17744 17745 17746 17747 17748 17749 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17742 class DeleteTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
17742 17743 17744 17745 17746 17747 17748 17749 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17742 class DeleteTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |