Class: Aws::QuickSight::Types::DeleteUserByPrincipalIdRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


17767
17768
17769
17770
17771
17772
17773
# File 'lib/aws-sdk-quicksight/types.rb', line 17767

class DeleteUserByPrincipalIdRequest < Struct.new(
  :principal_id,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace. Currently, you should set this to default.

Returns:

  • (String)


17767
17768
17769
17770
17771
17772
17773
# File 'lib/aws-sdk-quicksight/types.rb', line 17767

class DeleteUserByPrincipalIdRequest < Struct.new(
  :principal_id,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The principal ID of the user.

Returns:

  • (String)


17767
17768
17769
17770
17771
17772
17773
# File 'lib/aws-sdk-quicksight/types.rb', line 17767

class DeleteUserByPrincipalIdRequest < Struct.new(
  :principal_id,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end