Class: Aws::QuickSight::Types::DescribeAccountSettingsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAccountSettingsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_settings ⇒ Types::AccountSettings
The Amazon Quick Sight settings for this Amazon Web Services account.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#account_settings ⇒ Types::AccountSettings
The Amazon Quick Sight settings for this Amazon Web Services account. This information includes the edition of Amazon Quick Sight that you subscribed to (Standard or Enterprise) and the notification email for the Amazon Quick Sight subscription.
In the Quick Sight console, the Amazon Quick Sight subscription is sometimes referred to as a Quick Sight “account” even though it’s technically not an account by itself. Instead, it’s a subscription to the Amazon Quick Sight service for your Amazon Web Services account. The edition that you subscribe to applies to Quick in every Amazon Web Services Region where you use it.
16347 16348 16349 16350 16351 16352 16353 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16347 class DescribeAccountSettingsResponse < Struct.new( :account_settings, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16347 16348 16349 16350 16351 16352 16353 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16347 class DescribeAccountSettingsResponse < Struct.new( :account_settings, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
16347 16348 16349 16350 16351 16352 16353 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16347 class DescribeAccountSettingsResponse < Struct.new( :account_settings, :request_id, :status) SENSITIVE = [] include Aws::Structure end |