Class: Aws::QuickSight::Types::DescribeAccountSubscriptionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_infoTypes::AccountInfo

A structure that contains the following elements:

  • Your Quick Sight account name.

  • The edition of Quick Sight that your account is using.

  • The notification email address that is associated with the Amazon Quick Sight account.

  • The authentication type of the Quick Sight account.

  • The status of the Quick Sight account’s subscription.

Returns:



15244
15245
15246
15247
15248
15249
15250
# File 'lib/aws-sdk-quicksight/types.rb', line 15244

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


15244
15245
15246
15247
15248
15249
15250
# File 'lib/aws-sdk-quicksight/types.rb', line 15244

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


15244
15245
15246
15247
15248
15249
15250
# File 'lib/aws-sdk-quicksight/types.rb', line 15244

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end