Class: Aws::QuickSight::Types::DescribeActionConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeActionConnectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_connector ⇒ Types::ActionConnector
The detailed information about the action connector, including its configuration and current state.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status code of the request.
Instance Attribute Details
#action_connector ⇒ Types::ActionConnector
The detailed information about the action connector, including its configuration and current state.
14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14317 class DescribeActionConnectorResponse < Struct.new( :action_connector, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14317 class DescribeActionConnectorResponse < Struct.new( :action_connector, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status code of the request.
14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14317 class DescribeActionConnectorResponse < Struct.new( :action_connector, :request_id, :status) SENSITIVE = [] include Aws::Structure end |