Class: Aws::QuickSight::Types::DescribeAgentPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAgentPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier for the agent.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier for the agent.
16504 16505 16506 16507 16508 16509 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16504 class DescribeAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
16504 16505 16506 16507 16508 16509 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16504 class DescribeAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id) SENSITIVE = [] include Aws::Structure end |