Class: Aws::QuickSight::Types::DescribeAgentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAgentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent ⇒ Types::Agent
The full details of the agent, including its configuration, status, and associations.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
Instance Attribute Details
#agent ⇒ Types::Agent
The full details of the agent, including its configuration, status, and associations.
16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16394 class DescribeAgentResponse < Struct.new( :agent, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16394 16395 16396 16397 16398 16399 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16394 class DescribeAgentResponse < Struct.new( :agent, :request_id) SENSITIVE = [] include Aws::Structure end |