Class: Aws::QuickSight::Types::DescribeAnalysisDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAnalysisDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you're describing.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you're describing. The ID is part of the URL of the analysis.
18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18311 class DescribeAnalysisDefinitionRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis. You must be using the Amazon Web Services account that the analysis is in.
18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18311 class DescribeAnalysisDefinitionRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |