Class: Aws::QuickSight::Types::DescribeAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you’re describing.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you’re describing. The ID is part of the URL of the analysis.
16724 16725 16726 16727 16728 16729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16724 class DescribeAnalysisRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis. You must be using the Amazon Web Services account that the analysis is in.
16724 16725 16726 16727 16728 16729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16724 class DescribeAnalysisRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |