Class: Aws::QuickSight::Types::DescribeAppPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAppPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the app.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
Instance Attribute Details
#app_id ⇒ String
The ID of the app.
18489 18490 18491 18492 18493 18494 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18489 class DescribeAppPermissionsRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
18489 18490 18491 18492 18493 18494 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18489 class DescribeAppPermissionsRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |