Class: Aws::QuickSight::Types::DescribeAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAppRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the app that you want to describe.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
Instance Attribute Details
#app_id ⇒ String
The ID of the app that you want to describe.
18533 18534 18535 18536 18537 18538 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18533 class DescribeAppRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
18533 18534 18535 18536 18537 18538 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18533 class DescribeAppRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |