Class: Aws::QuickSight::Types::DescribeApprovalPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeApprovalPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_id ⇒ String
The unique identifier of the approval policy to describe.
Instance Attribute Details
#policy_id ⇒ String
The unique identifier of the approval policy to describe.
18563 18564 18565 18566 18567 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18563 class DescribeApprovalPolicyRequest < Struct.new( :policy_id) SENSITIVE = [] include Aws::Structure end |