Class: Aws::QuickSight::Types::DescribeAssetBundleImportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAssetBundleImportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the import job.
-
#asset_bundle_import_job_id ⇒ String
The ID of the job.
-
#asset_bundle_import_source ⇒ Types::AssetBundleImportSourceDescription
The source of the asset bundle zip file that contains the data that is imported by the job.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account the import job was executed in.
-
#created_time ⇒ Time
The time that the import job was created.
-
#errors ⇒ Array<Types::AssetBundleImportJobError>
An array of error records that describes any failures that occurred during the export job processing.
-
#failure_action ⇒ String
The failure action for the import job.
-
#job_status ⇒ String
Indicates the status of a job through its queuing and execution.
-
#override_parameters ⇒ Types::AssetBundleImportJobOverrideParameters
Optional overrides that are applied to the resource configuration before import.
-
#override_permissions ⇒ Types::AssetBundleImportJobOverridePermissions
Optional permission overrides that are applied to the resource configuration before import.
-
#override_tags ⇒ Types::AssetBundleImportJobOverrideTags
Optional tag overrides that are applied to the resource configuration before import.
-
#override_validation_strategy ⇒ Types::AssetBundleImportJobOverrideValidationStrategy
An optional validation strategy override for all analyses and dashboards to be applied to the resource configuration before import.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#rollback_errors ⇒ Array<Types::AssetBundleImportJobError>
An array of error records that describes any failures that occurred while an import job was attempting a rollback.
-
#status ⇒ Integer
The HTTP status of the response.
-
#warnings ⇒ Array<Types::AssetBundleImportJobWarning>
An array of warning records that describe all permitted errors that are encountered during the import job.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the import job.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#asset_bundle_import_job_id ⇒ String
The ID of the job. The job ID is set when you start a new job with a
StartAssetBundleImportJob API call.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#asset_bundle_import_source ⇒ Types::AssetBundleImportSourceDescription
The source of the asset bundle zip file that contains the data that is imported by the job.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account the import job was executed in.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that the import job was created.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::AssetBundleImportJobError>
An array of error records that describes any failures that occurred during the export job processing.
Error records accumulate while the job is still running. The complete set of error records is available after the job has completed and failed.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#failure_action ⇒ String
The failure action for the import job.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
Indicates the status of a job through its queuing and execution.
Poll the DescribeAssetBundleImport API until JobStatus returns
one of the following values:
-
SUCCESSFUL -
FAILED -
FAILED_ROLLBACK_COMPLETED -
FAILED_ROLLBACK_ERROR
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#override_parameters ⇒ Types::AssetBundleImportJobOverrideParameters
Optional overrides that are applied to the resource configuration before import.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#override_permissions ⇒ Types::AssetBundleImportJobOverridePermissions
Optional permission overrides that are applied to the resource configuration before import.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#override_tags ⇒ Types::AssetBundleImportJobOverrideTags
Optional tag overrides that are applied to the resource configuration before import.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#override_validation_strategy ⇒ Types::AssetBundleImportJobOverrideValidationStrategy
An optional validation strategy override for all analyses and dashboards to be applied to the resource configuration before import.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#rollback_errors ⇒ Array<Types::AssetBundleImportJobError>
An array of error records that describes any failures that occurred while an import job was attempting a rollback.
Error records accumulate while the job is still running. The complete set of error records is available after the job has completed and failed.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the response.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |
#warnings ⇒ Array<Types::AssetBundleImportJobWarning>
An array of warning records that describe all permitted errors that are encountered during the import job.
18100 18101 18102 18103 18104 18105 18106 18107 18108 18109 18110 18111 18112 18113 18114 18115 18116 18117 18118 18119 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18100 class DescribeAssetBundleImportJobResponse < Struct.new( :job_status, :errors, :rollback_errors, :arn, :created_time, :asset_bundle_import_job_id, :aws_account_id, :asset_bundle_import_source, :override_parameters, :failure_action, :request_id, :status, :override_permissions, :override_tags, :override_validation_strategy, :warnings) SENSITIVE = [] include Aws::Structure end |