Class: Aws::QuickSight::Types::DescribeCustomPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeCustomPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the custom permissions profile that you want described.
-
#custom_permissions_name ⇒ String
The name of the custom permissions profile to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the custom permissions profile that you want described.
17260 17261 17262 17263 17264 17265 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17260 class DescribeCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The name of the custom permissions profile to describe.
17260 17261 17262 17263 17264 17265 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17260 class DescribeCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name) SENSITIVE = [] include Aws::Structure end |