Class: Aws::QuickSight::Types::DescribeDashboardPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDashboardPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the dashboard that you're describing permissions for.
-
#dashboard_id ⇒ String
The ID for the dashboard, also added to the IAM policy.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the dashboard that you're describing permissions for.
19255 19256 19257 19258 19259 19260 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19255 class DescribeDashboardPermissionsRequest < Struct.new( :aws_account_id, :dashboard_id) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID for the dashboard, also added to the IAM policy.
19255 19256 19257 19258 19259 19260 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19255 class DescribeDashboardPermissionsRequest < Struct.new( :aws_account_id, :dashboard_id) SENSITIVE = [] include Aws::Structure end |