Class: Aws::QuickSight::Types::DescribeDashboardSnapshotJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.

Returns:

  • (String)


17777
17778
17779
17780
17781
17782
17783
# File 'lib/aws-sdk-quicksight/types.rb', line 17777

class DescribeDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_idString

The ID of the dashboard that you have started a snapshot job for.

Returns:

  • (String)


17777
17778
17779
17780
17781
17782
17783
# File 'lib/aws-sdk-quicksight/types.rb', line 17777

class DescribeDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_job_idString

The ID of the job to be described. The job ID is set when you start a new job with a StartDashboardSnapshotJob API call.

Returns:

  • (String)


17777
17778
17779
17780
17781
17782
17783
# File 'lib/aws-sdk-quicksight/types.rb', line 17777

class DescribeDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id)
  SENSITIVE = []
  include Aws::Structure
end