Class: Aws::QuickSight::Types::DescribeDashboardSnapshotJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDashboardSnapshotJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot job.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
-
#created_time ⇒ Time
The time that the snapshot job was created.
-
#dashboard_id ⇒ String
The ID of the dashboard that you have started a snapshot job for.
-
#job_status ⇒ String
Indicates the status of a job.
-
#last_updated_time ⇒ Time
The time that the snapshot job status was last updated.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#snapshot_configuration ⇒ Types::SnapshotConfiguration
The snapshot configuration of the job.
-
#snapshot_job_id ⇒ String
The ID of the job to be described.
-
#status ⇒ Integer
The HTTP status of the request.
-
#user_configuration ⇒ Types::SnapshotUserConfigurationRedacted
The user configuration for the snapshot job.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot job. The job ARN is generated when you start a new job with a ‘StartDashboardSnapshotJob` API call.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that the snapshot job was created.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID of the dashboard that you have started a snapshot job for.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
Indicates the status of a job. The status updates as the job executes. This shows one of the following values.
-
‘COMPLETED` - The job was completed successfully.
-
‘FAILED` - The job failed to execute.
-
‘QUEUED` - The job is queued and hasn’t started yet.
-
‘RUNNING` - The job is still running.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The time that the snapshot job status was last updated.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#snapshot_configuration ⇒ Types::SnapshotConfiguration
The snapshot configuration of the job. This information is provided when you make a ‘StartDashboardSnapshotJob` API call.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#snapshot_job_id ⇒ String
The ID of the job to be described. The job ID is set when you start a new job with a ‘StartDashboardSnapshotJob` API call.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#user_configuration ⇒ Types::SnapshotUserConfigurationRedacted
The user configuration for the snapshot job. This information is provided when you make a ‘StartDashboardSnapshotJob` API call.
16574 16575 16576 16577 16578 16579 16580 16581 16582 16583 16584 16585 16586 16587 16588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16574 class DescribeDashboardSnapshotJobResponse < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration, :arn, :job_status, :created_time, :last_updated_time, :request_id, :status) SENSITIVE = [] include Aws::Structure end |