Class: Aws::QuickSight::Types::DescribeDataSourcePermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDataSourcePermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the data source.
-
#data_source_id ⇒ String
The ID of the data source.
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the data source.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the data source.
19743 19744 19745 19746 19747 19748 19749 19750 19751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19743 class DescribeDataSourcePermissionsResponse < Struct.new( :data_source_arn, :data_source_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19743 19744 19745 19746 19747 19748 19749 19750 19751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19743 class DescribeDataSourcePermissionsResponse < Struct.new( :data_source_arn, :data_source_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the data source.
19743 19744 19745 19746 19747 19748 19749 19750 19751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19743 class DescribeDataSourcePermissionsResponse < Struct.new( :data_source_arn, :data_source_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
19743 19744 19745 19746 19747 19748 19749 19750 19751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19743 class DescribeDataSourcePermissionsResponse < Struct.new( :data_source_arn, :data_source_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
19743 19744 19745 19746 19747 19748 19749 19750 19751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19743 class DescribeDataSourcePermissionsResponse < Struct.new( :data_source_arn, :data_source_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |