Class: Aws::QuickSight::Types::DescribeDefaultQBusinessApplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDefaultQBusinessApplicationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the Amazon Q Business application that is linked to the Quick Sight account.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#application_id ⇒ String
The ID of the Amazon Q Business application that is linked to the Quick Sight account.
16960 16961 16962 16963 16964 16965 16966 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16960 class DescribeDefaultQBusinessApplicationResponse < Struct.new( :request_id, :status, :application_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16960 16961 16962 16963 16964 16965 16966 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16960 class DescribeDefaultQBusinessApplicationResponse < Struct.new( :request_id, :status, :application_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
16960 16961 16962 16963 16964 16965 16966 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16960 class DescribeDefaultQBusinessApplicationResponse < Struct.new( :request_id, :status, :application_id) SENSITIVE = [] include Aws::Structure end |