Class: Aws::QuickSight::Types::DescribeFlowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the flow that you are describing.

Returns:

  • (String)


17854
17855
17856
17857
17858
17859
17860
# File 'lib/aws-sdk-quicksight/types.rb', line 17854

class DescribeFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :publish_state)
  SENSITIVE = []
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow.

Returns:

  • (String)


17854
17855
17856
17857
17858
17859
17860
# File 'lib/aws-sdk-quicksight/types.rb', line 17854

class DescribeFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :publish_state)
  SENSITIVE = []
  include Aws::Structure
end

#publish_stateString

The publish state of the flow version to describe. Valid values are ‘DRAFT`, `PUBLISHED`, or `PENDING_APPROVAL`.

Returns:

  • (String)


17854
17855
17856
17857
17858
17859
17860
# File 'lib/aws-sdk-quicksight/types.rb', line 17854

class DescribeFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :publish_state)
  SENSITIVE = []
  include Aws::Structure
end