Class: Aws::QuickSight::Types::DescribeFolderPermissionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the folder.

Returns:

  • (String)


19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#folder_idString

The ID of the folder.

Returns:

  • (String)


19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token for the next set of results, or null if there are no more results.

Returns:

  • (String)


19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::ResourcePermission>

Information about the permissions on the folder.

Returns:



19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


19978
19979
19980
19981
19982
19983
19984
19985
19986
19987
# File 'lib/aws-sdk-quicksight/types.rb', line 19978

class DescribeFolderPermissionsResponse < Struct.new(
  :status,
  :folder_id,
  :arn,
  :permissions,
  :request_id,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end