Class: Aws::QuickSight::Types::DescribeFolderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeFolderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the folder.
-
#folder_id ⇒ String
The ID of the folder.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the folder.
19999 20000 20001 20002 20003 20004 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19999 class DescribeFolderRequest < Struct.new( :aws_account_id, :folder_id) SENSITIVE = [] include Aws::Structure end |
#folder_id ⇒ String
The ID of the folder.
19999 20000 20001 20002 20003 20004 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19999 class DescribeFolderRequest < Struct.new( :aws_account_id, :folder_id) SENSITIVE = [] include Aws::Structure end |