Class: Aws::QuickSight::Types::DescribeGroupMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeGroupMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#group_name ⇒ String
The name of the group that you want to search.
-
#member_name ⇒ String
The user name of the user that you want to search for.
-
#namespace ⇒ String
The namespace that includes the group you are searching within.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
20118 20119 20120 20121 20122 20123 20124 20125 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20118 class DescribeGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to search.
20118 20119 20120 20121 20122 20123 20124 20125 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20118 class DescribeGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The user name of the user that you want to search for.
20118 20119 20120 20121 20122 20123 20124 20125 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20118 class DescribeGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that includes the group you are searching within.
20118 20119 20120 20121 20122 20123 20124 20125 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20118 class DescribeGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |