Class: Aws::QuickSight::Types::DescribeKeyRegistrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the customer managed key registration specified in the request.

Returns:

  • (String)


18520
18521
18522
18523
18524
18525
18526
18527
18528
# File 'lib/aws-sdk-quicksight/types.rb', line 18520

class DescribeKeyRegistrationResponse < Struct.new(
  :aws_account_id,
  :key_registration,
  :q_data_key,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#key_registrationArray<Types::RegisteredCustomerManagedKey>

A list of ‘RegisteredCustomerManagedKey` objects in a Quick Sight account.



18520
18521
18522
18523
18524
18525
18526
18527
18528
# File 'lib/aws-sdk-quicksight/types.rb', line 18520

class DescribeKeyRegistrationResponse < Struct.new(
  :aws_account_id,
  :key_registration,
  :q_data_key,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#q_data_keyTypes::QDataKey

A list of ‘QDataKey` objects in a Quick Sight account.

Returns:



18520
18521
18522
18523
18524
18525
18526
18527
18528
# File 'lib/aws-sdk-quicksight/types.rb', line 18520

class DescribeKeyRegistrationResponse < Struct.new(
  :aws_account_id,
  :key_registration,
  :q_data_key,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


18520
18521
18522
18523
18524
18525
18526
18527
18528
# File 'lib/aws-sdk-quicksight/types.rb', line 18520

class DescribeKeyRegistrationResponse < Struct.new(
  :aws_account_id,
  :key_registration,
  :q_data_key,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


18520
18521
18522
18523
18524
18525
18526
18527
18528
# File 'lib/aws-sdk-quicksight/types.rb', line 18520

class DescribeKeyRegistrationResponse < Struct.new(
  :aws_account_id,
  :key_registration,
  :q_data_key,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end