Class: Aws::QuickSight::Types::DescribeKnowledgeBasePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeKnowledgeBasePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
18771 18772 18773 18774 18775 18776 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18771 class DescribeKnowledgeBasePermissionsRequest < Struct.new( :aws_account_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
18771 18772 18773 18774 18775 18776 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18771 class DescribeKnowledgeBasePermissionsRequest < Struct.new( :aws_account_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |