Class: Aws::QuickSight::Types::DescribeLimitsProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeLimitsProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that contains the limits profile.
-
#profile_id ⇒ String
The unique identifier for the limits profile.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that contains the limits profile.
20494 20495 20496 20497 20498 20499 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20494 class DescribeLimitsProfileRequest < Struct.new( :profile_id, :account_id) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier for the limits profile.
20494 20495 20496 20497 20498 20499 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20494 class DescribeLimitsProfileRequest < Struct.new( :profile_id, :account_id) SENSITIVE = [] include Aws::Structure end |