Class: Aws::QuickSight::Types::DescribeLimitsProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeLimitsProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#profile ⇒ Types::LimitsProfile
The details of the requested limits profile, including its name, description, resource limits, and metadata.
Instance Attribute Details
#profile ⇒ Types::LimitsProfile
The details of the requested limits profile, including its name, description, resource limits, and metadata.
20508 20509 20510 20511 20512 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20508 class DescribeLimitsProfileResponse < Struct.new( :profile) SENSITIVE = [] include Aws::Structure end |