Class: Aws::QuickSight::Types::DescribeQuickSightQSearchConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the Quick Sight Q Search configuration that the user wants described.

Returns:

  • (String)


18931
18932
18933
18934
18935
# File 'lib/aws-sdk-quicksight/types.rb', line 18931

class DescribeQuickSightQSearchConfigurationRequest < Struct.new(
  :aws_account_id)
  SENSITIVE = []
  include Aws::Structure
end