Class: Aws::QuickSight::Types::DescribeSelfUpgradeConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeSelfUpgradeConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration.
-
#namespace ⇒ String
The Quick namespace that you want to describe the Quick self-upgrade configuration for.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the Quick self-upgrade configuration.
17479 17480 17481 17482 17483 17484 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17479 class DescribeSelfUpgradeConfigurationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick namespace that you want to describe the Quick self-upgrade configuration for.
17479 17480 17481 17482 17483 17484 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17479 class DescribeSelfUpgradeConfigurationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |