Class: Aws::QuickSight::Types::DescribeSpacePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeSpacePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#space_id ⇒ String
The ID of the space that you want to describe permissions for.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
19106 19107 19108 19109 19110 19111 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19106 class DescribeSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to describe permissions for.
19106 19107 19108 19109 19110 19111 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19106 class DescribeSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id) SENSITIVE = [] include Aws::Structure end |