Class: Aws::QuickSight::Types::DescribeTemplateDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTemplateDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_name ⇒ String
The alias of the template that you want to describe.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the template.
-
#template_id ⇒ String
The ID of the template that you're describing.
-
#version_number ⇒ Integer
The version number of the template.
Instance Attribute Details
#alias_name ⇒ String
The alias of the template that you want to describe. If you name a
specific alias, you describe the version that the alias points to.
You can specify the latest version of the template by providing the
keyword $LATEST in the AliasName parameter. The keyword
$PUBLISHED doesn't apply to templates.
20163 20164 20165 20166 20167 20168 20169 20170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20163 class DescribeTemplateDefinitionRequest < Struct.new( :aws_account_id, :template_id, :version_number, :alias_name) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the template. You must be using the Amazon Web Services account that the template is in.
20163 20164 20165 20166 20167 20168 20169 20170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20163 class DescribeTemplateDefinitionRequest < Struct.new( :aws_account_id, :template_id, :version_number, :alias_name) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID of the template that you're describing.
20163 20164 20165 20166 20167 20168 20169 20170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20163 class DescribeTemplateDefinitionRequest < Struct.new( :aws_account_id, :template_id, :version_number, :alias_name) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version number of the template.
20163 20164 20165 20166 20167 20168 20169 20170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20163 class DescribeTemplateDefinitionRequest < Struct.new( :aws_account_id, :template_id, :version_number, :alias_name) SENSITIVE = [] include Aws::Structure end |