Class: Aws::QuickSight::Types::DescribeTemplatePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTemplatePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the template that you’re describing.
-
#template_id ⇒ String
The ID for the template.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the template that you’re describing.
16550 16551 16552 16553 16554 16555 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16550 class DescribeTemplatePermissionsRequest < Struct.new( :aws_account_id, :template_id) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID for the template.
16550 16551 16552 16553 16554 16555 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16550 class DescribeTemplatePermissionsRequest < Struct.new( :aws_account_id, :template_id) SENSITIVE = [] include Aws::Structure end |