Class: Aws::QuickSight::Types::DescribeTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#template ⇒ Types::Template
The template structure for the object you want to describe.
Instance Attribute Details
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
19466 19467 19468 19469 19470 19471 19472 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19466 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
19466 19467 19468 19469 19470 19471 19472 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19466 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#template ⇒ Types::Template
The template structure for the object you want to describe.
19466 19467 19468 19469 19470 19471 19472 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19466 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |