Class: Aws::QuickSight::Types::DescribeTopicPermissionsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicPermissionsV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want described.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want described.
20557 20558 20559 20560 20561 20562 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20557 class DescribeTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
20557 20558 20559 20560 20561 20562 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20557 class DescribeTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |