Class: Aws::QuickSight::Types::DescribeTopicPermissionsV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicPermissionsV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
21400 21401 21402 21403 21404 21405 21406 21407 21408 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21400 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
21400 21401 21402 21403 21404 21405 21406 21407 21408 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21400 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
21400 21401 21402 21403 21404 21405 21406 21407 21408 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21400 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
21400 21401 21402 21403 21404 21405 21406 21407 21408 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21400 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
21400 21401 21402 21403 21404 21405 21406 21407 21408 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21400 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |