Class: Aws::QuickSight::Types::DescribeTopicV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the topic that you want to describe.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
# File 'lib/aws-sdk-quicksight/types.rb', line 21589

class DescribeTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
# File 'lib/aws-sdk-quicksight/types.rb', line 21589

class DescribeTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id)
  SENSITIVE = []
  include Aws::Structure
end