Class: Aws::QuickSight::Types::DescribeTopicV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#custom_instructions ⇒ Types::CustomInstructions
Instructions that provide additional guidance and context for response generation.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic ⇒ Types::TopicV2Details
The definition of a topic.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#custom_instructions ⇒ Types::CustomInstructions
Instructions that provide additional guidance and context for response generation.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ Types::TopicV2Details
The definition of a topic.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
21624 21625 21626 21627 21628 21629 21630 21631 21632 21633 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21624 class DescribeTopicV2Response < Struct.new( :arn, :topic_id, :topic, :custom_instructions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |