Class: Aws::QuickSight::Types::DescribeVPCConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID of the account that contains the VPC connection that you want described.

Returns:

  • (String)


19428
19429
19430
19431
19432
19433
# File 'lib/aws-sdk-quicksight/types.rb', line 19428

class DescribeVPCConnectionRequest < Struct.new(
  :aws_account_id,
  :vpc_connection_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_connection_idString

The ID of the VPC connection that you’re creating. This ID is a unique identifier for each Amazon Web Services Region in an Amazon Web Services account.

Returns:

  • (String)


19428
19429
19430
19431
19432
19433
# File 'lib/aws-sdk-quicksight/types.rb', line 19428

class DescribeVPCConnectionRequest < Struct.new(
  :aws_account_id,
  :vpc_connection_id)
  SENSITIVE = []
  include Aws::Structure
end