Class: Aws::QuickSight::Types::DestinationTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Defines a destination table in data preparation that receives the final transformed data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

Alias for the destination table.

Returns:

  • (String)


18326
18327
18328
18329
18330
18331
# File 'lib/aws-sdk-quicksight/types.rb', line 18326

class DestinationTable < Struct.new(
  :alias,
  :source)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::DestinationTableSource

The source configuration that specifies which transform operation provides data to this destination table.



18326
18327
18328
18329
18330
18331
# File 'lib/aws-sdk-quicksight/types.rb', line 18326

class DestinationTable < Struct.new(
  :alias,
  :source)
  SENSITIVE = []
  include Aws::Structure
end