Class: Aws::QuickSight::Types::DestinationTableSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies the source of data for a destination table, including the transform operation and column mappings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#transform_operation_idString

The identifier of the transform operation that provides data to the destination table.

Returns:

  • (String)


17173
17174
17175
17176
17177
# File 'lib/aws-sdk-quicksight/types.rb', line 17173

class DestinationTableSource < Struct.new(
  :transform_operation_id)
  SENSITIVE = []
  include Aws::Structure
end