Class: Aws::QuickSight::Types::DonutCenterOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DonutCenterOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#label_visibility ⇒ String
Determines the visibility of the label in a donut chart.
Instance Attribute Details
#label_visibility ⇒ String
Determines the visibility of the label in a donut chart. In the
Quick Sight console, this option is called 'Show total'.
20104 20105 20106 20107 20108 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20104 class DonutCenterOptions < Struct.new( :label_visibility) SENSITIVE = [] include Aws::Structure end |