Class: Aws::QuickSight::Types::DropDownControlDisplayOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The display options of a control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#info_icon_label_optionsTypes::SheetControlInfoIconLabelOptions

The configuration of info icon label options.



20213
20214
20215
20216
20217
20218
20219
# File 'lib/aws-sdk-quicksight/types.rb', line 20213

class DropDownControlDisplayOptions < Struct.new(
  :select_all_options,
  :title_options,
  :info_icon_label_options)
  SENSITIVE = []
  include Aws::Structure
end

#select_all_optionsTypes::ListControlSelectAllOptions

The configuration of the Select all options in a dropdown control.



20213
20214
20215
20216
20217
20218
20219
# File 'lib/aws-sdk-quicksight/types.rb', line 20213

class DropDownControlDisplayOptions < Struct.new(
  :select_all_options,
  :title_options,
  :info_icon_label_options)
  SENSITIVE = []
  include Aws::Structure
end

#title_optionsTypes::LabelOptions

The options to configure the title visibility, name, and font size.

Returns:



20213
20214
20215
20216
20217
20218
20219
# File 'lib/aws-sdk-quicksight/types.rb', line 20213

class DropDownControlDisplayOptions < Struct.new(
  :select_all_options,
  :title_options,
  :info_icon_label_options)
  SENSITIVE = []
  include Aws::Structure
end