Class: Aws::QuickSight::Types::EffectiveLimit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The effective limit for a resource type that applies to a user, considering all applicable profile assignments and inheritance rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limit_unitString

The unit of measurement for the limit.

Returns:

  • (String)


22183
22184
22185
22186
22187
22188
22189
22190
22191
# File 'lib/aws-sdk-quicksight/types.rb', line 22183

class EffectiveLimit < Struct.new(
  :resource_type,
  :limit_value,
  :limit_unit,
  :source,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#limit_valueInteger

The maximum allowed value for the resource.

Returns:

  • (Integer)


22183
22184
22185
22186
22187
22188
22189
22190
22191
# File 'lib/aws-sdk-quicksight/types.rb', line 22183

class EffectiveLimit < Struct.new(
  :resource_type,
  :limit_value,
  :limit_unit,
  :source,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The identifier of the limits profile that defines this limit.

Returns:

  • (String)


22183
22184
22185
22186
22187
22188
22189
22190
22191
# File 'lib/aws-sdk-quicksight/types.rb', line 22183

class EffectiveLimit < Struct.new(
  :resource_type,
  :limit_value,
  :limit_unit,
  :source,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource that the limit applies to.

Returns:

  • (String)


22183
22184
22185
22186
22187
22188
22189
22190
22191
# File 'lib/aws-sdk-quicksight/types.rb', line 22183

class EffectiveLimit < Struct.new(
  :resource_type,
  :limit_value,
  :limit_unit,
  :source,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source from which this limit was inherited. Possible values:

  • DIRECT_USER – The limit comes from a profile directly assigned to the user.

  • GROUP – The limit comes from a profile assigned to a group the user belongs to.

  • ROLE – The limit comes from a profile assigned to a role the user has.

  • ACCOUNT – The limit comes from the account-level default profile.

  • SYSTEM_DEFAULT – The limit comes from the built-in system default.

Returns:

  • (String)


22183
22184
22185
22186
22187
22188
22189
22190
22191
# File 'lib/aws-sdk-quicksight/types.rb', line 22183

class EffectiveLimit < Struct.new(
  :resource_type,
  :limit_value,
  :limit_unit,
  :source,
  :profile_id)
  SENSITIVE = []
  include Aws::Structure
end