Class: Aws::QuickSight::Types::EmptyVisual

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An empty visual.

Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Quick Sight console is considered an EmptyVisual until a visual type is selected.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::VisualCustomAction>

The list of custom actions that are configured for a visual.

Returns:



21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-quicksight/types.rb', line 21252

class EmptyVisual < Struct.new(
  :visual_id,
  :data_set_identifier,
  :topic_identifier,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_identifierString

The data set that is used in the empty visual. Every visual requires a dataset or a topic to render.

Returns:

  • (String)


21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-quicksight/types.rb', line 21252

class EmptyVisual < Struct.new(
  :visual_id,
  :data_set_identifier,
  :topic_identifier,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#topic_identifierString

The topic that is used in the empty visual. Every visual requires a dataset or a topic to render.

Returns:

  • (String)


21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-quicksight/types.rb', line 21252

class EmptyVisual < Struct.new(
  :visual_id,
  :data_set_identifier,
  :topic_identifier,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#visual_idString

The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

Returns:

  • (String)


21252
21253
21254
21255
21256
21257
21258
21259
# File 'lib/aws-sdk-quicksight/types.rb', line 21252

class EmptyVisual < Struct.new(
  :visual_id,
  :data_set_identifier,
  :topic_identifier,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end