Class: Aws::QuickSight::Types::ExecutiveSummaryConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ExecutiveSummaryConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The executive summary settings of an embedded Quick Sight console or dashboard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
The executive summary settings of an embedded Quick Sight console or dashboard.
Instance Attribute Details
#enabled ⇒ Boolean
The executive summary settings of an embedded Quick Sight console or dashboard.
18655 18656 18657 18658 18659 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18655 class ExecutiveSummaryConfigurations < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |