Class: Aws::QuickSight::Types::ExportWithHiddenFieldsOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Determines whether or not hidden fields are visible on exported dashbaords.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_statusString

The status of the export with hidden fields options.

Returns:

  • (String)


17624
17625
17626
17627
17628
# File 'lib/aws-sdk-quicksight/types.rb', line 17624

class ExportWithHiddenFieldsOption < Struct.new(
  :availability_status)
  SENSITIVE = []
  include Aws::Structure
end