Class: Aws::QuickSight::Types::FMKBParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The connection parameters for a fully managed knowledge base data source. Provide these parameters in the DataSourceParameters object when you create or update a data source that uses a fully managed knowledge base.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#knowledge_base_arnString

The Amazon Resource Name (ARN) of the Amazon Bedrock knowledge base.

Returns:

  • (String)


20446
20447
20448
20449
20450
20451
# File 'lib/aws-sdk-quicksight/types.rb', line 20446

class FMKBParameters < Struct.new(
  :knowledge_base_arn,
  :linked_data_source_ids)
  SENSITIVE = []
  include Aws::Structure
end

#linked_data_source_idsArray<String>

The IDs of the linked data sources.

Returns:

  • (Array<String>)


20446
20447
20448
20449
20450
20451
# File 'lib/aws-sdk-quicksight/types.rb', line 20446

class FMKBParameters < Struct.new(
  :knowledge_base_arn,
  :linked_data_source_ids)
  SENSITIVE = []
  include Aws::Structure
end