Class: Aws::QuickSight::Types::FailedKeyRegistrationEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An entry that appears when a KeyRegistration update to Quick Sight fails.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_arnString

The ARN of the KMS key that failed to update.

Returns:

  • (String)


21492
21493
21494
21495
21496
21497
21498
21499
# File 'lib/aws-sdk-quicksight/types.rb', line 21492

class FailedKeyRegistrationEntry < Struct.new(
  :key_arn,
  :message,
  :status_code,
  :sender_fault)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message that provides information about why a FailedKeyRegistrationEntry error occurred.

Returns:

  • (String)


21492
21493
21494
21495
21496
21497
21498
21499
# File 'lib/aws-sdk-quicksight/types.rb', line 21492

class FailedKeyRegistrationEntry < Struct.new(
  :key_arn,
  :message,
  :status_code,
  :sender_fault)
  SENSITIVE = []
  include Aws::Structure
end

#sender_faultBoolean

A boolean that indicates whether a FailedKeyRegistrationEntry resulted from user error. If the value of this property is True, the error was caused by user error. If the value of this property is False, the error occurred on the backend. If your job continues fail and with a False SenderFault value, contact Amazon Web Services Support.

Returns:

  • (Boolean)


21492
21493
21494
21495
21496
21497
21498
21499
# File 'lib/aws-sdk-quicksight/types.rb', line 21492

class FailedKeyRegistrationEntry < Struct.new(
  :key_arn,
  :message,
  :status_code,
  :sender_fault)
  SENSITIVE = []
  include Aws::Structure
end

#status_codeInteger

The HTTP status of a FailedKeyRegistrationEntry error.

Returns:

  • (Integer)


21492
21493
21494
21495
21496
21497
21498
21499
# File 'lib/aws-sdk-quicksight/types.rb', line 21492

class FailedKeyRegistrationEntry < Struct.new(
  :key_arn,
  :message,
  :status_code,
  :sender_fault)
  SENSITIVE = []
  include Aws::Structure
end