Class: Aws::QuickSight::Types::FailedSpaceResourceOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FailedSpaceResourceOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A resource operation that failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_message ⇒ String
The error message that describes why the operation failed.
-
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
-
#resource_type ⇒ String
The type of the resource.
Instance Attribute Details
#error_message ⇒ String
The error message that describes why the operation failed.
20298 20299 20300 20301 20302 20303 20304 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20298 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
20298 20299 20300 20301 20302 20303 20304 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20298 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource.
20298 20299 20300 20301 20302 20303 20304 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20298 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |