Class: Aws::QuickSight::Types::FieldComboSeriesItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FieldComboSeriesItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The field series item configuration of a ‘ComboChartVisual`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_id ⇒ String
Field ID of the field for which you are setting the series configuration.
-
#settings ⇒ Types::ComboChartSeriesSettings
Options that determine the presentation of series associated to the field.
Instance Attribute Details
#field_id ⇒ String
Field ID of the field for which you are setting the series configuration.
17730 17731 17732 17733 17734 17735 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17730 class FieldComboSeriesItem < Struct.new( :field_id, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::ComboChartSeriesSettings
Options that determine the presentation of series associated to the field.
17730 17731 17732 17733 17734 17735 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17730 class FieldComboSeriesItem < Struct.new( :field_id, :settings) SENSITIVE = [] include Aws::Structure end |