Class: Aws::QuickSight::Types::FilledMapAggregatedFieldWells

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The aggregated field well of the filled map.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#geospatialArray<Types::DimensionField>

The aggregated location field well of the filled map. Values are grouped by location fields.

Returns:



19059
19060
19061
19062
19063
19064
# File 'lib/aws-sdk-quicksight/types.rb', line 19059

class FilledMapAggregatedFieldWells < Struct.new(
  :geospatial,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Types::MeasureField>

The aggregated color field well of a filled map. Values are aggregated based on location fields.

Returns:



19059
19060
19061
19062
19063
19064
# File 'lib/aws-sdk-quicksight/types.rb', line 19059

class FilledMapAggregatedFieldWells < Struct.new(
  :geospatial,
  :values)
  SENSITIVE = []
  include Aws::Structure
end