Class: Aws::QuickSight::Types::FilledMapConditionalFormattingOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FilledMapConditionalFormattingOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Conditional formatting options of a FilledMapVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shape ⇒ Types::FilledMapShapeConditionalFormatting
The conditional formatting that determines the shape of the filled map.
Instance Attribute Details
#shape ⇒ Types::FilledMapShapeConditionalFormatting
The conditional formatting that determines the shape of the filled map.
20823 20824 20825 20826 20827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20823 class FilledMapConditionalFormattingOption < Struct.new( :shape) SENSITIVE = [] include Aws::Structure end |