Class: Aws::QuickSight::Types::FilterDropDownControl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A control to display a dropdown list with buttons that are used to select a single value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cascading_control_configurationTypes::CascadingControlConfiguration

The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.



17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#commit_modeString

The visibility configuration of the Apply button on a ‘FilterDropDownControl`.

Returns:

  • (String)


17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#display_optionsTypes::DropDownControlDisplayOptions

The display options of the ‘FilterDropDownControl`.



17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#filter_control_idString

The ID of the ‘FilterDropDownControl`.

Returns:

  • (String)


17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#selectable_valuesTypes::FilterSelectableValues

A list of selectable values that are used in a control.



17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#source_filter_idString

The source filter ID of the ‘FilterDropDownControl`.

Returns:

  • (String)


17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the ‘FilterDropDownControl`.

Returns:

  • (String)


17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the ‘FilterDropDownControl`. Choose one of the following options:

  • ‘MULTI_SELECT`: The user can select multiple entries from a dropdown menu.

  • ‘SINGLE_SELECT`: The user can select a single entry from a dropdown menu.

Returns:

  • (String)


17874
17875
17876
17877
17878
17879
17880
17881
17882
17883
17884
17885
# File 'lib/aws-sdk-quicksight/types.rb', line 17874

class FilterDropDownControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode)
  SENSITIVE = []
  include Aws::Structure
end