Class: Aws::QuickSight::Types::FilterSliderControl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_optionsTypes::SliderControlDisplayOptions

The display options of a control.



18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#filter_control_idString

The ID of the ‘FilterSliderControl`.

Returns:

  • (String)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_valueFloat

The larger value that is displayed at the right of the slider.

Returns:

  • (Float)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_valueFloat

The smaller value that is displayed at the left of the slider.

Returns:

  • (Float)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#source_filter_idString

The source filter ID of the ‘FilterSliderControl`.

Returns:

  • (String)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#step_sizeFloat

The number of increments that the slider bar is divided into.

Returns:

  • (Float)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the ‘FilterSliderControl`.

Returns:

  • (String)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the ‘FilterSliderControl`. Choose one of the following options:

  • ‘SINGLE_POINT`: Filter against(equals) a single data point.

  • ‘RANGE`: Filter data that is in a specified range.

Returns:

  • (String)


18236
18237
18238
18239
18240
18241
18242
18243
18244
18245
18246
18247
# File 'lib/aws-sdk-quicksight/types.rb', line 18236

class FilterSliderControl < Struct.new(
  :filter_control_id,
  :title,
  :source_filter_id,
  :display_options,
  :type,
  :maximum_value,
  :minimum_value,
  :step_size)
  SENSITIVE = []
  include Aws::Structure
end