Class: Aws::QuickSight::Types::FontConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FontConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Configures the display properties of the given text.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#font_color ⇒ String
Determines the color of the text.
-
#font_decoration ⇒ String
Determines the appearance of decorative lines on the text.
-
#font_family ⇒ String
The font family that you want to use.
-
#font_size ⇒ Types::FontSize
The option that determines the text display size.
-
#font_style ⇒ String
Determines the text display face that is inherited by the given font family.
-
#font_weight ⇒ Types::FontWeight
The option that determines the text display weight, or boldness.
Instance Attribute Details
#font_color ⇒ String
Determines the color of the text.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |
#font_decoration ⇒ String
Determines the appearance of decorative lines on the text.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |
#font_family ⇒ String
The font family that you want to use.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |
#font_size ⇒ Types::FontSize
The option that determines the text display size.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |
#font_style ⇒ String
Determines the text display face that is inherited by the given font family.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |
#font_weight ⇒ Types::FontWeight
The option that determines the text display weight, or boldness.
23161 23162 23163 23164 23165 23166 23167 23168 23169 23170 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23161 class FontConfiguration < Struct.new( :font_size, :font_decoration, :font_color, :font_weight, :font_style, :font_family) SENSITIVE = [] include Aws::Structure end |