Class: Aws::QuickSight::Types::FontWeight
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FontWeight
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The option that determines the text display weight, or boldness.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The lexical name for the level of boldness of the text display.
Instance Attribute Details
#name ⇒ String
The lexical name for the level of boldness of the text display.
22233 22234 22235 22236 22237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22233 class FontWeight < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |