Class: Aws::QuickSight::Types::FunnelChartConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FunnelChartConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration of a FunnelChartVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category_label_options ⇒ Types::ChartAxisLabelOptions
The label options of the categories that are displayed in a
FunnelChartVisual. -
#data_label_options ⇒ Types::FunnelChartDataLabelOptions
The options that determine the presentation of the data labels.
-
#field_wells ⇒ Types::FunnelChartFieldWells
The field well configuration of a
FunnelChartVisual. -
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
-
#sort_configuration ⇒ Types::FunnelChartSortConfiguration
The sort configuration of a
FunnelChartVisual. -
#tooltip ⇒ Types::TooltipOptions
The tooltip configuration of a
FunnelChartVisual. -
#value_label_options ⇒ Types::ChartAxisLabelOptions
The label options for the values that are displayed in a
FunnelChartVisual. -
#visual_palette ⇒ Types::VisualPalette
The visual palette configuration of a
FunnelChartVisual.
Instance Attribute Details
#category_label_options ⇒ Types::ChartAxisLabelOptions
The label options of the categories that are displayed in a
FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#data_label_options ⇒ Types::FunnelChartDataLabelOptions
The options that determine the presentation of the data labels.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#field_wells ⇒ Types::FunnelChartFieldWells
The field well configuration of a FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#sort_configuration ⇒ Types::FunnelChartSortConfiguration
The sort configuration of a FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#tooltip ⇒ Types::TooltipOptions
The tooltip configuration of a FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#value_label_options ⇒ Types::ChartAxisLabelOptions
The label options for the values that are displayed in a
FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#visual_palette ⇒ Types::VisualPalette
The visual palette configuration of a FunnelChartVisual.
23590 23591 23592 23593 23594 23595 23596 23597 23598 23599 23600 23601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23590 class FunnelChartConfiguration < Struct.new( :field_wells, :sort_configuration, :category_label_options, :value_label_options, :tooltip, :data_label_options, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |