Class: Aws::QuickSight::Types::FunnelChartDataLabelOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FunnelChartDataLabelOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the presentation of the data labels.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category_label_visibility ⇒ String
The visibility of the category labels within the data labels.
-
#label_color ⇒ String
The color of the data label text.
-
#label_font_configuration ⇒ Types::FontConfiguration
The font configuration for the data labels.
-
#measure_data_label_style ⇒ String
Determines the style of the metric labels.
-
#measure_label_visibility ⇒ String
The visibility of the measure labels within the data labels.
-
#position ⇒ String
Determines the positioning of the data label relative to a section of the funnel.
-
#visibility ⇒ String
The visibility option that determines if data labels are displayed.
Instance Attribute Details
#category_label_visibility ⇒ String
The visibility of the category labels within the data labels.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#label_color ⇒ String
The color of the data label text.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#label_font_configuration ⇒ Types::FontConfiguration
The font configuration for the data labels.
Only the FontSize attribute of the font configuration is used for
data labels.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#measure_data_label_style ⇒ String
Determines the style of the metric labels.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#measure_label_visibility ⇒ String
The visibility of the measure labels within the data labels.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#position ⇒ String
Determines the positioning of the data label relative to a section of the funnel.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
The visibility option that determines if data labels are displayed.
23639 23640 23641 23642 23643 23644 23645 23646 23647 23648 23649 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23639 class FunnelChartDataLabelOptions < Struct.new( :visibility, :category_label_visibility, :measure_label_visibility, :position, :label_font_configuration, :label_color, :measure_data_label_style) SENSITIVE = [] include Aws::Structure end |