Class: Aws::QuickSight::Types::GaugeChartConditionalFormattingOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Conditional formatting options of a GaugeChartVisual.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arcTypes::GaugeChartArcConditionalFormatting

The options that determine the presentation of the arc of a GaugeChartVisual.



22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-quicksight/types.rb', line 22584

class GaugeChartConditionalFormattingOption < Struct.new(
  :primary_value,
  :arc)
  SENSITIVE = []
  include Aws::Structure
end

#primary_valueTypes::GaugeChartPrimaryValueConditionalFormatting

The conditional formatting for the primary value of a GaugeChartVisual.



22584
22585
22586
22587
22588
22589
# File 'lib/aws-sdk-quicksight/types.rb', line 22584

class GaugeChartConditionalFormattingOption < Struct.new(
  :primary_value,
  :arc)
  SENSITIVE = []
  include Aws::Structure
end