Class: Aws::QuickSight::Types::GaugeChartOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GaugeChartOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the presentation of the GaugeChartVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arc ⇒ Types::ArcConfiguration
The arc configuration of a
GaugeChartVisual. -
#arc_axis ⇒ Types::ArcAxisConfiguration
The arc axis configuration of a
GaugeChartVisual. -
#comparison ⇒ Types::ComparisonConfiguration
The comparison configuration of a
GaugeChartVisual. -
#primary_value_display_type ⇒ String
The options that determine the primary value display type.
-
#primary_value_font_configuration ⇒ Types::FontConfiguration
The options that determine the primary value font configuration.
Instance Attribute Details
#arc ⇒ Types::ArcConfiguration
The arc configuration of a GaugeChartVisual.
22886 22887 22888 22889 22890 22891 22892 22893 22894 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22886 class GaugeChartOptions < Struct.new( :primary_value_display_type, :comparison, :arc_axis, :arc, :primary_value_font_configuration) SENSITIVE = [] include Aws::Structure end |
#arc_axis ⇒ Types::ArcAxisConfiguration
The arc axis configuration of a GaugeChartVisual.
22886 22887 22888 22889 22890 22891 22892 22893 22894 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22886 class GaugeChartOptions < Struct.new( :primary_value_display_type, :comparison, :arc_axis, :arc, :primary_value_font_configuration) SENSITIVE = [] include Aws::Structure end |
#comparison ⇒ Types::ComparisonConfiguration
The comparison configuration of a GaugeChartVisual.
22886 22887 22888 22889 22890 22891 22892 22893 22894 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22886 class GaugeChartOptions < Struct.new( :primary_value_display_type, :comparison, :arc_axis, :arc, :primary_value_font_configuration) SENSITIVE = [] include Aws::Structure end |
#primary_value_display_type ⇒ String
The options that determine the primary value display type.
22886 22887 22888 22889 22890 22891 22892 22893 22894 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22886 class GaugeChartOptions < Struct.new( :primary_value_display_type, :comparison, :arc_axis, :arc, :primary_value_font_configuration) SENSITIVE = [] include Aws::Structure end |
#primary_value_font_configuration ⇒ Types::FontConfiguration
The options that determine the primary value font configuration.
22886 22887 22888 22889 22890 22891 22892 22893 22894 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22886 class GaugeChartOptions < Struct.new( :primary_value_display_type, :comparison, :arc_axis, :arc, :primary_value_font_configuration) SENSITIVE = [] include Aws::Structure end |