Class: Aws::QuickSight::Types::GaugeChartPrimaryValueConditionalFormatting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The conditional formatting for the primary value of a GaugeChartVisual.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iconTypes::ConditionalFormattingIcon

The conditional formatting of the primary value icon.



22702
22703
22704
22705
22706
22707
# File 'lib/aws-sdk-quicksight/types.rb', line 22702

class GaugeChartPrimaryValueConditionalFormatting < Struct.new(
  :text_color,
  :icon)
  SENSITIVE = []
  include Aws::Structure
end

#text_colorTypes::ConditionalFormattingColor

The conditional formatting of the primary value text color.



22702
22703
22704
22705
22706
22707
# File 'lib/aws-sdk-quicksight/types.rb', line 22702

class GaugeChartPrimaryValueConditionalFormatting < Struct.new(
  :text_color,
  :icon)
  SENSITIVE = []
  include Aws::Structure
end