Class: Aws::QuickSight::Types::GaugeChartVisual
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GaugeChartVisual
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A gauge chart.
For more information, see Using gauge charts in the Amazon Quick Suite User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::VisualCustomAction>
The list of custom actions that are configured for a visual.
-
#chart_configuration ⇒ Types::GaugeChartConfiguration
The configuration of a
GaugeChartVisual. -
#conditional_formatting ⇒ Types::GaugeChartConditionalFormatting
The conditional formatting of a
GaugeChartVisual. -
#subtitle ⇒ Types::VisualSubtitleLabelOptions
The subtitle that is displayed on the visual.
-
#title ⇒ Types::VisualTitleLabelOptions
The title that is displayed on the visual.
-
#visual_content_alt_text ⇒ String
The alt text for the visual.
-
#visual_id ⇒ String
The unique identifier of a visual.
Instance Attribute Details
#actions ⇒ Array<Types::VisualCustomAction>
The list of custom actions that are configured for a visual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#chart_configuration ⇒ Types::GaugeChartConfiguration
The configuration of a GaugeChartVisual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#conditional_formatting ⇒ Types::GaugeChartConditionalFormatting
The conditional formatting of a GaugeChartVisual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#subtitle ⇒ Types::VisualSubtitleLabelOptions
The subtitle that is displayed on the visual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#title ⇒ Types::VisualTitleLabelOptions
The title that is displayed on the visual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#visual_content_alt_text ⇒ String
The alt text for the visual.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#visual_id ⇒ String
The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
22751 22752 22753 22754 22755 22756 22757 22758 22759 22760 22761 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22751 class GaugeChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :conditional_formatting, :actions, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |