Class: Aws::QuickSight::Types::GenerativeAuthoringConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The generative BI authoring settings of an embedded Quick Sight console.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

The generative BI authoring settings of an embedded Quick Sight console.

Returns:

  • (Boolean)


22776
22777
22778
22779
22780
# File 'lib/aws-sdk-quicksight/types.rb', line 22776

class GenerativeAuthoringConfigurations < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end