Class: Aws::QuickSight::Types::GeospatialDataSourceItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GeospatialDataSourceItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The data source properties for the geospatial data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#static_file_data_source ⇒ Types::GeospatialStaticFileSource
The static file data source properties for the geospatial data.
Instance Attribute Details
#static_file_data_source ⇒ Types::GeospatialStaticFileSource
The static file data source properties for the geospatial data.
24556 24557 24558 24559 24560 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24556 class GeospatialDataSourceItem < Struct.new( :static_file_data_source) SENSITIVE = [] include Aws::Structure end |