Class: Aws::QuickSight::Types::GeospatialLayerMapConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The map definition that defines map state, map style, and geospatial layers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#interactionsTypes::VisualInteractionOptions

The general visual interactions setup for visual publish options



20177
20178
20179
20180
20181
20182
20183
20184
20185
# File 'lib/aws-sdk-quicksight/types.rb', line 20177

class GeospatialLayerMapConfiguration < Struct.new(
  :legend,
  :map_layers,
  :map_state,
  :map_style,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#legendTypes::LegendOptions

The options for the legend setup of a visual.



20177
20178
20179
20180
20181
20182
20183
20184
20185
# File 'lib/aws-sdk-quicksight/types.rb', line 20177

class GeospatialLayerMapConfiguration < Struct.new(
  :legend,
  :map_layers,
  :map_state,
  :map_style,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#map_layersArray<Types::GeospatialLayerItem>

The geospatial layers to visualize on the map.

Returns:



20177
20178
20179
20180
20181
20182
20183
20184
20185
# File 'lib/aws-sdk-quicksight/types.rb', line 20177

class GeospatialLayerMapConfiguration < Struct.new(
  :legend,
  :map_layers,
  :map_state,
  :map_style,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#map_stateTypes::GeospatialMapState

The map state properties for the map.



20177
20178
20179
20180
20181
20182
20183
20184
20185
# File 'lib/aws-sdk-quicksight/types.rb', line 20177

class GeospatialLayerMapConfiguration < Struct.new(
  :legend,
  :map_layers,
  :map_state,
  :map_style,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#map_styleTypes::GeospatialMapStyle

The map style properties for the map.



20177
20178
20179
20180
20181
20182
20183
20184
20185
# File 'lib/aws-sdk-quicksight/types.rb', line 20177

class GeospatialLayerMapConfiguration < Struct.new(
  :legend,
  :map_layers,
  :map_state,
  :map_style,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end