Class: Aws::QuickSight::Types::GeospatialPolygonSymbolStyle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The polygon symbol style for a polygon layer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fill_colorTypes::GeospatialColor

The color and opacity values for the fill color.



20586
20587
20588
20589
20590
20591
20592
# File 'lib/aws-sdk-quicksight/types.rb', line 20586

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end

#stroke_colorTypes::GeospatialColor

The color and opacity values for the stroke color.



20586
20587
20588
20589
20590
20591
20592
# File 'lib/aws-sdk-quicksight/types.rb', line 20586

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end

#stroke_widthTypes::GeospatialLineWidth

The width of the border stroke.



20586
20587
20588
20589
20590
20591
20592
# File 'lib/aws-sdk-quicksight/types.rb', line 20586

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end