Class: Aws::QuickSight::Types::GetSessionEmbedUrlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account associated with your Amazon Quick Sight subscription.

Returns:

  • (String)


21581
21582
21583
21584
21585
21586
21587
21588
# File 'lib/aws-sdk-quicksight/types.rb', line 21581

class GetSessionEmbedUrlRequest < Struct.new(
  :aws_account_id,
  :entry_point,
  :session_lifetime_in_minutes,
  :user_arn)
  SENSITIVE = []
  include Aws::Structure
end

#entry_pointString

The URL you use to access the embedded session. The entry point URL is constrained to the following paths:

  • ‘/start`

  • ‘/start/analyses`

  • ‘/start/dashboards`

  • ‘/start/favorites`

  • ‘/dashboards/DashboardId ` - where `DashboardId` is the actual ID key from the Amazon Quick Sight console URL of the dashboard

  • ‘/analyses/AnalysisId ` - where `AnalysisId` is the actual ID key from the Amazon Quick Sight console URL of the analysis

Returns:

  • (String)


21581
21582
21583
21584
21585
21586
21587
21588
# File 'lib/aws-sdk-quicksight/types.rb', line 21581

class GetSessionEmbedUrlRequest < Struct.new(
  :aws_account_id,
  :entry_point,
  :session_lifetime_in_minutes,
  :user_arn)
  SENSITIVE = []
  include Aws::Structure
end

#session_lifetime_in_minutesInteger

How many minutes the session is valid. The session lifetime must be 15-600 minutes.

Returns:

  • (Integer)


21581
21582
21583
21584
21585
21586
21587
21588
# File 'lib/aws-sdk-quicksight/types.rb', line 21581

class GetSessionEmbedUrlRequest < Struct.new(
  :aws_account_id,
  :entry_point,
  :session_lifetime_in_minutes,
  :user_arn)
  SENSITIVE = []
  include Aws::Structure
end

#user_arnString

The Amazon Quick Suite user’s Amazon Resource Name (ARN), for use with ‘QUICKSIGHT` identity type. You can use this for any type of Amazon Quick Suite users in your account (readers, authors, or admins). They need to be authenticated as one of the following:

  1. Active Directory (AD) users or group members

  2. Invited nonfederated users

  3. IAM users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation

Omit this parameter for users in the third group, IAM users and IAM role-based sessions.

Returns:

  • (String)


21581
21582
21583
21584
21585
21586
21587
21588
# File 'lib/aws-sdk-quicksight/types.rb', line 21581

class GetSessionEmbedUrlRequest < Struct.new(
  :aws_account_id,
  :entry_point,
  :session_lifetime_in_minutes,
  :user_arn)
  SENSITIVE = []
  include Aws::Structure
end