Class: Aws::QuickSight::Types::GridLayoutElement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An element within a grid layout.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#background_styleTypes::GridLayoutElementBackgroundStyle

The background style configuration of a grid layout element.



23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#border_radiusString

The border radius of a grid layout element.

Returns:

  • (String)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#border_styleTypes::GridLayoutElementBorderStyle

The border style configuration of a grid layout element.



23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#column_indexInteger

The column index for the upper left corner of an element.

Returns:

  • (Integer)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#column_spanInteger

The width of a grid element expressed as a number of grid columns.

Returns:

  • (Integer)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#element_idString

A unique identifier for an element within a grid layout.

Returns:

  • (String)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#element_typeString

The type of element.

Returns:

  • (String)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#loading_animationTypes::LoadingAnimation

The configuration of loading animation in free-form layout.



23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#paddingString

The padding of a grid layout element.

Returns:

  • (String)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#row_indexInteger

The row index for the upper left corner of an element.

Returns:

  • (Integer)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#row_spanInteger

The height of a grid element expressed as a number of grid rows.

Returns:

  • (Integer)


23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#selected_border_styleTypes::GridLayoutElementBorderStyle

The border style configuration of a grid layout element. This border style is used when the element is selected.



23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
# File 'lib/aws-sdk-quicksight/types.rb', line 23027

class GridLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :column_index,
  :column_span,
  :row_index,
  :row_span,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end