Class: Aws::QuickSight::Types::HeatMapConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The configuration of a heat map.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#color_scaleTypes::ColorScale

The color options (gradient color, point of divergence) in a heat map.

Returns:



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#column_axis_display_optionsTypes::AxisDisplayOptions

The options that determine the presentation of the row axis label.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#column_label_optionsTypes::ChartAxisLabelOptions

The label options of the column that is displayed in a heat map.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#data_labelsTypes::DataLabelOptions

The options that determine if visual data labels are displayed.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_wellsTypes::HeatMapFieldWells

The field wells of the visual.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#interactionsTypes::VisualInteractionOptions

The general visual interactions setup for a visual.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#legendTypes::LegendOptions

The legend display setup of the visual.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#row_axis_display_optionsTypes::AxisDisplayOptions

The options that determine the presentation of the row axis label.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#row_label_optionsTypes::ChartAxisLabelOptions

The label options of the row that is displayed in a ‘heat map`.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_configurationTypes::HeatMapSortConfiguration

The sort configuration of a heat map.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#tooltipTypes::TooltipOptions

The tooltip display setup of the visual.



24641
24642
24643
24644
24645
24646
24647
24648
24649
24650
24651
24652
24653
24654
24655
# File 'lib/aws-sdk-quicksight/types.rb', line 24641

class HeatMapConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :row_axis_display_options,
  :row_label_options,
  :column_axis_display_options,
  :column_label_options,
  :color_scale,
  :legend,
  :data_labels,
  :tooltip,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end