Class: Aws::QuickSight::Types::ImageMenuOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The menu options for the interactions of an image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_statusString

The availability status of the image menu. If the value of this property is set to ‘ENABLED`, dashboard readers can interact with the image menu.

Returns:

  • (String)


23875
23876
23877
23878
23879
# File 'lib/aws-sdk-quicksight/types.rb', line 23875

class ImageMenuOption < Struct.new(
  :availability_status)
  SENSITIVE = []
  include Aws::Structure
end