Class: Aws::QuickSight::Types::ImageSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ImageSource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
ImageSource is a union - when making an API calls you must set exactly one of the members.
Note:
ImageSource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ImageSource corresponding to the set member.
The source of the image.
Defined Under Namespace
Classes: PublicUrl, S3Uri, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#public_url ⇒ String
The public URL that points to the source image.
-
#s3_uri ⇒ String
The Amazon S3 URI that points to the source image.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#public_url ⇒ String
The public URL that points to the source image.
25235 25236 25237 25238 25239 25240 25241 25242 25243 25244 25245 25246 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25235 class ImageSource < Struct.new( :public_url, :s3_uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PublicUrl < ImageSource; end class S3Uri < ImageSource; end class Unknown < ImageSource; end end |
#s3_uri ⇒ String
The Amazon S3 URI that points to the source image.
25235 25236 25237 25238 25239 25240 25241 25242 25243 25244 25245 25246 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25235 class ImageSource < Struct.new( :public_url, :s3_uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PublicUrl < ImageSource; end class S3Uri < ImageSource; end class Unknown < ImageSource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
25235 25236 25237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25235 def unknown @unknown end |