Class: Aws::QuickSight::Types::ImportTableOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ImportTableOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that imports data from a source table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for this operation.
-
#source ⇒ Types::ImportTableOperationSource
The source configuration that specifies which source table to import and any column mappings.
Instance Attribute Details
#alias ⇒ String
Alias for this operation.
22746 22747 22748 22749 22750 22751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22746 class ImportTableOperation < Struct.new( :alias, :source) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::ImportTableOperationSource
The source configuration that specifies which source table to import and any column mappings.
22746 22747 22748 22749 22750 22751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22746 class ImportTableOperation < Struct.new( :alias, :source) SENSITIVE = [] include Aws::Structure end |