Class: Aws::QuickSight::Types::ImportTableOperationSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies the source table and column mappings for an import table operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_id_mappingsArray<Types::DataSetColumnIdMapping>

The mappings between source column identifiers and target column identifiers during the import.

Returns:



22767
22768
22769
22770
22771
22772
# File 'lib/aws-sdk-quicksight/types.rb', line 22767

class ImportTableOperationSource < Struct.new(
  :source_table_id,
  :column_id_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_idString

The identifier of the source table to import data from.

Returns:

  • (String)


22767
22768
22769
22770
22771
22772
# File 'lib/aws-sdk-quicksight/types.rb', line 22767

class ImportTableOperationSource < Struct.new(
  :source_table_id,
  :column_id_mappings)
  SENSITIVE = []
  include Aws::Structure
end