Class: Aws::QuickSight::Types::InlineCustomInstruction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An inline custom instruction with text content and optional file upload metadata.

Constant Summary collapse

SENSITIVE =
[:instruction_text]

Instance Attribute Summary collapse

Instance Attribute Details

#instruction_textString

The instruction text content.

Returns:

  • (String)


24456
24457
24458
24459
24460
24461
# File 'lib/aws-sdk-quicksight/types.rb', line 24456

class InlineCustomInstruction < Struct.new(
  :instruction_text,
  :uploaded_document_metadata)
  SENSITIVE = [:instruction_text]
  include Aws::Structure
end

#uploaded_document_metadataTypes::UploadedDocumentMetadata

Metadata about an uploaded document associated with this instruction.



24456
24457
24458
24459
24460
24461
# File 'lib/aws-sdk-quicksight/types.rb', line 24456

class InlineCustomInstruction < Struct.new(
  :instruction_text,
  :uploaded_document_metadata)
  SENSITIVE = [:instruction_text]
  include Aws::Structure
end