Class: Aws::QuickSight::Types::InputColumn

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Metadata for a column that is used as the input of a transform operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

A unique identifier for the input column.

Returns:

  • (String)


24044
24045
24046
24047
24048
24049
24050
24051
# File 'lib/aws-sdk-quicksight/types.rb', line 24044

class InputColumn < Struct.new(
  :name,
  :id,
  :type,
  :sub_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of this column in the underlying data source.

Returns:

  • (String)


24044
24045
24046
24047
24048
24049
24050
24051
# File 'lib/aws-sdk-quicksight/types.rb', line 24044

class InputColumn < Struct.new(
  :name,
  :id,
  :type,
  :sub_type)
  SENSITIVE = []
  include Aws::Structure
end

#sub_typeString

The sub data type of the column. Sub types are only available for decimal columns that are part of a SPICE dataset.

Returns:

  • (String)


24044
24045
24046
24047
24048
24049
24050
24051
# File 'lib/aws-sdk-quicksight/types.rb', line 24044

class InputColumn < Struct.new(
  :name,
  :id,
  :type,
  :sub_type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The data type of the column.

Note: ‘SEMISTRUCT` represents Athena’s map, row, and struct data types. It is supported when using the new data preparation experience.

Returns:

  • (String)


24044
24045
24046
24047
24048
24049
24050
24051
# File 'lib/aws-sdk-quicksight/types.rb', line 24044

class InputColumn < Struct.new(
  :name,
  :id,
  :type,
  :sub_type)
  SENSITIVE = []
  include Aws::Structure
end