Class: Aws::QuickSight::Types::JoinOperation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A transform operation that combines data from two sources based on specified join conditions.

Constant Summary collapse

SENSITIVE =
[:on_clause]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

Alias for this operation.

Returns:

  • (String)


22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#left_operandTypes::TransformOperationSource

The left operand for the join operation.



22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#left_operand_propertiesTypes::JoinOperandProperties

Properties that control how the left operand’s columns are handled in the join result.



22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#on_clauseString

The join condition that specifies how to match rows between the left and right operands.

Returns:

  • (String)


22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#right_operandTypes::TransformOperationSource

The right operand for the join operation.



22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#right_operand_propertiesTypes::JoinOperandProperties

Properties that control how the right operand’s columns are handled in the join result.



22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end

#typeString

The type of join to perform, such as ‘INNER`, `LEFT`, `RIGHT`, or `OUTER`.

Returns:

  • (String)


22763
22764
22765
22766
22767
22768
22769
22770
22771
22772
22773
# File 'lib/aws-sdk-quicksight/types.rb', line 22763

class JoinOperation < Struct.new(
  :alias,
  :left_operand,
  :right_operand,
  :type,
  :on_clause,
  :left_operand_properties,
  :right_operand_properties)
  SENSITIVE = [:on_clause]
  include Aws::Structure
end