Class: Aws::QuickSight::Types::KnowledgeBase
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::KnowledgeBase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A knowledge base resource that provides data from connected sources for AI-powered experiences in Amazon QuickSight.
Constant Summary collapse
- SENSITIVE =
[:knowledge_base_configuration, :primary_owner_username]
Instance Attribute Summary collapse
-
#access_control_configuration ⇒ Types::AccessControlConfiguration
The access control configuration for the knowledge base.
-
#created_at ⇒ Time
The date and time that the knowledge base was created.
-
#data_source_arn ⇒ String
The ARN of the data source associated with the knowledge base.
-
#description ⇒ String
The description of the knowledge base.
-
#document_count ⇒ Integer
The number of documents in the knowledge base.
-
#first_completed_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the first completed ingestion for the knowledge base.
-
#first_incomplete_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the first incomplete ingestion for the knowledge base.
-
#is_email_notification_opted_for_ingestion_failures ⇒ Boolean
Specifies whether email notifications are enabled for ingestion failures.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
The configuration settings for the knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
-
#knowledge_base_size_bytes ⇒ Integer
The size of the knowledge base in bytes.
-
#latest_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the most recent ingestion for the knowledge base.
-
#media_extraction_configuration ⇒ Types::MediaExtractionConfiguration
The media extraction configuration for the knowledge base.
-
#name ⇒ String
The name of the knowledge base.
-
#primary_owner_arn ⇒ String
The ARN of the primary owner of the knowledge base.
-
#primary_owner_username ⇒ String
The username of the primary owner of the knowledge base.
-
#status ⇒ String
The status of the knowledge base.
-
#type ⇒ String
The type of the knowledge base.
-
#updated_at ⇒ Time
The date and time that the knowledge base was last updated.
Instance Attribute Details
#access_control_configuration ⇒ Types::AccessControlConfiguration
The access control configuration for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the knowledge base was created.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#data_source_arn ⇒ String
The ARN of the data source associated with the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#description ⇒ String
The description of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#document_count ⇒ Integer
The number of documents in the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#first_completed_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the first completed ingestion for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#first_incomplete_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the first incomplete ingestion for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#is_email_notification_opted_for_ingestion_failures ⇒ Boolean
Specifies whether email notifications are enabled for ingestion failures.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
The configuration settings for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#knowledge_base_size_bytes ⇒ Integer
The size of the knowledge base in bytes.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#latest_ingestion_summary ⇒ Types::KnowledgeBaseIngestionSummary
A summary of the most recent ingestion for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#media_extraction_configuration ⇒ Types::MediaExtractionConfiguration
The media extraction configuration for the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#name ⇒ String
The name of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#primary_owner_arn ⇒ String
The ARN of the primary owner of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#primary_owner_username ⇒ String
The username of the primary owner of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#status ⇒ String
The status of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#type ⇒ String
The type of the knowledge base.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the knowledge base was last updated.
29163 29164 29165 29166 29167 29168 29169 29170 29171 29172 29173 29174 29175 29176 29177 29178 29179 29180 29181 29182 29183 29184 29185 29186 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29163 class KnowledgeBase < Struct.new( :knowledge_base_arn, :knowledge_base_id, :name, :status, :data_source_arn, :knowledge_base_configuration, :media_extraction_configuration, :access_control_configuration, :type, :created_at, :updated_at, :description, :is_email_notification_opted_for_ingestion_failures, :first_completed_ingestion_summary, :first_incomplete_ingestion_summary, :latest_ingestion_summary, :knowledge_base_size_bytes, :document_count, :primary_owner_arn, :primary_owner_username) SENSITIVE = [:knowledge_base_configuration, :primary_owner_username] include Aws::Structure end |