Class: Aws::QuickSight::Types::LabelActionMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Maps a sensitivity label from Microsoft Purview to an enforcement action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The enforcement action to apply when content with this sensitivity label is detected. Valid values are ALLOW, BLOCK, and WARN.

Returns:

  • (String)


29365
29366
29367
29368
29369
29370
29371
# File 'lib/aws-sdk-quicksight/types.rb', line 29365

class LabelActionMapping < Struct.new(
  :label_id,
  :label_name,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#label_idString

The identifier of the sensitivity label from the DLP provider.

Returns:

  • (String)


29365
29366
29367
29368
29369
29370
29371
# File 'lib/aws-sdk-quicksight/types.rb', line 29365

class LabelActionMapping < Struct.new(
  :label_id,
  :label_name,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#label_nameString

The display name of the sensitivity label from the DLP provider.

Returns:

  • (String)


29365
29366
29367
29368
29369
29370
29371
# File 'lib/aws-sdk-quicksight/types.rb', line 29365

class LabelActionMapping < Struct.new(
  :label_id,
  :label_name,
  :action)
  SENSITIVE = []
  include Aws::Structure
end