Class: Aws::QuickSight::Types::LayerCustomAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::LayerCustomAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A layer custom action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_operations ⇒ Array<Types::LayerCustomActionOperation>
A list of ‘LayerCustomActionOperations`.
-
#custom_action_id ⇒ String
The ID of the custom action.
-
#name ⇒ String
The name of the custom action.
-
#status ⇒ String
The status of the ‘LayerCustomAction`.
-
#trigger ⇒ String
The trigger of the ‘LayerCustomAction`.
Instance Attribute Details
#action_operations ⇒ Array<Types::LayerCustomActionOperation>
A list of ‘LayerCustomActionOperations`.
This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
25022 25023 25024 25025 25026 25027 25028 25029 25030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25022 class LayerCustomAction < Struct.new( :custom_action_id, :name, :status, :trigger, :action_operations) SENSITIVE = [] include Aws::Structure end |
#custom_action_id ⇒ String
The ID of the custom action.
25022 25023 25024 25025 25026 25027 25028 25029 25030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25022 class LayerCustomAction < Struct.new( :custom_action_id, :name, :status, :trigger, :action_operations) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the custom action.
25022 25023 25024 25025 25026 25027 25028 25029 25030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25022 class LayerCustomAction < Struct.new( :custom_action_id, :name, :status, :trigger, :action_operations) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the ‘LayerCustomAction`.
25022 25023 25024 25025 25026 25027 25028 25029 25030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25022 class LayerCustomAction < Struct.new( :custom_action_id, :name, :status, :trigger, :action_operations) SENSITIVE = [] include Aws::Structure end |
#trigger ⇒ String
The trigger of the ‘LayerCustomAction`.
Valid values are defined as follows:
-
‘DATA_POINT_CLICK`: Initiates a custom action by a left pointer click on a data point.
-
‘DATA_POINT_MENU`: Initiates a custom action by right pointer click from the menu.
25022 25023 25024 25025 25026 25027 25028 25029 25030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25022 class LayerCustomAction < Struct.new( :custom_action_id, :name, :status, :trigger, :action_operations) SENSITIVE = [] include Aws::Structure end |