Class: Aws::QuickSight::Types::LimitsProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A limits profile that defines resource usage limits for Amazon Quick Sight users. Limits profiles can be assigned to users, groups, or roles to control resource consumption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The ID of the Amazon Web Services account that contains the limits profile.

Returns:

  • (String)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the limits profile.

Returns:

  • (String)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the limits profile was created.

Returns:

  • (Time)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the limits profile.

Returns:

  • (String)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier for the limits profile.

Returns:

  • (String)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

The display name of the limits profile.

Returns:

  • (String)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#resource_limitsHash<String,Types::ProfileLimitValue>

A map of resource types to their limit values.

Returns:



29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the limits profile was last updated.

Returns:

  • (Time)


29696
29697
29698
29699
29700
29701
29702
29703
29704
29705
29706
29707
# File 'lib/aws-sdk-quicksight/types.rb', line 29696

class LimitsProfile < Struct.new(
  :profile_id,
  :arn,
  :account_id,
  :profile_name,
  :description,
  :resource_limits,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end