Class: Aws::QuickSight::Types::LineChartSeriesSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::LineChartSeriesSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the presentation of a line series in the visual
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#decal_settings ⇒ Types::DecalSettings
Decal settings for a line series in ‘LineChartVisual`.
-
#line_style_settings ⇒ Types::LineChartLineStyleSettings
Line styles options for a line series in ‘LineChartVisual`.
-
#marker_style_settings ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
Instance Attribute Details
#decal_settings ⇒ Types::DecalSettings
Decal settings for a line series in ‘LineChartVisual`.
24377 24378 24379 24380 24381 24382 24383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24377 class LineChartSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings) SENSITIVE = [] include Aws::Structure end |
#line_style_settings ⇒ Types::LineChartLineStyleSettings
Line styles options for a line series in ‘LineChartVisual`.
24377 24378 24379 24380 24381 24382 24383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24377 class LineChartSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings) SENSITIVE = [] include Aws::Structure end |
#marker_style_settings ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
24377 24378 24379 24380 24381 24382 24383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24377 class LineChartSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings) SENSITIVE = [] include Aws::Structure end |