Class: Aws::QuickSight::Types::ListTopicRefreshSchedulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ListTopicRefreshSchedulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want described.
-
#topic_id ⇒ String
The ID for the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want described.
25536 25537 25538 25539 25540 25541 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25536 class ListTopicRefreshSchedulesRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
25536 25537 25538 25539 25540 25541 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25536 class ListTopicRefreshSchedulesRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |