Class: Aws::QuickSight::Types::LookbackWindow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The lookback window setup of an incremental refresh configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_nameString

The name of the lookback window column.

Returns:

  • (String)


30585
30586
30587
30588
30589
30590
30591
# File 'lib/aws-sdk-quicksight/types.rb', line 30585

class LookbackWindow < Struct.new(
  :column_name,
  :size,
  :size_unit)
  SENSITIVE = []
  include Aws::Structure
end

#sizeInteger

The lookback window column size.

Returns:

  • (Integer)


30585
30586
30587
30588
30589
30590
30591
# File 'lib/aws-sdk-quicksight/types.rb', line 30585

class LookbackWindow < Struct.new(
  :column_name,
  :size,
  :size_unit)
  SENSITIVE = []
  include Aws::Structure
end

#size_unitString

The size unit that is used for the lookback window column. Valid values for this structure are HOUR, DAY, and WEEK.

Returns:

  • (String)


30585
30586
30587
30588
30589
30590
30591
# File 'lib/aws-sdk-quicksight/types.rb', line 30585

class LookbackWindow < Struct.new(
  :column_name,
  :size,
  :size_unit)
  SENSITIVE = []
  include Aws::Structure
end