Class: Aws::QuickSight::Types::MarginStyle
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::MarginStyle
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The display options for margins around the outside edge of sheets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#show ⇒ Boolean
This Boolean value controls whether to display sheet margins.
Instance Attribute Details
#show ⇒ Boolean
This Boolean value controls whether to display sheet margins.
28118 28119 28120 28121 28122 |
# File 'lib/aws-sdk-quicksight/types.rb', line 28118 class MarginStyle < Struct.new( :show) SENSITIVE = [] include Aws::Structure end |