Class: Aws::QuickSight::Types::MicrosoftPurviewCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The credentials for Microsoft Purview DLP integration. The credentials are stored in Amazon Web Services Secrets Manager and referenced by ARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#secret_arnString

The ARN of the Amazon Web Services Secrets Manager secret that contains the Microsoft Purview OAuth credentials. The secret includes the Azure tenant ID, client ID, and client secret or certificate.

Returns:

  • (String)


33229
33230
33231
33232
33233
# File 'lib/aws-sdk-quicksight/types.rb', line 33229

class MicrosoftPurviewCredentials < Struct.new(
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end