Class: Aws::QuickSight::Types::NamedEntityDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that represents a named entity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_nameString

The name of the entity.

Returns:

  • (String)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#is_hiddenBoolean

A Boolean value that indicates whether the named entity definition is hidden.

Returns:

  • (Boolean)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#metricTypes::NamedEntityDefinitionMetric

The definition of a metric.



33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#presentation_orderInteger

The presentation order of the named entity definition.

Returns:

  • (Integer)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#property_nameString

The property name to be used for the named entity.

Returns:

  • (String)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#property_roleString

The property role. Valid values for this structure are PRIMARY and ID.

Returns:

  • (String)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#property_usageString

The property usage. Valid values for this structure are INHERIT, DIMENSION, and MEASURE.

Returns:

  • (String)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end

#rank_orderInteger

The rank order of the named entity definition.

Returns:

  • (Integer)


33365
33366
33367
33368
33369
33370
33371
33372
33373
33374
33375
33376
# File 'lib/aws-sdk-quicksight/types.rb', line 33365

class NamedEntityDefinition < Struct.new(
  :field_name,
  :property_name,
  :property_role,
  :property_usage,
  :metric,
  :rank_order,
  :presentation_order,
  :is_hidden)
  SENSITIVE = []
  include Aws::Structure
end