Class: Aws::QuickSight::Types::NumberDisplayFormatConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The options that determine the number display format configuration.

Constant Summary collapse

SENSITIVE =
[:prefix, :suffix]

Instance Attribute Summary collapse

Instance Attribute Details

#decimal_places_configurationTypes::DecimalPlacesConfiguration

The option that determines the decimal places configuration.



29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#negative_value_configurationTypes::NegativeValueConfiguration

The options that determine the negative value configuration.



29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#null_value_format_configurationTypes::NullValueFormatConfiguration

The options that determine the null value format configuration.



29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#number_scaleString

Determines the number scale value of the number format.

Returns:

  • (String)


29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#prefixString

Determines the prefix value of the number format.

Returns:

  • (String)


29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#separator_configurationTypes::NumericSeparatorConfiguration

The options that determine the numeric separator configuration.



29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end

#suffixString

Determines the suffix value of the number format.

Returns:

  • (String)


29095
29096
29097
29098
29099
29100
29101
29102
29103
29104
29105
# File 'lib/aws-sdk-quicksight/types.rb', line 29095

class NumberDisplayFormatConfiguration < Struct.new(
  :prefix,
  :suffix,
  :separator_configuration,
  :decimal_places_configuration,
  :number_scale,
  :negative_value_configuration,
  :null_value_format_configuration)
  SENSITIVE = [:prefix, :suffix]
  include Aws::Structure
end