Class: Aws::QuickSight::Types::NumericalAggregationFunction
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::NumericalAggregationFunction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Aggregation for numerical values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#percentile_aggregation ⇒ Types::PercentileAggregation
An aggregation based on the percentile of values in a dimension or measure.
-
#simple_numerical_aggregation ⇒ String
Built-in aggregation functions for numerical values.
Instance Attribute Details
#percentile_aggregation ⇒ Types::PercentileAggregation
An aggregation based on the percentile of values in a dimension or measure.
31265 31266 31267 31268 31269 31270 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31265 class NumericalAggregationFunction < Struct.new( :simple_numerical_aggregation, :percentile_aggregation) SENSITIVE = [] include Aws::Structure end |
#simple_numerical_aggregation ⇒ String
Built-in aggregation functions for numerical values.
-
SUM: The sum of a dimension or measure. -
AVERAGE: The average of a dimension or measure. -
MIN: The minimum value of a dimension or measure. -
MAX: The maximum value of a dimension or measure. -
COUNT: The count of a dimension or measure. -
DISTINCT_COUNT: The count of distinct values in a dimension or measure. -
VAR: The variance of a dimension or measure. -
VARP: The partitioned variance of a dimension or measure. -
STDEV: The standard deviation of a dimension or measure. -
STDEVP: The partitioned standard deviation of a dimension or measure. -
MEDIAN: The median value of a dimension or measure.
31265 31266 31267 31268 31269 31270 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31265 class NumericalAggregationFunction < Struct.new( :simple_numerical_aggregation, :percentile_aggregation) SENSITIVE = [] include Aws::Structure end |