Class: Aws::QuickSight::Types::OAuthClientCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::OAuthClientCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The OAuth 2.0 client credentials used for authenticating a data source connection. Use this structure to provide a client ID, client secret, and username directly instead of referencing a secret stored in Amazon Secrets Manager. This structure supports data sources that use two-legged OAuth (2LO) authentication, such as Snowflake.
Constant Summary collapse
- SENSITIVE =
[:client_id, :client_secret, :username]
Instance Attribute Summary collapse
-
#client_id ⇒ String
The client ID of the OAuth 2.0 application that is registered with the data source provider.
-
#client_secret ⇒ String
The client secret of the OAuth 2.0 application that is registered with the data source provider.
-
#username ⇒ String
The username of the account that is used for OAuth 2.0 client credentials authentication with the data source provider.
Instance Attribute Details
#client_id ⇒ String
The client ID of the OAuth 2.0 application that is registered with the data source provider.
28987 28988 28989 28990 28991 28992 28993 |
# File 'lib/aws-sdk-quicksight/types.rb', line 28987 class OAuthClientCredentials < Struct.new( :client_id, :client_secret, :username) SENSITIVE = [:client_id, :client_secret, :username] include Aws::Structure end |
#client_secret ⇒ String
The client secret of the OAuth 2.0 application that is registered with the data source provider.
28987 28988 28989 28990 28991 28992 28993 |
# File 'lib/aws-sdk-quicksight/types.rb', line 28987 class OAuthClientCredentials < Struct.new( :client_id, :client_secret, :username) SENSITIVE = [:client_id, :client_secret, :username] include Aws::Structure end |
#username ⇒ String
The username of the account that is used for OAuth 2.0 client credentials authentication with the data source provider.
28987 28988 28989 28990 28991 28992 28993 |
# File 'lib/aws-sdk-quicksight/types.rb', line 28987 class OAuthClientCredentials < Struct.new( :client_id, :client_secret, :username) SENSITIVE = [:client_id, :client_secret, :username] include Aws::Structure end |