Class: Aws::QuickSight::Types::OAuthParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An object that contains information needed to create a data source connection that uses OAuth client credentials. This option is available for data source connections that are made with Snowflake and Starburst.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_provider_ca_certificates_bundle_s3_uriString

The S3 URI of the identity provider’s CA certificates bundle in PEM format. Use this parameter to provide a custom CA certificate bundle for the identity provider when the default trust store does not include the required certificates.

Returns:

  • (String)


29137
29138
29139
29140
29141
29142
29143
29144
29145
# File 'lib/aws-sdk-quicksight/types.rb', line 29137

class OAuthParameters < Struct.new(
  :token_provider_url,
  :o_auth_scope,
  :identity_provider_vpc_connection_properties,
  :identity_provider_resource_uri,
  :identity_provider_ca_certificates_bundle_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_resource_uriString

The resource uri of the identity provider.

Returns:

  • (String)


29137
29138
29139
29140
29141
29142
29143
29144
29145
# File 'lib/aws-sdk-quicksight/types.rb', line 29137

class OAuthParameters < Struct.new(
  :token_provider_url,
  :o_auth_scope,
  :identity_provider_vpc_connection_properties,
  :identity_provider_resource_uri,
  :identity_provider_ca_certificates_bundle_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#identity_provider_vpc_connection_propertiesTypes::VpcConnectionProperties

VPC connection properties.



29137
29138
29139
29140
29141
29142
29143
29144
29145
# File 'lib/aws-sdk-quicksight/types.rb', line 29137

class OAuthParameters < Struct.new(
  :token_provider_url,
  :o_auth_scope,
  :identity_provider_vpc_connection_properties,
  :identity_provider_resource_uri,
  :identity_provider_ca_certificates_bundle_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#o_auth_scopeString

The OAuth scope.

Returns:

  • (String)


29137
29138
29139
29140
29141
29142
29143
29144
29145
# File 'lib/aws-sdk-quicksight/types.rb', line 29137

class OAuthParameters < Struct.new(
  :token_provider_url,
  :o_auth_scope,
  :identity_provider_vpc_connection_properties,
  :identity_provider_resource_uri,
  :identity_provider_ca_certificates_bundle_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end

#token_provider_urlString

The token endpoint URL of the identity provider.

Returns:

  • (String)


29137
29138
29139
29140
29141
29142
29143
29144
29145
# File 'lib/aws-sdk-quicksight/types.rb', line 29137

class OAuthParameters < Struct.new(
  :token_provider_url,
  :o_auth_scope,
  :identity_provider_vpc_connection_properties,
  :identity_provider_resource_uri,
  :identity_provider_ca_certificates_bundle_s3_uri)
  SENSITIVE = []
  include Aws::Structure
end