Class: Aws::QuickSight::Types::OneDriveParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The connection parameters for an OneDrive data source. Provide these parameters in the DataSourceParameters object when you create or update a data source that uses OneDrive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_typeString

The authentication type for the OneDrive data source. Valid values include:

  • TWO_LEGGED_OAUTH – Server-to-server authentication using client credentials that do not require user interaction.

  • THREE_LEGGED_OAUTH – Interactive OAuth that requires user consent.

Returns:

  • (String)


31778
31779
31780
31781
31782
31783
31784
# File 'lib/aws-sdk-quicksight/types.rb', line 31778

class OneDriveParameters < Struct.new(
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The client ID for the OneDrive data source.

Returns:

  • (String)


31778
31779
31780
31781
31782
31783
31784
# File 'lib/aws-sdk-quicksight/types.rb', line 31778

class OneDriveParameters < Struct.new(
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_idString

The tenant ID for the OneDrive data source.

Returns:

  • (String)


31778
31779
31780
31781
31782
31783
31784
# File 'lib/aws-sdk-quicksight/types.rb', line 31778

class OneDriveParameters < Struct.new(
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end