Class: Aws::QuickSight::Types::OracleParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::OracleParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The parameters for Oracle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database ⇒ String
The database.
-
#host ⇒ String
An Oracle host.
-
#port ⇒ Integer
The port.
-
#use_service_name ⇒ Boolean
A Boolean value that indicates whether the
Databaseuses a service name or an SID.
Instance Attribute Details
#database ⇒ String
The database.
34342 34343 34344 34345 34346 34347 34348 34349 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34342 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#host ⇒ String
An Oracle host.
34342 34343 34344 34345 34346 34347 34348 34349 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34342 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port.
34342 34343 34344 34345 34346 34347 34348 34349 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34342 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#use_service_name ⇒ Boolean
A Boolean value that indicates whether the Database uses a service
name or an SID. If this value is left blank, the default value is
SID. If this value is set to false, the value is SID.
34342 34343 34344 34345 34346 34347 34348 34349 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34342 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |