Class: Aws::QuickSight::Types::ParameterSelectableValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A list of selectable values that are used in a control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The column identifier that fetches values from the data set.



31272
31273
31274
31275
31276
31277
# File 'lib/aws-sdk-quicksight/types.rb', line 31272

class ParameterSelectableValues < Struct.new(
  :values,
  :link_to_data_set_column)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

The values that are used in ‘ParameterSelectableValues`.

Returns:

  • (Array<String>)


31272
31273
31274
31275
31276
31277
# File 'lib/aws-sdk-quicksight/types.rb', line 31272

class ParameterSelectableValues < Struct.new(
  :values,
  :link_to_data_set_column)
  SENSITIVE = []
  include Aws::Structure
end