Class: Aws::QuickSight::Types::ParameterTextAreaControl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A control to display a text box that is used to enter multiple entries.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#control_title_format_textTypes::ControlTitleFormatText

The title text format configuration for the control.



29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#delimiterString

The delimiter that is used to separate the lines in text.

Returns:

  • (String)


29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#display_optionsTypes::TextAreaControlDisplayOptions

The display options of a control.



29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_control_idString

The ID of the ‘ParameterTextAreaControl`.

Returns:

  • (String)


29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#source_parameter_nameString

The source parameter name of the ‘ParameterTextAreaControl`.

Returns:

  • (String)


29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the ‘ParameterTextAreaControl`.

Returns:

  • (String)


29719
29720
29721
29722
29723
29724
29725
29726
29727
29728
# File 'lib/aws-sdk-quicksight/types.rb', line 29719

class ParameterTextAreaControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :delimiter,
  :display_options,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end