Class: Aws::QuickSight::Types::Parameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A list of Quick Sight parameters and the list’s override values.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#date_time_parametersArray<Types::DateTimeParameter>

The parameters that have a data type of date-time.

Returns:



28436
28437
28438
28439
28440
28441
28442
28443
# File 'lib/aws-sdk-quicksight/types.rb', line 28436

class Parameters < Struct.new(
  :string_parameters,
  :integer_parameters,
  :decimal_parameters,
  :date_time_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#decimal_parametersArray<Types::DecimalParameter>

The parameters that have a data type of decimal.

Returns:



28436
28437
28438
28439
28440
28441
28442
28443
# File 'lib/aws-sdk-quicksight/types.rb', line 28436

class Parameters < Struct.new(
  :string_parameters,
  :integer_parameters,
  :decimal_parameters,
  :date_time_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#integer_parametersArray<Types::IntegerParameter>

The parameters that have a data type of integer.

Returns:



28436
28437
28438
28439
28440
28441
28442
28443
# File 'lib/aws-sdk-quicksight/types.rb', line 28436

class Parameters < Struct.new(
  :string_parameters,
  :integer_parameters,
  :decimal_parameters,
  :date_time_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#string_parametersArray<Types::StringParameter>

The parameters that have a data type of string.

Returns:



28436
28437
28438
28439
28440
28441
28442
28443
# File 'lib/aws-sdk-quicksight/types.rb', line 28436

class Parameters < Struct.new(
  :string_parameters,
  :integer_parameters,
  :decimal_parameters,
  :date_time_parameters)
  SENSITIVE = []
  include Aws::Structure
end