Class: Aws::QuickSight::Types::Permission
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::Permission
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that contains the permission information for one principal against one flow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<String>
A list of actions that the principal can perform against the flow.
-
#principal ⇒ String
The Amazon Resource Name (ARN) of the principal.
Instance Attribute Details
#actions ⇒ Array<String>
A list of actions that the principal can perform against the flow.
The following are the list of values to set a principal as a flow owner:
-
quicksight:PublishFlow
-
quicksight:GetFlow
-
quicksight:UpdateFlowPermissions
-
quicksight:GetFlowSession
-
quicksight:StartFlowSession
-
quicksight:StopFlowSession
-
quicksight:UpdateFlowSession
-
quicksight:UnpublishFlow
-
quicksight:GetFlowStages
-
quicksight:DeleteFlow
-
quicksight:DescribeFlowPermissions
-
quicksight:UpdateFlow
-
quicksight:CreatePresignedUrl
The following are the list of values to set a principal as a flow viewer:
-
quicksight:GetFlow
-
quicksight:UpdateFlowSession
-
quicksight:StartFlowSession
-
quicksight:StopFlowSession
-
quicksight:GetFlowSession
-
quicksight:CreatePresignedUrl
-
quicksight:GetFlowStages
29883 29884 29885 29886 29887 29888 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29883 class Permission < Struct.new( :actions, :principal) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
The Amazon Resource Name (ARN) of the principal. This can be an Amazon Quick user, group or namespace associated with the flow. Namespace principal can only be set as a viewer and will grant everyone in the same namespace viewer permissions.
29883 29884 29885 29886 29887 29888 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29883 class Permission < Struct.new( :actions, :principal) SENSITIVE = [] include Aws::Structure end |