Class: Aws::QuickSight::Types::PhysicalTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PhysicalTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A view of a data source that contains information about the shape of the data in the underlying source. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_sql ⇒ Types::CustomSql
A physical table type built from the results of the custom SQL query.
-
#file_source ⇒ Types::FileSource
A physical table type for a file data source.
-
#relational_table ⇒ Types::RelationalTable
A physical table type for relational data sources.
-
#s3_source ⇒ Types::S3Source
A physical table type for an S3 data source.
-
#saa_s_table ⇒ Types::SaaSTable
A physical table type for Software-as-a-Service (SaaS) sources.
Instance Attribute Details
#custom_sql ⇒ Types::CustomSql
A physical table type built from the results of the custom SQL query.
33836 33837 33838 33839 33840 33841 33842 33843 33844 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33836 class PhysicalTable < Struct.new( :relational_table, :custom_sql, :s3_source, :saa_s_table, :file_source) SENSITIVE = [] include Aws::Structure end |
#file_source ⇒ Types::FileSource
A physical table type for a file data source.
33836 33837 33838 33839 33840 33841 33842 33843 33844 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33836 class PhysicalTable < Struct.new( :relational_table, :custom_sql, :s3_source, :saa_s_table, :file_source) SENSITIVE = [] include Aws::Structure end |
#relational_table ⇒ Types::RelationalTable
A physical table type for relational data sources.
33836 33837 33838 33839 33840 33841 33842 33843 33844 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33836 class PhysicalTable < Struct.new( :relational_table, :custom_sql, :s3_source, :saa_s_table, :file_source) SENSITIVE = [] include Aws::Structure end |
#s3_source ⇒ Types::S3Source
A physical table type for an S3 data source.
33836 33837 33838 33839 33840 33841 33842 33843 33844 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33836 class PhysicalTable < Struct.new( :relational_table, :custom_sql, :s3_source, :saa_s_table, :file_source) SENSITIVE = [] include Aws::Structure end |
#saa_s_table ⇒ Types::SaaSTable
A physical table type for Software-as-a-Service (SaaS) sources.
33836 33837 33838 33839 33840 33841 33842 33843 33844 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33836 class PhysicalTable < Struct.new( :relational_table, :custom_sql, :s3_source, :saa_s_table, :file_source) SENSITIVE = [] include Aws::Structure end |