Class: Aws::QuickSight::Types::PivotOperation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A transform operation that pivots data by converting row values into columns.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

Alias for this operation.

Returns:

  • (String)


32698
32699
32700
32701
32702
32703
32704
32705
32706
# File 'lib/aws-sdk-quicksight/types.rb', line 32698

class PivotOperation < Struct.new(
  :alias,
  :source,
  :group_by_column_names,
  :value_column_configuration,
  :pivot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#group_by_column_namesArray<String>

The list of column names to group by when performing the pivot operation.

Returns:

  • (Array<String>)


32698
32699
32700
32701
32702
32703
32704
32705
32706
# File 'lib/aws-sdk-quicksight/types.rb', line 32698

class PivotOperation < Struct.new(
  :alias,
  :source,
  :group_by_column_names,
  :value_column_configuration,
  :pivot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pivot_configurationTypes::PivotConfiguration

Configuration that specifies which labels to pivot and how to structure the resulting columns.



32698
32699
32700
32701
32702
32703
32704
32705
32706
# File 'lib/aws-sdk-quicksight/types.rb', line 32698

class PivotOperation < Struct.new(
  :alias,
  :source,
  :group_by_column_names,
  :value_column_configuration,
  :pivot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TransformOperationSource

The source transform operation that provides input data for pivoting.



32698
32699
32700
32701
32702
32703
32704
32705
32706
# File 'lib/aws-sdk-quicksight/types.rb', line 32698

class PivotOperation < Struct.new(
  :alias,
  :source,
  :group_by_column_names,
  :value_column_configuration,
  :pivot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#value_column_configurationTypes::ValueColumnConfiguration

Configuration for how to aggregate values when multiple rows map to the same pivoted column.



32698
32699
32700
32701
32702
32703
32704
32705
32706
# File 'lib/aws-sdk-quicksight/types.rb', line 32698

class PivotOperation < Struct.new(
  :alias,
  :source,
  :group_by_column_names,
  :value_column_configuration,
  :pivot_configuration)
  SENSITIVE = []
  include Aws::Structure
end