Class: Aws::QuickSight::Types::PivotTableConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PivotTableConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration for a PivotTableVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_customization_visual_options ⇒ Types::DashboardCustomizationVisualOptions
The options that define customizations available to dashboard readers for a specific visual.
-
#field_options ⇒ Types::PivotTableFieldOptions
The field options for a pivot table visual.
-
#field_wells ⇒ Types::PivotTableFieldWells
The field wells of the visual.
-
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
-
#paginated_report_options ⇒ Types::PivotTablePaginatedReportOptions
The paginated report options for a pivot table visual.
-
#sort_configuration ⇒ Types::PivotTableSortConfiguration
The sort configuration for a
PivotTableVisual. -
#table_options ⇒ Types::PivotTableOptions
The table options for a pivot table visual.
-
#tooltip ⇒ Types::TooltipOptions
The display options for the visual tooltip.
-
#total_options ⇒ Types::PivotTableTotalOptions
The total options for a pivot table visual.
Instance Attribute Details
#dashboard_customization_visual_options ⇒ Types::DashboardCustomizationVisualOptions
The options that define customizations available to dashboard readers for a specific visual
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#field_options ⇒ Types::PivotTableFieldOptions
The field options for a pivot table visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#field_wells ⇒ Types::PivotTableFieldWells
The field wells of the visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#paginated_report_options ⇒ Types::PivotTablePaginatedReportOptions
The paginated report options for a pivot table visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#sort_configuration ⇒ Types::PivotTableSortConfiguration
The sort configuration for a PivotTableVisual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#table_options ⇒ Types::PivotTableOptions
The table options for a pivot table visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#tooltip ⇒ Types::TooltipOptions
The display options for the visual tooltip.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |
#total_options ⇒ Types::PivotTableTotalOptions
The total options for a pivot table visual.
34277 34278 34279 34280 34281 34282 34283 34284 34285 34286 34287 34288 34289 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34277 class PivotTableConfiguration < Struct.new( :field_wells, :sort_configuration, :table_options, :total_options, :field_options, :paginated_report_options, :tooltip, :dashboard_customization_visual_options, :interactions) SENSITIVE = [] include Aws::Structure end |