Class: Aws::QuickSight::Types::PivotTableFieldCollapseStateOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PivotTableFieldCollapseStateOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The collapse state options for the pivot table field options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state ⇒ String
The state of the field target of a pivot table.
-
#target ⇒ Types::PivotTableFieldCollapseStateTarget
A tagged-union object that sets the collapse state.
Instance Attribute Details
#state ⇒ String
The state of the field target of a pivot table. Choose one of the following options:
-
COLLAPSED -
EXPANDED
32936 32937 32938 32939 32940 32941 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32936 class PivotTableFieldCollapseStateOption < Struct.new( :target, :state) SENSITIVE = [] include Aws::Structure end |
#target ⇒ Types::PivotTableFieldCollapseStateTarget
A tagged-union object that sets the collapse state.
32936 32937 32938 32939 32940 32941 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32936 class PivotTableFieldCollapseStateOption < Struct.new( :target, :state) SENSITIVE = [] include Aws::Structure end |