Class: Aws::QuickSight::Types::PivotTotalOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PivotTotalOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The optional configuration of totals cells in a ‘PivotTableVisual`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_label ⇒ String
The custom label string for the total cells.
-
#metric_header_cell_style ⇒ Types::TableCellStyle
The cell styling options for the total of header cells.
-
#placement ⇒ String
The placement (start, end) for the total cells.
-
#scroll_status ⇒ String
The scroll status (pinned, scrolled) for the total cells.
-
#total_aggregation_options ⇒ Array<Types::TotalAggregationOption>
The total aggregation options for each value field.
-
#total_cell_style ⇒ Types::TableCellStyle
The cell styling options for the total cells.
-
#totals_visibility ⇒ String
The visibility configuration for the total cells.
-
#value_cell_style ⇒ Types::TableCellStyle
The cell styling options for the totals of value cells.
Instance Attribute Details
#custom_label ⇒ String
The custom label string for the total cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#metric_header_cell_style ⇒ Types::TableCellStyle
The cell styling options for the total of header cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ String
The placement (start, end) for the total cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#scroll_status ⇒ String
The scroll status (pinned, scrolled) for the total cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#total_aggregation_options ⇒ Array<Types::TotalAggregationOption>
The total aggregation options for each value field.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#total_cell_style ⇒ Types::TableCellStyle
The cell styling options for the total cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#totals_visibility ⇒ String
The visibility configuration for the total cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |
#value_cell_style ⇒ Types::TableCellStyle
The cell styling options for the totals of value cells.
32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32587 class PivotTotalOptions < Struct.new( :totals_visibility, :placement, :scroll_status, :custom_label, :total_cell_style, :value_cell_style, :metric_header_cell_style, :total_aggregation_options) SENSITIVE = [] include Aws::Structure end |