Class: Aws::QuickSight::Types::PivotedLabel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies a label value to be pivoted into a separate column, including the new column name and identifier.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#label_nameString

The label value from the source data to be pivoted.

Returns:

  • (String)


29626
29627
29628
29629
29630
29631
29632
# File 'lib/aws-sdk-quicksight/types.rb', line 29626

class PivotedLabel < Struct.new(
  :label_name,
  :new_column_name,
  :new_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#new_column_idString

A unique identifier for the new column created from this pivoted label.

Returns:

  • (String)


29626
29627
29628
29629
29630
29631
29632
# File 'lib/aws-sdk-quicksight/types.rb', line 29626

class PivotedLabel < Struct.new(
  :label_name,
  :new_column_name,
  :new_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#new_column_nameString

The name for the new column created from this pivoted label.

Returns:

  • (String)


29626
29627
29628
29629
29630
29631
29632
# File 'lib/aws-sdk-quicksight/types.rb', line 29626

class PivotedLabel < Struct.new(
  :label_name,
  :new_column_name,
  :new_column_id)
  SENSITIVE = []
  include Aws::Structure
end