Class: Aws::QuickSight::Types::ProviderConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Note:

ProviderConfig is a union - when making an API calls you must set exactly one of the members.

Note:

ProviderConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProviderConfig corresponding to the set member.

The provider-specific configuration for a DLP integration. This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

Defined Under Namespace

Classes: MicrosoftPurview, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#microsoft_purviewTypes::MicrosoftPurviewProviderConfig

The configuration for a Microsoft Purview DLP integration.



36573
36574
36575
36576
36577
36578
36579
36580
36581
36582
# File 'lib/aws-sdk-quicksight/types.rb', line 36573

class ProviderConfig < Struct.new(
  :microsoft_purview,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MicrosoftPurview < ProviderConfig; end
  class Unknown < ProviderConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



36573
36574
36575
# File 'lib/aws-sdk-quicksight/types.rb', line 36573

def unknown
  @unknown
end