Class: Aws::QuickSight::Types::QDataKey
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::QDataKey
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that contains information about the ‘QDataKey`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#q_data_key_arn ⇒ String
The ARN of the KMS key that is registered to a Quick Sight account for encryption and decryption use as a ‘QDataKey`.
-
#q_data_key_type ⇒ String
The type of ‘QDataKey`.
Instance Attribute Details
#q_data_key_arn ⇒ String
The ARN of the KMS key that is registered to a Quick Sight account for encryption and decryption use as a ‘QDataKey`.
30100 30101 30102 30103 30104 30105 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30100 class QDataKey < Struct.new( :q_data_key_arn, :q_data_key_type) SENSITIVE = [] include Aws::Structure end |