Class: Aws::QuickSight::Types::ReadAuthConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ReadAuthConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Read-only authentication configuration containing non-sensitive authentication details for action connectors.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_metadata ⇒ Types::ReadAuthenticationMetadata
The authentication metadata containing configuration details specific to the authentication type.
-
#authentication_type ⇒ String
The type of authentication being used (BASIC, API_KEY, OAUTH2_CLIENT_CREDENTIALS, or OAUTH2_AUTHORIZATION_CODE).
Instance Attribute Details
#authentication_metadata ⇒ Types::ReadAuthenticationMetadata
The authentication metadata containing configuration details specific to the authentication type.
31850 31851 31852 31853 31854 31855 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31850 class ReadAuthConfig < Struct.new( :authentication_type, :authentication_metadata) SENSITIVE = [] include Aws::Structure end |
#authentication_type ⇒ String
The type of authentication being used (BASIC, API_KEY, OAUTH2_CLIENT_CREDENTIALS, or OAUTH2_AUTHORIZATION_CODE).
31850 31851 31852 31853 31854 31855 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31850 class ReadAuthConfig < Struct.new( :authentication_type, :authentication_metadata) SENSITIVE = [] include Aws::Structure end |