Class: Aws::QuickSight::Types::ReadAuthorizationCodeGrantCredentialsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ReadAuthorizationCodeGrantCredentialsDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
ReadAuthorizationCodeGrantCredentialsDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReadAuthorizationCodeGrantCredentialsDetails corresponding to the set member.
Read-only credentials details for OAuth2 authorization code grant flow, containing non-sensitive configuration information.
Direct Known Subclasses
Defined Under Namespace
Classes: ReadAuthorizationCodeGrantDetails, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#read_authorization_code_grant_details ⇒ Types::ReadAuthorizationCodeGrantDetails
The read-only authorization code grant configuration details.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#read_authorization_code_grant_details ⇒ Types::ReadAuthorizationCodeGrantDetails
The read-only authorization code grant configuration details.
33562 33563 33564 33565 33566 33567 33568 33569 33570 33571 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33562 class ReadAuthorizationCodeGrantCredentialsDetails < Struct.new( :read_authorization_code_grant_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ReadAuthorizationCodeGrantDetails < ReadAuthorizationCodeGrantCredentialsDetails; end class Unknown < ReadAuthorizationCodeGrantCredentialsDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
33562 33563 33564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33562 def unknown @unknown end |