Class: Aws::QuickSight::Types::ReadAuthorizationCodeGrantDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Read-only configuration details for OAuth2 authorization code grant flow, including endpoints and client information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorization_endpointString

The authorization server endpoint used to obtain authorization codes from the resource owner.

Returns:

  • (String)


30600
30601
30602
30603
30604
30605
30606
# File 'lib/aws-sdk-quicksight/types.rb', line 30600

class ReadAuthorizationCodeGrantDetails < Struct.new(
  :client_id,
  :token_endpoint,
  :authorization_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The client identifier for the OAuth2 authorization code grant flow.

Returns:

  • (String)


30600
30601
30602
30603
30604
30605
30606
# File 'lib/aws-sdk-quicksight/types.rb', line 30600

class ReadAuthorizationCodeGrantDetails < Struct.new(
  :client_id,
  :token_endpoint,
  :authorization_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#token_endpointString

The authorization server endpoint used to obtain access tokens via the authorization code grant flow.

Returns:

  • (String)


30600
30601
30602
30603
30604
30605
30606
# File 'lib/aws-sdk-quicksight/types.rb', line 30600

class ReadAuthorizationCodeGrantDetails < Struct.new(
  :client_id,
  :token_endpoint,
  :authorization_endpoint)
  SENSITIVE = []
  include Aws::Structure
end