Class: Aws::QuickSight::Types::ReadAuthorizationCodeGrantMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ReadAuthorizationCodeGrantMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Read-only metadata for OAuth2 authorization code grant authentication configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization_code_grant_credentials_source ⇒ String
The source of credentials for the authorization code grant flow.
-
#base_endpoint ⇒ String
The base endpoint URL for the OAuth2 authorization code grant flow.
-
#read_authorization_code_grant_credentials_details ⇒ Types::ReadAuthorizationCodeGrantCredentialsDetails
The read-only credentials details for the authorization code grant flow.
-
#redirect_url ⇒ String
The redirect URL where the authorization server will send the user after authorization.
Instance Attribute Details
#authorization_code_grant_credentials_source ⇒ String
The source of credentials for the authorization code grant flow.
30631 30632 30633 30634 30635 30636 30637 30638 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30631 class ReadAuthorizationCodeGrantMetadata < Struct.new( :base_endpoint, :redirect_url, :read_authorization_code_grant_credentials_details, :authorization_code_grant_credentials_source) SENSITIVE = [] include Aws::Structure end |
#base_endpoint ⇒ String
The base endpoint URL for the OAuth2 authorization code grant flow.
30631 30632 30633 30634 30635 30636 30637 30638 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30631 class ReadAuthorizationCodeGrantMetadata < Struct.new( :base_endpoint, :redirect_url, :read_authorization_code_grant_credentials_details, :authorization_code_grant_credentials_source) SENSITIVE = [] include Aws::Structure end |
#read_authorization_code_grant_credentials_details ⇒ Types::ReadAuthorizationCodeGrantCredentialsDetails
The read-only credentials details for the authorization code grant flow.
30631 30632 30633 30634 30635 30636 30637 30638 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30631 class ReadAuthorizationCodeGrantMetadata < Struct.new( :base_endpoint, :redirect_url, :read_authorization_code_grant_credentials_details, :authorization_code_grant_credentials_source) SENSITIVE = [] include Aws::Structure end |
#redirect_url ⇒ String
The redirect URL where the authorization server will send the user after authorization.
30631 30632 30633 30634 30635 30636 30637 30638 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30631 class ReadAuthorizationCodeGrantMetadata < Struct.new( :base_endpoint, :redirect_url, :read_authorization_code_grant_credentials_details, :authorization_code_grant_credentials_source) SENSITIVE = [] include Aws::Structure end |