Class: Aws::QuickSight::Types::ReadClientCredentialsDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ReadClientCredentialsDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
ReadClientCredentialsDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReadClientCredentialsDetails corresponding to the set member.
Read-only details for OAuth2 client credentials, containing non-sensitive configuration information.
Direct Known Subclasses
Defined Under Namespace
Classes: ReadClientCredentialsGrantDetails, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#read_client_credentials_grant_details ⇒ Types::ReadClientCredentialsGrantDetails
The read-only client credentials grant configuration details.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#read_client_credentials_grant_details ⇒ Types::ReadClientCredentialsGrantDetails
The read-only client credentials grant configuration details.
32024 32025 32026 32027 32028 32029 32030 32031 32032 32033 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32024 class ReadClientCredentialsDetails < Struct.new( :read_client_credentials_grant_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ReadClientCredentialsGrantDetails < ReadClientCredentialsDetails; end class Unknown < ReadClientCredentialsDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
32024 32025 32026 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32024 def unknown @unknown end |