Class: Aws::QuickSight::Types::RedshiftParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The parameters for Amazon Redshift. The ClusterId field can be blank if Host and Port are both set. The Host and Port fields can be blank if the ClusterId field is set.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idString

Cluster ID. This field can be blank if the Host and Port are provided.

Returns:

  • (String)


37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

Database.

Returns:

  • (String)


37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#hostString

Host. This field can be blank if ClusterId is provided.

Returns:

  • (String)


37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#iam_parametersTypes::RedshiftIAMParameters

An optional parameter that uses IAM authentication to grant Quick Sight access to your cluster. This parameter can be used instead of DataSourceCredentials.



37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_configurationTypes::IdentityCenterConfiguration

An optional parameter that configures IAM Identity Center authentication to grant Quick Sight access to your cluster.

This parameter can only be specified if your Quick Sight account is configured with IAM Identity Center.



37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

Port. This field can be blank if the ClusterId is provided.

Returns:

  • (Integer)


37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
# File 'lib/aws-sdk-quicksight/types.rb', line 37453

class RedshiftParameters < Struct.new(
  :host,
  :port,
  :database,
  :cluster_id,
  :iam_parameters,
  :identity_center_configuration)
  SENSITIVE = []
  include Aws::Structure
end