Class: Aws::QuickSight::Types::ReferenceLineLabelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ReferenceLineLabelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The label configuration of a reference line.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_label_configuration ⇒ Types::ReferenceLineCustomLabelConfiguration
The custom label configuration of the label in a reference line.
-
#font_color ⇒ String
The font color configuration of the label in a reference line.
-
#font_configuration ⇒ Types::FontConfiguration
The font configuration of the label in a reference line.
-
#horizontal_position ⇒ String
The horizontal position configuration of the label in a reference line.
-
#value_label_configuration ⇒ Types::ReferenceLineValueLabelConfiguration
The value label configuration of the label in a reference line.
-
#vertical_position ⇒ String
The vertical position configuration of the label in a reference line.
Instance Attribute Details
#custom_label_configuration ⇒ Types::ReferenceLineCustomLabelConfiguration
The custom label configuration of the label in a reference line.
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |
#font_color ⇒ String
The font color configuration of the label in a reference line.
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |
#font_configuration ⇒ Types::FontConfiguration
The font configuration of the label in a reference line.
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |
#horizontal_position ⇒ String
The horizontal position configuration of the label in a reference line. Choose one of the following options:
-
‘LEFT`
-
‘CENTER`
-
‘RIGHT`
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |
#value_label_configuration ⇒ Types::ReferenceLineValueLabelConfiguration
The value label configuration of the label in a reference line.
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |
#vertical_position ⇒ String
The vertical position configuration of the label in a reference line. Choose one of the following options:
-
‘ABOVE`
-
‘BELOW`
32913 32914 32915 32916 32917 32918 32919 32920 32921 32922 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32913 class ReferenceLineLabelConfiguration < Struct.new( :value_label_configuration, :custom_label_configuration, :font_configuration, :font_color, :horizontal_position, :vertical_position) SENSITIVE = [] include Aws::Structure end |