Class: Aws::QuickSight::Types::RefreshSchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::RefreshSchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The refresh schedule of a dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the refresh schedule.
-
#refresh_type ⇒ String
The type of refresh that a datset undergoes.
-
#schedule_frequency ⇒ Types::RefreshFrequency
The frequency for the refresh schedule.
-
#schedule_id ⇒ String
An identifier for the refresh schedule.
-
#start_after_date_time ⇒ Time
Time after which the refresh schedule can be started, expressed in
YYYY-MM-DDTHH:MM:SSformat.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the refresh schedule.
36375 36376 36377 36378 36379 36380 36381 36382 36383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36375 class RefreshSchedule < Struct.new( :schedule_id, :schedule_frequency, :start_after_date_time, :refresh_type, :arn) SENSITIVE = [] include Aws::Structure end |
#refresh_type ⇒ String
The type of refresh that a datset undergoes. Valid values are as follows:
-
FULL_REFRESH: A complete refresh of a dataset. -
INCREMENTAL_REFRESH: A partial refresh of some rows of a dataset, based on the time window specified.
For more information on full and incremental refreshes, see Refreshing SPICE data in the Amazon Quick Suite User Guide.
36375 36376 36377 36378 36379 36380 36381 36382 36383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36375 class RefreshSchedule < Struct.new( :schedule_id, :schedule_frequency, :start_after_date_time, :refresh_type, :arn) SENSITIVE = [] include Aws::Structure end |
#schedule_frequency ⇒ Types::RefreshFrequency
The frequency for the refresh schedule.
36375 36376 36377 36378 36379 36380 36381 36382 36383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36375 class RefreshSchedule < Struct.new( :schedule_id, :schedule_frequency, :start_after_date_time, :refresh_type, :arn) SENSITIVE = [] include Aws::Structure end |
#schedule_id ⇒ String
An identifier for the refresh schedule.
36375 36376 36377 36378 36379 36380 36381 36382 36383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36375 class RefreshSchedule < Struct.new( :schedule_id, :schedule_frequency, :start_after_date_time, :refresh_type, :arn) SENSITIVE = [] include Aws::Structure end |
#start_after_date_time ⇒ Time
Time after which the refresh schedule can be started, expressed in
YYYY-MM-DDTHH:MM:SS format.
36375 36376 36377 36378 36379 36380 36381 36382 36383 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36375 class RefreshSchedule < Struct.new( :schedule_id, :schedule_frequency, :start_after_date_time, :refresh_type, :arn) SENSITIVE = [] include Aws::Structure end |