Class: Aws::QuickSight::Types::RestoreAnalysisResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::RestoreAnalysisResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you're restoring.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis that you're restoring.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#restoration_failed_folder_arns ⇒ Array<String>
A list of folder arns thatthe analysis failed to be restored to.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you're restoring.
36181 36182 36183 36184 36185 36186 36187 36188 36189 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36181 class RestoreAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :request_id, :restoration_failed_folder_arns) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the analysis that you're restoring.
36181 36182 36183 36184 36185 36186 36187 36188 36189 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36181 class RestoreAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :request_id, :restoration_failed_folder_arns) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
36181 36182 36183 36184 36185 36186 36187 36188 36189 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36181 class RestoreAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :request_id, :restoration_failed_folder_arns) SENSITIVE = [] include Aws::Structure end |
#restoration_failed_folder_arns ⇒ Array<String>
A list of folder arns thatthe analysis failed to be restored to.
36181 36182 36183 36184 36185 36186 36187 36188 36189 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36181 class RestoreAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :request_id, :restoration_failed_folder_arns) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
36181 36182 36183 36184 36185 36186 36187 36188 36189 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36181 class RestoreAnalysisResponse < Struct.new( :status, :arn, :analysis_id, :request_id, :restoration_failed_folder_arns) SENSITIVE = [] include Aws::Structure end |