Class: Aws::QuickSight::Types::RowLevelPermissionTagRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::RowLevelPermissionTagRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A set of rules associated with a tag.
Constant Summary collapse
- SENSITIVE =
[:match_all_value]
Instance Attribute Summary collapse
-
#column_name ⇒ String
The column name that a tag key is assigned to.
-
#match_all_value ⇒ String
A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one.
-
#tag_key ⇒ String
The unique key for a tag.
-
#tag_multi_value_delimiter ⇒ String
A string that you want to use to delimit the values when you pass the values at run time.
Instance Attribute Details
#column_name ⇒ String
The column name that a tag key is assigned to.
31616 31617 31618 31619 31620 31621 31622 31623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31616 class RowLevelPermissionTagRule < Struct.new( :tag_key, :column_name, :tag_multi_value_delimiter, :match_all_value) SENSITIVE = [:match_all_value] include Aws::Structure end |
#match_all_value ⇒ String
A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one. For example, you can use an asterisk as your match all value.
31616 31617 31618 31619 31620 31621 31622 31623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31616 class RowLevelPermissionTagRule < Struct.new( :tag_key, :column_name, :tag_multi_value_delimiter, :match_all_value) SENSITIVE = [:match_all_value] include Aws::Structure end |
#tag_key ⇒ String
The unique key for a tag.
31616 31617 31618 31619 31620 31621 31622 31623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31616 class RowLevelPermissionTagRule < Struct.new( :tag_key, :column_name, :tag_multi_value_delimiter, :match_all_value) SENSITIVE = [:match_all_value] include Aws::Structure end |
#tag_multi_value_delimiter ⇒ String
A string that you want to use to delimit the values when you pass the values at run time. For example, you can delimit the values with a comma.
31616 31617 31618 31619 31620 31621 31622 31623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31616 class RowLevelPermissionTagRule < Struct.new( :tag_key, :column_name, :tag_multi_value_delimiter, :match_all_value) SENSITIVE = [:match_all_value] include Aws::Structure end |