Class: Aws::QuickSight::Types::S3BucketConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::S3BucketConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An optional structure that contains the Amazon S3 bucket configuration that the generated snapshots are stored in. If you don't provide this information, generated snapshots are stored in the default Amazon Quick Sight bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of an existing Amazon S3 bucket where the generated snapshot artifacts are sent.
-
#bucket_prefix ⇒ String
The prefix of the Amazon S3 bucket that the generated snapshots are stored in.
-
#bucket_region ⇒ String
The region that the Amazon S3 bucket is located in.
Instance Attribute Details
#bucket_name ⇒ String
The name of an existing Amazon S3 bucket where the generated snapshot artifacts are sent.
36490 36491 36492 36493 36494 36495 36496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36490 class S3BucketConfiguration < Struct.new( :bucket_name, :bucket_prefix, :bucket_region) SENSITIVE = [] include Aws::Structure end |
#bucket_prefix ⇒ String
The prefix of the Amazon S3 bucket that the generated snapshots are stored in.
36490 36491 36492 36493 36494 36495 36496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36490 class S3BucketConfiguration < Struct.new( :bucket_name, :bucket_prefix, :bucket_region) SENSITIVE = [] include Aws::Structure end |
#bucket_region ⇒ String
The region that the Amazon S3 bucket is located in. The bucket must
be located in the same region that the StartDashboardSnapshotJob
API call is made.
36490 36491 36492 36493 36494 36495 36496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36490 class S3BucketConfiguration < Struct.new( :bucket_name, :bucket_prefix, :bucket_region) SENSITIVE = [] include Aws::Structure end |