Class: Aws::QuickSight::Types::SchedulesConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SchedulesConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The schedules configuration for an embedded Quick Sight dashboard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
The schedules configuration for an embedded Quick Sight dashboard.
Instance Attribute Details
#enabled ⇒ Boolean
The schedules configuration for an embedded Quick Sight dashboard.
35993 35994 35995 35996 35997 |
# File 'lib/aws-sdk-quicksight/types.rb', line 35993 class SchedulesConfigurations < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |