Class: Aws::QuickSight::Types::SearchActionConnectorsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID in which to search for action connectors.

Returns:

  • (String)


33022
33023
33024
33025
33026
33027
33028
33029
# File 'lib/aws-sdk-quicksight/types.rb', line 33022

class SearchActionConnectorsRequest < Struct.new(
  :aws_account_id,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::ActionConnectorSearchFilter>

The search filters to apply. You can filter by connector name, type, or user permissions. Maximum of one filter is supported.



33022
33023
33024
33025
33026
33027
33028
33029
# File 'lib/aws-sdk-quicksight/types.rb', line 33022

class SearchActionConnectorsRequest < Struct.new(
  :aws_account_id,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of action connectors to return in a single response. Valid range is 1 to 100.

Returns:

  • (Integer)


33022
33023
33024
33025
33026
33027
33028
33029
# File 'lib/aws-sdk-quicksight/types.rb', line 33022

class SearchActionConnectorsRequest < Struct.new(
  :aws_account_id,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token to retrieve the next set of results. Use the token returned from a previous call to continue searching.

Returns:

  • (String)


33022
33023
33024
33025
33026
33027
33028
33029
# File 'lib/aws-sdk-quicksight/types.rb', line 33022

class SearchActionConnectorsRequest < Struct.new(
  :aws_account_id,
  :max_results,
  :next_token,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end