Class: Aws::QuickSight::Types::SearchAgentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the agents.

Returns:

  • (String)


36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-quicksight/types.rb', line 36801

class SearchAgentsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::AgentSearchFilter>

The filters to apply when searching agents.

Returns:



36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-quicksight/types.rb', line 36801

class SearchAgentsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-quicksight/types.rb', line 36801

class SearchAgentsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/aws-sdk-quicksight/types.rb', line 36801

class SearchAgentsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end