Class: Aws::QuickSight::Types::SearchAppsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the apps to search.

Returns:

  • (String)


39854
39855
39856
39857
39858
39859
39860
39861
# File 'lib/aws-sdk-quicksight/types.rb', line 39854

class SearchAppsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::SearchAppsFilter>

The filters to apply to the search.

Returns:



39854
39855
39856
39857
39858
39859
39860
39861
# File 'lib/aws-sdk-quicksight/types.rb', line 39854

class SearchAppsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in a single request. Valid range is 1 to 100. If you don't specify a value, the default is 20.

Returns:

  • (Integer)


39854
39855
39856
39857
39858
39859
39860
39861
# File 'lib/aws-sdk-quicksight/types.rb', line 39854

class SearchAppsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


39854
39855
39856
39857
39858
39859
39860
39861
# File 'lib/aws-sdk-quicksight/types.rb', line 39854

class SearchAppsRequest < Struct.new(
  :aws_account_id,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end