Class: Aws::QuickSight::Types::SearchAppsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_summary_listArray<Types::AppSummary>

A list of app summaries that match the search criteria.

Returns:



39878
39879
39880
39881
39882
39883
39884
# File 'lib/aws-sdk-quicksight/types.rb', line 39878

class SearchAppsResponse < Struct.new(
  :app_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


39878
39879
39880
39881
39882
39883
39884
# File 'lib/aws-sdk-quicksight/types.rb', line 39878

class SearchAppsResponse < Struct.new(
  :app_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


39878
39879
39880
39881
39882
39883
39884
# File 'lib/aws-sdk-quicksight/types.rb', line 39878

class SearchAppsResponse < Struct.new(
  :app_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end