Class: Aws::QuickSight::Types::SearchDashboardsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_summary_listArray<Types::DashboardSummary>

The list of dashboards owned by the user specified in Filters in your request.

Returns:



37241
37242
37243
37244
37245
37246
37247
37248
# File 'lib/aws-sdk-quicksight/types.rb', line 37241

class SearchDashboardsResponse < Struct.new(
  :dashboard_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


37241
37242
37243
37244
37245
37246
37247
37248
# File 'lib/aws-sdk-quicksight/types.rb', line 37241

class SearchDashboardsResponse < Struct.new(
  :dashboard_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


37241
37242
37243
37244
37245
37246
37247
37248
# File 'lib/aws-sdk-quicksight/types.rb', line 37241

class SearchDashboardsResponse < Struct.new(
  :dashboard_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


37241
37242
37243
37244
37245
37246
37247
37248
# File 'lib/aws-sdk-quicksight/types.rb', line 37241

class SearchDashboardsResponse < Struct.new(
  :dashboard_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end