Class: Aws::QuickSight::Types::SearchDataSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchDataSetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_summaries ⇒ Array<Types::DataSetSummary>
A
DataSetSummariesobject that returns a summary of a dataset. -
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_set_summaries ⇒ Array<Types::DataSetSummary>
A DataSetSummaries object that returns a summary of a dataset.
37358 37359 37360 37361 37362 37363 37364 37365 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37358 class SearchDataSetsResponse < Struct.new( :data_set_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
37358 37359 37360 37361 37362 37363 37364 37365 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37358 class SearchDataSetsResponse < Struct.new( :data_set_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
37358 37359 37360 37361 37362 37363 37364 37365 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37358 class SearchDataSetsResponse < Struct.new( :data_set_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
37358 37359 37360 37361 37362 37363 37364 37365 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37358 class SearchDataSetsResponse < Struct.new( :data_set_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |