Class: Aws::QuickSight::Types::SearchDataSourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchDataSourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_summaries ⇒ Array<Types::DataSourceSummary>
A
DataSourceSummariesobject that returns a summary of a data source. -
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_source_summaries ⇒ Array<Types::DataSourceSummary>
A DataSourceSummaries object that returns a summary of a data
source.
37378 37379 37380 37381 37382 37383 37384 37385 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37378 class SearchDataSourcesResponse < Struct.new( :data_source_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
37378 37379 37380 37381 37382 37383 37384 37385 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37378 class SearchDataSourcesResponse < Struct.new( :data_source_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
37378 37379 37380 37381 37382 37383 37384 37385 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37378 class SearchDataSourcesResponse < Struct.new( :data_source_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
37378 37379 37380 37381 37382 37383 37384 37385 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37378 class SearchDataSourcesResponse < Struct.new( :data_source_summaries, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |