Class: Aws::QuickSight::Types::SearchFlowsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where you are searching for flows from.

Returns:

  • (String)


34588
34589
34590
34591
34592
34593
34594
34595
# File 'lib/aws-sdk-quicksight/types.rb', line 34588

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::SearchFlowsFilter>

The filters applied to the search when searching for flows in the Amazon Web Services account.

Returns:



34588
34589
34590
34591
34592
34593
34594
34595
# File 'lib/aws-sdk-quicksight/types.rb', line 34588

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned per request.

Returns:

  • (Integer)


34588
34589
34590
34591
34592
34593
34594
34595
# File 'lib/aws-sdk-quicksight/types.rb', line 34588

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next set of results, or null if you want to retrieve the first set.

Returns:

  • (String)


34588
34589
34590
34591
34592
34593
34594
34595
# File 'lib/aws-sdk-quicksight/types.rb', line 34588

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end