Class: Aws::QuickSight::Types::SearchFlowsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchFlowsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_summary_list ⇒ Array<Types::FlowSummary>
The list of flows found against the search.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#flow_summary_list ⇒ Array<Types::FlowSummary>
The list of flows found against the search.
36456 36457 36458 36459 36460 36461 36462 36463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36456 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
36456 36457 36458 36459 36460 36461 36462 36463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36456 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
36456 36457 36458 36459 36460 36461 36462 36463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36456 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
36456 36457 36458 36459 36460 36461 36462 36463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36456 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |