Class: Aws::QuickSight::Types::SearchFoldersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#folder_summary_listArray<Types::FolderSummary>

A structure that contains all of the folders in the Amazon Web Services account. This structure provides basic information about the folders.

Returns:



35347
35348
35349
35350
35351
35352
35353
35354
# File 'lib/aws-sdk-quicksight/types.rb', line 35347

class SearchFoldersResponse < Struct.new(
  :status,
  :folder_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


35347
35348
35349
35350
35351
35352
35353
35354
# File 'lib/aws-sdk-quicksight/types.rb', line 35347

class SearchFoldersResponse < Struct.new(
  :status,
  :folder_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


35347
35348
35349
35350
35351
35352
35353
35354
# File 'lib/aws-sdk-quicksight/types.rb', line 35347

class SearchFoldersResponse < Struct.new(
  :status,
  :folder_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


35347
35348
35349
35350
35351
35352
35353
35354
# File 'lib/aws-sdk-quicksight/types.rb', line 35347

class SearchFoldersResponse < Struct.new(
  :status,
  :folder_summary_list,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end