Class: Aws::QuickSight::Types::SearchKnowledgeBasesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the knowledge base.

Returns:

  • (String)


37318
37319
37320
37321
37322
37323
37324
37325
37326
# File 'lib/aws-sdk-quicksight/types.rb', line 37318

class SearchKnowledgeBasesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::KnowledgeBaseSearchFilter>

The filters to apply when searching knowledge bases.



37318
37319
37320
37321
37322
37323
37324
37325
37326
# File 'lib/aws-sdk-quicksight/types.rb', line 37318

class SearchKnowledgeBasesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


37318
37319
37320
37321
37322
37323
37324
37325
37326
# File 'lib/aws-sdk-quicksight/types.rb', line 37318

class SearchKnowledgeBasesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


37318
37319
37320
37321
37322
37323
37324
37325
37326
# File 'lib/aws-sdk-quicksight/types.rb', line 37318

class SearchKnowledgeBasesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byTypes::KnowledgeBaseSortBy

The sort configuration for the search results.



37318
37319
37320
37321
37322
37323
37324
37325
37326
# File 'lib/aws-sdk-quicksight/types.rb', line 37318

class SearchKnowledgeBasesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters,
  :sort_by)
  SENSITIVE = []
  include Aws::Structure
end