Class: Aws::QuickSight::Types::SearchSpacesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the spaces.

Returns:

  • (String)


37375
37376
37377
37378
37379
37380
37381
37382
# File 'lib/aws-sdk-quicksight/types.rb', line 37375

class SearchSpacesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::SpaceQuicksightSearchFilter>

The filters to apply to the search.



37375
37376
37377
37378
37379
37380
37381
37382
# File 'lib/aws-sdk-quicksight/types.rb', line 37375

class SearchSpacesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


37375
37376
37377
37378
37379
37380
37381
37382
# File 'lib/aws-sdk-quicksight/types.rb', line 37375

class SearchSpacesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


37375
37376
37377
37378
37379
37380
37381
37382
# File 'lib/aws-sdk-quicksight/types.rb', line 37375

class SearchSpacesRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end