Class: Aws::QuickSight::Types::SearchTopicsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchTopicsV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to search.
-
#filters ⇒ Array<Types::TopicSearchFilter>
The filters that you want to use to search for the topic.
-
#max_results ⇒ Integer
The maximum number of results to be returned per request.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to search.
38924 38925 38926 38927 38928 38929 38930 38931 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38924 class SearchTopicsV2Request < Struct.new( :aws_account_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::TopicSearchFilter>
The filters that you want to use to search for the topic.
38924 38925 38926 38927 38928 38929 38930 38931 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38924 class SearchTopicsV2Request < Struct.new( :aws_account_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned per request.
38924 38925 38926 38927 38928 38929 38930 38931 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38924 class SearchTopicsV2Request < Struct.new( :aws_account_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
38924 38925 38926 38927 38928 38929 38930 38931 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38924 class SearchTopicsV2Request < Struct.new( :aws_account_id, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |