Class: Aws::QuickSight::Types::SearchTopicsV2Response

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


38953
38954
38955
38956
38957
38958
38959
38960
# File 'lib/aws-sdk-quicksight/types.rb', line 38953

class SearchTopicsV2Response < Struct.new(
  :topic_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


38953
38954
38955
38956
38957
38958
38959
38960
# File 'lib/aws-sdk-quicksight/types.rb', line 38953

class SearchTopicsV2Response < Struct.new(
  :topic_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


38953
38954
38955
38956
38957
38958
38959
38960
# File 'lib/aws-sdk-quicksight/types.rb', line 38953

class SearchTopicsV2Response < Struct.new(
  :topic_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_summary_listArray<Types::TopicV2Summary>

A list of topic summaries that is returned by the search topic request.

Returns:



38953
38954
38955
38956
38957
38958
38959
38960
# File 'lib/aws-sdk-quicksight/types.rb', line 38953

class SearchTopicsV2Response < Struct.new(
  :topic_summary_list,
  :next_token,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end