Class: Aws::QuickSight::Types::SemanticTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A semantic table that represents the final analytical structure of the data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

Alias for the semantic table.

Returns:

  • (String)


35288
35289
35290
35291
35292
35293
35294
# File 'lib/aws-sdk-quicksight/types.rb', line 35288

class SemanticTable < Struct.new(
  :alias,
  :destination_table_id,
  :row_level_permission_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#destination_table_idString

The identifier of the destination table from data preparation that provides data to this semantic table.

Returns:

  • (String)


35288
35289
35290
35291
35292
35293
35294
# File 'lib/aws-sdk-quicksight/types.rb', line 35288

class SemanticTable < Struct.new(
  :alias,
  :destination_table_id,
  :row_level_permission_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#row_level_permission_configurationTypes::RowLevelPermissionConfiguration

Configuration for row level security that control data access for this semantic table.



35288
35289
35290
35291
35292
35293
35294
# File 'lib/aws-sdk-quicksight/types.rb', line 35288

class SemanticTable < Struct.new(
  :alias,
  :destination_table_id,
  :row_level_permission_configuration)
  SENSITIVE = []
  include Aws::Structure
end