Class: Aws::QuickSight::Types::ShapeConditionalFormat
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ShapeConditionalFormat
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The shape conditional formatting of a filled map visual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#background_color ⇒ Types::ConditionalFormattingColor
The conditional formatting for the shape background color of a filled map visual.
Instance Attribute Details
#background_color ⇒ Types::ConditionalFormattingColor
The conditional formatting for the shape background color of a filled map visual.
34045 34046 34047 34048 34049 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34045 class ShapeConditionalFormat < Struct.new( :background_color) SENSITIVE = [] include Aws::Structure end |