Class: Aws::QuickSight::Types::SharePointParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The connection parameters for a SharePoint data source. Provide these parameters in the DataSourceParameters object when you create or update a data source that uses SharePoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_typeString

The authentication type for the SharePoint data source. Valid values include:

  • TWO_LEGGED_OAUTH – Server-to-server authentication using client credentials that do not require user interaction.

  • THREE_LEGGED_OAUTH – Interactive OAuth that requires user consent.

Returns:

  • (String)


38310
38311
38312
38313
38314
38315
38316
38317
# File 'lib/aws-sdk-quicksight/types.rb', line 38310

class SharePointParameters < Struct.new(
  :share_point_domain,
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#client_idString

The client ID for the SharePoint data source.

Returns:

  • (String)


38310
38311
38312
38313
38314
38315
38316
38317
# File 'lib/aws-sdk-quicksight/types.rb', line 38310

class SharePointParameters < Struct.new(
  :share_point_domain,
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#share_point_domainString

The SharePoint domain for the data source.

Returns:

  • (String)


38310
38311
38312
38313
38314
38315
38316
38317
# File 'lib/aws-sdk-quicksight/types.rb', line 38310

class SharePointParameters < Struct.new(
  :share_point_domain,
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_idString

The tenant ID for the SharePoint data source.

Returns:

  • (String)


38310
38311
38312
38313
38314
38315
38316
38317
# File 'lib/aws-sdk-quicksight/types.rb', line 38310

class SharePointParameters < Struct.new(
  :share_point_domain,
  :tenant_id,
  :client_id,
  :auth_type)
  SENSITIVE = []
  include Aws::Structure
end