Class: Aws::QuickSight::Types::Sheet
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::Sheet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A sheet, which is an object that contains a set of visuals that are viewed together on one page in Quick Sight. Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#images ⇒ Array<Types::SheetImage>
A list of images on a sheet.
-
#name ⇒ String
The name of a sheet.
-
#sheet_id ⇒ String
The unique identifier associated with a sheet.
Instance Attribute Details
#images ⇒ Array<Types::SheetImage>
A list of images on a sheet.
41129 41130 41131 41132 41133 41134 41135 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41129 class Sheet < Struct.new( :sheet_id, :name, :images) SENSITIVE = [] include Aws::Structure end |