Class: Aws::QuickSight::Types::SheetDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SheetDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report. Every analysis and dashboard must contain at least one sheet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The layout content type of the sheet.
-
#custom_action_defaults ⇒ Types::VisualCustomActionDefaults
A list of visual custom actions for the sheet.
-
#description ⇒ String
A description of the sheet.
-
#filter_controls ⇒ Array<Types::FilterControl>
The list of filter controls that are on a sheet.
-
#images ⇒ Array<Types::SheetImage>
A list of images on a sheet.
-
#layouts ⇒ Array<Types::Layout>
Layouts define how the components of a sheet are arranged.
-
#name ⇒ String
The name of the sheet.
-
#parameter_controls ⇒ Array<Types::ParameterControl>
The list of parameter controls that are on a sheet.
-
#sheet_control_layouts ⇒ Array<Types::SheetControlLayout>
The control layouts of the sheet.
-
#sheet_id ⇒ String
The unique identifier of a sheet.
-
#text_boxes ⇒ Array<Types::SheetTextBox>
The text boxes that are on a sheet.
-
#title ⇒ String
The title of the sheet.
-
#visuals ⇒ Array<Types::Visual>
A list of the visuals that are on a sheet.
Instance Attribute Details
#content_type ⇒ String
The layout content type of the sheet. Choose one of the following options:
-
PAGINATED: Creates a sheet for a paginated report. -
INTERACTIVE: Creates a sheet for an interactive dashboard.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#custom_action_defaults ⇒ Types::VisualCustomActionDefaults
A list of visual custom actions for the sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#filter_controls ⇒ Array<Types::FilterControl>
The list of filter controls that are on a sheet.
For more information, see Adding filter controls to analysis sheets in the Amazon Quick Suite User Guide.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#images ⇒ Array<Types::SheetImage>
A list of images on a sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#layouts ⇒ Array<Types::Layout>
Layouts define how the components of a sheet are arranged.
For more information, see Types of layout in the Amazon Quick Suite User Guide.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the sheet. This name is displayed on the sheet's tab in the Quick console.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#parameter_controls ⇒ Array<Types::ParameterControl>
The list of parameter controls that are on a sheet.
For more information, see Using a Control with a Parameter in Amazon Quick Sight in the Amazon Quick Suite User Guide.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#sheet_control_layouts ⇒ Array<Types::SheetControlLayout>
The control layouts of the sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#sheet_id ⇒ String
The unique identifier of a sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#text_boxes ⇒ Array<Types::SheetTextBox>
The text boxes that are on a sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |
#visuals ⇒ Array<Types::Visual>
A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.
38579 38580 38581 38582 38583 38584 38585 38586 38587 38588 38589 38590 38591 38592 38593 38594 38595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38579 class SheetDefinition < Struct.new( :sheet_id, :title, :description, :name, :parameter_controls, :filter_controls, :visuals, :text_boxes, :images, :layouts, :sheet_control_layouts, :content_type, :custom_action_defaults) SENSITIVE = [] include Aws::Structure end |