Class: Aws::QuickSight::Types::SheetElementRenderingRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The rendering rules of a sheet that uses a free-form layout.

Constant Summary collapse

SENSITIVE =
[:expression]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_overridesTypes::SheetElementConfigurationOverrides

The override configuration of the rendering rules of a sheet.



35714
35715
35716
35717
35718
35719
# File 'lib/aws-sdk-quicksight/types.rb', line 35714

class SheetElementRenderingRule < Struct.new(
  :expression,
  :configuration_overrides)
  SENSITIVE = [:expression]
  include Aws::Structure
end

#expressionString

The expression of the rendering rules of a sheet.

Returns:

  • (String)


35714
35715
35716
35717
35718
35719
# File 'lib/aws-sdk-quicksight/types.rb', line 35714

class SheetElementRenderingRule < Struct.new(
  :expression,
  :configuration_overrides)
  SENSITIVE = [:expression]
  include Aws::Structure
end