Class: Aws::QuickSight::Types::SheetImage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An image that is located on a sheet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::ImageCustomAction>

A list of custom actions that are configured for an image.

Returns:



34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#image_content_alt_textString

The alt text for the image.

Returns:

  • (String)


34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#interactionsTypes::ImageInteractionOptions

The general image interactions setup for an image.



34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#scalingTypes::SheetImageScalingConfiguration

Determines how the image is scaled.



34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#sheet_image_idString

The ID of the sheet image.

Returns:

  • (String)


34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::SheetImageSource

The source of the image.



34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end

#tooltipTypes::SheetImageTooltipConfiguration

The tooltip to be shown when hovering over the image.



34352
34353
34354
34355
34356
34357
34358
34359
34360
34361
34362
# File 'lib/aws-sdk-quicksight/types.rb', line 34352

class SheetImage < Struct.new(
  :sheet_image_id,
  :source,
  :scaling,
  :tooltip,
  :image_content_alt_text,
  :interactions,
  :actions)
  SENSITIVE = []
  include Aws::Structure
end