Class: Aws::QuickSight::Types::SheetVisualScopingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SheetVisualScopingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The filter that is applied to the options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scope ⇒ String
The scope of the applied entities.
-
#sheet_id ⇒ String
The selected sheet that the filter is applied to.
-
#visual_ids ⇒ Array<String>
The selected visuals that the filter is applied to.
Instance Attribute Details
#scope ⇒ String
The scope of the applied entities. Choose one of the following options:
-
ALL_VISUALS -
SELECTED_VISUALS
38907 38908 38909 38910 38911 38912 38913 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38907 class SheetVisualScopingConfiguration < Struct.new( :sheet_id, :scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |
#sheet_id ⇒ String
The selected sheet that the filter is applied to.
38907 38908 38909 38910 38911 38912 38913 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38907 class SheetVisualScopingConfiguration < Struct.new( :sheet_id, :scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |
#visual_ids ⇒ Array<String>
The selected visuals that the filter is applied to.
38907 38908 38909 38910 38911 38912 38913 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38907 class SheetVisualScopingConfiguration < Struct.new( :sheet_id, :scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |