Class: Aws::QuickSight::Types::SnapshotAnonymousUserRedacted
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SnapshotAnonymousUserRedacted
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Use this structure to redact sensitive information that you provide about an anonymous user from the snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#row_level_permission_tag_keys ⇒ Array<String>
The tag keys for the ‘RowLevelPermissionTags`.
Instance Attribute Details
#row_level_permission_tag_keys ⇒ Array<String>
The tag keys for the ‘RowLevelPermissionTags`.
36407 36408 36409 36410 36411 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36407 class SnapshotAnonymousUserRedacted < Struct.new( :row_level_permission_tag_keys) SENSITIVE = [] include Aws::Structure end |