Class: Aws::QuickSight::Types::SnapshotFileSheetSelection
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SnapshotFileSheetSelection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that contains information that identifies the snapshot that needs to be generated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#selection_scope ⇒ String
The selection scope of the visuals on a sheet of a dashboard that you are generating a snapthot of.
-
#sheet_id ⇒ String
The sheet ID of the dashboard to generate the snapshot artifact from.
-
#visual_ids ⇒ Array<String>
A structure that lists the IDs of the visuals in the selected sheet.
Instance Attribute Details
#selection_scope ⇒ String
The selection scope of the visuals on a sheet of a dashboard that you are generating a snapthot of. You can choose one of the following options.
-
‘ALL_VISUALS` - Selects all visuals that are on the sheet. This value is required if the snapshot is a PDF.
-
‘SELECTED_VISUALS` - Select the visual that you want to add to the snapshot. This value is required if the snapshot is a CSV or Excel workbook.
36532 36533 36534 36535 36536 36537 36538 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36532 class SnapshotFileSheetSelection < Struct.new( :sheet_id, :selection_scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |
#sheet_id ⇒ String
The sheet ID of the dashboard to generate the snapshot artifact from. This value is required for CSV, Excel, and PDF format types.
36532 36533 36534 36535 36536 36537 36538 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36532 class SnapshotFileSheetSelection < Struct.new( :sheet_id, :selection_scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |
#visual_ids ⇒ Array<String>
A structure that lists the IDs of the visuals in the selected sheet. Supported visual types are table, pivot table visuals. This value is required if you are generating a CSV or Excel workbook. This value supports a maximum of 1 visual ID for CSV and 5 visual IDs across up to 5 sheet selections for Excel. If you are generating an Excel workbook, the order of the visual IDs provided in this structure determines the order of the worksheets in the Excel file.
36532 36533 36534 36535 36536 36537 36538 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36532 class SnapshotFileSheetSelection < Struct.new( :sheet_id, :selection_scope, :visual_ids) SENSITIVE = [] include Aws::Structure end |