Class: Aws::QuickSight::Types::SnapshotJobResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An object that provides information on the result of a snapshot job. This object provides information about the job, the job status, and the location of the generated file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anonymous_usersArray<Types::AnonymousUserSnapshotJobResult>

A list of ‘AnonymousUserSnapshotJobResult` objects that contain information on anonymous users and their user configurations. This data provided by you when you make a `StartDashboardSnapshotJob` API call.



34950
34951
34952
34953
34954
34955
# File 'lib/aws-sdk-quicksight/types.rb', line 34950

class SnapshotJobResult < Struct.new(
  :anonymous_users,
  :registered_users)
  SENSITIVE = []
  include Aws::Structure
end

#registered_usersArray<Types::RegisteredUserSnapshotJobResult>

A list of ‘RegisteredUserSnapshotJobResult` objects that contain information about files that are requested for registered user during a `StartDashboardSnapshotJob` API call.



34950
34951
34952
34953
34954
34955
# File 'lib/aws-sdk-quicksight/types.rb', line 34950

class SnapshotJobResult < Struct.new(
  :anonymous_users,
  :registered_users)
  SENSITIVE = []
  include Aws::Structure
end