Class: Aws::QuickSight::Types::SnapshotJobS3Result

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The Amazon S3 result from the snapshot job. The result includes the DestinationConfiguration and the Amazon S3 Uri. If an error occured during the job, the result returns information on the error.

Constant Summary collapse

SENSITIVE =
[:s3_uri]

Instance Attribute Summary collapse

Instance Attribute Details

#error_infoArray<Types::SnapshotJobResultErrorInfo>

An array of error records that describe any failures that occur while the dashboard snapshot job runs.



42110
42111
42112
42113
42114
42115
42116
# File 'lib/aws-sdk-quicksight/types.rb', line 42110

class SnapshotJobS3Result < Struct.new(
  :s3_destination_configuration,
  :s3_uri,
  :error_info)
  SENSITIVE = [:s3_uri]
  include Aws::Structure
end

#s3_destination_configurationTypes::SnapshotS3DestinationConfiguration

A list of Amazon S3 bucket configurations that are provided when you make a StartDashboardSnapshotJob API call.



42110
42111
42112
42113
42114
42115
42116
# File 'lib/aws-sdk-quicksight/types.rb', line 42110

class SnapshotJobS3Result < Struct.new(
  :s3_destination_configuration,
  :s3_uri,
  :error_info)
  SENSITIVE = [:s3_uri]
  include Aws::Structure
end

#s3_uriString

The Amazon S3 Uri.

Returns:

  • (String)


42110
42111
42112
42113
42114
42115
42116
# File 'lib/aws-sdk-quicksight/types.rb', line 42110

class SnapshotJobS3Result < Struct.new(
  :s3_destination_configuration,
  :s3_uri,
  :error_info)
  SENSITIVE = [:s3_uri]
  include Aws::Structure
end