Class: Aws::QuickSight::Types::SnapshotUserConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that contains information about the users that the dashboard snapshot is generated for.

When using identity-enhanced session credentials, set the UserConfiguration request attribute to null. Otherwise, the request will be invalid.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anonymous_usersArray<Types::SnapshotAnonymousUser>

An array of records that describe the anonymous users that the dashboard snapshot is generated for.

Returns:



35054
35055
35056
35057
35058
# File 'lib/aws-sdk-quicksight/types.rb', line 35054

class SnapshotUserConfiguration < Struct.new(
  :anonymous_users)
  SENSITIVE = []
  include Aws::Structure
end