Class: Aws::QuickSight::Types::SnowflakeParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SnowflakeParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The parameters for Snowflake.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
The authentication type that you want to use for your connection.
-
#database ⇒ String
Database.
-
#database_access_control_role ⇒ String
The database access control role.
-
#host ⇒ String
Host.
-
#o_auth_parameters ⇒ Types::OAuthParameters
An object that contains information needed to create a data source connection between an Quick Sight account and Snowflake.
-
#warehouse ⇒ String
Warehouse.
Instance Attribute Details
#authentication_type ⇒ String
The authentication type that you want to use for your connection. This parameter accepts OAuth and non-OAuth authentication types.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
Database.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |
#database_access_control_role ⇒ String
The database access control role.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |
#host ⇒ String
Host.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |
#o_auth_parameters ⇒ Types::OAuthParameters
An object that contains information needed to create a data source connection between an Quick Sight account and Snowflake.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |
#warehouse ⇒ String
Warehouse.
36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36410 class SnowflakeParameters < Struct.new( :host, :database, :warehouse, :authentication_type, :database_access_control_role, :o_auth_parameters) SENSITIVE = [] include Aws::Structure end |