Class: Aws::QuickSight::Types::SpaceContributor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A contributor to an Amazon QuickSight space.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#percentageFloat

The percentage of total contributions made by the user.

Returns:

  • (Float)


39494
39495
39496
39497
39498
39499
39500
# File 'lib/aws-sdk-quicksight/types.rb', line 39494

class SpaceContributor < Struct.new(
  :user_name,
  :raw_file_size_bytes,
  :percentage)
  SENSITIVE = []
  include Aws::Structure
end

#raw_file_size_bytesInteger

The raw file size in bytes contributed by the user.

Returns:

  • (Integer)


39494
39495
39496
39497
39498
39499
39500
# File 'lib/aws-sdk-quicksight/types.rb', line 39494

class SpaceContributor < Struct.new(
  :user_name,
  :raw_file_size_bytes,
  :percentage)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The user name of the contributor.

Returns:

  • (String)


39494
39495
39496
39497
39498
39499
39500
# File 'lib/aws-sdk-quicksight/types.rb', line 39494

class SpaceContributor < Struct.new(
  :user_name,
  :raw_file_size_bytes,
  :percentage)
  SENSITIVE = []
  include Aws::Structure
end