Class: Aws::QuickSight::Types::SpaceResourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SpaceResourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A summary of a resource in a space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
-
#resource_name ⇒ String
The name of the resource.
-
#resource_type ⇒ String
The type of the resource.
-
#updated_at ⇒ Time
The date and time that the resource was last updated.
Instance Attribute Details
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
38556 38557 38558 38559 38560 38561 38562 38563 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38556 class SpaceResourceSummary < Struct.new( :resource_type, :resource_details, :resource_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The name of the resource.
38556 38557 38558 38559 38560 38561 38562 38563 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38556 class SpaceResourceSummary < Struct.new( :resource_type, :resource_details, :resource_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource.
38556 38557 38558 38559 38560 38561 38562 38563 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38556 class SpaceResourceSummary < Struct.new( :resource_type, :resource_details, :resource_name, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the resource was last updated.
38556 38557 38558 38559 38560 38561 38562 38563 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38556 class SpaceResourceSummary < Struct.new( :resource_type, :resource_details, :resource_name, :updated_at) SENSITIVE = [] include Aws::Structure end |