Class: Aws::QuickSight::Types::SpaceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SpaceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A summary of an Amazon QuickSight space.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#consumed_source_doc_count ⇒ Integer
The number of consumed source documents.
-
#consumed_source_size ⇒ Integer
The total consumed source size in bytes.
-
#created_at ⇒ Time
The date and time that the space was created.
-
#created_by ⇒ String
The user who created the space.
-
#created_by_arn ⇒ String
The ARN of the user who created the space.
-
#description ⇒ String
The description of the space.
-
#name ⇒ String
The display name of the space.
-
#resources_count ⇒ Integer
The number of resources in the space.
-
#space_arn ⇒ String
The ARN of the space.
-
#space_id ⇒ String
The ID of the space.
-
#updated_at ⇒ Time
The date and time that the space was last updated.
Instance Attribute Details
#consumed_source_doc_count ⇒ Integer
The number of consumed source documents.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#consumed_source_size ⇒ Integer
The total consumed source size in bytes.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the space was created.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The user who created the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#created_by_arn ⇒ String
The ARN of the user who created the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The display name of the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#resources_count ⇒ Integer
The number of resources in the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#space_arn ⇒ String
The ARN of the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#space_id ⇒ String
The ID of the space.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the space was last updated.
38613 38614 38615 38616 38617 38618 38619 38620 38621 38622 38623 38624 38625 38626 38627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38613 class SpaceSummary < Struct.new( :space_id, :space_arn, :name, :description, :updated_at, :consumed_source_size, :consumed_source_doc_count, :created_at, :created_by, :created_by_arn, :resources_count) SENSITIVE = [:description] include Aws::Structure end |