Class: Aws::QuickSight::Types::StarburstParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The parameters that are required to connect to a Starburst data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_typeString

The authentication type that you want to use for your connection. This parameter accepts OAuth and non-OAuth authentication types.

Returns:

  • (String)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

The catalog name for the Starburst data source.

Returns:

  • (String)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#database_access_control_roleString

The database access control role.

Returns:

  • (String)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#hostString

The host name of the Starburst data source.

Returns:

  • (String)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#o_auth_parametersTypes::OAuthParameters

An object that contains information needed to create a data source connection between an Quick Sight account and Starburst.



35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port for the Starburst data source.

Returns:

  • (Integer)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#product_typeString

The product type for the Starburst data source.

Returns:

  • (String)


35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
# File 'lib/aws-sdk-quicksight/types.rb', line 35280

class StarburstParameters < Struct.new(
  :host,
  :port,
  :catalog,
  :product_type,
  :database_access_control_role,
  :authentication_type,
  :o_auth_parameters)
  SENSITIVE = []
  include Aws::Structure
end