Class: Aws::QuickSight::Types::StartAssetBundleExportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_bundle_export_job_idString

The ID of the job. This ID is unique while the job is running. After the job is completed, you can reuse this ID for another job.

Returns:

  • (String)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account to export assets from.

Returns:

  • (String)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_formation_override_property_configurationTypes::AssetBundleCloudFormationOverridePropertyConfiguration

An optional collection of structures that generate CloudFormation parameters to override the existing resource property values when the resource is exported to a new CloudFormation template.

Use this field if the ExportFormat field of a StartAssetBundleExportJobRequest API call is set to CLOUDFORMATION_JSON.



40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#export_formatString

The export data format.

Returns:

  • (String)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#include_all_dependenciesBoolean

A Boolean that determines whether all dependencies of each resource ARN are recursively exported with the job. For example, say you provided a Dashboard ARN to the ResourceArns parameter. If you set IncludeAllDependencies to TRUE, any theme, dataset, and data source resource that is a dependency of the dashboard is also exported.

Returns:

  • (Boolean)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#include_folder_membersString

A setting that indicates whether you want to include folder assets. You can also use this setting to recusrsively include all subfolders of an exported folder.

Returns:

  • (String)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#include_folder_membershipsBoolean

A Boolean that determines if the exported asset carries over information about the folders that the asset is a member of.

Returns:

  • (Boolean)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#include_permissionsBoolean

A Boolean that determines whether all permissions for each resource ARN are exported with the job. If you set IncludePermissions to TRUE, any permissions associated with each resource are exported.

Returns:

  • (Boolean)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#include_tagsBoolean

A Boolean that determines whether all tags for each resource ARN are exported with the job. If you set IncludeTags to TRUE, any tags associated with each resource are exported.

Returns:

  • (Boolean)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

An array of resource ARNs to export. The following resources are supported.

  • Analysis

  • Dashboard

  • DataSet

  • DataSource

  • RefreshSchedule

  • Theme

  • VPCConnection

The API caller must have the necessary permissions in their IAM role to access each resource before the resources can be exported.

Returns:

  • (Array<String>)


40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end

#validation_strategyTypes::AssetBundleExportJobValidationStrategy

An optional parameter that determines which validation strategy to use for the export job. If StrictModeForAllResources is set to TRUE, strict validation for every error is enforced. If it is set to FALSE, validation is skipped for specific UI errors that are shown as warnings. The default value for StrictModeForAllResources is FALSE.



40058
40059
40060
40061
40062
40063
40064
40065
40066
40067
40068
40069
40070
40071
40072
# File 'lib/aws-sdk-quicksight/types.rb', line 40058

class StartAssetBundleExportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_export_job_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = []
  include Aws::Structure
end