Class: Aws::QuickSight::Types::StartDashboardSnapshotJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::StartDashboardSnapshotJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
-
#dashboard_id ⇒ String
The ID of the dashboard that you want to start a snapshot job for.
-
#snapshot_configuration ⇒ Types::SnapshotConfiguration
A structure that describes the configuration of the dashboard snapshot.
-
#snapshot_job_id ⇒ String
An ID for the dashboard snapshot job.
-
#user_configuration ⇒ Types::SnapshotUserConfiguration
A structure that contains information about the users that the dashboard snapshot is generated for.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
41440 41441 41442 41443 41444 41445 41446 41447 41448 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41440 class StartDashboardSnapshotJobRequest < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID of the dashboard that you want to start a snapshot job for.
41440 41441 41442 41443 41444 41445 41446 41447 41448 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41440 class StartDashboardSnapshotJobRequest < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration) SENSITIVE = [] include Aws::Structure end |
#snapshot_configuration ⇒ Types::SnapshotConfiguration
A structure that describes the configuration of the dashboard snapshot.
41440 41441 41442 41443 41444 41445 41446 41447 41448 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41440 class StartDashboardSnapshotJobRequest < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration) SENSITIVE = [] include Aws::Structure end |
#snapshot_job_id ⇒ String
An ID for the dashboard snapshot job. This ID is unique to the
dashboard while the job is running. This ID can be used to poll the
status of a job with a DescribeDashboardSnapshotJob while the job
runs. You can reuse this ID for another job 24 hours after the
current job is completed.
41440 41441 41442 41443 41444 41445 41446 41447 41448 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41440 class StartDashboardSnapshotJobRequest < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration) SENSITIVE = [] include Aws::Structure end |
#user_configuration ⇒ Types::SnapshotUserConfiguration
A structure that contains information about the users that the dashboard snapshot is generated for. The users can be either anonymous users or registered users. Anonymous users cannot be used together with registered users.
When using identity-enhanced session credentials, set the UserConfiguration request attribute to null. Otherwise, the request will be invalid.
41440 41441 41442 41443 41444 41445 41446 41447 41448 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41440 class StartDashboardSnapshotJobRequest < Struct.new( :aws_account_id, :dashboard_id, :snapshot_job_id, :user_configuration, :snapshot_configuration) SENSITIVE = [] include Aws::Structure end |