Class: Aws::QuickSight::Types::TableCellImageSizingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TableCellImageSizingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The sizing options for the table image configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#table_cell_image_scaling_configuration ⇒ String
The cell scaling configuration of the sizing options for the table image configuration.
Instance Attribute Details
#table_cell_image_scaling_configuration ⇒ String
The cell scaling configuration of the sizing options for the table image configuration.
37463 37464 37465 37466 37467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37463 class TableCellImageSizingConfiguration < Struct.new( :table_cell_image_scaling_configuration) SENSITIVE = [] include Aws::Structure end |