Class: Aws::QuickSight::Types::TableFieldOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The field options of a table visual.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#orderArray<String>

The order of the field IDs that are configured as field options for a table visual.

Returns:

  • (Array<String>)


42257
42258
42259
42260
42261
42262
42263
42264
# File 'lib/aws-sdk-quicksight/types.rb', line 42257

class TableFieldOptions < Struct.new(
  :selected_field_options,
  :order,
  :pinned_field_options,
  :transposed_table_options)
  SENSITIVE = []
  include Aws::Structure
end

#pinned_field_optionsTypes::TablePinnedFieldOptions

The settings for the pinned columns of a table visual.



42257
42258
42259
42260
42261
42262
42263
42264
# File 'lib/aws-sdk-quicksight/types.rb', line 42257

class TableFieldOptions < Struct.new(
  :selected_field_options,
  :order,
  :pinned_field_options,
  :transposed_table_options)
  SENSITIVE = []
  include Aws::Structure
end

#selected_field_optionsArray<Types::TableFieldOption>

The field options to be configured to a table.

Returns:



42257
42258
42259
42260
42261
42262
42263
42264
# File 'lib/aws-sdk-quicksight/types.rb', line 42257

class TableFieldOptions < Struct.new(
  :selected_field_options,
  :order,
  :pinned_field_options,
  :transposed_table_options)
  SENSITIVE = []
  include Aws::Structure
end

#transposed_table_optionsArray<Types::TransposedTableOption>

The TableOptions of a transposed table.

Returns:



42257
42258
42259
42260
42261
42262
42263
42264
# File 'lib/aws-sdk-quicksight/types.rb', line 42257

class TableFieldOptions < Struct.new(
  :selected_field_options,
  :order,
  :pinned_field_options,
  :transposed_table_options)
  SENSITIVE = []
  include Aws::Structure
end