Class: Aws::QuickSight::Types::TableSideBorderOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TableSideBorderOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The side border options for a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bottom ⇒ Types::TableBorderOptions
The table border options of the bottom border.
-
#inner_horizontal ⇒ Types::TableBorderOptions
The table border options of the inner horizontal border.
-
#inner_vertical ⇒ Types::TableBorderOptions
The table border options of the inner vertical border.
-
#left ⇒ Types::TableBorderOptions
The table border options of the left border.
-
#right ⇒ Types::TableBorderOptions
The table border options of the right border.
-
#top ⇒ Types::TableBorderOptions
The table border options of the top border.
Instance Attribute Details
#bottom ⇒ Types::TableBorderOptions
The table border options of the bottom border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |
#inner_horizontal ⇒ Types::TableBorderOptions
The table border options of the inner horizontal border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |
#inner_vertical ⇒ Types::TableBorderOptions
The table border options of the inner vertical border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |
#left ⇒ Types::TableBorderOptions
The table border options of the left border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |
#right ⇒ Types::TableBorderOptions
The table border options of the right border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |
#top ⇒ Types::TableBorderOptions
The table border options of the top border.
40949 40950 40951 40952 40953 40954 40955 40956 40957 40958 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40949 class TableSideBorderOptions < Struct.new( :inner_vertical, :inner_horizontal, :left, :right, :top, :bottom) SENSITIVE = [] include Aws::Structure end |