Class: Aws::QuickSight::Types::TextBoxMenuOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TextBoxMenuOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The menu options for the interactions of a textbox.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_status ⇒ String
The availability status of the textbox menu.
Instance Attribute Details
#availability_status ⇒ String
The availability status of the textbox menu. If the value of this property is set to ‘ENABLED`, dashboard readers can interact with the textbox menu.
38955 38956 38957 38958 38959 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38955 class TextBoxMenuOption < Struct.new( :availability_status) SENSITIVE = [] include Aws::Structure end |