Class: Aws::QuickSight::Types::TextFieldControlDisplayOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TextFieldControlDisplayOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The display options of a control.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#info_icon_label_options ⇒ Types::SheetControlInfoIconLabelOptions
The configuration of info icon label options.
-
#placeholder_options ⇒ Types::TextControlPlaceholderOptions
The configuration of the placeholder options in a text field control.
-
#title_options ⇒ Types::LabelOptions
The options to configure the title visibility, name, and font size.
Instance Attribute Details
#info_icon_label_options ⇒ Types::SheetControlInfoIconLabelOptions
The configuration of info icon label options.
42024 42025 42026 42027 42028 42029 42030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42024 class TextFieldControlDisplayOptions < Struct.new( :title_options, :placeholder_options, :info_icon_label_options) SENSITIVE = [] include Aws::Structure end |
#placeholder_options ⇒ Types::TextControlPlaceholderOptions
The configuration of the placeholder options in a text field control.
42024 42025 42026 42027 42028 42029 42030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42024 class TextFieldControlDisplayOptions < Struct.new( :title_options, :placeholder_options, :info_icon_label_options) SENSITIVE = [] include Aws::Structure end |
#title_options ⇒ Types::LabelOptions
The options to configure the title visibility, name, and font size.
42024 42025 42026 42027 42028 42029 42030 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42024 class TextFieldControlDisplayOptions < Struct.new( :title_options, :placeholder_options, :info_icon_label_options) SENSITIVE = [] include Aws::Structure end |