Class: Aws::QuickSight::Types::Theme

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Summary information about a theme.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the theme.

Returns:

  • (String)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The date and time that the theme was created.

Returns:

  • (Time)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The date and time that the theme was last updated.

Returns:

  • (Time)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that the user gives to the theme.

Returns:

  • (String)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#theme_idString

The identifier that the user gives to the theme.

Returns:

  • (String)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of theme, based on how it was created. Valid values include: ‘QUICKSIGHT` and `CUSTOM`.

Returns:

  • (String)


39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#versionTypes::ThemeVersion

A version of a theme.

Returns:



39058
39059
39060
39061
39062
39063
39064
39065
39066
39067
39068
# File 'lib/aws-sdk-quicksight/types.rb', line 39058

class Theme < Struct.new(
  :arn,
  :name,
  :theme_id,
  :version,
  :created_time,
  :last_updated_time,
  :type)
  SENSITIVE = []
  include Aws::Structure
end