Class: Aws::QuickSight::Types::ThousandSeparatorOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The options that determine the thousands separator configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grouping_styleString

Determines the way numbers are styled to accommodate different readability standards. The DEFAULT value uses the standard international grouping system and groups numbers by the thousands. The LAKHS value uses the Indian numbering system and groups numbers by lakhs and crores.

Returns:

  • (String)


43474
43475
43476
43477
43478
43479
43480
# File 'lib/aws-sdk-quicksight/types.rb', line 43474

class ThousandSeparatorOptions < Struct.new(
  :symbol,
  :visibility,
  :grouping_style)
  SENSITIVE = []
  include Aws::Structure
end

#symbolString

Determines the thousands separator symbol.

Returns:

  • (String)


43474
43475
43476
43477
43478
43479
43480
# File 'lib/aws-sdk-quicksight/types.rb', line 43474

class ThousandSeparatorOptions < Struct.new(
  :symbol,
  :visibility,
  :grouping_style)
  SENSITIVE = []
  include Aws::Structure
end

#visibilityString

Determines the visibility of the thousands separator.

Returns:

  • (String)


43474
43475
43476
43477
43478
43479
43480
# File 'lib/aws-sdk-quicksight/types.rb', line 43474

class ThousandSeparatorOptions < Struct.new(
  :symbol,
  :visibility,
  :grouping_style)
  SENSITIVE = []
  include Aws::Structure
end