Class: Aws::QuickSight::Types::ThresholdAlertsConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The threshold alerts configuration for an embedded Quick Sight dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

The threshold alerts configuration for an embedded Quick Sight dashboard.

Returns:

  • (Boolean)


39111
39112
39113
39114
39115
# File 'lib/aws-sdk-quicksight/types.rb', line 39111

class ThresholdAlertsConfigurations < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end