Class: Aws::QuickSight::Types::TopicConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration of a topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_group_schema_list ⇒ Array<Types::ColumnGroupSchema>
The list of column group schemas in the topic configuration.
-
#data_set_schema ⇒ Types::DataSetSchema
Topic schema.
-
#placeholder ⇒ String
The placeholder for the topic configuration.
Instance Attribute Details
#column_group_schema_list ⇒ Array<Types::ColumnGroupSchema>
The list of column group schemas in the topic configuration.
44348 44349 44350 44351 44352 44353 44354 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44348 class TopicConfiguration < Struct.new( :placeholder, :data_set_schema, :column_group_schema_list) SENSITIVE = [] include Aws::Structure end |
#data_set_schema ⇒ Types::DataSetSchema
Topic schema.
44348 44349 44350 44351 44352 44353 44354 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44348 class TopicConfiguration < Struct.new( :placeholder, :data_set_schema, :column_group_schema_list) SENSITIVE = [] include Aws::Structure end |
#placeholder ⇒ String
The placeholder for the topic configuration.
44348 44349 44350 44351 44352 44353 44354 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44348 class TopicConfiguration < Struct.new( :placeholder, :data_set_schema, :column_group_schema_list) SENSITIVE = [] include Aws::Structure end |