Class: Aws::QuickSight::Types::TopicNamedEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that represents a named entity.

Constant Summary collapse

SENSITIVE =
[:entity_description, :entity_synonyms]

Instance Attribute Summary collapse

Instance Attribute Details

#definitionArray<Types::NamedEntityDefinition>

The definition of a named entity.

Returns:



46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_descriptionString

The description of the named entity.

Returns:

  • (String)


46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_nameString

The name of the named entity.

Returns:

  • (String)


46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_synonymsArray<String>

The other names or aliases for the named entity.

Returns:

  • (Array<String>)


46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#presentation_orderInteger

The presentation order of the named entity.

Returns:

  • (Integer)


46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#rank_orderInteger

The rank order of the named entity.

Returns:

  • (Integer)


46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#semantic_entity_typeTypes::SemanticEntityType

The type of named entity that a topic represents.



46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#sortArray<Types::NamedEntitySort>

The sort configuration of the named entity.

Returns:



46434
46435
46436
46437
46438
46439
46440
46441
46442
46443
46444
46445
# File 'lib/aws-sdk-quicksight/types.rb', line 46434

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end