Class: Aws::QuickSight::Types::TopicV2Details

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The definition of a topic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_set_relationsArray<Types::TopicV2DataSetRelation>

The relations between the data sets that the topic is associated with.

Returns:



45390
45391
45392
45393
45394
45395
45396
45397
# File 'lib/aws-sdk-quicksight/types.rb', line 45390

class TopicV2Details < Struct.new(
  :name,
  :description,
  :data_sets,
  :data_set_relations)
  SENSITIVE = []
  include Aws::Structure
end

#data_setsArray<Types::TopicV2DataSetReference>

The data sets that the topic is associated with.

Returns:



45390
45391
45392
45393
45394
45395
45396
45397
# File 'lib/aws-sdk-quicksight/types.rb', line 45390

class TopicV2Details < Struct.new(
  :name,
  :description,
  :data_sets,
  :data_set_relations)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the topic.

Returns:

  • (String)


45390
45391
45392
45393
45394
45395
45396
45397
# File 'lib/aws-sdk-quicksight/types.rb', line 45390

class TopicV2Details < Struct.new(
  :name,
  :description,
  :data_sets,
  :data_set_relations)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the topic.

Returns:

  • (String)


45390
45391
45392
45393
45394
45395
45396
45397
# File 'lib/aws-sdk-quicksight/types.rb', line 45390

class TopicV2Details < Struct.new(
  :name,
  :description,
  :data_sets,
  :data_set_relations)
  SENSITIVE = []
  include Aws::Structure
end