Class: Aws::QuickSight::Types::TransformOperationSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TransformOperationSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Specifies the source of data for a transform operation, including the source operation and column mappings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_id_mappings ⇒ Array<Types::DataSetColumnIdMapping>
The mappings between source column identifiers and target column identifiers for this transformation.
-
#transform_operation_id ⇒ String
The identifier of the transform operation that provides input data.
Instance Attribute Details
#column_id_mappings ⇒ Array<Types::DataSetColumnIdMapping>
The mappings between source column identifiers and target column identifiers for this transformation.
41010 41011 41012 41013 41014 41015 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41010 class TransformOperationSource < Struct.new( :transform_operation_id, :column_id_mappings) SENSITIVE = [] include Aws::Structure end |
#transform_operation_id ⇒ String
The identifier of the transform operation that provides input data.
41010 41011 41012 41013 41014 41015 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41010 class TransformOperationSource < Struct.new( :transform_operation_id, :column_id_mappings) SENSITIVE = [] include Aws::Structure end |