Class: Aws::QuickSight::Types::TransformStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TransformStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A step in data preparation that performs a specific operation on the data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregate_step ⇒ Types::AggregateOperation
A transform step that groups data and applies aggregation functions to calculate summary values.
-
#append_step ⇒ Types::AppendOperation
A transform step that combines rows from multiple sources by stacking them vertically.
-
#cast_column_types_step ⇒ Types::CastColumnTypesOperation
A transform step that changes the data types of one or more columns.
-
#create_columns_step ⇒ Types::CreateColumnsOperation
A transform operation that creates calculated columns.
-
#filters_step ⇒ Types::FiltersOperation
A transform step that applies filter conditions.
-
#import_table_step ⇒ Types::ImportTableOperation
A transform step that brings data from a source table.
-
#join_step ⇒ Types::JoinOperation
A transform step that combines data from two sources based on specified join conditions.
-
#pivot_step ⇒ Types::PivotOperation
A transform step that converts row values into columns to reshape the data structure.
-
#project_step ⇒ Types::ProjectOperation
A transform operation that projects columns.
-
#rename_columns_step ⇒ Types::RenameColumnsOperation
A transform step that changes the names of one or more columns.
-
#unpivot_step ⇒ Types::UnpivotOperation
A transform step that converts columns into rows to normalize the data structure.
Instance Attribute Details
#aggregate_step ⇒ Types::AggregateOperation
A transform step that groups data and applies aggregation functions to calculate summary values.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#append_step ⇒ Types::AppendOperation
A transform step that combines rows from multiple sources by stacking them vertically.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#cast_column_types_step ⇒ Types::CastColumnTypesOperation
A transform step that changes the data types of one or more columns.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#create_columns_step ⇒ Types::CreateColumnsOperation
A transform operation that creates calculated columns. Columns created in one such operation form a lexical closure.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#filters_step ⇒ Types::FiltersOperation
A transform step that applies filter conditions.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#import_table_step ⇒ Types::ImportTableOperation
A transform step that brings data from a source table.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#join_step ⇒ Types::JoinOperation
A transform step that combines data from two sources based on specified join conditions.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#pivot_step ⇒ Types::PivotOperation
A transform step that converts row values into columns to reshape the data structure.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#project_step ⇒ Types::ProjectOperation
A transform operation that projects columns. Operations that come after a projection can only refer to projected columns.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#rename_columns_step ⇒ Types::RenameColumnsOperation
A transform step that changes the names of one or more columns.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |
#unpivot_step ⇒ Types::UnpivotOperation
A transform step that converts columns into rows to normalize the data structure.
44248 44249 44250 44251 44252 44253 44254 44255 44256 44257 44258 44259 44260 44261 44262 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44248 class TransformStep < Struct.new( :import_table_step, :project_step, :filters_step, :create_columns_step, :rename_columns_step, :cast_column_types_step, :join_step, :aggregate_step, :pivot_step, :unpivot_step, :append_step) SENSITIVE = [] include Aws::Structure end |