Class: Aws::QuickSight::Types::UnpivotOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UnpivotOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that converts columns into rows, normalizing the data structure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for this operation.
-
#columns_to_unpivot ⇒ Array<Types::ColumnToUnpivot>
The list of columns to unpivot from the source data.
-
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for unpivoting.
-
#unpivoted_label_column_id ⇒ String
A unique identifier for the new column that will contain the unpivoted column names.
-
#unpivoted_label_column_name ⇒ String
The name for the new column that will contain the unpivoted column names.
-
#unpivoted_value_column_id ⇒ String
A unique identifier for the new column that will contain the unpivoted values.
-
#unpivoted_value_column_name ⇒ String
The name for the new column that will contain the unpivoted values.
Instance Attribute Details
#alias ⇒ String
Alias for this operation.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#columns_to_unpivot ⇒ Array<Types::ColumnToUnpivot>
The list of columns to unpivot from the source data.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for unpivoting.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#unpivoted_label_column_id ⇒ String
A unique identifier for the new column that will contain the unpivoted column names.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#unpivoted_label_column_name ⇒ String
The name for the new column that will contain the unpivoted column names.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#unpivoted_value_column_id ⇒ String
A unique identifier for the new column that will contain the unpivoted values.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |
#unpivoted_value_column_name ⇒ String
The name for the new column that will contain the unpivoted values.
41469 41470 41471 41472 41473 41474 41475 41476 41477 41478 41479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41469 class UnpivotOperation < Struct.new( :alias, :source, :columns_to_unpivot, :unpivoted_label_column_name, :unpivoted_label_column_id, :unpivoted_value_column_name, :unpivoted_value_column_id) SENSITIVE = [] include Aws::Structure end |