Class: Aws::QuickSight::Types::UpdateAccountCustomizationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_customizationTypes::AccountCustomization

The Quick Sight customizations you’re updating.



43861
43862
43863
43864
43865
43866
43867
# File 'lib/aws-sdk-quicksight/types.rb', line 43861

class UpdateAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :account_customization)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID for the Amazon Web Services account that you want to update Quick Sight customizations for.

Returns:

  • (String)


43861
43862
43863
43864
43865
43866
43867
# File 'lib/aws-sdk-quicksight/types.rb', line 43861

class UpdateAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :account_customization)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that you want to update Quick Sight customizations for.

Returns:

  • (String)


43861
43862
43863
43864
43865
43866
43867
# File 'lib/aws-sdk-quicksight/types.rb', line 43861

class UpdateAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :account_customization)
  SENSITIVE = []
  include Aws::Structure
end