Class: Aws::QuickSight::Types::UpdateAgentPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAgentPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier for the agent.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant on the agent.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the agent.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier for the agent.
44116 44117 44118 44119 44120 44121 44122 44123 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44116 class UpdateAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
44116 44117 44118 44119 44120 44121 44122 44123 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44116 class UpdateAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant on the agent.
44116 44117 44118 44119 44120 44121 44122 44123 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44116 class UpdateAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the agent.
44116 44117 44118 44119 44120 44121 44122 44123 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44116 class UpdateAgentPermissionsRequest < Struct.new( :agent_id, :aws_account_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |