Class: Aws::QuickSight::Types::UpdateAgentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAgentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier for the agent.
-
#agent_status ⇒ String
The status of the agent.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
-
#failed_to_add_action_connectors ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the action connectors that were requested to be added.
-
#failed_to_add_spaces ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the spaces that were requested to be added.
-
#failed_to_remove_action_connectors ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the action connectors that were requested to be removed.
-
#failed_to_remove_spaces ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the spaces that were requested to be removed.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier for the agent.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#agent_status ⇒ String
The status of the agent.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#failed_to_add_action_connectors ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the action connectors that were requested to be added.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#failed_to_add_spaces ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the spaces that were requested to be added.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#failed_to_remove_action_connectors ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the action connectors that were requested to be removed.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#failed_to_remove_spaces ⇒ Array<Types::FailedToUpdateAssociation>
A list of per-ARN failures from the spaces that were requested to be removed.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
48369 48370 48371 48372 48373 48374 48375 48376 48377 48378 48379 48380 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48369 class UpdateAgentResponse < Struct.new( :arn, :agent_id, :agent_status, :failed_to_add_spaces, :failed_to_remove_spaces, :failed_to_add_action_connectors, :failed_to_remove_action_connectors, :request_id) SENSITIVE = [] include Aws::Structure end |