Class: Aws::QuickSight::Types::UpdateAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID for the analysis that you’re updating.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis that you’re updating.
-
#definition ⇒ Types::AnalysisDefinition
The definition of an analysis.
-
#name ⇒ String
A descriptive name for the analysis that you’re updating.
-
#parameters ⇒ Types::Parameters
The parameter names and override values that you want to use.
-
#source_entity ⇒ Types::AnalysisSourceEntity
A source entity to use for the analysis that you’re updating.
-
#theme_arn ⇒ String
The Amazon Resource Name (ARN) for the theme to apply to the analysis that you’re creating.
-
#validation_strategy ⇒ Types::ValidationStrategy
The option to relax the validation needed to update an analysis with definition objects.
Instance Attribute Details
#analysis_id ⇒ String
The ID for the analysis that you’re updating. This ID displays in the URL of the analysis.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis that you’re updating.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#definition ⇒ Types::AnalysisDefinition
The definition of an analysis.
A definition is the data model of all features in a Dashboard, Template, or Analysis.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive name for the analysis that you’re updating. This name displays for the analysis in the Amazon Quick Sight console.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::Parameters
The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#source_entity ⇒ Types::AnalysisSourceEntity
A source entity to use for the analysis that you’re updating. This metadata structure contains details that describe a source template and one or more datasets.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#theme_arn ⇒ String
The Amazon Resource Name (ARN) for the theme to apply to the analysis that you’re creating. To see the theme in the Amazon Quick Sight console, make sure that you have access to it.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |
#validation_strategy ⇒ Types::ValidationStrategy
The option to relax the validation needed to update an analysis with definition objects. This skips the validation step for specific errors.
39630 39631 39632 39633 39634 39635 39636 39637 39638 39639 39640 39641 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39630 class UpdateAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :name, :parameters, :source_entity, :theme_arn, :definition, :validation_strategy) SENSITIVE = [] include Aws::Structure end |