Class: Aws::QuickSight::Types::UpdateAppPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAppPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the app.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to grant on the app.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to revoke from the app.
-
#visibility ⇒ String
The visibility to set for the app.
Instance Attribute Details
#app_id ⇒ String
The ID of the app.
48565 48566 48567 48568 48569 48570 48571 48572 48573 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48565 class UpdateAppPermissionsRequest < Struct.new( :aws_account_id, :app_id, :grant_permissions, :revoke_permissions, :visibility) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
48565 48566 48567 48568 48569 48570 48571 48572 48573 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48565 class UpdateAppPermissionsRequest < Struct.new( :aws_account_id, :app_id, :grant_permissions, :revoke_permissions, :visibility) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to grant on the app.
48565 48566 48567 48568 48569 48570 48571 48572 48573 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48565 class UpdateAppPermissionsRequest < Struct.new( :aws_account_id, :app_id, :grant_permissions, :revoke_permissions, :visibility) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to revoke from the app.
48565 48566 48567 48568 48569 48570 48571 48572 48573 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48565 class UpdateAppPermissionsRequest < Struct.new( :aws_account_id, :app_id, :grant_permissions, :revoke_permissions, :visibility) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
The visibility to set for the app. Currently, only PRIVATE is
accepted, which removes public (anonymous) access from the app. If
you don't specify a value, the app's visibility is unchanged.
Setting an app to PUBLIC through this operation is not supported.
48565 48566 48567 48568 48569 48570 48571 48572 48573 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48565 class UpdateAppPermissionsRequest < Struct.new( :aws_account_id, :app_id, :grant_permissions, :revoke_permissions, :visibility) SENSITIVE = [] include Aws::Structure end |