Class: Aws::QuickSight::Types::UpdateApplicationWithTokenExchangeGrantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateApplicationWithTokenExchangeGrantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to be updated with a token exchange grant.
-
#namespace ⇒ String
The namespace of the Quick application.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to be updated with a token exchange grant.
45212 45213 45214 45215 45216 45217 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45212 class UpdateApplicationWithTokenExchangeGrantRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the Quick application.
45212 45213 45214 45215 45216 45217 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45212 class UpdateApplicationWithTokenExchangeGrantRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |