Class: Aws::QuickSight::Types::UpdateApprovalPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<String>

The list of governed actions that trigger the approval workflow.

Returns:

  • (Array<String>)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#applicable_toTypes::ApplicableTo

The scoping configuration that determines who the approval policy applies to.

Returns:



48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#approval_groupsArray<String>

The list of group ARNs whose members can approve requests.

Returns:

  • (Array<String>)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#asset_typesArray<String>

The list of asset types that the approval policy applies to.

Returns:

  • (Array<String>)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the approval policy.

Returns:

  • (String)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the approval policy.

Returns:

  • (String)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end

#policy_idString

The unique identifier of the approval policy to update.

Returns:

  • (String)


48673
48674
48675
48676
48677
48678
48679
48680
48681
48682
48683
# File 'lib/aws-sdk-quicksight/types.rb', line 48673

class UpdateApprovalPolicyRequest < Struct.new(
  :policy_id,
  :name,
  :description,
  :actions,
  :asset_types,
  :applicable_to,
  :approval_groups)
  SENSITIVE = []
  include Aws::Structure
end