Class: Aws::QuickSight::Types::UpdateDefaultQBusinessApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateDefaultQBusinessApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_id ⇒ String
The ID of the Amazon Q Business application that you want to update.
-
#aws_account_id ⇒ String
The ID of the Quick Sight account that is connected to the Amazon Q Business application that you want to update.
-
#namespace ⇒ String
The Quick Sight namespace that contains the linked Amazon Q Business application.
Instance Attribute Details
#application_id ⇒ String
The ID of the Amazon Q Business application that you want to update.
47910 47911 47912 47913 47914 47915 47916 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47910 class UpdateDefaultQBusinessApplicationRequest < Struct.new( :aws_account_id, :namespace, :application_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Quick Sight account that is connected to the Amazon Q Business application that you want to update.
47910 47911 47912 47913 47914 47915 47916 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47910 class UpdateDefaultQBusinessApplicationRequest < Struct.new( :aws_account_id, :namespace, :application_id) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick Sight namespace that contains the linked Amazon Q Business application. If this field is left blank, the default namespace is used. Currently, the default namespace is the only valid value for this parameter.
47910 47911 47912 47913 47914 47915 47916 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47910 class UpdateDefaultQBusinessApplicationRequest < Struct.new( :aws_account_id, :namespace, :application_id) SENSITIVE = [] include Aws::Structure end |