Class: Aws::QuickSight::Types::UpdateDlpSettingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the DLP setting that you want to update.

Returns:

  • (String)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dlp_setting_idString

The ID of the DLP setting that you want to update.

Returns:

  • (String)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether DLP enforcement is active for this setting. Set to true to enable enforcement, or false to disable it.

Returns:

  • (Boolean)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

An updated display name for the DLP setting.

Returns:

  • (String)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provider_configTypes::ProviderConfig

An updated provider-specific configuration for the DLP integration. This is a union type structure. For this structure to be valid, only one of the attributes can be defined.



49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provider_outage_actionString

An updated behavior to apply when the DLP provider is unreachable. Valid values are ALLOW, WARN, and BLOCK.

Returns:

  • (String)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#provider_typeString

An updated DLP provider type. Currently, the only supported value is MICROSOFT_PURVIEW.

Returns:

  • (String)


49661
49662
49663
49664
49665
49666
49667
49668
49669
49670
49671
# File 'lib/aws-sdk-quicksight/types.rb', line 49661

class UpdateDlpSettingRequest < Struct.new(
  :aws_account_id,
  :dlp_setting_id,
  :name,
  :provider_type,
  :provider_config,
  :provider_outage_action,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end