Class: Aws::QuickSight::Types::UpdateFlowPermissionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the flow you are updating permissions against.

Returns:

  • (String)


45404
45405
45406
45407
45408
45409
45410
45411
# File 'lib/aws-sdk-quicksight/types.rb', line 45404

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow to update permissions for.

Returns:

  • (String)


45404
45405
45406
45407
45408
45409
45410
45411
# File 'lib/aws-sdk-quicksight/types.rb', line 45404

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#grant_permissionsArray<Types::Permission>

The permissions that you want to grant on this flow.

Returns:



45404
45405
45406
45407
45408
45409
45410
45411
# File 'lib/aws-sdk-quicksight/types.rb', line 45404

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_permissionsArray<Types::Permission>

The permissions that you want to revoke from this flow.

Returns:



45404
45405
45406
45407
45408
45409
45410
45411
# File 'lib/aws-sdk-quicksight/types.rb', line 45404

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end