Class: Aws::QuickSight::Types::UpdateFlowPermissionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateFlowPermissionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow you are updating permissions against.
-
#flow_id ⇒ String
The unique identifier of the flow with updated permissions.
-
#permissions ⇒ Array<Types::Permission>
The permissions on the flow after they are updated.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow you are updating permissions against.
43188 43189 43190 43191 43192 43193 43194 43195 43196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43188 class UpdateFlowPermissionsOutput < Struct.new( :status, :arn, :permissions, :request_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow with updated permissions.
43188 43189 43190 43191 43192 43193 43194 43195 43196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43188 class UpdateFlowPermissionsOutput < Struct.new( :status, :arn, :permissions, :request_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::Permission>
The permissions on the flow after they are updated.
43188 43189 43190 43191 43192 43193 43194 43195 43196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43188 class UpdateFlowPermissionsOutput < Struct.new( :status, :arn, :permissions, :request_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
43188 43189 43190 43191 43192 43193 43194 43195 43196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43188 class UpdateFlowPermissionsOutput < Struct.new( :status, :arn, :permissions, :request_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
43188 43189 43190 43191 43192 43193 43194 43195 43196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43188 class UpdateFlowPermissionsOutput < Struct.new( :status, :arn, :permissions, :request_id, :flow_id) SENSITIVE = [] include Aws::Structure end |