Class: Aws::QuickSight::Types::UpdateFlowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:flow_definition]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the flow that you are updating.

Returns:

  • (String)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#descriptionString

Updated description for the flow. Omit to preserve the existing description.

Returns:

  • (String)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#flow_definitionHash, ...

The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow's internal format. The format is subject to change. When provided, all existing steps are replaced. Omit to preserve the existing definition.

Always derive or depend on the flow definition from the DescribeFlow operation to ensure you are working with the latest format.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow to update.

Returns:

  • (String)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#nameString

Updated display name for the flow. Omit to preserve the existing name.

Returns:

  • (String)


46665
46666
46667
46668
46669
46670
46671
46672
46673
46674
# File 'lib/aws-sdk-quicksight/types.rb', line 46665

class UpdateFlowRequest < Struct.new(
  :aws_account_id,
  :flow_id,
  :name,
  :description,
  :flow_definition,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end