Class: Aws::QuickSight::Types::UpdateIpRestrictionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateIpRestrictionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the IP rules.
-
#enabled ⇒ Boolean
A value that specifies whether IP rules are turned on.
-
#ip_restriction_rule_map ⇒ Hash<String,String>
A map that describes the updated IP rules with CIDR ranges and descriptions.
-
#vpc_endpoint_id_restriction_rule_map ⇒ Hash<String,String>
A map of allowed VPC endpoint IDs and their corresponding rule descriptions.
-
#vpc_id_restriction_rule_map ⇒ Hash<String,String>
A map of VPC IDs and their corresponding rules.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the IP rules.
50171 50172 50173 50174 50175 50176 50177 50178 50179 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50171 class UpdateIpRestrictionRequest < Struct.new( :aws_account_id, :ip_restriction_rule_map, :vpc_id_restriction_rule_map, :vpc_endpoint_id_restriction_rule_map, :enabled) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
A value that specifies whether IP rules are turned on.
50171 50172 50173 50174 50175 50176 50177 50178 50179 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50171 class UpdateIpRestrictionRequest < Struct.new( :aws_account_id, :ip_restriction_rule_map, :vpc_id_restriction_rule_map, :vpc_endpoint_id_restriction_rule_map, :enabled) SENSITIVE = [] include Aws::Structure end |
#ip_restriction_rule_map ⇒ Hash<String,String>
A map that describes the updated IP rules with CIDR ranges and descriptions.
50171 50172 50173 50174 50175 50176 50177 50178 50179 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50171 class UpdateIpRestrictionRequest < Struct.new( :aws_account_id, :ip_restriction_rule_map, :vpc_id_restriction_rule_map, :vpc_endpoint_id_restriction_rule_map, :enabled) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id_restriction_rule_map ⇒ Hash<String,String>
A map of allowed VPC endpoint IDs and their corresponding rule descriptions.
50171 50172 50173 50174 50175 50176 50177 50178 50179 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50171 class UpdateIpRestrictionRequest < Struct.new( :aws_account_id, :ip_restriction_rule_map, :vpc_id_restriction_rule_map, :vpc_endpoint_id_restriction_rule_map, :enabled) SENSITIVE = [] include Aws::Structure end |
#vpc_id_restriction_rule_map ⇒ Hash<String,String>
A map of VPC IDs and their corresponding rules. When you configure this parameter, traffic from all VPC endpoints that are present in the specified VPC is allowed.
50171 50172 50173 50174 50175 50176 50177 50178 50179 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50171 class UpdateIpRestrictionRequest < Struct.new( :aws_account_id, :ip_restriction_rule_map, :vpc_id_restriction_rule_map, :vpc_endpoint_id_restriction_rule_map, :enabled) SENSITIVE = [] include Aws::Structure end |