Class: Aws::QuickSight::Types::UpdateKeyRegistrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateKeyRegistrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the customer managed key registration that you want to update.
-
#key_registration ⇒ Array<Types::RegisteredCustomerManagedKey>
A list of ‘RegisteredCustomerManagedKey` objects to be updated to the Quick Sight account.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the customer managed key registration that you want to update.
41940 41941 41942 41943 41944 41945 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41940 class UpdateKeyRegistrationRequest < Struct.new( :aws_account_id, :key_registration) SENSITIVE = [] include Aws::Structure end |
#key_registration ⇒ Array<Types::RegisteredCustomerManagedKey>
A list of ‘RegisteredCustomerManagedKey` objects to be updated to the Quick Sight account.
41940 41941 41942 41943 41944 41945 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41940 class UpdateKeyRegistrationRequest < Struct.new( :aws_account_id, :key_registration) SENSITIVE = [] include Aws::Structure end |