Class: Aws::QuickSight::Types::UpdateKnowledgeBasePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the knowledge base.

Returns:

  • (String)


47135
47136
47137
47138
47139
47140
47141
47142
# File 'lib/aws-sdk-quicksight/types.rb', line 47135

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#grant_permissionsArray<Types::ResourcePermission>

The resource permissions that you want to grant on the knowledge base.

Returns:



47135
47136
47137
47138
47139
47140
47141
47142
# File 'lib/aws-sdk-quicksight/types.rb', line 47135

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for the knowledge base.

Returns:

  • (String)


47135
47136
47137
47138
47139
47140
47141
47142
# File 'lib/aws-sdk-quicksight/types.rb', line 47135

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_permissionsArray<Types::ResourcePermission>

The resource permissions that you want to revoke from the knowledge base.

Returns:



47135
47136
47137
47138
47139
47140
47141
47142
# File 'lib/aws-sdk-quicksight/types.rb', line 47135

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end