Class: Aws::QuickSight::Types::UpdateLimitsProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The ID of the Amazon Web Services account that contains the limits profile.

Returns:

  • (String)


50412
50413
50414
50415
50416
50417
50418
50419
50420
# File 'lib/aws-sdk-quicksight/types.rb', line 50412

class UpdateLimitsProfileRequest < Struct.new(
  :profile_id,
  :account_id,
  :profile_name,
  :description,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A new description for the limits profile.

Returns:

  • (String)


50412
50413
50414
50415
50416
50417
50418
50419
50420
# File 'lib/aws-sdk-quicksight/types.rb', line 50412

class UpdateLimitsProfileRequest < Struct.new(
  :profile_id,
  :account_id,
  :profile_name,
  :description,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The unique identifier for the limits profile to update.

Returns:

  • (String)


50412
50413
50414
50415
50416
50417
50418
50419
50420
# File 'lib/aws-sdk-quicksight/types.rb', line 50412

class UpdateLimitsProfileRequest < Struct.new(
  :profile_id,
  :account_id,
  :profile_name,
  :description,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

A new display name for the limits profile.

Returns:

  • (String)


50412
50413
50414
50415
50416
50417
50418
50419
50420
# File 'lib/aws-sdk-quicksight/types.rb', line 50412

class UpdateLimitsProfileRequest < Struct.new(
  :profile_id,
  :account_id,
  :profile_name,
  :description,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end

#resource_limitsHash<String,Types::ProfileLimitValue>

A map of resource types to their updated limit values.

Returns:



50412
50413
50414
50415
50416
50417
50418
50419
50420
# File 'lib/aws-sdk-quicksight/types.rb', line 50412

class UpdateLimitsProfileRequest < Struct.new(
  :profile_id,
  :account_id,
  :profile_name,
  :description,
  :resource_limits)
  SENSITIVE = []
  include Aws::Structure
end