Class: Aws::QuickSight::Types::UpdateQPersonalizationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateQPersonalizationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account account that contains the personalization configuration that the user wants to update.
-
#personalization_mode ⇒ String
An option to allow Amazon Quick Sight to customize data stories with user specific metadata, specifically location and job information, in your IAM Identity Center instance.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account account that contains the personalization configuration that the user wants to update.
50579 50580 50581 50582 50583 50584 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50579 class UpdateQPersonalizationConfigurationRequest < Struct.new( :aws_account_id, :personalization_mode) SENSITIVE = [] include Aws::Structure end |
#personalization_mode ⇒ String
An option to allow Amazon Quick Sight to customize data stories with user specific metadata, specifically location and job information, in your IAM Identity Center instance.
50579 50580 50581 50582 50583 50584 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50579 class UpdateQPersonalizationConfigurationRequest < Struct.new( :aws_account_id, :personalization_mode) SENSITIVE = [] include Aws::Structure end |