Class: Aws::QuickSight::Types::UpdateQuickSightQSearchConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateQuickSightQSearchConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#q_search_status ⇒ String
The status of the Quick Sight Q Search configuration.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#q_search_status ⇒ String
The status of the Quick Sight Q Search configuration.
48837 48838 48839 48840 48841 48842 48843 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48837 class UpdateQuickSightQSearchConfigurationResponse < Struct.new( :q_search_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
48837 48838 48839 48840 48841 48842 48843 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48837 class UpdateQuickSightQSearchConfigurationResponse < Struct.new( :q_search_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
48837 48838 48839 48840 48841 48842 48843 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48837 class UpdateQuickSightQSearchConfigurationResponse < Struct.new( :q_search_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |