Class: Aws::QuickSight::Types::UpdateSelfUpgradeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateSelfUpgradeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform on the self-upgrade request.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the self-upgrade request.
-
#namespace ⇒ String
The Quick namespace for the self-upgrade request.
-
#upgrade_request_id ⇒ String
The ID of the self-upgrade request to update.
Instance Attribute Details
#action ⇒ String
The action to perform on the self-upgrade request. Valid values are ‘APPROVE`, `DENY`, or `VERIFY`.
43774 43775 43776 43777 43778 43779 43780 43781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43774 class UpdateSelfUpgradeRequest < Struct.new( :aws_account_id, :namespace, :upgrade_request_id, :action) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the self-upgrade request.
43774 43775 43776 43777 43778 43779 43780 43781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43774 class UpdateSelfUpgradeRequest < Struct.new( :aws_account_id, :namespace, :upgrade_request_id, :action) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick namespace for the self-upgrade request.
43774 43775 43776 43777 43778 43779 43780 43781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43774 class UpdateSelfUpgradeRequest < Struct.new( :aws_account_id, :namespace, :upgrade_request_id, :action) SENSITIVE = [] include Aws::Structure end |
#upgrade_request_id ⇒ String
The ID of the self-upgrade request to update.
43774 43775 43776 43777 43778 43779 43780 43781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43774 class UpdateSelfUpgradeRequest < Struct.new( :aws_account_id, :namespace, :upgrade_request_id, :action) SENSITIVE = [] include Aws::Structure end |