Class: Aws::QuickSight::Types::UpdateSpacePermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateSpacePermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to grant on the space.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to revoke from the space.
-
#space_id ⇒ String
The ID of the space that you want to update permissions for.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
46402 46403 46404 46405 46406 46407 46408 46409 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46402 class UpdateSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to grant on the space.
46402 46403 46404 46405 46406 46407 46408 46409 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46402 class UpdateSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The permissions that you want to revoke from the space.
46402 46403 46404 46405 46406 46407 46408 46409 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46402 class UpdateSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to update permissions for.
46402 46403 46404 46405 46406 46407 46408 46409 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46402 class UpdateSpacePermissionsRequest < Struct.new( :aws_account_id, :space_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |