Class: Aws::QuickSight::Types::UpdateSpaceResourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_resourcesArray<Types::SpaceResourceOperation>

A list of resources to add to the space.

Returns:



47312
47313
47314
47315
47316
47317
47318
47319
# File 'lib/aws-sdk-quicksight/types.rb', line 47312

class UpdateSpaceResourcesRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :add_resources,
  :remove_resources)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


47312
47313
47314
47315
47316
47317
47318
47319
# File 'lib/aws-sdk-quicksight/types.rb', line 47312

class UpdateSpaceResourcesRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :add_resources,
  :remove_resources)
  SENSITIVE = []
  include Aws::Structure
end

#remove_resourcesArray<Types::SpaceResourceOperation>

A list of resources to remove from the space.

Returns:



47312
47313
47314
47315
47316
47317
47318
47319
# File 'lib/aws-sdk-quicksight/types.rb', line 47312

class UpdateSpaceResourcesRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :add_resources,
  :remove_resources)
  SENSITIVE = []
  include Aws::Structure
end

#space_idString

The ID of the space that you want to update resources for.

Returns:

  • (String)


47312
47313
47314
47315
47316
47317
47318
47319
# File 'lib/aws-sdk-quicksight/types.rb', line 47312

class UpdateSpaceResourcesRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :add_resources,
  :remove_resources)
  SENSITIVE = []
  include Aws::Structure
end