Class: Aws::QuickSight::Types::UpdateTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the template.
-
#creation_status ⇒ String
The creation status of the template.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#template_id ⇒ String
The ID for the template.
-
#version_arn ⇒ String
The ARN for the template, including the version information of the first version.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the template.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#creation_status ⇒ String
The creation status of the template.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID for the template.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#version_arn ⇒ String
The ARN for the template, including the version information of the first version.
44824 44825 44826 44827 44828 44829 44830 44831 44832 44833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44824 class UpdateTemplateResponse < Struct.new( :template_id, :arn, :version_arn, :creation_status, :status, :request_id) SENSITIVE = [] include Aws::Structure end |