Class: Aws::QuickSight::Types::UpdateTopicPermissionsV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicPermissionsV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update the permissions for.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant to the topic.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update the permissions for.
49722 49723 49724 49725 49726 49727 49728 49729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 49722 class UpdateTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant to the topic.
49722 49723 49724 49725 49726 49727 49728 49729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 49722 class UpdateTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the topic.
49722 49723 49724 49725 49726 49727 49728 49729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 49722 class UpdateTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
49722 49723 49724 49725 49726 49727 49728 49729 |
# File 'lib/aws-sdk-quicksight/types.rb', line 49722 class UpdateTopicPermissionsV2Request < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |