Class: Aws::QuickSight::Types::UpdateTopicRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the topic that you want to update.

Returns:

  • (String)


51651
51652
51653
51654
51655
51656
51657
51658
# File 'lib/aws-sdk-quicksight/types.rb', line 51651

class UpdateTopicRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#custom_instructionsTypes::CustomInstructions

Custom instructions for the topic.



51651
51652
51653
51654
51655
51656
51657
51658
# File 'lib/aws-sdk-quicksight/types.rb', line 51651

class UpdateTopicRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#topicTypes::TopicDetails

The definition of the topic that you want to update.

Returns:



51651
51652
51653
51654
51655
51656
51657
51658
# File 'lib/aws-sdk-quicksight/types.rb', line 51651

class UpdateTopicRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


51651
51652
51653
51654
51655
51656
51657
51658
# File 'lib/aws-sdk-quicksight/types.rb', line 51651

class UpdateTopicRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions)
  SENSITIVE = []
  include Aws::Structure
end