Class: Aws::QuickSight::Types::UpdateTopicV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
51747 51748 51749 51750 51751 51752 51753 51754 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51747 class UpdateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
51747 51748 51749 51750 51751 51752 51753 51754 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51747 class UpdateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
51747 51748 51749 51750 51751 51752 51753 51754 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51747 class UpdateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
51747 51748 51749 51750 51751 51752 51753 51754 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51747 class UpdateTopicV2Response < Struct.new( :arn, :topic_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |