Class: Aws::QuickSight::Types::User
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::User
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A registered user of Quick Sight.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active ⇒ Boolean
The active status of user.
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the user.
-
#custom_permissions_name ⇒ String
The custom permissions profile associated with this user.
-
#email ⇒ String
The user’s email address.
-
#external_login_federation_provider_type ⇒ String
The type of supported external login provider that provides identity to let the user federate into Quick Sight with an associated IAM role.
-
#external_login_federation_provider_url ⇒ String
The URL of the external login provider.
-
#external_login_id ⇒ String
The identity ID for the user in the external login provider.
-
#identity_type ⇒ String
The type of identity authentication used by the user.
-
#principal_id ⇒ String
The principal ID of the user.
-
#role ⇒ String
The Quick Sight role for the user.
-
#user_name ⇒ String
The user’s user name.
Instance Attribute Details
#active ⇒ Boolean
The active status of user. When you create an Quick Sight user that’s not an IAM user or an Active Directory user, that user is inactive until they sign in and provide a password.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) for the user.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The custom permissions profile associated with this user.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#email ⇒ String
The user’s email address.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#external_login_federation_provider_type ⇒ String
The type of supported external login provider that provides identity to let the user federate into Quick Sight with an associated IAM role. The type can be one of the following.
-
‘COGNITO`: Amazon Cognito. The provider URL is cognito-identity.amazonaws.com.
-
‘CUSTOM_OIDC`: Custom OpenID Connect (OIDC) provider.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#external_login_federation_provider_url ⇒ String
The URL of the external login provider.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#external_login_id ⇒ String
The identity ID for the user in the external login provider.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#identity_type ⇒ String
The type of identity authentication used by the user.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The principal ID of the user.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The Quick Sight role for the user. The user role can be one of the following:.
-
‘READER`: A user who has read-only access to dashboards.
-
‘AUTHOR`: A user who can create data sources, datasets, analyses, and dashboards.
-
‘ADMIN`: A user who is an author, who can also manage Amazon Quick Sight settings.
-
‘READER_PRO`: Reader Pro adds Generative BI capabilities to the Reader role. Reader Pros have access to Amazon Q in Quick Sight, can build stories with Amazon Q, and can generate executive summaries from dashboards.
-
‘AUTHOR_PRO`: Author Pro adds Generative BI capabilities to the Author role. Author Pros can author dashboards with natural language with Amazon Q, build stories with Amazon Q, create Topics for Q&A, and generate executive summaries from dashboards.
-
‘ADMIN_PRO`: Admin Pros are Author Pros who can also manage Quick Sight administrative settings. Admin Pro users are billed at Author Pro pricing.
-
‘RESTRICTED_READER`: This role isn’t currently available for use.
-
‘RESTRICTED_AUTHOR`: This role isn’t currently available for use.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The user’s user name. This value is required if you are registering a user that will be managed in Quick Sight. In the output, the value for ‘UserName` is `N/A` when the value for `IdentityType` is `IAM` and the corresponding IAM user is deleted.
47563 47564 47565 47566 47567 47568 47569 47570 47571 47572 47573 47574 47575 47576 47577 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47563 class User < Struct.new( :arn, :user_name, :email, :role, :identity_type, :active, :principal_id, :custom_permissions_name, :external_login_federation_provider_type, :external_login_federation_provider_url, :external_login_id) SENSITIVE = [] include Aws::Structure end |