Class: Aws::QuickSight::Types::UserIndexCapacity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A summary of a user’s index capacity consumption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#emailString

The email address of the user.

Returns:

  • (String)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#kb_countInteger

The number of knowledge bases owned by the user.

Returns:

  • (Integer)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The role of the user.

Returns:

  • (String)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#space_countInteger

The number of spaces owned by the user.

Returns:

  • (Integer)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_capacity_bytesInteger

The total index capacity consumed by the user in bytes.

Returns:

  • (Integer)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_kb_capacity_bytesInteger

The total index capacity consumed by the user’s knowledge bases in bytes.

Returns:

  • (Integer)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_space_capacity_bytesInteger

The total index capacity consumed by the user’s spaces in bytes.

Returns:

  • (Integer)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#user_arnString

The ARN of the user.

Returns:

  • (String)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The username of the user.

Returns:

  • (String)


48484
48485
48486
48487
48488
48489
48490
48491
48492
48493
48494
48495
48496
# File 'lib/aws-sdk-quicksight/types.rb', line 48484

class UserIndexCapacity < Struct.new(
  :user_arn,
  :user_name,
  :email,
  :role,
  :total_capacity_bytes,
  :total_kb_capacity_bytes,
  :total_space_capacity_bytes,
  :kb_count,
  :space_count)
  SENSITIVE = []
  include Aws::Structure
end