Class: Aws::QuickSight::Types::ValueColumnConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Configuration for how to handle value columns in pivot operations, including aggregation settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_functionTypes::DataPrepAggregationFunction

The aggregation function to apply when multiple values map to the same pivoted cell.



45194
45195
45196
45197
45198
# File 'lib/aws-sdk-quicksight/types.rb', line 45194

class ValueColumnConfiguration < Struct.new(
  :aggregation_function)
  SENSITIVE = []
  include Aws::Structure
end