Class: Aws::QuickSight::Types::WaterfallChartGroupColorConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::WaterfallChartGroupColorConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The color configuration for individual groups within a waterfall visual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#negative_bar_color ⇒ String
Defines the color for the negative bars of a waterfall chart.
-
#positive_bar_color ⇒ String
Defines the color for the positive bars of a waterfall chart.
-
#total_bar_color ⇒ String
Defines the color for the total bars of a waterfall chart.
Instance Attribute Details
#negative_bar_color ⇒ String
Defines the color for the negative bars of a waterfall chart.
43299 43300 43301 43302 43303 43304 43305 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43299 class WaterfallChartGroupColorConfiguration < Struct.new( :positive_bar_color, :negative_bar_color, :total_bar_color) SENSITIVE = [] include Aws::Structure end |
#positive_bar_color ⇒ String
Defines the color for the positive bars of a waterfall chart.
43299 43300 43301 43302 43303 43304 43305 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43299 class WaterfallChartGroupColorConfiguration < Struct.new( :positive_bar_color, :negative_bar_color, :total_bar_color) SENSITIVE = [] include Aws::Structure end |
#total_bar_color ⇒ String
Defines the color for the total bars of a waterfall chart.
43299 43300 43301 43302 43303 43304 43305 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43299 class WaterfallChartGroupColorConfiguration < Struct.new( :positive_bar_color, :negative_bar_color, :total_bar_color) SENSITIVE = [] include Aws::Structure end |