Class: Aws::QuickSight::Types::WebProxyCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The credentials for authenticating with a web proxy server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#web_proxy_passwordString

The password for authenticating with the web proxy server.

Returns:

  • (String)


46804
46805
46806
46807
46808
46809
# File 'lib/aws-sdk-quicksight/types.rb', line 46804

class WebProxyCredentials < Struct.new(
  :web_proxy_username,
  :web_proxy_password)
  SENSITIVE = []
  include Aws::Structure
end

#web_proxy_usernameString

The username for authenticating with the web proxy server.

Returns:

  • (String)


46804
46805
46806
46807
46808
46809
# File 'lib/aws-sdk-quicksight/types.rb', line 46804

class WebProxyCredentials < Struct.new(
  :web_proxy_username,
  :web_proxy_password)
  SENSITIVE = []
  include Aws::Structure
end