Class: Aws::QuickSight::Types::WhatIfPointScenario
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::WhatIfPointScenario
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Provides the forecast to meet the target for a particular date.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date ⇒ Time
The date that you need the forecast results for.
-
#value ⇒ Float
The target value that you want to meet for the provided date.
Instance Attribute Details
#date ⇒ Time
The date that you need the forecast results for.
44511 44512 44513 44514 44515 44516 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44511 class WhatIfPointScenario < Struct.new( :date, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Float
The target value that you want to meet for the provided date.
44511 44512 44513 44514 44515 44516 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44511 class WhatIfPointScenario < Struct.new( :date, :value) SENSITIVE = [] include Aws::Structure end |