Class: Aws::QuickSight::Types::AccountSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AccountSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The Quick Sight settings associated with your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_name ⇒ String
The "account name" you provided for the Quick Sight subscription in your Amazon Web Services account.
-
#default_namespace ⇒ String
The default Quick Sight namespace for your Amazon Web Services account.
-
#edition ⇒ String
The edition of Quick Sight that you're currently subscribed to: Enterprise edition or Standard edition.
-
#notification_email ⇒ String
The main notification email for your Quick Sight subscription.
-
#public_sharing_enabled ⇒ Boolean
A Boolean value that indicates whether public sharing is turned on for an Quick account.
-
#termination_protection_enabled ⇒ Boolean
A boolean value that determines whether or not an Quick Sight account can be deleted.
Instance Attribute Details
#account_name ⇒ String
The "account name" you provided for the Quick Sight subscription in your Amazon Web Services account. You create this name when you sign up for Quick Sight. It is unique in all of Amazon Web Services and it appears only when users sign in.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#default_namespace ⇒ String
The default Quick Sight namespace for your Amazon Web Services account.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#edition ⇒ String
The edition of Quick Sight that you're currently subscribed to: Enterprise edition or Standard edition.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#notification_email ⇒ String
The main notification email for your Quick Sight subscription.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#public_sharing_enabled ⇒ Boolean
A Boolean value that indicates whether public sharing is turned on for an Quick account. For more information about turning on public sharing, see UpdatePublicSharingSettings.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#termination_protection_enabled ⇒ Boolean
A boolean value that determines whether or not an Quick Sight
account can be deleted. A True value doesn't allow the account to
be deleted and results in an error message if a user tries to make a
DeleteAccountSubsctiption request. A False value will allow the
ccount to be deleted.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-quicksight/types.rb', line 196 class AccountSettings < Struct.new( :account_name, :edition, :default_namespace, :notification_email, :public_sharing_enabled, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |