Class: Aws::QuickSight::Types::Agent
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::Agent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An agent resource in Amazon QuickSight that provides AI-powered conversational experiences.
Constant Summary collapse
- SENSITIVE =
[:starter_prompts, :welcome_message]
Instance Attribute Summary collapse
-
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors attached to the agent.
-
#agent_id ⇒ String
The unique identifier for the agent.
-
#agent_lifecycle ⇒ String
The lifecycle state of the agent.
-
#agent_status ⇒ String
The status of the agent.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
-
#created_at ⇒ Time
The date and time that the agent was created.
-
#creator ⇒ String
The identity of the user who created the agent.
-
#custom_prompt_interface ⇒ Types::CustomPromptInterface
The custom prompt interface configuration for the agent.
-
#description ⇒ String
A description of the agent.
-
#error_message ⇒ String
An error message associated with the agent, if applicable.
-
#icon_id ⇒ String
The icon identifier for the agent.
-
#name ⇒ String
The name of the agent.
-
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces attached to the agent.
-
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
-
#updated_at ⇒ Time
The date and time that the agent was last updated.
-
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
Instance Attribute Details
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors attached to the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier for the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#agent_lifecycle ⇒ String
The lifecycle state of the agent. Valid values are ‘PREVIEW` and `PUBLISHED`.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#agent_status ⇒ String
The status of the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the agent was created.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#creator ⇒ String
The identity of the user who created the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#custom_prompt_interface ⇒ Types::CustomPromptInterface
The custom prompt interface configuration for the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#description ⇒ String
A description of the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#error_message ⇒ String
An error message associated with the agent, if applicable.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#icon_id ⇒ String
The icon identifier for the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#name ⇒ String
The name of the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces attached to the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the agent was last updated.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 482 class Agent < Struct.new( :spaces, :action_connectors, :description, :icon_id, :name, :starter_prompts, :welcome_message, :arn, :agent_id, :agent_lifecycle, :agent_status, :created_at, :creator, :custom_prompt_interface, :error_message, :updated_at) SENSITIVE = [:starter_prompts, :welcome_message] include Aws::Structure end |