Class: Aws::QuickSight::Types::AgentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AgentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A summary of an agent, including its identifier, name, and metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier for the agent.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
-
#created_at ⇒ Time
The date and time that the agent was created.
-
#description ⇒ String
A description of the agent.
-
#icon_id ⇒ String
The icon identifier for the agent.
-
#name ⇒ String
The name of the agent.
-
#updated_at ⇒ Time
The date and time that the agent was last updated.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier for the agent.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the agent.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the agent was created.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the agent.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#icon_id ⇒ String
The icon identifier for the agent.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the agent.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the agent was last updated.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-quicksight/types.rb', line 559 class AgentSummary < Struct.new( :arn, :agent_id, :name, :description, :created_at, :updated_at, :icon_id) SENSITIVE = [] include Aws::Structure end |