Class: Aws::QuickSight::Types::AnonymousUserGenerativeQnAEmbeddingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AnonymousUserGenerativeQnAEmbeddingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The settings that you want to use for the Generative Q&A experience.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#initial_topic_id ⇒ String
The Quick Sight Q topic ID of the new reader experience topic that you want the anonymous user to see first.
Instance Attribute Details
#initial_topic_id ⇒ String
The Quick Sight Q topic ID of the new reader experience topic that you want the anonymous user to see first. This ID is included in the output URL. When the URL in response is accessed, Quick Sight renders the Generative Q&A experience with this new reader experience topic pre selected.
The Amazon Resource Name (ARN) of this Q new reader experience topic must be included in the ‘AuthorizedResourceArns` parameter. Otherwise, the request fails with an `InvalidParameterValueException` error.
1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1173 class AnonymousUserGenerativeQnAEmbeddingConfiguration < Struct.new( :initial_topic_id) SENSITIVE = [] include Aws::Structure end |