Class: Aws::QuickSight::Types::AnonymousUserSnapshotJobResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AnonymousUserSnapshotJobResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that contains the file groups that are requested for the artifact generation in a ‘StartDashboardSnapshotJob` API call.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_groups ⇒ Array<Types::SnapshotJobResultFileGroup>
A list of ‘SnapshotJobResultFileGroup` objects that contain information on the files that are requested during a `StartDashboardSnapshotJob` API call.
Instance Attribute Details
#file_groups ⇒ Array<Types::SnapshotJobResultFileGroup>
A list of ‘SnapshotJobResultFileGroup` objects that contain information on the files that are requested during a `StartDashboardSnapshotJob` API call. If the job succeeds, these objects contain the location where the snapshot artifacts are stored. If the job fails, the objects contain information about the error that caused the job to fail.
1214 1215 1216 1217 1218 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1214 class AnonymousUserSnapshotJobResult < Struct.new( :file_groups) SENSITIVE = [] include Aws::Structure end |