Class: Aws::QuickSight::Types::AnonymousUserSnapshotJobResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that contains the file groups that are requested for the artifact generation in a ‘StartDashboardSnapshotJob` API call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_groupsArray<Types::SnapshotJobResultFileGroup>

A list of ‘SnapshotJobResultFileGroup` objects that contain information on the files that are requested during a `StartDashboardSnapshotJob` API call. If the job succeeds, these objects contain the location where the snapshot artifacts are stored. If the job fails, the objects contain information about the error that caused the job to fail.



1207
1208
1209
1210
1211
# File 'lib/aws-sdk-quicksight/types.rb', line 1207

class AnonymousUserSnapshotJobResult < Struct.new(
  :file_groups)
  SENSITIVE = []
  include Aws::Structure
end