Class: Aws::QuickSight::Types::AssetBundleCloudFormationOverridePropertyConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleCloudFormationOverridePropertyConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An optional collection of CloudFormation property configurations that control how the export job is generated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analyses ⇒ Array<Types::AssetBundleExportJobAnalysisOverrideProperties>
An optional list of structures that control how ‘Analysis` resources are parameterized in the returned CloudFormation template.
-
#dashboards ⇒ Array<Types::AssetBundleExportJobDashboardOverrideProperties>
An optional list of structures that control how ‘Dashboard` resources are parameterized in the returned CloudFormation template.
-
#data_sets ⇒ Array<Types::AssetBundleExportJobDataSetOverrideProperties>
An optional list of structures that control how ‘DataSet` resources are parameterized in the returned CloudFormation template.
-
#data_sources ⇒ Array<Types::AssetBundleExportJobDataSourceOverrideProperties>
An optional list of structures that control how ‘DataSource` resources are parameterized in the returned CloudFormation template.
-
#folders ⇒ Array<Types::AssetBundleExportJobFolderOverrideProperties>
An optional list of structures that controls how ‘Folder` resources are parameterized in the returned CloudFormation template.
-
#refresh_schedules ⇒ Array<Types::AssetBundleExportJobRefreshScheduleOverrideProperties>
An optional list of structures that control how ‘RefreshSchedule` resources are parameterized in the returned CloudFormation template.
-
#resource_id_override_configuration ⇒ Types::AssetBundleExportJobResourceIdOverrideConfiguration
An optional list of structures that control how resource IDs are parameterized in the returned CloudFormation template.
-
#themes ⇒ Array<Types::AssetBundleExportJobThemeOverrideProperties>
An optional list of structures that control how ‘Theme` resources are parameterized in the returned CloudFormation template.
-
#vpc_connections ⇒ Array<Types::AssetBundleExportJobVPCConnectionOverrideProperties>
An optional list of structures that control how ‘VPCConnection` resources are parameterized in the returned CloudFormation template.
Instance Attribute Details
#analyses ⇒ Array<Types::AssetBundleExportJobAnalysisOverrideProperties>
An optional list of structures that control how ‘Analysis` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#dashboards ⇒ Array<Types::AssetBundleExportJobDashboardOverrideProperties>
An optional list of structures that control how ‘Dashboard` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#data_sets ⇒ Array<Types::AssetBundleExportJobDataSetOverrideProperties>
An optional list of structures that control how ‘DataSet` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Array<Types::AssetBundleExportJobDataSourceOverrideProperties>
An optional list of structures that control how ‘DataSource` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#folders ⇒ Array<Types::AssetBundleExportJobFolderOverrideProperties>
An optional list of structures that controls how ‘Folder` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#refresh_schedules ⇒ Array<Types::AssetBundleExportJobRefreshScheduleOverrideProperties>
An optional list of structures that control how ‘RefreshSchedule` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#resource_id_override_configuration ⇒ Types::AssetBundleExportJobResourceIdOverrideConfiguration
An optional list of structures that control how resource IDs are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#themes ⇒ Array<Types::AssetBundleExportJobThemeOverrideProperties>
An optional list of structures that control how ‘Theme` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |
#vpc_connections ⇒ Array<Types::AssetBundleExportJobVPCConnectionOverrideProperties>
An optional list of structures that control how ‘VPCConnection` resources are parameterized in the returned CloudFormation template.
1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1410 class AssetBundleCloudFormationOverridePropertyConfiguration < Struct.new( :resource_id_override_configuration, :vpc_connections, :refresh_schedules, :data_sources, :data_sets, :themes, :analyses, :dashboards, :folders) SENSITIVE = [] include Aws::Structure end |