Class: Aws::QuickSight::Types::AssetBundleExportJobResourceIdOverrideConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleExportJobResourceIdOverrideConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An optional structure that configures resource ID overrides for the export job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix_for_all_resources ⇒ Boolean
An option to request a CloudFormation variable for a prefix to be prepended to each resource’s ID before import.
Instance Attribute Details
#prefix_for_all_resources ⇒ Boolean
An option to request a CloudFormation variable for a prefix to be prepended to each resource’s ID before import. The prefix is only added to the asset IDs and does not change the name of the asset.
1612 1613 1614 1615 1616 |
# File 'lib/aws-sdk-quicksight/types.rb', line 1612 class AssetBundleExportJobResourceIdOverrideConfiguration < Struct.new( :prefix_for_all_resources) SENSITIVE = [] include Aws::Structure end |