Class: Aws::QuickSight::Types::AssetBundleExportJobValidationStrategy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The option to relax the validation that is required to export each asset. When StrictModeForAllResource is set to false, validation is skipped for specific UI errors.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#strict_mode_for_all_resourcesBoolean

A Boolean value that indicates whether to export resources under strict or lenient mode.

Returns:

  • (Boolean)


1923
1924
1925
1926
1927
# File 'lib/aws-sdk-quicksight/types.rb', line 1923

class AssetBundleExportJobValidationStrategy < Struct.new(
  :strict_mode_for_all_resources)
  SENSITIVE = []
  include Aws::Structure
end