Class: Aws::QuickSight::Types::AssetBundleImportJobResourceIdOverrideConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportJobResourceIdOverrideConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An optional structure that configures resource ID overrides for the import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix_for_all_resources ⇒ String
An option to request a CloudFormation variable for a prefix to be prepended to each resource’s ID before import.
Instance Attribute Details
#prefix_for_all_resources ⇒ String
An option to request a CloudFormation variable for a prefix to be prepended to each resource’s ID before import. The prefix is only added to the asset IDs and does not change the name of the asset.
2395 2396 2397 2398 2399 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2395 class AssetBundleImportJobResourceIdOverrideConfiguration < Struct.new( :prefix_for_all_resources) SENSITIVE = [] include Aws::Structure end |