Class: Aws::QuickSight::Types::AssetBundleImportJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A summary of the import job that includes details of the requested job’s configuration and its current status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the import job.
-
#asset_bundle_import_job_id ⇒ String
The ID of the job.
-
#created_time ⇒ Time
The time that the import job was created.
-
#failure_action ⇒ String
The failure action for the import job.
-
#job_status ⇒ String
The current status of the import job.
Instance Attribute Details
#arn ⇒ String
The ARN of the import job.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2427 class AssetBundleImportJobSummary < Struct.new( :job_status, :arn, :created_time, :asset_bundle_import_job_id, :failure_action) SENSITIVE = [] include Aws::Structure end |
#asset_bundle_import_job_id ⇒ String
The ID of the job. This ID is unique while the job is running. After the job is completed, you can reuse this ID for another job.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2427 class AssetBundleImportJobSummary < Struct.new( :job_status, :arn, :created_time, :asset_bundle_import_job_id, :failure_action) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that the import job was created.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2427 class AssetBundleImportJobSummary < Struct.new( :job_status, :arn, :created_time, :asset_bundle_import_job_id, :failure_action) SENSITIVE = [] include Aws::Structure end |
#failure_action ⇒ String
The failure action for the import job.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2427 class AssetBundleImportJobSummary < Struct.new( :job_status, :arn, :created_time, :asset_bundle_import_job_id, :failure_action) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The current status of the import job.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2427 class AssetBundleImportJobSummary < Struct.new( :job_status, :arn, :created_time, :asset_bundle_import_job_id, :failure_action) SENSITIVE = [] include Aws::Structure end |