Class: Aws::QuickSight::Types::AssetBundleImportJobTopicV2OverrideParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportJobTopicV2OverrideParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The override parameters for a single topic that is being imported.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A new description for the topic.
-
#name ⇒ String
A new name for the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to apply overrides to.
Instance Attribute Details
#description ⇒ String
A new description for the topic.
2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2897 class AssetBundleImportJobTopicV2OverrideParameters < Struct.new( :topic_id, :name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A new name for the topic.
2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2897 class AssetBundleImportJobTopicV2OverrideParameters < Struct.new( :topic_id, :name, :description) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to apply overrides to.
2897 2898 2899 2900 2901 2902 2903 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2897 class AssetBundleImportJobTopicV2OverrideParameters < Struct.new( :topic_id, :name, :description) SENSITIVE = [] include Aws::Structure end |