Class: Aws::QuickSight::Types::AssetBundleImportJobTopicV2OverridePermissions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportJobTopicV2OverridePermissions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An object that contains a list of permissions to be applied to a list of topic IDs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Types::AssetBundleResourcePermissions
A list of permissions for the topics that you want to apply overrides to.
-
#topic_ids ⇒ Array<String>
A list of topic IDs that you want to apply overrides to.
Instance Attribute Details
#permissions ⇒ Types::AssetBundleResourcePermissions
A list of permissions for the topics that you want to apply overrides to.
2920 2921 2922 2923 2924 2925 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2920 class AssetBundleImportJobTopicV2OverridePermissions < Struct.new( :topic_ids, :permissions) SENSITIVE = [] include Aws::Structure end |
#topic_ids ⇒ Array<String>
A list of topic IDs that you want to apply overrides to. You can use
* to override all topics in this asset bundle.
2920 2921 2922 2923 2924 2925 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2920 class AssetBundleImportJobTopicV2OverridePermissions < Struct.new( :topic_ids, :permissions) SENSITIVE = [] include Aws::Structure end |