Class: Aws::QuickSight::Types::AssetBundleImportSourceDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetBundleImportSourceDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A description of the import source that you provide at the start of an import job. This value is set to either ‘Body` or `S3Uri`, depending on how the `StartAssetBundleImportJobRequest` is configured.
Constant Summary collapse
- SENSITIVE =
[:body]
Instance Attribute Summary collapse
-
#body ⇒ String
An HTTPS download URL for the provided asset bundle that you optionally provided at the start of the import job.
-
#s3_uri ⇒ String
The Amazon S3 URI that you provided at the start of the import job.
Instance Attribute Details
#body ⇒ String
An HTTPS download URL for the provided asset bundle that you optionally provided at the start of the import job. This URL is valid for five minutes after issuance. Call ‘DescribeAssetBundleExportJob` again for a fresh URL if needed. The downloaded asset bundle is a `.qs` zip file.
2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2622 class AssetBundleImportSourceDescription < Struct.new( :body, :s3_uri) SENSITIVE = [:body] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 URI that you provided at the start of the import job.
2622 2623 2624 2625 2626 2627 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2622 class AssetBundleImportSourceDescription < Struct.new( :body, :s3_uri) SENSITIVE = [:body] include Aws::Structure end |