Class: Aws::QuickSight::Types::AssetOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AssetOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An array of analysis level configurations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_action_defaults ⇒ Types::VisualCustomActionDefaults
A list of visual custom actions for the analysis.
-
#excluded_data_set_arns ⇒ Array<String>
A list of dataset ARNS to exclude from Dashboard Q&A.
-
#q_business_insights_status ⇒ String
Determines whether insight summaries from Amazon Q Business are allowed in Dashboard Q&A.
-
#timezone ⇒ String
Determines the timezone for the analysis.
-
#visual_messages ⇒ Types::VisualMessages
The configuration options for the messages that are displayed on visuals in the analysis.
-
#week_start ⇒ String
Determines the week start day for an analysis.
Instance Attribute Details
#custom_action_defaults ⇒ Types::VisualCustomActionDefaults
A list of visual custom actions for the analysis.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |
#excluded_data_set_arns ⇒ Array<String>
A list of dataset ARNS to exclude from Dashboard Q&A.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |
#q_business_insights_status ⇒ String
Determines whether insight summaries from Amazon Q Business are allowed in Dashboard Q&A.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
Determines the timezone for the analysis.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |
#visual_messages ⇒ Types::VisualMessages
The configuration options for the messages that are displayed on visuals in the analysis.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |
#week_start ⇒ String
Determines the week start day for an analysis.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2906 class AssetOptions < Struct.new( :timezone, :week_start, :q_business_insights_status, :excluded_data_set_arns, :custom_action_defaults, :visual_messages) SENSITIVE = [] include Aws::Structure end |