Class: Aws::QuickSight::Types::AthenaParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::AthenaParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Parameters for Amazon Athena.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_account_role_arn ⇒ String
Use ‘ConsumerAccountRoleArn` to perform cross-account Athena access.
-
#identity_center_configuration ⇒ Types::IdentityCenterConfiguration
An optional parameter that configures IAM Identity Center authentication to grant Quick Sight access to your workgroup.
-
#role_arn ⇒ String
Use the ‘RoleArn` structure to override an account-wide role for a specific Athena data source.
-
#work_group ⇒ String
The workgroup that Amazon Athena uses.
Instance Attribute Details
#consumer_account_role_arn ⇒ String
Use ‘ConsumerAccountRoleArn` to perform cross-account Athena access. This is an IAM role ARN in the same AWS account as the Athena resources you want to access. Provide this along with `RoleArn` to enable role-chaining, where Amazon Quick Sight first assumes the `RoleArn` and then assumes the `ConsumerAccountRoleArn` to access Athena resources.
2735 2736 2737 2738 2739 2740 2741 2742 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2735 class AthenaParameters < Struct.new( :work_group, :role_arn, :consumer_account_role_arn, :identity_center_configuration) SENSITIVE = [] include Aws::Structure end |
#identity_center_configuration ⇒ Types::IdentityCenterConfiguration
An optional parameter that configures IAM Identity Center authentication to grant Quick Sight access to your workgroup.
This parameter can only be specified if your Quick Sight account is configured with IAM Identity Center.
2735 2736 2737 2738 2739 2740 2741 2742 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2735 class AthenaParameters < Struct.new( :work_group, :role_arn, :consumer_account_role_arn, :identity_center_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
Use the ‘RoleArn` structure to override an account-wide role for a specific Athena data source. For example, say an account administrator has turned off all Athena access with an account-wide role. The administrator can then use `RoleArn` to bypass the account-wide role and allow Athena access for the single Athena data source that is specified in the structure, even if the account-wide role forbidding Athena access is still active.
2735 2736 2737 2738 2739 2740 2741 2742 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2735 class AthenaParameters < Struct.new( :work_group, :role_arn, :consumer_account_role_arn, :identity_center_configuration) SENSITIVE = [] include Aws::Structure end |
#work_group ⇒ String
The workgroup that Amazon Athena uses.
2735 2736 2737 2738 2739 2740 2741 2742 |
# File 'lib/aws-sdk-quicksight/types.rb', line 2735 class AthenaParameters < Struct.new( :work_group, :role_arn, :consumer_account_role_arn, :identity_center_configuration) SENSITIVE = [] include Aws::Structure end |