Class: Aws::QuickSight::Types::BatchCreateTopicReviewedAnswerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchCreateTopicReviewedAnswerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answers ⇒ Array<Types::CreateTopicReviewedAnswer>
The definition of the Answers to be created.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a reviewed answer in.
-
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to create.
Instance Attribute Details
#answers ⇒ Array<Types::CreateTopicReviewedAnswer>
The definition of the Answers to be created.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3827 class BatchCreateTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answers) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a reviewed answer in.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3827 class BatchCreateTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answers) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
3827 3828 3829 3830 3831 3832 3833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3827 class BatchCreateTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answers) SENSITIVE = [] include Aws::Structure end |