Class: Aws::QuickSight::Types::BatchDeleteTopicReviewedAnswerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchDeleteTopicReviewedAnswerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#answer_ids ⇒ Array<String>
The Answer IDs of the Answers to be deleted.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to delete a reviewed answers in.
-
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to delete.
Instance Attribute Details
#answer_ids ⇒ Array<String>
The Answer IDs of the Answers to be deleted.
3682 3683 3684 3685 3686 3687 3688 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3682 class BatchDeleteTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answer_ids) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to delete a reviewed answers in.
3682 3683 3684 3685 3686 3687 3688 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3682 class BatchDeleteTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answer_ids) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic reviewed answer that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
3682 3683 3684 3685 3686 3687 3688 |
# File 'lib/aws-sdk-quicksight/types.rb', line 3682 class BatchDeleteTopicReviewedAnswerRequest < Struct.new( :aws_account_id, :topic_id, :answer_ids) SENSITIVE = [] include Aws::Structure end |