Class: Aws::QuickSight::Types::BatchDeleteTopicReviewedAnswerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BatchDeleteTopicReviewedAnswerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invalid_answers ⇒ Array<Types::InvalidTopicReviewedAnswer>
The definition of Answers that are invalid and not deleted.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#succeeded_answers ⇒ Array<Types::SucceededTopicReviewedAnswer>
The definition of Answers that are successfully deleted.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic reviewed answer that you want to delete.
Instance Attribute Details
#invalid_answers ⇒ Array<Types::InvalidTopicReviewedAnswer>
The definition of Answers that are invalid and not deleted.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#succeeded_answers ⇒ Array<Types::SucceededTopicReviewedAnswer>
The definition of Answers that are successfully deleted.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic reviewed answer that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4041 class BatchDeleteTopicReviewedAnswerResponse < Struct.new( :topic_id, :topic_arn, :succeeded_answers, :invalid_answers, :request_id, :status) SENSITIVE = [] include Aws::Structure end |