Class: Aws::QuickSight::Types::BodySectionRepeatConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::BodySectionRepeatConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Describes the configurations that are required to declare a section as repeating.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimension_configurations ⇒ Array<Types::BodySectionRepeatDimensionConfiguration>
List of ‘BodySectionRepeatDimensionConfiguration` values that describe the dataset column and constraints for the column used to repeat the contents of a section.
-
#non_repeating_visuals ⇒ Array<String>
List of visuals to exclude from repetition in repeating sections.
-
#page_break_configuration ⇒ Types::BodySectionRepeatPageBreakConfiguration
Page break configuration to apply for each repeating instance.
Instance Attribute Details
#dimension_configurations ⇒ Array<Types::BodySectionRepeatDimensionConfiguration>
List of ‘BodySectionRepeatDimensionConfiguration` values that describe the dataset column and constraints for the column used to repeat the contents of a section.
4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4080 class BodySectionRepeatConfiguration < Struct.new( :dimension_configurations, :page_break_configuration, :non_repeating_visuals) SENSITIVE = [] include Aws::Structure end |
#non_repeating_visuals ⇒ Array<String>
List of visuals to exclude from repetition in repeating sections. The visuals will render identically, and ignore the repeating configurations in all repeating instances.
4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4080 class BodySectionRepeatConfiguration < Struct.new( :dimension_configurations, :page_break_configuration, :non_repeating_visuals) SENSITIVE = [] include Aws::Structure end |
#page_break_configuration ⇒ Types::BodySectionRepeatPageBreakConfiguration
Page break configuration to apply for each repeating instance.
4080 4081 4082 4083 4084 4085 4086 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4080 class BodySectionRepeatConfiguration < Struct.new( :dimension_configurations, :page_break_configuration, :non_repeating_visuals) SENSITIVE = [] include Aws::Structure end |