Class: Aws::QuickSight::Types::CalculatedField
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CalculatedField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The calculated field of an analysis.
Constant Summary collapse
- SENSITIVE =
[:expression]
Instance Attribute Summary collapse
-
#data_set_identifier ⇒ String
The data set that is used in this calculated field.
-
#expression ⇒ String
The expression of the calculated field.
-
#name ⇒ String
The name of the calculated field.
Instance Attribute Details
#data_set_identifier ⇒ String
The data set that is used in this calculated field.
4650 4651 4652 4653 4654 4655 4656 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4650 class CalculatedField < Struct.new( :data_set_identifier, :name, :expression) SENSITIVE = [:expression] include Aws::Structure end |
#expression ⇒ String
The expression of the calculated field.
4650 4651 4652 4653 4654 4655 4656 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4650 class CalculatedField < Struct.new( :data_set_identifier, :name, :expression) SENSITIVE = [:expression] include Aws::Structure end |
#name ⇒ String
The name of the calculated field.
4650 4651 4652 4653 4654 4655 4656 |
# File 'lib/aws-sdk-quicksight/types.rb', line 4650 class CalculatedField < Struct.new( :data_set_identifier, :name, :expression) SENSITIVE = [:expression] include Aws::Structure end |