Class: Aws::QuickSight::Types::CastColumnTypesOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CastColumnTypesOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that changes the data types of one or more columns in the dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for this operation.
-
#cast_column_type_operations ⇒ Array<Types::CastColumnTypeOperation>
The list of column type casting operations to perform.
-
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the type casting.
Instance Attribute Details
#alias ⇒ String
Alias for this operation.
5776 5777 5778 5779 5780 5781 5782 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5776 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |
#cast_column_type_operations ⇒ Array<Types::CastColumnTypeOperation>
The list of column type casting operations to perform.
5776 5777 5778 5779 5780 5781 5782 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5776 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::TransformOperationSource
The source transform operation that provides input data for the type casting.
5776 5777 5778 5779 5780 5781 5782 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5776 class CastColumnTypesOperation < Struct.new( :alias, :source, :cast_column_type_operations) SENSITIVE = [] include Aws::Structure end |