Class: Aws::QuickSight::Types::ColumnGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Groupings of columns that work together in certain Quick Sight features. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#geo_spatial_column_groupTypes::GeoSpatialColumnGroup

Geospatial column group that denotes a hierarchy.



5293
5294
5295
5296
5297
# File 'lib/aws-sdk-quicksight/types.rb', line 5293

class ColumnGroup < Struct.new(
  :geo_spatial_column_group)
  SENSITIVE = []
  include Aws::Structure
end