Class: Aws::QuickSight::Types::ColumnHierarchy
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ColumnHierarchy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The option that determines the hierarchy of the fields for a visual element.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date_time_hierarchy ⇒ Types::DateTimeHierarchy
The option that determines the hierarchy of any
DateTimefields. -
#explicit_hierarchy ⇒ Types::ExplicitHierarchy
The option that determines the hierarchy of the fields that are built within a visual's field wells.
-
#predefined_hierarchy ⇒ Types::PredefinedHierarchy
The option that determines the hierarchy of the fields that are defined during data preparation.
Instance Attribute Details
#date_time_hierarchy ⇒ Types::DateTimeHierarchy
The option that determines the hierarchy of any DateTime fields.
6713 6714 6715 6716 6717 6718 6719 |
# File 'lib/aws-sdk-quicksight/types.rb', line 6713 class ColumnHierarchy < Struct.new( :explicit_hierarchy, :date_time_hierarchy, :predefined_hierarchy) SENSITIVE = [] include Aws::Structure end |
#explicit_hierarchy ⇒ Types::ExplicitHierarchy
The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
6713 6714 6715 6716 6717 6718 6719 |
# File 'lib/aws-sdk-quicksight/types.rb', line 6713 class ColumnHierarchy < Struct.new( :explicit_hierarchy, :date_time_hierarchy, :predefined_hierarchy) SENSITIVE = [] include Aws::Structure end |
#predefined_hierarchy ⇒ Types::PredefinedHierarchy
The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.
6713 6714 6715 6716 6717 6718 6719 |
# File 'lib/aws-sdk-quicksight/types.rb', line 6713 class ColumnHierarchy < Struct.new( :explicit_hierarchy, :date_time_hierarchy, :predefined_hierarchy) SENSITIVE = [] include Aws::Structure end |