Class: Aws::QuickSight::Types::ColumnHierarchy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The option that determines the hierarchy of the fields for a visual element.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#date_time_hierarchyTypes::DateTimeHierarchy

The option that determines the hierarchy of any ‘DateTime` fields.



6340
6341
6342
6343
6344
6345
6346
# File 'lib/aws-sdk-quicksight/types.rb', line 6340

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#explicit_hierarchyTypes::ExplicitHierarchy

The option that determines the hierarchy of the fields that are built within a visual’s field wells. These fields can’t be duplicated to other visuals.



6340
6341
6342
6343
6344
6345
6346
# File 'lib/aws-sdk-quicksight/types.rb', line 6340

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_hierarchyTypes::PredefinedHierarchy

The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.



6340
6341
6342
6343
6344
6345
6346
# File 'lib/aws-sdk-quicksight/types.rb', line 6340

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end