Class: Aws::QuickSight::Types::ColumnHierarchy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The option that determines the hierarchy of the fields for a visual element.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#date_time_hierarchyTypes::DateTimeHierarchy

The option that determines the hierarchy of any ‘DateTime` fields.



6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-quicksight/types.rb', line 6314

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#explicit_hierarchyTypes::ExplicitHierarchy

The option that determines the hierarchy of the fields that are built within a visual’s field wells. These fields can’t be duplicated to other visuals.



6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-quicksight/types.rb', line 6314

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#predefined_hierarchyTypes::PredefinedHierarchy

The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.



6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-quicksight/types.rb', line 6314

class ColumnHierarchy < Struct.new(
  :explicit_hierarchy,
  :date_time_hierarchy,
  :predefined_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end