Class: Aws::QuickSight::Types::ColumnToUnpivot
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ColumnToUnpivot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Specifies a column to be unpivoted, transforming it from a column into rows with associated values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_name ⇒ String
The name of the column to unpivot from the source data.
-
#new_value ⇒ String
The value to assign to this column in the unpivoted result, typically the column name or a descriptive label.
Instance Attribute Details
#column_name ⇒ String
The name of the column to unpivot from the source data.
5488 5489 5490 5491 5492 5493 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5488 class ColumnToUnpivot < Struct.new( :column_name, :new_value) SENSITIVE = [] include Aws::Structure end |
#new_value ⇒ String
The value to assign to this column in the unpivoted result, typically the column name or a descriptive label.
5488 5489 5490 5491 5492 5493 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5488 class ColumnToUnpivot < Struct.new( :column_name, :new_value) SENSITIVE = [] include Aws::Structure end |