Class: Aws::QuickSight::Types::ComboChartConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ComboChartConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration of a ComboChartVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bar_data_labels ⇒ Types::DataLabelOptions
The options that determine if visual data labels are displayed.
-
#bars_arrangement ⇒ String
Determines the bar arrangement in a combo chart.
-
#category_axis ⇒ Types::AxisDisplayOptions
The category axis of a combo chart.
-
#category_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
-
#color_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
-
#default_series_settings ⇒ Types::ComboChartDefaultSeriesSettings
The options that determine the default presentation of all series in
ComboChartVisual. -
#field_wells ⇒ Types::ComboChartFieldWells
The field wells of the visual.
-
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
-
#legend ⇒ Types::LegendOptions
The legend display setup of the visual.
-
#line_data_labels ⇒ Types::DataLabelOptions
The options that determine if visual data labels are displayed.
-
#primary_y_axis_display_options ⇒ Types::AxisDisplayOptions
The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
-
#primary_y_axis_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
-
#reference_lines ⇒ Array<Types::ReferenceLine>
The reference line setup of the visual.
-
#secondary_y_axis_display_options ⇒ Types::AxisDisplayOptions
The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
-
#secondary_y_axis_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
-
#series ⇒ Array<Types::ComboSeriesItem>
The series item configuration of a
ComboChartVisual. -
#single_axis_options ⇒ Types::SingleAxisOptions
The settings of a chart's single axis configuration.
-
#sort_configuration ⇒ Types::ComboChartSortConfiguration
The sort configuration of a
ComboChartVisual. -
#tooltip ⇒ Types::TooltipOptions
The legend display setup of the visual.
-
#visual_palette ⇒ Types::VisualPalette
The palette (chart color) display setup of the visual.
Instance Attribute Details
#bar_data_labels ⇒ Types::DataLabelOptions
The options that determine if visual data labels are displayed.
The data label options for a bar in a combo chart.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#bars_arrangement ⇒ String
Determines the bar arrangement in a combo chart. The following are valid values in this structure:
-
CLUSTERED: For clustered bar combo charts. -
STACKED: For stacked bar combo charts. -
STACKED_PERCENT: Do not use. If you use this value, the operation returns a validation error.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#category_axis ⇒ Types::AxisDisplayOptions
The category axis of a combo chart.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#category_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#color_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#default_series_settings ⇒ Types::ComboChartDefaultSeriesSettings
The options that determine the default presentation of all series in
ComboChartVisual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#field_wells ⇒ Types::ComboChartFieldWells
The field wells of the visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#legend ⇒ Types::LegendOptions
The legend display setup of the visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#line_data_labels ⇒ Types::DataLabelOptions
The options that determine if visual data labels are displayed.
The data label options for a line in a combo chart.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#primary_y_axis_display_options ⇒ Types::AxisDisplayOptions
The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#primary_y_axis_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#reference_lines ⇒ Array<Types::ReferenceLine>
The reference line setup of the visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#secondary_y_axis_display_options ⇒ Types::AxisDisplayOptions
The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#secondary_y_axis_label_options ⇒ Types::ChartAxisLabelOptions
The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#series ⇒ Array<Types::ComboSeriesItem>
The series item configuration of a ComboChartVisual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#single_axis_options ⇒ Types::SingleAxisOptions
The settings of a chart's single axis configuration.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#sort_configuration ⇒ Types::ComboChartSortConfiguration
The sort configuration of a ComboChartVisual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#tooltip ⇒ Types::TooltipOptions
The legend display setup of the visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |
#visual_palette ⇒ Types::VisualPalette
The palette (chart color) display setup of the visual.
7061 7062 7063 7064 7065 7066 7067 7068 7069 7070 7071 7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 7084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7061 class ComboChartConfiguration < Struct.new( :field_wells, :sort_configuration, :bars_arrangement, :category_axis, :category_label_options, :primary_y_axis_display_options, :primary_y_axis_label_options, :secondary_y_axis_display_options, :secondary_y_axis_label_options, :single_axis_options, :color_label_options, :default_series_settings, :series, :legend, :bar_data_labels, :line_data_labels, :tooltip, :reference_lines, :visual_palette, :interactions) SENSITIVE = [] include Aws::Structure end |