Class: Aws::QuickSight::Types::ComboChartConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The configuration of a ‘ComboChartVisual`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bar_data_labelsTypes::DataLabelOptions

The options that determine if visual data labels are displayed.

The data label options for a bar in a combo chart.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#bars_arrangementString

Determines the bar arrangement in a combo chart. The following are valid values in this structure:

  • ‘CLUSTERED`: For clustered bar combo charts.

  • ‘STACKED`: For stacked bar combo charts.

  • ‘STACKED_PERCENT`: Do not use. If you use this value, the operation returns a validation error.

Returns:

  • (String)


6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#category_axisTypes::AxisDisplayOptions

The category axis of a combo chart.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#category_label_optionsTypes::ChartAxisLabelOptions

The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#color_label_optionsTypes::ChartAxisLabelOptions

The label options (label text, label visibility, and sort icon visibility) of a combo chart’s color field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#default_series_settingsTypes::ComboChartDefaultSeriesSettings

The options that determine the default presentation of all series in ‘ComboChartVisual`.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_wellsTypes::ComboChartFieldWells

The field wells of the visual.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#interactionsTypes::VisualInteractionOptions

The general visual interactions setup for a visual.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#legendTypes::LegendOptions

The legend display setup of the visual.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#line_data_labelsTypes::DataLabelOptions

The options that determine if visual data labels are displayed.

The data label options for a line in a combo chart.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#primary_y_axis_display_optionsTypes::AxisDisplayOptions

The label display options (grid line, range, scale, and axis step) of a combo chart’s primary y-axis (bar) field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#primary_y_axis_label_optionsTypes::ChartAxisLabelOptions

The label options (label text, label visibility, and sort icon visibility) of a combo chart’s primary y-axis (bar) field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#reference_linesArray<Types::ReferenceLine>

The reference line setup of the visual.

Returns:



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_y_axis_display_optionsTypes::AxisDisplayOptions

The label display options (grid line, range, scale, axis step) of a combo chart’s secondary y-axis (line) field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#secondary_y_axis_label_optionsTypes::ChartAxisLabelOptions

The label options (label text, label visibility, and sort icon visibility) of a combo chart’s secondary y-axis(line) field well.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#seriesArray<Types::ComboSeriesItem>

The series item configuration of a ‘ComboChartVisual`.

Returns:



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#single_axis_optionsTypes::SingleAxisOptions

The settings of a chart’s single axis configuration.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_configurationTypes::ComboChartSortConfiguration

The sort configuration of a ‘ComboChartVisual`.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#tooltipTypes::TooltipOptions

The legend display setup of the visual.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#visual_paletteTypes::VisualPalette

The palette (chart color) display setup of the visual.



6992
6993
6994
6995
6996
6997
6998
6999
7000
7001
7002
7003
7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
# File 'lib/aws-sdk-quicksight/types.rb', line 6992

class ComboChartConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :bars_arrangement,
  :category_axis,
  :category_label_options,
  :primary_y_axis_display_options,
  :primary_y_axis_label_options,
  :secondary_y_axis_display_options,
  :secondary_y_axis_label_options,
  :single_axis_options,
  :color_label_options,
  :default_series_settings,
  :series,
  :legend,
  :bar_data_labels,
  :line_data_labels,
  :tooltip,
  :reference_lines,
  :visual_palette,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end