Class: Aws::QuickSight::Types::ComboChartDefaultSeriesSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The options that determine the default presentation of all series in ‘ComboChartVisual`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#border_settingsTypes::BorderSettings

Border settings for all bar series in the visual.



5708
5709
5710
5711
5712
5713
5714
5715
# File 'lib/aws-sdk-quicksight/types.rb', line 5708

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#decal_settingsTypes::DecalSettings

Decal settings for all series in the visual.



5708
5709
5710
5711
5712
5713
5714
5715
# File 'lib/aws-sdk-quicksight/types.rb', line 5708

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#line_style_settingsTypes::LineChartLineStyleSettings

Line styles options for all line series in the visual.



5708
5709
5710
5711
5712
5713
5714
5715
# File 'lib/aws-sdk-quicksight/types.rb', line 5708

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end

#marker_style_settingsTypes::LineChartMarkerStyleSettings

Marker styles options for all line series in the visual.



5708
5709
5710
5711
5712
5713
5714
5715
# File 'lib/aws-sdk-quicksight/types.rb', line 5708

class ComboChartDefaultSeriesSettings < Struct.new(
  :line_style_settings,
  :marker_style_settings,
  :decal_settings,
  :border_settings)
  SENSITIVE = []
  include Aws::Structure
end