Class: Aws::QuickSight::Types::ComboChartDefaultSeriesSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ComboChartDefaultSeriesSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the default presentation of all series in ‘ComboChartVisual`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#border_settings ⇒ Types::BorderSettings
Border settings for all bar series in the visual.
-
#decal_settings ⇒ Types::DecalSettings
Decal settings for all series in the visual.
-
#line_style_settings ⇒ Types::LineChartLineStyleSettings
Line styles options for all line series in the visual.
-
#marker_style_settings ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for all line series in the visual.
Instance Attribute Details
#border_settings ⇒ Types::BorderSettings
Border settings for all bar series in the visual.
5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5708 class ComboChartDefaultSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings, :border_settings) SENSITIVE = [] include Aws::Structure end |
#decal_settings ⇒ Types::DecalSettings
Decal settings for all series in the visual.
5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5708 class ComboChartDefaultSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings, :border_settings) SENSITIVE = [] include Aws::Structure end |
#line_style_settings ⇒ Types::LineChartLineStyleSettings
Line styles options for all line series in the visual.
5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5708 class ComboChartDefaultSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings, :border_settings) SENSITIVE = [] include Aws::Structure end |
#marker_style_settings ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for all line series in the visual.
5708 5709 5710 5711 5712 5713 5714 5715 |
# File 'lib/aws-sdk-quicksight/types.rb', line 5708 class ComboChartDefaultSeriesSettings < Struct.new( :line_style_settings, :marker_style_settings, :decal_settings, :border_settings) SENSITIVE = [] include Aws::Structure end |