Class: Aws::QuickSight::Types::ComboChartVisual
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ComboChartVisual
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A combo chart.
The ComboChartVisual includes stacked bar combo charts and clustered
bar combo charts
For more information, see Using combo charts in the Amazon Quick Suite User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::VisualCustomAction>
The list of custom actions that are configured for a visual.
-
#chart_configuration ⇒ Types::ComboChartConfiguration
The configuration settings of the visual.
-
#column_hierarchies ⇒ Array<Types::ColumnHierarchy>
The column hierarchy that is used during drill-downs and drill-ups.
-
#subtitle ⇒ Types::VisualSubtitleLabelOptions
The subtitle that is displayed on the visual.
-
#title ⇒ Types::VisualTitleLabelOptions
The title that is displayed on the visual.
-
#visual_content_alt_text ⇒ String
The alt text for the visual.
-
#visual_id ⇒ String
The unique identifier of a visual.
Instance Attribute Details
#actions ⇒ Array<Types::VisualCustomAction>
The list of custom actions that are configured for a visual.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#chart_configuration ⇒ Types::ComboChartConfiguration
The configuration settings of the visual.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#column_hierarchies ⇒ Array<Types::ColumnHierarchy>
The column hierarchy that is used during drill-downs and drill-ups.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#subtitle ⇒ Types::VisualSubtitleLabelOptions
The subtitle that is displayed on the visual.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#title ⇒ Types::VisualTitleLabelOptions
The title that is displayed on the visual.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#visual_content_alt_text ⇒ String
The alt text for the visual.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |
#visual_id ⇒ String
The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
7240 7241 7242 7243 7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7240 class ComboChartVisual < Struct.new( :visual_id, :title, :subtitle, :chart_configuration, :actions, :column_hierarchies, :visual_content_alt_text) SENSITIVE = [] include Aws::Structure end |