Class: Aws::QuickSight::Types::CreateActionConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateActionConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#action_connector_id ⇒ String
A unique identifier for the action connector.
-
#authentication_config ⇒ Types::AuthConfig
The authentication configuration for connecting to the external service.
-
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with the action connector.
-
#description ⇒ String
An optional description of the action connector.
-
#name ⇒ String
A descriptive name for the action connector.
-
#permissions ⇒ Array<Types::ResourcePermission>
The permissions configuration that defines which users, groups, or namespaces can access this action connector and what operations they can perform.
-
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the action connector for resource management and organization.
-
#type ⇒ String
The type of action connector.
-
#vpc_connection_arn ⇒ String
The ARN of the VPC connection to use for secure connectivity to the external service.
Instance Attribute Details
#action_connector_id ⇒ String
A unique identifier for the action connector. This ID must be unique within the Amazon Web Services account. The ‘ActionConnectorId` must not start with the prefix `quicksuite-`
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#authentication_config ⇒ Types::AuthConfig
The authentication configuration for connecting to the external service. This includes the authentication type, base URL, and authentication metadata such as client credentials or API keys.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#aws_account_id ⇒ String
The Amazon Web Services account ID associated with the action connector.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
An optional description of the action connector.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
A descriptive name for the action connector.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
The permissions configuration that defines which users, groups, or namespaces can access this action connector and what operations they can perform.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to apply to the action connector for resource management and organization.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#type ⇒ String
The type of action connector.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |
#vpc_connection_arn ⇒ String
The ARN of the VPC connection to use for secure connectivity to the external service.
7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7817 class CreateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :type, :authentication_config, :description, :permissions, :vpc_connection_arn, :tags) SENSITIVE = [:name, :description] include Aws::Structure end |