Class: Aws::QuickSight::Types::CreateAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:starter_prompts, :welcome_message, :custom_prompt_input]

Instance Attribute Summary collapse

Instance Attribute Details

#action_connectorsArray<String>

The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.

Returns:

  • (Array<String>)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#agent_idString

A unique identifier for the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#agent_lifecycleString

The lifecycle state of the agent. Valid values are ‘PREVIEW` and `PUBLISHED`.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#custom_prompt_inputTypes::CustomPromptInput

The custom prompt configuration for the agent.



8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#descriptionString

A description of the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#icon_idString

The icon identifier for the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#nameString

The name of the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#spacesArray<String>

The Amazon Resource Names (ARNs) of the spaces to attach to the agent.

Returns:

  • (Array<String>)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#starter_promptsArray<String>

A list of starter prompts that are displayed to users when they begin interacting with the agent.

Returns:

  • (Array<String>)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#welcome_messageString

The welcome message that is displayed when a user starts a conversation with the agent.

Returns:

  • (String)


8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/aws-sdk-quicksight/types.rb', line 8077

class CreateAgentRequest < Struct.new(
  :spaces,
  :action_connectors,
  :aws_account_id,
  :agent_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :agent_lifecycle,
  :custom_prompt_input)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end