Class: Aws::QuickSight::Types::CreateAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:starter_prompts, :welcome_message, :custom_prompt_input]
Instance Attribute Summary collapse
-
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
-
#agent_id ⇒ String
A unique identifier for the agent.
-
#agent_lifecycle ⇒ String
The lifecycle state of the agent.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
-
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
-
#description ⇒ String
A description of the agent.
-
#icon_id ⇒ String
The icon identifier for the agent.
-
#name ⇒ String
The name of the agent.
-
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
-
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
-
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
Instance Attribute Details
#action_connectors ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#agent_id ⇒ String
A unique identifier for the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#agent_lifecycle ⇒ String
The lifecycle state of the agent. Valid values are ‘PREVIEW` and `PUBLISHED`.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#description ⇒ String
A description of the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#icon_id ⇒ String
The icon identifier for the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#name ⇒ String
The name of the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#spaces ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
8077 8078 8079 8080 8081 8082 8083 8084 8085 8086 8087 8088 8089 8090 8091 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8077 class CreateAgentRequest < Struct.new( :spaces, :action_connectors, :aws_account_id, :agent_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :agent_lifecycle, :custom_prompt_input) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |