Class: Aws::QuickSight::Types::CreateAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The ID for the analysis that you’re creating. This ID displays in the URL of the analysis.

Returns:

  • (String)


8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account where you are creating an analysis.

Returns:

  • (String)


8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#definitionTypes::AnalysisDefinition

The definition of an analysis.

A definition is the data model of all features in a Dashboard, Template, or Analysis.

Either a ‘SourceEntity` or a `Definition` must be provided in order for the request to be valid.



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#folder_arnsArray<String>

When you create the analysis, Amazon Quick Sight adds the analysis to these folders.

Returns:

  • (Array<String>)


8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive name for the analysis that you’re creating. This name displays for the analysis in the Amazon Quick Sight console.

Returns:

  • (String)


8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::Parameters

The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.

Returns:



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::ResourcePermission>

A structure that describes the principals and the resource-level permissions on an analysis. You can use the ‘Permissions` structure to grant permissions by providing a list of Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

To specify no permissions, omit ‘Permissions`.

Returns:



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#source_entityTypes::AnalysisSourceEntity

A source entity to use for the analysis that you’re creating. This metadata structure contains details that describe a source template and one or more datasets.

Either a ‘SourceEntity` or a `Definition` must be provided in order for the request to be valid.



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

Returns:



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#theme_arnString

The ARN for the theme to apply to the analysis that you’re creating. To see the theme in the Amazon Quick Sight console, make sure that you have access to it.

Returns:

  • (String)


8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end

#validation_strategyTypes::ValidationStrategy

The option to relax the validation needed to create an analysis with definition objects. This skips the validation step for specific errors.



8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-quicksight/types.rb', line 8199

class CreateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :permissions,
  :source_entity,
  :theme_arn,
  :tags,
  :definition,
  :validation_strategy,
  :folder_arns)
  SENSITIVE = []
  include Aws::Structure
end