Class: Aws::QuickSight::Types::CreateCustomPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateCustomPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create the custom permissions profile in.
-
#capabilities ⇒ Types::Capabilities
A set of actions to include in the custom permissions profile.
-
#custom_permissions_name ⇒ String
The name of the custom permissions profile that you want to create.
-
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile.
-
#tags ⇒ Array<Types::Tag>
The tags to associate with the custom permissions profile.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create the custom permissions profile in.
8545 8546 8547 8548 8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8545 class CreateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance, :tags) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::Capabilities
A set of actions to include in the custom permissions profile.
8545 8546 8547 8548 8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8545 class CreateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance, :tags) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The name of the custom permissions profile that you want to create.
8545 8546 8547 8548 8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8545 class CreateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance, :tags) SENSITIVE = [] include Aws::Structure end |
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile.
When governance controls are defined for a category, any
capabilities in that category not explicitly set to ALLOW in
Capabilities are denied. Even newly added capabilities in the
category are implicitly disabled when Amazon Quick releases them.
8545 8546 8547 8548 8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8545 class CreateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to associate with the custom permissions profile.
8545 8546 8547 8548 8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8545 class CreateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance, :tags) SENSITIVE = [] include Aws::Structure end |