Class: Aws::QuickSight::Types::CreateDataSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateDataSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset that you want to create.
-
#ingestion_arn ⇒ String
The ARN for the ingestion, which is triggered as a result of dataset creation if the import mode is SPICE.
-
#ingestion_id ⇒ String
The ID of the ingestion, which is triggered as a result of dataset creation if the import mode is SPICE.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#ingestion_arn ⇒ String
The ARN for the ingestion, which is triggered as a result of dataset creation if the import mode is SPICE.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#ingestion_id ⇒ String
The ID of the ingestion, which is triggered as a result of dataset creation if the import mode is SPICE.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9630 class CreateDataSetResponse < Struct.new( :arn, :data_set_id, :ingestion_arn, :ingestion_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |