Class: Aws::QuickSight::Types::CreateFlowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:flow_definition]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where you want to create the flow.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#descriptionString

The description for the flow.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#flow_definitionHash, ...

The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow's internal format. The format is subject to change.

Always derive or depend on the flow definition from the DescribeFlow operation to ensure you are working with the latest format.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#nameString

The display name for the flow.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#permissionsArray<Types::Permission>

Initial permissions for the flow. If omitted, the flow is created without any permissions.

Returns:



9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-quicksight/types.rb', line 9042

class CreateFlowRequest < Struct.new(
  :aws_account_id,
  :name,
  :description,
  :flow_definition,
  :permissions,
  :client_token)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end