Class: Aws::QuickSight::Types::CreateGroupMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateGroupMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#group_name ⇒ String
The name of the group that you want to add the user to.
-
#member_name ⇒ String
The name of the user that you want to add to the group membership.
-
#namespace ⇒ String
The namespace that you want the user to be a part of.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
9231 9232 9233 9234 9235 9236 9237 9238 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9231 class CreateGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to add the user to.
9231 9232 9233 9234 9235 9236 9237 9238 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9231 class CreateGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The name of the user that you want to add to the group membership.
9231 9232 9233 9234 9235 9236 9237 9238 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9231 class CreateGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that you want the user to be a part of.
9231 9232 9233 9234 9235 9236 9237 9238 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9231 class CreateGroupMembershipRequest < Struct.new( :member_name, :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |