Class: Aws::QuickSight::Types::CreateGroupMembershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


8669
8670
8671
8672
8673
8674
8675
8676
# File 'lib/aws-sdk-quicksight/types.rb', line 8669

class CreateGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group that you want to add the user to.

Returns:

  • (String)


8669
8670
8671
8672
8673
8674
8675
8676
# File 'lib/aws-sdk-quicksight/types.rb', line 8669

class CreateGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#member_nameString

The name of the user that you want to add to the group membership.

Returns:

  • (String)


8669
8670
8671
8672
8673
8674
8675
8676
# File 'lib/aws-sdk-quicksight/types.rb', line 8669

class CreateGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that you want the user to be a part of.

Returns:

  • (String)


8669
8670
8671
8672
8673
8674
8675
8676
# File 'lib/aws-sdk-quicksight/types.rb', line 8669

class CreateGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end