Class: Aws::QuickSight::Types::CreateGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The request object for this operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


9284
9285
9286
9287
9288
9289
9290
9291
# File 'lib/aws-sdk-quicksight/types.rb', line 9284

class CreateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the group that you want to create.

Returns:

  • (String)


9284
9285
9286
9287
9288
9289
9290
9291
# File 'lib/aws-sdk-quicksight/types.rb', line 9284

class CreateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

A name for the group that you want to create.

Returns:

  • (String)


9284
9285
9286
9287
9288
9289
9290
9291
# File 'lib/aws-sdk-quicksight/types.rb', line 9284

class CreateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that you want the group to be a part of.

Returns:

  • (String)


9284
9285
9286
9287
9288
9289
9290
9291
# File 'lib/aws-sdk-quicksight/types.rb', line 9284

class CreateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end