Class: Aws::QuickSight::Types::CreateGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The request object for this operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#description ⇒ String
A description for the group that you want to create.
-
#group_name ⇒ String
A name for the group that you want to create.
-
#namespace ⇒ String
The namespace that you want the group to be a part of.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
9243 9244 9245 9246 9247 9248 9249 9250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9243 class CreateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the group that you want to create.
9243 9244 9245 9246 9247 9248 9249 9250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9243 class CreateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
A name for the group that you want to create.
9243 9244 9245 9246 9247 9248 9249 9250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9243 class CreateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that you want the group to be a part of.
9243 9244 9245 9246 9247 9248 9249 9250 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9243 class CreateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |