Class: Aws::QuickSight::Types::CreateIAMPolicyAssignmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateIAMPolicyAssignmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assignment_name ⇒ String
The name of the assignment, also called a rule.
-
#assignment_status ⇒ String
The status of the assignment.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to assign an IAM policy to Amazon Quick Sight users or groups.
-
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that you want to assign the policy to.
-
#namespace ⇒ String
The namespace that contains the assignment.
-
#policy_arn ⇒ String
The ARN for the IAM policy to apply to the Amazon Quick Sight users and groups specified in this assignment.
Instance Attribute Details
#assignment_name ⇒ String
The name of the assignment, also called a rule. The name must be unique within the Amazon Web Services account.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |
#assignment_status ⇒ String
The status of the assignment. Possible values are as follows:
-
‘ENABLED` - Anything specified in this assignment is used when creating the data source.
-
‘DISABLED` - This assignment isn’t used when creating the data source.
-
‘DRAFT` - This assignment is an unfinished draft and isn’t used when creating the data source.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to assign an IAM policy to Amazon Quick Sight users or groups.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that you want to assign the policy to.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that contains the assignment.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The ARN for the IAM policy to apply to the Amazon Quick Sight users and groups specified in this assignment.
8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8768 class CreateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :assignment_status, :policy_arn, :identities, :namespace) SENSITIVE = [] include Aws::Structure end |