Class: Aws::QuickSight::Types::CreateIAMPolicyAssignmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateIAMPolicyAssignmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assignment_id ⇒ String
The ID for the assignment.
-
#assignment_name ⇒ String
The name of the assignment.
-
#assignment_status ⇒ String
The status of the assignment.
-
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that the IAM policy is assigned to.
-
#policy_arn ⇒ String
The ARN for the IAM policy that is applied to the Amazon Quick Sight users and groups specified in this assignment.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#assignment_id ⇒ String
The ID for the assignment.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#assignment_name ⇒ String
The name of the assignment. The name must be unique within the Amazon Web Services account.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#assignment_status ⇒ String
The status of the assignment. Possible values are as follows:
-
‘ENABLED` - Anything specified in this assignment is used when creating the data source.
-
‘DISABLED` - This assignment isn’t used when creating the data source.
-
‘DRAFT` - This assignment is an unfinished draft and isn’t used when creating the data source.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that the IAM policy is assigned to.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The ARN for the IAM policy that is applied to the Amazon Quick Sight users and groups specified in this assignment.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
7796 7797 7798 7799 7800 7801 7802 7803 7804 7805 7806 |
# File 'lib/aws-sdk-quicksight/types.rb', line 7796 class CreateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :assignment_status, :policy_arn, :identities, :request_id, :status) SENSITIVE = [] include Aws::Structure end |