Class: Aws::QuickSight::Types::CreateIngestionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateIngestionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#data_set_id ⇒ String
The ID of the dataset used in the ingestion.
-
#ingestion_id ⇒ String
An ID for the ingestion.
-
#ingestion_type ⇒ String
The type of ingestion that you want to create.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
8877 8878 8879 8880 8881 8882 8883 8884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8877 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID of the dataset used in the ingestion.
8877 8878 8879 8880 8881 8882 8883 8884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8877 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#ingestion_id ⇒ String
An ID for the ingestion.
8877 8878 8879 8880 8881 8882 8883 8884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8877 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |
#ingestion_type ⇒ String
The type of ingestion that you want to create.
8877 8878 8879 8880 8881 8882 8883 8884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8877 class CreateIngestionRequest < Struct.new( :data_set_id, :ingestion_id, :aws_account_id, :ingestion_type) SENSITIVE = [] include Aws::Structure end |