Class: Aws::QuickSight::Types::CreateKnowledgeBaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:knowledge_base_configuration]

Instance Attribute Summary collapse

Instance Attribute Details

#access_control_configurationTypes::AccessControlConfiguration

The access control configuration for the knowledge base. If you don't specify this parameter, document-level ACLs are disabled.



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the knowledge base.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#data_source_arnString

The Amazon Resource Name (ARN) of the data source for the knowledge base.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#descriptionString

A description for the knowledge base. If you don't specify a description, the knowledge base is created without one.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseConfiguration

The configuration settings for a knowledge base.



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for the knowledge base.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#media_extraction_configurationTypes::MediaExtractionConfiguration

The configuration for media extraction from knowledge base documents.



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#nameString

The name of the knowledge base.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#permissionsArray<Types::ResourcePermission>

A list of resource permissions on the knowledge base. Each entry grants a specified Amazon QuickSight principal either owner or viewer access. If you don't specify permissions, only the primary owner (if provided) receives owner access.

Returns:



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#primary_owner_arnString

The Amazon Resource Name (ARN) of the primary owner for the knowledge base. The specified user is always granted owner access, regardless of what is specified in the Permissions field. If you don't specify a primary owner, the knowledge base is created without one.

Returns:

  • (String)


10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags to assign to the knowledge base. If you don't specify tags, the knowledge base is created without tags.

Returns:



10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
# File 'lib/aws-sdk-quicksight/types.rb', line 10284

class CreateKnowledgeBaseRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :name,
  :data_source_arn,
  :knowledge_base_configuration,
  :description,
  :permissions,
  :media_extraction_configuration,
  :access_control_configuration,
  :primary_owner_arn,
  :tags)
  SENSITIVE = [:knowledge_base_configuration]
  include Aws::Structure
end