Class: Aws::QuickSight::Types::CreateKnowledgeBaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateKnowledgeBaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:knowledge_base_configuration]
Instance Attribute Summary collapse
-
#access_control_configuration ⇒ Types::AccessControlConfiguration
The access control configuration for the knowledge base.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
-
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the data source for the knowledge base.
-
#description ⇒ String
A description for the knowledge base.
-
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
The configuration settings for a knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
-
#media_extraction_configuration ⇒ Types::MediaExtractionConfiguration
The configuration for media extraction from knowledge base documents.
-
#name ⇒ String
The name of the knowledge base.
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the knowledge base.
-
#primary_owner_arn ⇒ String
The Amazon Resource Name (ARN) of the primary owner for the knowledge base.
-
#tags ⇒ Array<Types::Tag>
The tags to assign to the knowledge base.
Instance Attribute Details
#access_control_configuration ⇒ Types::AccessControlConfiguration
The access control configuration for the knowledge base. If you don't specify this parameter, document-level ACLs are disabled.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the knowledge base.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#data_source_arn ⇒ String
The Amazon Resource Name (ARN) of the data source for the knowledge base.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#description ⇒ String
A description for the knowledge base. If you don't specify a description, the knowledge base is created without one.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
The configuration settings for a knowledge base.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier for the knowledge base.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#media_extraction_configuration ⇒ Types::MediaExtractionConfiguration
The configuration for media extraction from knowledge base documents.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#name ⇒ String
The name of the knowledge base.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the knowledge base. Each entry grants a specified Amazon QuickSight principal either owner or viewer access. If you don't specify permissions, only the primary owner (if provided) receives owner access.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#primary_owner_arn ⇒ String
The Amazon Resource Name (ARN) of the primary owner for the
knowledge base. The specified user is always granted owner access,
regardless of what is specified in the Permissions field. If you
don't specify a primary owner, the knowledge base is created
without one.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to assign to the knowledge base. If you don't specify tags, the knowledge base is created without tags.
9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9539 class CreateKnowledgeBaseRequest < Struct.new( :aws_account_id, :knowledge_base_id, :name, :data_source_arn, :knowledge_base_configuration, :description, :permissions, :media_extraction_configuration, :access_control_configuration, :primary_owner_arn, :tags) SENSITIVE = [:knowledge_base_configuration] include Aws::Structure end |