Class: Aws::QuickSight::Types::CreateOAuthClientApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateOAuthClientApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#client_id ⇒ String
The client ID of the OAuth application that is registered with the identity provider.
-
#client_secret ⇒ String
The client secret of the OAuth application that is registered with the identity provider.
-
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used with.
-
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
-
#name ⇒ String
The display name for the OAuthClientApplication.
-
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
-
#o_auth_client_application_id ⇒ String
An ID for the OAuthClientApplication that you want to create.
-
#o_auth_client_authentication_type ⇒ String
The authentication type to use for the OAuthClientApplication.
-
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
-
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
-
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the OAuthClientApplication.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#client_id ⇒ String
The client ID of the OAuth application that is registered with the identity provider.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#client_secret ⇒ String
The client secret of the OAuth application that is registered with the identity provider.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used
with. Valid values are SNOWFLAKE.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#name ⇒ String
The display name for the OAuthClientApplication.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_client_application_id ⇒ String
An ID for the OAuthClientApplication that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_client_authentication_type ⇒ String
The authentication type to use for the OAuthClientApplication. This
determines the OAuth 2.0 grant flow that is used when the data
source connects to the identity provider. Valid values are TOKEN.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags assigned to the OAuthClientApplication.
10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 10483 10484 10485 10486 10487 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10472 class CreateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :tags) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |