Class: Aws::QuickSight::Types::CreateOAuthClientApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#client_idString

The client ID of the OAuth application that is registered with the identity provider.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#client_secretString

The client secret of the OAuth application that is registered with the identity provider.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#data_source_typeString

The type of data source that the OAuthClientApplication is used with. Valid values are SNOWFLAKE.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#identity_provider_vpc_connection_propertiesTypes::VpcConnectionProperties

VPC connection properties.



9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#nameString

The display name for the OAuthClientApplication.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_authorization_endpoint_urlString

The authorization endpoint URL of the identity provider that is used to obtain authorization codes.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_client_application_idString

An ID for the OAuthClientApplication that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_client_authentication_typeString

The authentication type to use for the OAuthClientApplication. This determines the OAuth 2.0 grant flow that is used when the data source connects to the identity provider. Valid values are TOKEN.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_scopesString

The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_token_endpoint_urlString

The token endpoint URL of the identity provider that is used to obtain access tokens.

Returns:

  • (String)


9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#tagsArray<Types::Tag>

Contains a map of the key-value pairs for the resource tag or tags assigned to the OAuthClientApplication.

Returns:



9764
9765
9766
9767
9768
9769
9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
# File 'lib/aws-sdk-quicksight/types.rb', line 9764

class CreateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :tags)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end