Class: Aws::QuickSight::Types::CreateRoleMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateRoleMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#member_name ⇒ String
The name of the group that you want to add to the role.
-
#namespace ⇒ String
The namespace that the role belongs to.
-
#role ⇒ String
The role that you want to add a group to.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
9572 9573 9574 9575 9576 9577 9578 9579 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9572 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The name of the group that you want to add to the role.
9572 9573 9574 9575 9576 9577 9578 9579 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9572 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that the role belongs to.
9572 9573 9574 9575 9576 9577 9578 9579 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9572 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role that you want to add a group to.
9572 9573 9574 9575 9576 9577 9578 9579 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9572 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |