Class: Aws::QuickSight::Types::CreateRoleMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateRoleMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#member_name ⇒ String
The name of the group that you want to add to the role.
-
#namespace ⇒ String
The namespace that the role belongs to.
-
#role ⇒ String
The role that you want to add a group to.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
8016 8017 8018 8019 8020 8021 8022 8023 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8016 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The name of the group that you want to add to the role.
8016 8017 8018 8019 8020 8021 8022 8023 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8016 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that the role belongs to.
8016 8017 8018 8019 8020 8021 8022 8023 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8016 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role that you want to add a group to.
8016 8017 8018 8019 8020 8021 8022 8023 |
# File 'lib/aws-sdk-quicksight/types.rb', line 8016 class CreateRoleMembershipRequest < Struct.new( :member_name, :aws_account_id, :namespace, :role) SENSITIVE = [] include Aws::Structure end |