Class: Aws::QuickSight::Types::CreateSpaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateSpaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#description ⇒ String
A description of the space.
-
#name ⇒ String
A display name for the space.
-
#space_id ⇒ String
The ID of the space.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
9617 9618 9619 9620 9621 9622 9623 9624 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9617 class CreateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description of the space.
9617 9618 9619 9620 9621 9622 9623 9624 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9617 class CreateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
A display name for the space.
9617 9618 9619 9620 9621 9622 9623 9624 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9617 class CreateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#space_id ⇒ String
The ID of the space. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
9617 9618 9619 9620 9621 9622 9623 9624 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9617 class CreateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |