Class: Aws::QuickSight::Types::CreateTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. You use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#definitionTypes::TemplateVersionDefinition

The definition of a template.

A definition is the data model of all features in a Dashboard, Template, or Analysis.

Either a SourceEntity or a Definition must be provided in order for the request to be valid.



10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A display name for the template.

Returns:

  • (String)


10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::ResourcePermission>

A list of resource permissions to be set on the template.

Returns:



10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#source_entityTypes::TemplateSourceEntity

The entity that you are using as a source when you create the template. In SourceEntity, you specify the type of object you're using as source: SourceTemplate for a template or SourceAnalysis for an analysis. Both of these require an Amazon Resource Name (ARN). For SourceTemplate, specify the ARN of the source template. For SourceAnalysis, specify the ARN of the source analysis. The SourceTemplate ARN can contain any Amazon Web Services account and any Quick Sight-supported Amazon Web Services Region.

Use the DataSetReferences entity within SourceTemplate or SourceAnalysis to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

Either a SourceEntity or a Definition must be provided in order for the request to be valid.



10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

Returns:



10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

An ID for the template that you want to create. This template is unique per Amazon Web Services Region; in each Amazon Web Services account.

Returns:

  • (String)


10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#validation_strategyTypes::ValidationStrategy

TThe option to relax the validation needed to create a template with definition objects. This skips the validation step for specific errors.



10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#version_descriptionString

A description of the current template version being created. This API operation creates the first version of the template. Every time UpdateTemplate is called, a new version is created. Each version of the template maintains a description of the version in the VersionDescription field.

Returns:

  • (String)


10045
10046
10047
10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-quicksight/types.rb', line 10045

class CreateTemplateRequest < Struct.new(
  :aws_account_id,
  :template_id,
  :name,
  :permissions,
  :source_entity,
  :tags,
  :version_description,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end