Class: Aws::QuickSight::Types::CreateTopicRefreshScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicRefreshScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic you’re creating a refresh schedule for.
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#dataset_name ⇒ String
The name of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic you’re creating a refresh schedule for.
9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9361 class CreateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_arn, :dataset_name, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9361 class CreateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_arn, :dataset_name, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#dataset_name ⇒ String
The name of the dataset.
9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9361 class CreateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_arn, :dataset_name, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9361 class CreateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_arn, :dataset_name, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
9361 9362 9363 9364 9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9361 class CreateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_arn, :dataset_name, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |