Class: Aws::QuickSight::Types::CreateTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
10300 10301 10302 10303 10304 10305 10306 10307 10308 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10300 class CreateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
10300 10301 10302 10303 10304 10305 10306 10307 10308 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10300 class CreateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
10300 10301 10302 10303 10304 10305 10306 10307 10308 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10300 class CreateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
10300 10301 10302 10303 10304 10305 10306 10307 10308 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10300 class CreateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
10300 10301 10302 10303 10304 10305 10306 10307 10308 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10300 class CreateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |