Class: Aws::QuickSight::Types::CreateTopicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a topic in.
-
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
-
#folder_arns ⇒ Array<String>
The Folder ARN of the folder that you want the topic to reside in.
-
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags that are assigned to the dataset.
-
#topic ⇒ Types::TopicDetails
The definition of a topic to create.
-
#topic_id ⇒ String
The ID for the topic that you want to create.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a topic in.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#folder_arns ⇒ Array<String>
The Folder ARN of the folder that you want the topic to reside in.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags that are assigned to the dataset.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ Types::TopicDetails
The definition of a topic to create.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9483 class CreateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |