Class: Aws::QuickSight::Types::CreateTopicV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CreateTopicV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a topic in.
-
#custom_instructions ⇒ Types::CustomInstructions
Instructions that provide additional guidance and context for response generation.
-
#folder_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the folders that you want the topic to reside in.
-
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags that are assigned to the topic.
-
#topic ⇒ Types::TopicV2Details
The definition of a topic to create.
-
#topic_id ⇒ String
The ID for the topic that you want to create.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that you want to create a topic in.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#custom_instructions ⇒ Types::CustomInstructions
Instructions that provide additional guidance and context for response generation.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#folder_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the folders that you want the topic to reside in.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Contains a map of the key-value pairs for the resource tag or tags that are assigned to the topic.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ Types::TopicV2Details
The definition of a topic to create.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID for the topic that you want to create. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
11200 11201 11202 11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11200 class CreateTopicV2Request < Struct.new( :aws_account_id, :topic_id, :topic, :tags, :folder_arns, :custom_instructions) SENSITIVE = [] include Aws::Structure end |