Class: Aws::QuickSight::Types::CustomContentConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CustomContentConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration of a CustomContentVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The content type of the custom content visual.
-
#content_url ⇒ String
The input URL that links to the custom content that you want in the custom visual.
-
#image_scaling ⇒ String
The sizing options for the size of the custom content visual.
-
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
Instance Attribute Details
#content_type ⇒ String
The content type of the custom content visual. You can use this to have the visual render as an image.
11557 11558 11559 11560 11561 11562 11563 11564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11557 class CustomContentConfiguration < Struct.new( :content_url, :content_type, :image_scaling, :interactions) SENSITIVE = [] include Aws::Structure end |
#content_url ⇒ String
The input URL that links to the custom content that you want in the custom visual.
11557 11558 11559 11560 11561 11562 11563 11564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11557 class CustomContentConfiguration < Struct.new( :content_url, :content_type, :image_scaling, :interactions) SENSITIVE = [] include Aws::Structure end |
#image_scaling ⇒ String
The sizing options for the size of the custom content visual. This
structure is required when the ContentType of the visual is
'IMAGE'.
11557 11558 11559 11560 11561 11562 11563 11564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11557 class CustomContentConfiguration < Struct.new( :content_url, :content_type, :image_scaling, :interactions) SENSITIVE = [] include Aws::Structure end |
#interactions ⇒ Types::VisualInteractionOptions
The general visual interactions setup for a visual.
11557 11558 11559 11560 11561 11562 11563 11564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11557 class CustomContentConfiguration < Struct.new( :content_url, :content_type, :image_scaling, :interactions) SENSITIVE = [] include Aws::Structure end |