Class: Aws::QuickSight::Types::CustomInstruction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A custom instruction that provides guidance on how the dataset should be consumed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inline_custom_instructionTypes::InlineCustomInstruction

An inline custom instruction containing text and optional uploaded document metadata.



10132
10133
10134
10135
10136
# File 'lib/aws-sdk-quicksight/types.rb', line 10132

class CustomInstruction < Struct.new(
  :inline_custom_instruction)
  SENSITIVE = []
  include Aws::Structure
end