Class: Aws::QuickSight::Types::CustomPermissions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CustomPermissions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The custom permissions profile.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the custom permissions profile.
-
#capabilities ⇒ Types::Capabilities
A set of actions in the custom permissions profile.
-
#custom_permissions_name ⇒ String
The name of the custom permissions profile.
-
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the custom permissions profile.
11822 11823 11824 11825 11826 11827 11828 11829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11822 class CustomPermissions < Struct.new( :arn, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::Capabilities
A set of actions in the custom permissions profile.
11822 11823 11824 11825 11826 11827 11828 11829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11822 class CustomPermissions < Struct.new( :arn, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The name of the custom permissions profile.
11822 11823 11824 11825 11826 11827 11828 11829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11822 class CustomPermissions < Struct.new( :arn, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile.
When you enable governance for a category, Amazon Quick denies
access to any current or new capability in that category unless you
explicitly set that capability to ALLOW in Capabilities.
11822 11823 11824 11825 11826 11827 11828 11829 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11822 class CustomPermissions < Struct.new( :arn, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |