Class: Aws::QuickSight::Types::CustomPromptInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::CustomPromptInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
CustomPromptInput is a union - when making an API calls you must set exactly one of the members.
The custom prompt input for an agent. This is a union type that can be either an existing prompt profile or new prompt parameters.
Direct Known Subclasses
Defined Under Namespace
Classes: ExistingPrompt, NewPrompt, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#existing_prompt ⇒ Types::CustomPromptProfile
An existing custom prompt profile to use for the agent.
-
#new_prompt ⇒ Types::CustomPromptInputParameters
New custom prompt parameters to configure for the agent.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#existing_prompt ⇒ Types::CustomPromptProfile
An existing custom prompt profile to use for the agent.
10740 10741 10742 10743 10744 10745 10746 10747 10748 10749 10750 10751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10740 class CustomPromptInput < Struct.new( :existing_prompt, :new_prompt, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExistingPrompt < CustomPromptInput; end class NewPrompt < CustomPromptInput; end class Unknown < CustomPromptInput; end end |
#new_prompt ⇒ Types::CustomPromptInputParameters
New custom prompt parameters to configure for the agent.
10740 10741 10742 10743 10744 10745 10746 10747 10748 10749 10750 10751 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10740 class CustomPromptInput < Struct.new( :existing_prompt, :new_prompt, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ExistingPrompt < CustomPromptInput; end class NewPrompt < CustomPromptInput; end class Unknown < CustomPromptInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10740 10741 10742 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10740 def unknown @unknown end |