Class: Aws::QuickSight::Types::DashboardVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DashboardVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Dashboard version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
-
#created_time ⇒ Time
The time that this dashboard version was created.
-
#data_set_arns ⇒ Array<String>
The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
-
#description ⇒ String
Description.
-
#errors ⇒ Array<Types::DashboardError>
Errors associated with this dashboard version.
-
#sheets ⇒ Array<Types::Sheet>
A list of the associated sheets with the unique identifier and name of each sheet.
-
#source_entity_arn ⇒ String
Source entity ARN.
-
#status ⇒ String
The HTTP status of the request.
-
#theme_arn ⇒ String
The ARN of the theme associated with a version of the dashboard.
-
#version_number ⇒ Integer
Version number for this version of the dashboard.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that this dashboard version was created.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#data_set_arns ⇒ Array<String>
The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::DashboardError>
Errors associated with this dashboard version.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#sheets ⇒ Array<Types::Sheet>
A list of the associated sheets with the unique identifier and name of each sheet.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#source_entity_arn ⇒ String
Source entity ARN.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The HTTP status of the request.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#theme_arn ⇒ String
The ARN of the theme associated with a version of the dashboard.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
Version number for this version of the dashboard.
11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11454 class DashboardVersion < Struct.new( :created_time, :errors, :version_number, :status, :arn, :source_entity_arn, :data_set_arns, :description, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |