Class: Aws::QuickSight::Types::DataColorPalette
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataColorPalette
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The theme colors that are used for data colors in charts. The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ‘#`, for example #37BFF5.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#colors ⇒ Array<String>
The hexadecimal codes for the colors.
-
#empty_fill_color ⇒ String
The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
-
#min_max_gradient ⇒ Array<String>
The minimum and maximum hexadecimal codes that describe a color gradient.
Instance Attribute Details
#colors ⇒ Array<String>
The hexadecimal codes for the colors.
9634 9635 9636 9637 9638 9639 9640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9634 class DataColorPalette < Struct.new( :colors, :min_max_gradient, :empty_fill_color) SENSITIVE = [] include Aws::Structure end |
#empty_fill_color ⇒ String
The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
9634 9635 9636 9637 9638 9639 9640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9634 class DataColorPalette < Struct.new( :colors, :min_max_gradient, :empty_fill_color) SENSITIVE = [] include Aws::Structure end |
#min_max_gradient ⇒ Array<String>
The minimum and maximum hexadecimal codes that describe a color gradient.
9634 9635 9636 9637 9638 9639 9640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 9634 class DataColorPalette < Struct.new( :colors, :min_max_gradient, :empty_fill_color) SENSITIVE = [] include Aws::Structure end |