Class: Aws::QuickSight::Types::DataFieldComboSeriesItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The data field series item configuration of a ‘ComboChartVisual`.

Constant Summary collapse

SENSITIVE =
[:field_value]

Instance Attribute Summary collapse

Instance Attribute Details

#field_idString

Field ID of the field that you are setting the series configuration for.

Returns:

  • (String)


9922
9923
9924
9925
9926
9927
9928
# File 'lib/aws-sdk-quicksight/types.rb', line 9922

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end

#field_valueString

Field value of the field that you are setting the series configuration for.

Returns:

  • (String)


9922
9923
9924
9925
9926
9927
9928
# File 'lib/aws-sdk-quicksight/types.rb', line 9922

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end

#settingsTypes::ComboChartSeriesSettings

Options that determine the presentation of series associated to the field.



9922
9923
9924
9925
9926
9927
9928
# File 'lib/aws-sdk-quicksight/types.rb', line 9922

class DataFieldComboSeriesItem < Struct.new(
  :field_id,
  :field_value,
  :settings)
  SENSITIVE = [:field_value]
  include Aws::Structure
end