Class: Aws::QuickSight::Types::DataPrepSimpleAggregationFunction
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataPrepSimpleAggregationFunction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A simple aggregation function that performs standard statistical operations on a column.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_type ⇒ String
The type of aggregation function to perform, such as ‘COUNT`, `SUM`, `AVERAGE`, `MIN`, `MAX`, `MEDIAN`, `VARIANCE`, or `STANDARD_DEVIATION`.
-
#input_column_name ⇒ String
The name of the column on which to perform the aggregation function.
Instance Attribute Details
#function_type ⇒ String
The type of aggregation function to perform, such as ‘COUNT`, `SUM`, `AVERAGE`, `MIN`, `MAX`, `MEDIAN`, `VARIANCE`, or `STANDARD_DEVIATION`.
10315 10316 10317 10318 10319 10320 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10315 class DataPrepSimpleAggregationFunction < Struct.new( :input_column_name, :function_type) SENSITIVE = [] include Aws::Structure end |
#input_column_name ⇒ String
The name of the column on which to perform the aggregation function.
10315 10316 10317 10318 10319 10320 |
# File 'lib/aws-sdk-quicksight/types.rb', line 10315 class DataPrepSimpleAggregationFunction < Struct.new( :input_column_name, :function_type) SENSITIVE = [] include Aws::Structure end |