Class: Aws::QuickSight::Types::DataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The structure of a data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alternate_data_source_parameters ⇒ Array<Types::DataSourceParameters>
A set of alternate data source parameters that you want to share for the credentials stored with this data source.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the data source.
-
#created_time ⇒ Time
The time that this data source was created.
-
#credential_status ⇒ String
The credential verification status of the data source.
-
#data_source_id ⇒ String
The ID of the data source.
-
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Quick Sight uses to connect to your underlying source.
-
#error_info ⇒ Types::DataSourceErrorInfo
Error information from the last update or the creation of the data source.
-
#last_credential_verified_at ⇒ Time
The time that the credentials were last verified.
-
#last_updated_time ⇒ Time
The last time that this data source was updated.
-
#name ⇒ String
A display name for the data source.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
-
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Quick Sight connects to your underlying source.
-
#status ⇒ String
The HTTP status of the request.
-
#type ⇒ String
The type of the data source.
-
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
The VPC connection information.
Instance Attribute Details
#alternate_data_source_parameters ⇒ Array<Types::DataSourceParameters>
A set of alternate data source parameters that you want to share for
the credentials stored with this data source. The credentials are
applied in tandem with the data source parameters when you copy a
data source by using a create or update request. The API operation
compares the DataSourceParameters structure that's in the request
with the structures in the AlternateDataSourceParameters allow
list. If the structures are an exact match, the request is allowed
to use the credentials from this existing data source. If the
AlternateDataSourceParameters list is null, the Credentials
originally used with this DataSourceParameters are automatically
allowed.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the data source.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that this data source was created.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#credential_status ⇒ String
The credential verification status of the data source. Valid values include:
-
CONNECTED– Credential validation succeeded. -
AUTH_FAILED– Credential validation failed. -
NOT_VERIFIED– Credential validation has not been performed.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Quick Sight uses to connect to your underlying source. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#error_info ⇒ Types::DataSourceErrorInfo
Error information from the last update or the creation of the data source.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#last_credential_verified_at ⇒ Time
The time that the credentials were last verified.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The last time that this data source was updated.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A display name for the data source.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Quick Sight connects to your underlying source.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The HTTP status of the request.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source. This type indicates which database engine the data source connects to.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
The VPC connection information. You need to use this parameter only when you want Quick Sight to use a VPC connection when connecting to your underlying source.
13214 13215 13216 13217 13218 13219 13220 13221 13222 13223 13224 13225 13226 13227 13228 13229 13230 13231 13232 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13214 class DataSource < Struct.new( :arn, :data_source_id, :name, :type, :status, :created_time, :last_updated_time, :data_source_parameters, :alternate_data_source_parameters, :vpc_connection_properties, :ssl_properties, :error_info, :secret_arn, :credential_status, :last_credential_verified_at) SENSITIVE = [] include Aws::Structure end |