Class: Aws::QuickSight::Types::DataSourceCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Data source credentials. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_source_arnString

The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When CopySourceArn is not null, the credential pair from the data source in the ARN is used as the credentials for the DataSourceCredentials structure.

Returns:

  • (String)


13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#credential_pairTypes::CredentialPair

Credential pair. For more information, see CredentialPair.



13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#key_pair_credentialsTypes::KeyPairCredentials

The credentials for connecting using key-pair.



13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#o_auth_client_credentialsTypes::OAuthClientCredentials

The OAuth client credentials for connecting to a data source using OAuth 2.0 client credentials (2LO) authentication. For more information, see OAuthClientCredentials.



13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.

Returns:

  • (String)


13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end

#web_proxy_credentialsTypes::WebProxyCredentials

The credentials for connecting through a web proxy server.



13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/aws-sdk-quicksight/types.rb', line 13269

class DataSourceCredentials < Struct.new(
  :credential_pair,
  :copy_source_arn,
  :secret_arn,
  :key_pair_credentials,
  :web_proxy_credentials,
  :o_auth_client_credentials)
  SENSITIVE = []
  include Aws::Structure
end