Class: Aws::QuickSight::Types::DataSourceCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataSourceCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Data source credentials. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_source_arn ⇒ String
The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.
-
#credential_pair ⇒ Types::CredentialPair
Credential pair.
-
#key_pair_credentials ⇒ Types::KeyPairCredentials
The credentials for connecting using key-pair.
-
#o_auth_client_credentials ⇒ Types::OAuthClientCredentials
The OAuth client credentials for connecting to a data source using OAuth 2.0 client credentials (2LO) authentication.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
-
#web_proxy_credentials ⇒ Types::WebProxyCredentials
The credentials for connecting through a web proxy server.
Instance Attribute Details
#copy_source_arn ⇒ String
The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ‘CopySourceArn` is not null, the credential pair from the data source in the ARN is used as the credentials for the `DataSourceCredentials` structure.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |
#credential_pair ⇒ Types::CredentialPair
Credential pair. For more information, see ‘ CredentialPair `.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |
#key_pair_credentials ⇒ Types::KeyPairCredentials
The credentials for connecting using key-pair.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |
#o_auth_client_credentials ⇒ Types::OAuthClientCredentials
The OAuth client credentials for connecting to a data source using OAuth 2.0 client credentials (2LO) authentication. For more information, see ‘ OAuthClientCredentials `.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |
#web_proxy_credentials ⇒ Types::WebProxyCredentials
The credentials for connecting through a web proxy server.
12154 12155 12156 12157 12158 12159 12160 12161 12162 12163 |
# File 'lib/aws-sdk-quicksight/types.rb', line 12154 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials, :o_auth_client_credentials) SENSITIVE = [] include Aws::Structure end |