Class: Aws::QuickSight::Types::DataSourceCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DataSourceCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Data source credentials. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_source_arn ⇒ String
The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.
-
#credential_pair ⇒ Types::CredentialPair
Credential pair.
-
#key_pair_credentials ⇒ Types::KeyPairCredentials
The credentials for connecting using key-pair.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
-
#web_proxy_credentials ⇒ Types::WebProxyCredentials
The credentials for connecting through a web proxy server.
Instance Attribute Details
#copy_source_arn ⇒ String
The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ‘CopySourceArn` is not null, the credential pair from the data source in the ARN is used as the credentials for the `DataSourceCredentials` structure.
11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11152 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials) SENSITIVE = [] include Aws::Structure end |
#credential_pair ⇒ Types::CredentialPair
Credential pair. For more information, see ‘ CredentialPair `.
11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11152 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials) SENSITIVE = [] include Aws::Structure end |
#key_pair_credentials ⇒ Types::KeyPairCredentials
The credentials for connecting using key-pair.
11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11152 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.
11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11152 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials) SENSITIVE = [] include Aws::Structure end |
#web_proxy_credentials ⇒ Types::WebProxyCredentials
The credentials for connecting through a web proxy server.
11152 11153 11154 11155 11156 11157 11158 11159 11160 |
# File 'lib/aws-sdk-quicksight/types.rb', line 11152 class DataSourceCredentials < Struct.new( :credential_pair, :copy_source_arn, :secret_arn, :key_pair_credentials, :web_proxy_credentials) SENSITIVE = [] include Aws::Structure end |