Class: Aws::QuickSight::Types::DataStoriesConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The data story settings of an embedded Quick Sight console.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

The data story settings of an embedded Quick Sight console.

Returns:

  • (Boolean)


11466
11467
11468
11469
11470
# File 'lib/aws-sdk-quicksight/types.rb', line 11466

class DataStoriesConfigurations < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end