Class: Aws::QuickSight::Types::DecalSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Decal settings for accessibility features that define visual patterns and styling for data elements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#decal_colorString

Color configuration for the decal pattern.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/aws-sdk-quicksight/types.rb', line 12004

class DecalSettings < Struct.new(
  :element_value,
  :decal_visibility,
  :decal_color,
  :decal_pattern_type,
  :decal_style_type)
  SENSITIVE = []
  include Aws::Structure
end

#decal_pattern_typeString

Type of pattern used for the decal, such as solid, diagonal, or circular patterns in various sizes.

  • ‘SOLID`: Solid fill pattern.

  • ‘DIAGONAL_SMALL`: Small diagonal stripes pattern.

  • ‘DIAGONAL_MEDIUM`: Medium diagonal stripes pattern.

  • ‘DIAGONAL_LARGE`: Large diagonal stripes pattern.

  • ‘DIAGONAL_OPPOSITE_SMALL`: Small cross-diagonal stripes pattern.

  • ‘DIAGONAL_OPPOSITE_MEDIUM`: Medium cross-diagonal stripes pattern.

  • ‘DIAGONAL_OPPOSITE_LARGE`: Large cross-diagonal stripes pattern.

  • ‘CIRCLE_SMALL`: Small circle pattern.

  • ‘CIRCLE_MEDIUM`: Medium circle pattern.

  • ‘CIRCLE_LARGE`: Large circle pattern.

  • ‘DIAMOND_SMALL`: Small diamonds pattern.

  • ‘DIAMOND_MEDIUM`: Medium diamonds pattern.

  • ‘DIAMOND_LARGE`: Large diamonds pattern.

  • ‘DIAMOND_GRID_SMALL`: Small diamond grid pattern.

  • ‘DIAMOND_GRID_MEDIUM`: Medium diamond grid pattern.

  • ‘DIAMOND_GRID_LARGE`: Large diamond grid pattern.

  • ‘CHECKERBOARD_SMALL`: Small checkerboard pattern.

  • ‘CHECKERBOARD_MEDIUM`: Medium checkerboard pattern.

  • ‘CHECKERBOARD_LARGE`: Large checkerboard pattern.

  • ‘TRIANGLE_SMALL`: Small triangles pattern.

  • ‘TRIANGLE_MEDIUM`: Medium triangles pattern.

  • ‘TRIANGLE_LARGE`: Large triangles pattern.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/aws-sdk-quicksight/types.rb', line 12004

class DecalSettings < Struct.new(
  :element_value,
  :decal_visibility,
  :decal_color,
  :decal_pattern_type,
  :decal_style_type)
  SENSITIVE = []
  include Aws::Structure
end

#decal_style_typeString

Style type for the decal, which can be either manual or automatic. This field is only applicable for line series.

  • ‘Manual`: Apply manual line and marker configuration for line series.

  • ‘Auto`: Apply automatic line and marker configuration for line series.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/aws-sdk-quicksight/types.rb', line 12004

class DecalSettings < Struct.new(
  :element_value,
  :decal_visibility,
  :decal_color,
  :decal_pattern_type,
  :decal_style_type)
  SENSITIVE = []
  include Aws::Structure
end

#decal_visibilityString

Visibility setting for the decal pattern.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/aws-sdk-quicksight/types.rb', line 12004

class DecalSettings < Struct.new(
  :element_value,
  :decal_visibility,
  :decal_color,
  :decal_pattern_type,
  :decal_style_type)
  SENSITIVE = []
  include Aws::Structure
end

#element_valueString

Field value of the field that you are setting the decal pattern to. Applicable only for field level settings.

Returns:

  • (String)


12004
12005
12006
12007
12008
12009
12010
12011
12012
# File 'lib/aws-sdk-quicksight/types.rb', line 12004

class DecalSettings < Struct.new(
  :element_value,
  :decal_visibility,
  :decal_color,
  :decal_pattern_type,
  :decal_style_type)
  SENSITIVE = []
  include Aws::Structure
end