Class: Aws::QuickSight::Types::DeleteAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you're deleting.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to delete an analysis.
-
#force_delete_without_recovery ⇒ Boolean
This option defaults to the value
NoForceDeleteWithoutRecovery. -
#recovery_window_in_days ⇒ Integer
A value that specifies the number of days that Amazon Quick Sight waits before it deletes the analysis.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you're deleting.
14988 14989 14990 14991 14992 14993 14994 14995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14988 class DeleteAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :recovery_window_in_days, :force_delete_without_recovery) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where you want to delete an analysis.
14988 14989 14990 14991 14992 14993 14994 14995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14988 class DeleteAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :recovery_window_in_days, :force_delete_without_recovery) SENSITIVE = [] include Aws::Structure end |
#force_delete_without_recovery ⇒ Boolean
This option defaults to the value NoForceDeleteWithoutRecovery. To
immediately delete the analysis, add the
ForceDeleteWithoutRecovery option. You can't restore an analysis
after it's deleted.
14988 14989 14990 14991 14992 14993 14994 14995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14988 class DeleteAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :recovery_window_in_days, :force_delete_without_recovery) SENSITIVE = [] include Aws::Structure end |
#recovery_window_in_days ⇒ Integer
A value that specifies the number of days that Amazon Quick Sight
waits before it deletes the analysis. You can't use this parameter
with the ForceDeleteWithoutRecovery option in the same API call.
The default value is 30.
14988 14989 14990 14991 14992 14993 14994 14995 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14988 class DeleteAnalysisRequest < Struct.new( :aws_account_id, :analysis_id, :recovery_window_in_days, :force_delete_without_recovery) SENSITIVE = [] include Aws::Structure end |