Class: Aws::QuickSight::Types::DeleteAppRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteAppRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the app that you want to delete.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
Instance Attribute Details
#app_id ⇒ String
The ID of the app that you want to delete.
16372 16373 16374 16375 16376 16377 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16372 class DeleteAppRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the app.
16372 16373 16374 16375 16376 16377 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16372 class DeleteAppRequest < Struct.new( :aws_account_id, :app_id) SENSITIVE = [] include Aws::Structure end |