Class: Aws::QuickSight::Types::DeleteDataSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteDataSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#data_set_id ⇒ String
The ID for the dataset that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
14061 14062 14063 14064 14065 14066 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14061 class DeleteDataSetRequest < Struct.new( :aws_account_id, :data_set_id) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
14061 14062 14063 14064 14065 14066 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14061 class DeleteDataSetRequest < Struct.new( :aws_account_id, :data_set_id) SENSITIVE = [] include Aws::Structure end |