Class: Aws::QuickSight::Types::DeleteDataSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteDataSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset that you want to delete.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
15246 15247 15248 15249 15250 15251 15252 15253 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15246 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
15246 15247 15248 15249 15250 15251 15252 15253 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15246 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
15246 15247 15248 15249 15250 15251 15252 15253 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15246 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
15246 15247 15248 15249 15250 15251 15252 15253 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15246 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |