Class: Aws::QuickSight::Types::DeleteDataSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteDataSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset that you want to delete.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14329 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14329 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14329 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14329 class DeleteDataSetResponse < Struct.new( :arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |