Class: Aws::QuickSight::Types::DeleteGroupMembershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


15254
15255
15256
15257
15258
15259
15260
15261
# File 'lib/aws-sdk-quicksight/types.rb', line 15254

class DeleteGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group that you want to delete the user from.

Returns:

  • (String)


15254
15255
15256
15257
15258
15259
15260
15261
# File 'lib/aws-sdk-quicksight/types.rb', line 15254

class DeleteGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#member_nameString

The name of the user that you want to delete from the group membership.

Returns:

  • (String)


15254
15255
15256
15257
15258
15259
15260
15261
# File 'lib/aws-sdk-quicksight/types.rb', line 15254

class DeleteGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the group that you want to remove a user from.

Returns:

  • (String)


15254
15255
15256
15257
15258
15259
15260
15261
# File 'lib/aws-sdk-quicksight/types.rb', line 15254

class DeleteGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end