Class: Aws::QuickSight::Types::DeleteGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#group_name ⇒ String
The name of the group that you want to delete.
-
#namespace ⇒ String
The namespace of the group that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
16330 16331 16332 16333 16334 16335 16336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16330 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to delete.
16330 16331 16332 16333 16334 16335 16336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16330 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the group that you want to delete.
16330 16331 16332 16333 16334 16335 16336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16330 class DeleteGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |