Class: Aws::QuickSight::Types::DeleteRoleCustomPermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


16627
16628
16629
16630
16631
16632
16633
# File 'lib/aws-sdk-quicksight/types.rb', line 16627

class DeleteRoleCustomPermissionRequest < Struct.new(
  :role,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that includes the role.

Returns:

  • (String)


16627
16628
16629
16630
16631
16632
16633
# File 'lib/aws-sdk-quicksight/types.rb', line 16627

class DeleteRoleCustomPermissionRequest < Struct.new(
  :role,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The role that you want to remove permissions from.

Returns:

  • (String)


16627
16628
16629
16630
16631
16632
16633
# File 'lib/aws-sdk-quicksight/types.rb', line 16627

class DeleteRoleCustomPermissionRequest < Struct.new(
  :role,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end