Class: Aws::QuickSight::Types::DeleteRoleCustomPermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteRoleCustomPermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#namespace ⇒ String
The namespace that includes the role.
-
#role ⇒ String
The role that you want to remove permissions from.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
13463 13464 13465 13466 13467 13468 13469 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13463 class DeleteRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that includes the role.
13463 13464 13465 13466 13467 13468 13469 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13463 class DeleteRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role that you want to remove permissions from.
13463 13464 13465 13466 13467 13468 13469 |
# File 'lib/aws-sdk-quicksight/types.rb', line 13463 class DeleteRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |