Class: Aws::QuickSight::Types::DeleteRoleMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteRoleMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#member_name ⇒ String
The name of the group.
-
#namespace ⇒ String
The namespace that contains the role.
-
#role ⇒ String
The role that you want to remove permissions from.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
14715 14716 14717 14718 14719 14720 14721 14722 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14715 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#member_name ⇒ String
The name of the group.
14715 14716 14717 14718 14719 14720 14721 14722 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14715 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that contains the role.
14715 14716 14717 14718 14719 14720 14721 14722 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14715 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role that you want to remove permissions from.
14715 14716 14717 14718 14719 14720 14721 14722 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14715 class DeleteRoleMembershipRequest < Struct.new( :member_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |