Class: Aws::QuickSight::Types::DeleteSpaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteSpaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#space_id ⇒ String
The ID of the space that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
15503 15504 15505 15506 15507 15508 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15503 class DeleteSpaceRequest < Struct.new( :aws_account_id, :space_id) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to delete.
15503 15504 15505 15506 15507 15508 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15503 class DeleteSpaceRequest < Struct.new( :aws_account_id, :space_id) SENSITIVE = [] include Aws::Structure end |