Class: Aws::QuickSight::Types::DeleteTopicRefreshScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteTopicRefreshScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
16972 16973 16974 16975 16976 16977 16978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16972 class DeleteTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
16972 16973 16974 16975 16976 16977 16978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16972 class DeleteTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
16972 16973 16974 16975 16976 16977 16978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16972 class DeleteTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |