Class: Aws::QuickSight::Types::DeleteTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
14875 14876 14877 14878 14879 14880 14881 14882 14883 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14875 class DeleteTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
14875 14876 14877 14878 14879 14880 14881 14882 14883 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14875 class DeleteTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
14875 14876 14877 14878 14879 14880 14881 14882 14883 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14875 class DeleteTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
14875 14876 14877 14878 14879 14880 14881 14882 14883 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14875 class DeleteTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
14875 14876 14877 14878 14879 14880 14881 14882 14883 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14875 class DeleteTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |