Class: Aws::QuickSight::Types::DeleteTopicV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteTopicV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to delete.
-
#topic_id ⇒ String
The ID of the topic that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to delete.
17072 17073 17074 17075 17076 17077 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17072 class DeleteTopicV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to delete. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
17072 17073 17074 17075 17076 17077 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17072 class DeleteTopicV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |