Class: Aws::QuickSight::Types::DeleteUserByPrincipalIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteUserByPrincipalIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in.
-
#namespace ⇒ String
The namespace.
-
#principal_id ⇒ String
The principal ID of the user.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
15236 15237 15238 15239 15240 15241 15242 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15236 class DeleteUserByPrincipalIdRequest < Struct.new( :principal_id, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace. Currently, you should set this to ‘default`.
15236 15237 15238 15239 15240 15241 15242 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15236 class DeleteUserByPrincipalIdRequest < Struct.new( :principal_id, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The principal ID of the user.
15236 15237 15238 15239 15240 15241 15242 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15236 class DeleteUserByPrincipalIdRequest < Struct.new( :principal_id, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |