Class: Aws::QuickSight::Types::DeleteUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DeleteUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in.
-
#namespace ⇒ String
The namespace.
-
#user_name ⇒ String
The name of the user that you want to delete.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17205 class DeleteUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace. Currently, you should set this to default.
17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17205 class DeleteUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the user that you want to delete.
17205 17206 17207 17208 17209 17210 17211 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17205 class DeleteUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |