Class: Aws::QuickSight::Types::DeleteUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


14975
14976
14977
14978
14979
14980
14981
# File 'lib/aws-sdk-quicksight/types.rb', line 14975

class DeleteUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace. Currently, you should set this to ‘default`.

Returns:

  • (String)


14975
14976
14977
14978
14979
14980
14981
# File 'lib/aws-sdk-quicksight/types.rb', line 14975

class DeleteUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the user that you want to delete.

Returns:

  • (String)


14975
14976
14977
14978
14979
14980
14981
# File 'lib/aws-sdk-quicksight/types.rb', line 14975

class DeleteUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end