Class: Aws::QuickSight::Types::DescribeAccountCustomizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAccountCustomizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to describe Quick Sight customizations for.
-
#namespace ⇒ String
The Quick Sight namespace that you want to describe Quick Sight customizations for.
-
#resolved ⇒ Boolean
The ‘Resolved` flag works with the other parameters to determine which view of Quick Sight customizations is returned.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to describe Quick Sight customizations for.
16264 16265 16266 16267 16268 16269 16270 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16264 class DescribeAccountCustomizationRequest < Struct.new( :aws_account_id, :namespace, :resolved) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick Sight namespace that you want to describe Quick Sight customizations for.
16264 16265 16266 16267 16268 16269 16270 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16264 class DescribeAccountCustomizationRequest < Struct.new( :aws_account_id, :namespace, :resolved) SENSITIVE = [] include Aws::Structure end |
#resolved ⇒ Boolean
The ‘Resolved` flag works with the other parameters to determine which view of Quick Sight customizations is returned. You can add this flag to your command to use the same view that Quick Sight uses to identify which customizations to apply to the console. Omit this flag, or set it to `no-resolved`, to reveal customizations that are configured at different levels.
16264 16265 16266 16267 16268 16269 16270 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16264 class DescribeAccountCustomizationRequest < Struct.new( :aws_account_id, :namespace, :resolved) SENSITIVE = [] include Aws::Structure end |