Class: Aws::QuickSight::Types::DescribeAccountCustomizationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that you want to describe Quick Sight customizations for.

Returns:

  • (String)


16092
16093
16094
16095
16096
16097
16098
# File 'lib/aws-sdk-quicksight/types.rb', line 16092

class DescribeAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :resolved)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The Quick Sight namespace that you want to describe Quick Sight customizations for.

Returns:

  • (String)


16092
16093
16094
16095
16096
16097
16098
# File 'lib/aws-sdk-quicksight/types.rb', line 16092

class DescribeAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :resolved)
  SENSITIVE = []
  include Aws::Structure
end

#resolvedBoolean

The ‘Resolved` flag works with the other parameters to determine which view of Quick Sight customizations is returned. You can add this flag to your command to use the same view that Quick Sight uses to identify which customizations to apply to the console. Omit this flag, or set it to `no-resolved`, to reveal customizations that are configured at different levels.

Returns:

  • (Boolean)


16092
16093
16094
16095
16096
16097
16098
# File 'lib/aws-sdk-quicksight/types.rb', line 16092

class DescribeAccountCustomizationRequest < Struct.new(
  :aws_account_id,
  :namespace,
  :resolved)
  SENSITIVE = []
  include Aws::Structure
end