Class: Aws::QuickSight::Types::DescribeAccountSettingsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_settingsTypes::AccountSettings

The Amazon Quick Sight settings for this Amazon Web Services account. This information includes the edition of Amazon Quick Sight that you subscribed to (Standard or Enterprise) and the notification email for the Amazon Quick Sight subscription.

In the Quick Sight console, the Amazon Quick Sight subscription is sometimes referred to as a Quick Sight “account” even though it’s technically not an account by itself. Instead, it’s a subscription to the Amazon Quick Sight service for your Amazon Web Services account. The edition that you subscribe to applies to Quick in every Amazon Web Services Region where you use it.



15253
15254
15255
15256
15257
15258
15259
# File 'lib/aws-sdk-quicksight/types.rb', line 15253

class DescribeAccountSettingsResponse < Struct.new(
  :account_settings,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


15253
15254
15255
15256
15257
15258
15259
# File 'lib/aws-sdk-quicksight/types.rb', line 15253

class DescribeAccountSettingsResponse < Struct.new(
  :account_settings,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


15253
15254
15255
15256
15257
15258
15259
# File 'lib/aws-sdk-quicksight/types.rb', line 15253

class DescribeAccountSettingsResponse < Struct.new(
  :account_settings,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end