Class: Aws::QuickSight::Types::DescribeAccountSubscriptionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_infoTypes::AccountInfo

A structure that contains the following elements:

  • Your Quick Sight account name.

  • The edition of Quick Sight that your account is using.

  • The notification email address that is associated with the Amazon Quick Sight account.

  • The authentication type of the Quick Sight account.

  • The status of the Quick Sight account’s subscription.

Returns:



14224
14225
14226
14227
14228
14229
14230
# File 'lib/aws-sdk-quicksight/types.rb', line 14224

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


14224
14225
14226
14227
14228
14229
14230
# File 'lib/aws-sdk-quicksight/types.rb', line 14224

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


14224
14225
14226
14227
14228
14229
14230
# File 'lib/aws-sdk-quicksight/types.rb', line 14224

class DescribeAccountSubscriptionResponse < Struct.new(
  :account_info,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end