Class: Aws::QuickSight::Types::DescribeActionConnectorPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeActionConnectorPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_connector_id ⇒ String
The unique identifier of the action connector.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the action connector.
-
#permissions ⇒ Array<Types::ResourcePermission>
The list of permissions associated with the action connector, including the principals and their allowed actions.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status code of the request.
Instance Attribute Details
#action_connector_id ⇒ String
The unique identifier of the action connector.
14274 14275 14276 14277 14278 14279 14280 14281 14282 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14274 class DescribeActionConnectorPermissionsResponse < Struct.new( :arn, :action_connector_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the action connector.
14274 14275 14276 14277 14278 14279 14280 14281 14282 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14274 class DescribeActionConnectorPermissionsResponse < Struct.new( :arn, :action_connector_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
The list of permissions associated with the action connector, including the principals and their allowed actions.
14274 14275 14276 14277 14278 14279 14280 14281 14282 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14274 class DescribeActionConnectorPermissionsResponse < Struct.new( :arn, :action_connector_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
14274 14275 14276 14277 14278 14279 14280 14281 14282 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14274 class DescribeActionConnectorPermissionsResponse < Struct.new( :arn, :action_connector_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status code of the request.
14274 14275 14276 14277 14278 14279 14280 14281 14282 |
# File 'lib/aws-sdk-quicksight/types.rb', line 14274 class DescribeActionConnectorPermissionsResponse < Struct.new( :arn, :action_connector_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |