Class: Aws::QuickSight::Types::DescribeAnalysisDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAnalysisDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you're describing.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you're describing. The ID is part of the URL of the analysis.
16816 16817 16818 16819 16820 16821 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16816 class DescribeAnalysisDefinitionRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis. You must be using the Amazon Web Services account that the analysis is in.
16816 16817 16818 16819 16820 16821 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16816 class DescribeAnalysisDefinitionRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |