Class: Aws::QuickSight::Types::DescribeAnalysisPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAnalysisPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis whose permissions you’re describing.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis whose permissions you’re describing.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis whose permissions you’re describing. The ID is part of the analysis URL.
15442 15443 15444 15445 15446 15447 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15442 class DescribeAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis whose permissions you’re describing. You must be using the Amazon Web Services account that the analysis is in.
15442 15443 15444 15445 15446 15447 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15442 class DescribeAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |