Class: Aws::QuickSight::Types::DescribeAnalysisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAnalysisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis that you’re describing.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis that you’re describing. The ID is part of the URL of the analysis.
16552 16553 16554 16555 16556 16557 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16552 class DescribeAnalysisRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis. You must be using the Amazon Web Services account that the analysis is in.
16552 16553 16554 16555 16556 16557 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16552 class DescribeAnalysisRequest < Struct.new( :aws_account_id, :analysis_id) SENSITIVE = [] include Aws::Structure end |