Class: Aws::QuickSight::Types::DescribeAssetBundleExportJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAssetBundleExportJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:download_url]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the export job.
-
#asset_bundle_export_job_id ⇒ String
The ID of the job.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the export job was executed in.
-
#cloud_formation_override_property_configuration ⇒ Types::AssetBundleCloudFormationOverridePropertyConfiguration
The CloudFormation override property configuration for the export job.
-
#created_time ⇒ Time
The time that the export job was created.
-
#download_url ⇒ String
The URL to download the exported asset bundle data from.
-
#errors ⇒ Array<Types::AssetBundleExportJobError>
An array of error records that describes any failures that occurred during the export job processing.
-
#export_format ⇒ String
The format of the exported asset bundle.
-
#include_all_dependencies ⇒ Boolean
The include dependencies flag.
-
#include_folder_members ⇒ String
A setting that determines whether folder members are included.
-
#include_folder_memberships ⇒ Boolean
The include folder memberships flag.
-
#include_permissions ⇒ Boolean
The include permissions flag.
-
#include_tags ⇒ Boolean
The include tags flag.
-
#job_status ⇒ String
Indicates the status of a job through its queuing and execution.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#resource_arns ⇒ Array<String>
A list of resource ARNs that exported with the job.
-
#status ⇒ Integer
The HTTP status of the response.
-
#validation_strategy ⇒ Types::AssetBundleExportJobValidationStrategy
The validation strategy that is used to export the analysis or dashboard.
-
#warnings ⇒ Array<Types::AssetBundleExportJobWarning>
An array of warning records that describe the analysis or dashboard that is exported.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the export job.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#asset_bundle_export_job_id ⇒ String
The ID of the job. The job ID is set when you start a new job with a
StartAssetBundleExportJob API call.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the export job was executed in.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#cloud_formation_override_property_configuration ⇒ Types::AssetBundleCloudFormationOverridePropertyConfiguration
The CloudFormation override property configuration for the export job.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#created_time ⇒ Time
The time that the export job was created.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#download_url ⇒ String
The URL to download the exported asset bundle data from.
This URL is available only after the job has succeeded. This URL is
valid for 5 minutes after issuance. Call
DescribeAssetBundleExportJob again for a fresh URL if needed.
The downloaded asset bundle is a zip file named
assetbundle-{jobId}.qs. The file has a .qs extension.
This URL can't be used in a StartAssetBundleImportJob API call
and should only be used for download purposes.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#errors ⇒ Array<Types::AssetBundleExportJobError>
An array of error records that describes any failures that occurred during the export job processing.
Error records accumulate while the job runs. The complete set of error records is available after the job has completed and failed.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#export_format ⇒ String
The format of the exported asset bundle. A QUICKSIGHT_JSON
formatted file can be used to make a StartAssetBundleImportJob API
call. A CLOUDFORMATION_JSON formatted file can be used in the
CloudFormation console and with the CloudFormation APIs.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#include_all_dependencies ⇒ Boolean
The include dependencies flag.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#include_folder_members ⇒ String
A setting that determines whether folder members are included.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#include_folder_memberships ⇒ Boolean
The include folder memberships flag.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#include_permissions ⇒ Boolean
The include permissions flag.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#include_tags ⇒ Boolean
The include tags flag.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#job_status ⇒ String
Indicates the status of a job through its queuing and execution.
Poll this DescribeAssetBundleExportApi until JobStatus is either
SUCCESSFUL or FAILED.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#resource_arns ⇒ Array<String>
A list of resource ARNs that exported with the job.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the response.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#validation_strategy ⇒ Types::AssetBundleExportJobValidationStrategy
The validation strategy that is used to export the analysis or dashboard.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |
#warnings ⇒ Array<Types::AssetBundleExportJobWarning>
An array of warning records that describe the analysis or dashboard that is exported. This array includes UI errors that can be skipped during the validation process.
This property only appears if StrictModeForAllResources in
ValidationStrategy is set to FALSE.
17110 17111 17112 17113 17114 17115 17116 17117 17118 17119 17120 17121 17122 17123 17124 17125 17126 17127 17128 17129 17130 17131 17132 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17110 class DescribeAssetBundleExportJobResponse < Struct.new( :job_status, :download_url, :errors, :arn, :created_time, :asset_bundle_export_job_id, :aws_account_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :request_id, :status, :include_permissions, :include_tags, :validation_strategy, :warnings, :include_folder_memberships, :include_folder_members) SENSITIVE = [:download_url] include Aws::Structure end |