Class: Aws::QuickSight::Types::DescribeAssetBundleExportJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:download_url]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the export job.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#asset_bundle_export_job_idString

The ID of the job. The job ID is set when you start a new job with a StartAssetBundleExportJob API call.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that the export job was executed in.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#cloud_formation_override_property_configurationTypes::AssetBundleCloudFormationOverridePropertyConfiguration

The CloudFormation override property configuration for the export job.



17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#created_timeTime

The time that the export job was created.

Returns:

  • (Time)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#download_urlString

The URL to download the exported asset bundle data from.

This URL is available only after the job has succeeded. This URL is valid for 5 minutes after issuance. Call DescribeAssetBundleExportJob again for a fresh URL if needed.

The downloaded asset bundle is a zip file named assetbundle-{jobId}.qs. The file has a .qs extension.

This URL can't be used in a StartAssetBundleImportJob API call and should only be used for download purposes.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#errorsArray<Types::AssetBundleExportJobError>

An array of error records that describes any failures that occurred during the export job processing.

Error records accumulate while the job runs. The complete set of error records is available after the job has completed and failed.



17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#export_formatString

The format of the exported asset bundle. A QUICKSIGHT_JSON formatted file can be used to make a StartAssetBundleImportJob API call. A CLOUDFORMATION_JSON formatted file can be used in the CloudFormation console and with the CloudFormation APIs.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#include_all_dependenciesBoolean

The include dependencies flag.

Returns:

  • (Boolean)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#include_folder_membersString

A setting that determines whether folder members are included.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#include_folder_membershipsBoolean

The include folder memberships flag.

Returns:

  • (Boolean)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#include_permissionsBoolean

The include permissions flag.

Returns:

  • (Boolean)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#include_tagsBoolean

The include tags flag.

Returns:

  • (Boolean)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#job_statusString

Indicates the status of a job through its queuing and execution.

Poll this DescribeAssetBundleExportApi until JobStatus is either SUCCESSFUL or FAILED.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#resource_arnsArray<String>

A list of resource ARNs that exported with the job.

Returns:

  • (Array<String>)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#statusInteger

The HTTP status of the response.

Returns:

  • (Integer)


17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#validation_strategyTypes::AssetBundleExportJobValidationStrategy

The validation strategy that is used to export the analysis or dashboard.



17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end

#warningsArray<Types::AssetBundleExportJobWarning>

An array of warning records that describe the analysis or dashboard that is exported. This array includes UI errors that can be skipped during the validation process.

This property only appears if StrictModeForAllResources in ValidationStrategy is set to FALSE.



17065
17066
17067
17068
17069
17070
17071
17072
17073
17074
17075
17076
17077
17078
17079
17080
17081
17082
17083
17084
17085
17086
17087
# File 'lib/aws-sdk-quicksight/types.rb', line 17065

class DescribeAssetBundleExportJobResponse < Struct.new(
  :job_status,
  :download_url,
  :errors,
  :arn,
  :created_time,
  :asset_bundle_export_job_id,
  :aws_account_id,
  :resource_arns,
  :include_all_dependencies,
  :export_format,
  :cloud_formation_override_property_configuration,
  :request_id,
  :status,
  :include_permissions,
  :include_tags,
  :validation_strategy,
  :warnings,
  :include_folder_memberships,
  :include_folder_members)
  SENSITIVE = [:download_url]
  include Aws::Structure
end