Class: Aws::QuickSight::Types::DescribeAssetBundleImportJobResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the import job.

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#asset_bundle_import_job_idString

The ID of the job. The job ID is set when you start a new job with a ‘StartAssetBundleImportJob` API call.

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#asset_bundle_import_sourceTypes::AssetBundleImportSourceDescription

The source of the asset bundle zip file that contains the data that is imported by the job.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account the import job was executed in.

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time that the import job was created.

Returns:

  • (Time)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::AssetBundleImportJobError>

An array of error records that describes any failures that occurred during the export job processing.

Error records accumulate while the job is still running. The complete set of error records is available after the job has completed and failed.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#failure_actionString

The failure action for the import job.

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

Indicates the status of a job through its queuing and execution.

Poll the ‘DescribeAssetBundleImport` API until `JobStatus` returns one of the following values:

  • ‘SUCCESSFUL`

  • ‘FAILED`

  • ‘FAILED_ROLLBACK_COMPLETED`

  • ‘FAILED_ROLLBACK_ERROR`

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#override_parametersTypes::AssetBundleImportJobOverrideParameters

Optional overrides that are applied to the resource configuration before import.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#override_permissionsTypes::AssetBundleImportJobOverridePermissions

Optional permission overrides that are applied to the resource configuration before import.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#override_tagsTypes::AssetBundleImportJobOverrideTags

Optional tag overrides that are applied to the resource configuration before import.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#override_validation_strategyTypes::AssetBundleImportJobOverrideValidationStrategy

An optional validation strategy override for all analyses and dashboards to be applied to the resource configuration before import.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_errorsArray<Types::AssetBundleImportJobError>

An array of error records that describes any failures that occurred while an import job was attempting a rollback.

Error records accumulate while the job is still running. The complete set of error records is available after the job has completed and failed.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the response.

Returns:

  • (Integer)


15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end

#warningsArray<Types::AssetBundleImportJobWarning>

An array of warning records that describe all permitted errors that are encountered during the import job.



15791
15792
15793
15794
15795
15796
15797
15798
15799
15800
15801
15802
15803
15804
15805
15806
15807
15808
15809
15810
# File 'lib/aws-sdk-quicksight/types.rb', line 15791

class DescribeAssetBundleImportJobResponse < Struct.new(
  :job_status,
  :errors,
  :rollback_errors,
  :arn,
  :created_time,
  :asset_bundle_import_job_id,
  :aws_account_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :request_id,
  :status,
  :override_permissions,
  :override_tags,
  :override_validation_strategy,
  :warnings)
  SENSITIVE = []
  include Aws::Structure
end