Class: Aws::QuickSight::Types::DescribeAutomationJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#automation_group_idString

The ID of the automation group that contains the automation.

Returns:

  • (String)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#automation_idString

The ID of the automation that the job belongs to.

Returns:

  • (String)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the automation job.

Returns:

  • (String)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#include_input_payloadBoolean

A Boolean value that indicates whether to include the input payload in the response. If set to true, the input payload will be included. If set to false, the input payload will be returned as null.

Returns:

  • (Boolean)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#include_output_payloadBoolean

A Boolean value that indicates whether to include the output payload in the response. If set to true, the output payload will be included. If set to false, the output payload will be returned as null.

Returns:

  • (Boolean)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The ID of the automation job to describe.

Returns:

  • (String)


17286
17287
17288
17289
17290
17291
17292
17293
17294
17295
# File 'lib/aws-sdk-quicksight/types.rb', line 17286

class DescribeAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :include_input_payload,
  :include_output_payload,
  :job_id)
  SENSITIVE = []
  include Aws::Structure
end