Class: Aws::QuickSight::Types::DescribeAutomationJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAutomationJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#automation_group_id ⇒ String
The ID of the automation group that contains the automation.
-
#automation_id ⇒ String
The ID of the automation that the job belongs to.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the automation job.
-
#include_input_payload ⇒ Boolean
A Boolean value that indicates whether to include the input payload in the response.
-
#include_output_payload ⇒ Boolean
A Boolean value that indicates whether to include the output payload in the response.
-
#job_id ⇒ String
The ID of the automation job to describe.
Instance Attribute Details
#automation_group_id ⇒ String
The ID of the automation group that contains the automation.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |
#automation_id ⇒ String
The ID of the automation that the job belongs to.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the automation job.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |
#include_input_payload ⇒ Boolean
A Boolean value that indicates whether to include the input payload
in the response. If set to true, the input payload will be
included. If set to false, the input payload will be returned as
null.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |
#include_output_payload ⇒ Boolean
A Boolean value that indicates whether to include the output payload
in the response. If set to true, the output payload will be
included. If set to false, the output payload will be returned as
null.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The ID of the automation job to describe.
17258 17259 17260 17261 17262 17263 17264 17265 17266 17267 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17258 class DescribeAutomationJobRequest < Struct.new( :aws_account_id, :automation_group_id, :automation_id, :include_input_payload, :include_output_payload, :job_id) SENSITIVE = [] include Aws::Structure end |