Class: Aws::QuickSight::Types::DescribeAutomationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAutomationJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:input_payload, :output_payload]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the automation job.
-
#created_at ⇒ Time
The time that the automation job was created.
-
#ended_at ⇒ Time
The time that the automation job finished running.
-
#input_payload ⇒ String
The input payload that was provided when the automation job was started.
-
#job_status ⇒ String
The current status of the automation job.
-
#output_payload ⇒ String
The output payload that was generated by the automation job.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#started_at ⇒ Time
The time that the automation job started running.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the automation job.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#created_at ⇒ Time
The time that the automation job was created.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#ended_at ⇒ Time
The time that the automation job finished running.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#input_payload ⇒ String
The input payload that was provided when the automation job was
started. This field is only included when IncludeInputPayload is
set to true in the request.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#job_status ⇒ String
The current status of the automation job.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#output_payload ⇒ String
The output payload that was generated by the automation job. This
field is only included when IncludeOutputPayload is set to true
in the request.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#started_at ⇒ Time
The time that the automation job started running.
17307 17308 17309 17310 17311 17312 17313 17314 17315 17316 17317 17318 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17307 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |