Class: Aws::QuickSight::Types::DescribeAutomationJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeAutomationJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:input_payload, :output_payload]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the automation job.
-
#created_at ⇒ Time
The time that the automation job was created.
-
#ended_at ⇒ Time
The time that the automation job finished running.
-
#input_payload ⇒ String
The input payload that was provided when the automation job was started.
-
#job_status ⇒ String
The current status of the automation job.
-
#output_payload ⇒ String
The output payload that was generated by the automation job.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#started_at ⇒ Time
The time that the automation job started running.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the automation job.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#created_at ⇒ Time
The time that the automation job was created.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#ended_at ⇒ Time
The time that the automation job finished running.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#input_payload ⇒ String
The input payload that was provided when the automation job was started. This field is only included when ‘IncludeInputPayload` is set to `true` in the request.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#job_status ⇒ String
The current status of the automation job.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#output_payload ⇒ String
The output payload that was generated by the automation job. This field is only included when ‘IncludeOutputPayload` is set to `true` in the request.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |
#started_at ⇒ Time
The time that the automation job started running.
15894 15895 15896 15897 15898 15899 15900 15901 15902 15903 15904 15905 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15894 class DescribeAutomationJobResponse < Struct.new( :arn, :created_at, :started_at, :ended_at, :job_status, :input_payload, :output_payload, :request_id) SENSITIVE = [:input_payload, :output_payload] include Aws::Structure end |