Class: Aws::QuickSight::Types::DescribeDashboardPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDashboardPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
-
#dashboard_id ⇒ String
The ID for the dashboard.
-
#link_sharing_configuration ⇒ Types::LinkSharingConfiguration
A structure that contains the configuration of a shareable link that grants access to the dashboard.
-
#permissions ⇒ Array<Types::ResourcePermission>
A structure that contains the permissions for the dashboard.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID for the dashboard.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#link_sharing_configuration ⇒ Types::LinkSharingConfiguration
A structure that contains the configuration of a shareable link that grants access to the dashboard. Your users can use the link to view and interact with the dashboard, if the dashboard has been shared with them. For more information about sharing dashboards, see Sharing Dashboards.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A structure that contains the permissions for the dashboard.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
17654 17655 17656 17657 17658 17659 17660 17661 17662 17663 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17654 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |