Class: Aws::QuickSight::Types::DescribeDashboardPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDashboardPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
-
#dashboard_id ⇒ String
The ID for the dashboard.
-
#link_sharing_configuration ⇒ Types::LinkSharingConfiguration
A structure that contains the configuration of a shareable link that grants access to the dashboard.
-
#permissions ⇒ Array<Types::ResourcePermission>
A structure that contains the permissions for the dashboard.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#dashboard_arn ⇒ String
The Amazon Resource Name (ARN) of the dashboard.
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID for the dashboard.
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#link_sharing_configuration ⇒ Types::LinkSharingConfiguration
A structure that contains the configuration of a shareable link that grants access to the dashboard. Your users can use the link to view and interact with the dashboard, if the dashboard has been shared with them. For more information about sharing dashboards, see [Sharing Dashboards].
[1]: docs.aws.amazon.com/quicksight/latest/user/sharing-a-dashboard.html
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A structure that contains the permissions for the dashboard.
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
17297 17298 17299 17300 17301 17302 17303 17304 17305 17306 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17297 class DescribeDashboardPermissionsResponse < Struct.new( :dashboard_id, :dashboard_arn, :permissions, :status, :request_id, :link_sharing_configuration) SENSITIVE = [] include Aws::Structure end |