Class: Aws::QuickSight::Types::DescribeDashboardPermissionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_arnString

The Amazon Resource Name (ARN) of the dashboard.

Returns:

  • (String)


16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_idString

The ID for the dashboard.

Returns:

  • (String)


16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end

A structure that contains the configuration of a shareable link that grants access to the dashboard. Your users can use the link to view and interact with the dashboard, if the dashboard has been shared with them. For more information about sharing dashboards, see [Sharing Dashboards].

[1]: docs.aws.amazon.com/quicksight/latest/user/sharing-a-dashboard.html



16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<Types::ResourcePermission>

A structure that contains the permissions for the dashboard.

Returns:



16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


16427
16428
16429
16430
16431
16432
16433
16434
16435
16436
# File 'lib/aws-sdk-quicksight/types.rb', line 16427

class DescribeDashboardPermissionsResponse < Struct.new(
  :dashboard_id,
  :dashboard_arn,
  :permissions,
  :status,
  :request_id,
  :link_sharing_configuration)
  SENSITIVE = []
  include Aws::Structure
end