Class: Aws::QuickSight::Types::DescribeDashboardSnapshotJobResultResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDashboardSnapshotJobResultResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot job.
-
#created_time ⇒ Time
The time that a snapshot job was created.
-
#error_info ⇒ Types::SnapshotJobErrorInfo
Displays information for the error that caused a job to fail.
-
#job_status ⇒ String
Indicates the status of a job after it has reached a terminal state.
-
#last_updated_time ⇒ Time
The time that a snapshot job status was last updated.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#result ⇒ Types::SnapshotJobResult
The result of the snapshot job.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot job. The job ARN is generated when you start a new job with a ‘StartDashboardSnapshotJob` API call.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time that a snapshot job was created.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#error_info ⇒ Types::SnapshotJobErrorInfo
Displays information for the error that caused a job to fail.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
Indicates the status of a job after it has reached a terminal state. A finished snapshot job will retuen a ‘COMPLETED` or `FAILED` status.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The time that a snapshot job status was last updated.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#result ⇒ Types::SnapshotJobResult
The result of the snapshot job. Jobs that have successfully completed will return the S3Uri where they are located. Jobs that have failedwill return information on the error that caused the job to fail.
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request
16655 16656 16657 16658 16659 16660 16661 16662 16663 16664 16665 16666 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16655 class DescribeDashboardSnapshotJobResultResponse < Struct.new( :arn, :job_status, :created_time, :last_updated_time, :result, :error_info, :request_id, :status) SENSITIVE = [] include Aws::Structure end |