Class: Aws::QuickSight::Types::DescribeDashboardSnapshotJobResultResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the snapshot job. The job ARN is generated when you start a new job with a ‘StartDashboardSnapshotJob` API call.

Returns:

  • (String)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The time that a snapshot job was created.

Returns:

  • (Time)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoTypes::SnapshotJobErrorInfo

Displays information for the error that caused a job to fail.



16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#job_statusString

Indicates the status of a job after it has reached a terminal state. A finished snapshot job will retuen a ‘COMPLETED` or `FAILED` status.

Returns:

  • (String)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The time that a snapshot job status was last updated.

Returns:

  • (Time)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#resultTypes::SnapshotJobResult

The result of the snapshot job. Jobs that have successfully completed will return the S3Uri where they are located. Jobs that have failedwill return information on the error that caused the job to fail.



16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request

Returns:

  • (Integer)


16469
16470
16471
16472
16473
16474
16475
16476
16477
16478
16479
16480
# File 'lib/aws-sdk-quicksight/types.rb', line 16469

class DescribeDashboardSnapshotJobResultResponse < Struct.new(
  :arn,
  :job_status,
  :created_time,
  :last_updated_time,
  :result,
  :error_info,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end