Class: Aws::QuickSight::Types::DescribeDataSetPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDataSetPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset that you want to describe.
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the dataset.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
16901 16902 16903 16904 16905 16906 16907 16908 16909 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16901 class DescribeDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
16901 16902 16903 16904 16905 16906 16907 16908 16909 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16901 class DescribeDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the dataset.
16901 16902 16903 16904 16905 16906 16907 16908 16909 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16901 class DescribeDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16901 16902 16903 16904 16905 16906 16907 16908 16909 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16901 class DescribeDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
16901 16902 16903 16904 16905 16906 16907 16908 16909 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16901 class DescribeDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :permissions, :request_id, :status) SENSITIVE = [] include Aws::Structure end |