Class: Aws::QuickSight::Types::DescribeDataSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDataSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#data_set_id ⇒ String
The ID for the dataset that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
18927 18928 18929 18930 18931 18932 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18927 class DescribeDataSetRequest < Struct.new( :aws_account_id, :data_set_id) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
18927 18928 18929 18930 18931 18932 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18927 class DescribeDataSetRequest < Struct.new( :aws_account_id, :data_set_id) SENSITIVE = [] include Aws::Structure end |