Class: Aws::QuickSight::Types::DescribeDefaultQBusinessApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeDefaultQBusinessApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Quick Sight account that is linked to the Amazon Q Business application that you want described.
-
#namespace ⇒ String
The Quick Sight namespace that contains the linked Amazon Q Business application.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Quick Sight account that is linked to the Amazon Q Business application that you want described.
15637 15638 15639 15640 15641 15642 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15637 class DescribeDefaultQBusinessApplicationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The Quick Sight namespace that contains the linked Amazon Q Business application. If this field is left blank, the default namespace is used. Currently, the default namespace is the only valid value for this parameter.
15637 15638 15639 15640 15641 15642 |
# File 'lib/aws-sdk-quicksight/types.rb', line 15637 class DescribeDefaultQBusinessApplicationRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |