Class: Aws::QuickSight::Types::DescribeFlowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeFlowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are describing.
-
#flow_id ⇒ String
The unique identifier of the flow.
-
#publish_state ⇒ String
The publish state of the flow version to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are describing.
17854 17855 17856 17857 17858 17859 17860 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17854 class DescribeFlowRequest < Struct.new( :aws_account_id, :flow_id, :publish_state) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow.
17854 17855 17856 17857 17858 17859 17860 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17854 class DescribeFlowRequest < Struct.new( :aws_account_id, :flow_id, :publish_state) SENSITIVE = [] include Aws::Structure end |
#publish_state ⇒ String
The publish state of the flow version to describe. Valid values are ‘DRAFT`, `PUBLISHED`, or `PENDING_APPROVAL`.
17854 17855 17856 17857 17858 17859 17860 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17854 class DescribeFlowRequest < Struct.new( :aws_account_id, :flow_id, :publish_state) SENSITIVE = [] include Aws::Structure end |