Class: Aws::QuickSight::Types::DescribeGroupMembershipRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


17167
17168
17169
17170
17171
17172
17173
17174
# File 'lib/aws-sdk-quicksight/types.rb', line 17167

class DescribeGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group that you want to search.

Returns:

  • (String)


17167
17168
17169
17170
17171
17172
17173
17174
# File 'lib/aws-sdk-quicksight/types.rb', line 17167

class DescribeGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#member_nameString

The user name of the user that you want to search for.

Returns:

  • (String)


17167
17168
17169
17170
17171
17172
17173
17174
# File 'lib/aws-sdk-quicksight/types.rb', line 17167

class DescribeGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that includes the group you are searching within.

Returns:

  • (String)


17167
17168
17169
17170
17171
17172
17173
17174
# File 'lib/aws-sdk-quicksight/types.rb', line 17167

class DescribeGroupMembershipRequest < Struct.new(
  :member_name,
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end