Class: Aws::QuickSight::Types::DescribeGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#group_name ⇒ String
The name of the group that you want to describe.
-
#namespace ⇒ String
The namespace of the group that you want described.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
18533 18534 18535 18536 18537 18538 18539 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18533 class DescribeGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to describe.
18533 18534 18535 18536 18537 18538 18539 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18533 class DescribeGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the group that you want described.
18533 18534 18535 18536 18537 18538 18539 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18533 class DescribeGroupRequest < Struct.new( :group_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |