Class: Aws::QuickSight::Types::DescribeGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


17372
17373
17374
17375
17376
17377
17378
# File 'lib/aws-sdk-quicksight/types.rb', line 17372

class DescribeGroupRequest < Struct.new(
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group that you want to describe.

Returns:

  • (String)


17372
17373
17374
17375
17376
17377
17378
# File 'lib/aws-sdk-quicksight/types.rb', line 17372

class DescribeGroupRequest < Struct.new(
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the group that you want described.

Returns:

  • (String)


17372
17373
17374
17375
17376
17377
17378
# File 'lib/aws-sdk-quicksight/types.rb', line 17372

class DescribeGroupRequest < Struct.new(
  :group_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end