Class: Aws::QuickSight::Types::DescribeNamespaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namespaceTypes::NamespaceInfoV2

The information about the namespace that you’re describing. The response includes the namespace ARN, name, Amazon Web Services Region, creation status, and identity store. ‘DescribeNamespace` also works for namespaces that are in the process of being created. For incomplete namespaces, this API operation lists the namespace error types and messages associated with the creation process.



18657
18658
18659
18660
18661
18662
18663
# File 'lib/aws-sdk-quicksight/types.rb', line 18657

class DescribeNamespaceResponse < Struct.new(
  :namespace,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


18657
18658
18659
18660
18661
18662
18663
# File 'lib/aws-sdk-quicksight/types.rb', line 18657

class DescribeNamespaceResponse < Struct.new(
  :namespace,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


18657
18658
18659
18660
18661
18662
18663
# File 'lib/aws-sdk-quicksight/types.rb', line 18657

class DescribeNamespaceResponse < Struct.new(
  :namespace,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end