Class: Aws::QuickSight::Types::DescribeRoleCustomPermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeRoleCustomPermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#namespace ⇒ String
The namespace that contains the role.
-
#role ⇒ String
The name of the role whose permissions you want described.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
17623 17624 17625 17626 17627 17628 17629 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17623 class DescribeRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that contains the role.
17623 17624 17625 17626 17627 17628 17629 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17623 class DescribeRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name of the role whose permissions you want described.
17623 17624 17625 17626 17627 17628 17629 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17623 class DescribeRoleCustomPermissionRequest < Struct.new( :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |