Class: Aws::QuickSight::Types::DescribeSpacePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


18659
18660
18661
18662
18663
18664
# File 'lib/aws-sdk-quicksight/types.rb', line 18659

class DescribeSpacePermissionsRequest < Struct.new(
  :aws_account_id,
  :space_id)
  SENSITIVE = []
  include Aws::Structure
end

#space_idString

The ID of the space that you want to describe permissions for.

Returns:

  • (String)


18659
18660
18661
18662
18663
18664
# File 'lib/aws-sdk-quicksight/types.rb', line 18659

class DescribeSpacePermissionsRequest < Struct.new(
  :aws_account_id,
  :space_id)
  SENSITIVE = []
  include Aws::Structure
end