Class: Aws::QuickSight::Types::DescribeSpaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


18707
18708
18709
18710
18711
18712
18713
# File 'lib/aws-sdk-quicksight/types.rb', line 18707

class DescribeSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :max_contributors)
  SENSITIVE = []
  include Aws::Structure
end

#max_contributorsInteger

The maximum number of contributors to include in the response.

Returns:

  • (Integer)


18707
18708
18709
18710
18711
18712
18713
# File 'lib/aws-sdk-quicksight/types.rb', line 18707

class DescribeSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :max_contributors)
  SENSITIVE = []
  include Aws::Structure
end

#space_idString

The ID of the space that you want to describe.

Returns:

  • (String)


18707
18708
18709
18710
18711
18712
18713
# File 'lib/aws-sdk-quicksight/types.rb', line 18707

class DescribeSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :max_contributors)
  SENSITIVE = []
  include Aws::Structure
end