Class: Aws::QuickSight::Types::DescribeSpaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeSpaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#max_contributors ⇒ Integer
The maximum number of contributors to include in the response.
-
#space_id ⇒ String
The ID of the space that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
18707 18708 18709 18710 18711 18712 18713 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18707 class DescribeSpaceRequest < Struct.new( :aws_account_id, :space_id, :max_contributors) SENSITIVE = [] include Aws::Structure end |
#max_contributors ⇒ Integer
The maximum number of contributors to include in the response.
18707 18708 18709 18710 18711 18712 18713 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18707 class DescribeSpaceRequest < Struct.new( :aws_account_id, :space_id, :max_contributors) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to describe.
18707 18708 18709 18710 18711 18712 18713 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18707 class DescribeSpaceRequest < Struct.new( :aws_account_id, :space_id, :max_contributors) SENSITIVE = [] include Aws::Structure end |