Class: Aws::QuickSight::Types::DescribeTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#template ⇒ Types::Template
The template structure for the object you want to describe.
Instance Attribute Details
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
17752 17753 17754 17755 17756 17757 17758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17752 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
17752 17753 17754 17755 17756 17757 17758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17752 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#template ⇒ Types::Template
The template structure for the object you want to describe.
17752 17753 17754 17755 17756 17757 17758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17752 class DescribeTemplateResponse < Struct.new( :template, :status, :request_id) SENSITIVE = [] include Aws::Structure end |