Class: Aws::QuickSight::Types::DescribeTopicPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want described.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want described.
17923 17924 17925 17926 17927 17928 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17923 class DescribeTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
17923 17924 17925 17926 17927 17928 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17923 class DescribeTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |