Class: Aws::QuickSight::Types::DescribeTopicPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
19192 19193 19194 19195 19196 19197 19198 19199 19200 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19192 class DescribeTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
19192 19193 19194 19195 19196 19197 19198 19199 19200 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19192 class DescribeTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
19192 19193 19194 19195 19196 19197 19198 19199 19200 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19192 class DescribeTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
19192 19193 19194 19195 19196 19197 19198 19199 19200 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19192 class DescribeTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19192 19193 19194 19195 19196 19197 19198 19199 19200 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19192 class DescribeTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |