Class: Aws::QuickSight::Types::DescribeTopicPermissionsV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicPermissionsV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions that are configured to the topic.
20587 20588 20589 20590 20591 20592 20593 20594 20595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20587 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
20587 20588 20589 20590 20591 20592 20593 20594 20595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20587 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
20587 20588 20589 20590 20591 20592 20593 20594 20595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20587 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
20587 20588 20589 20590 20591 20592 20593 20594 20595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20587 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
20587 20588 20589 20590 20591 20592 20593 20594 20595 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20587 class DescribeTopicPermissionsV2Response < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |