Class: Aws::QuickSight::Types::DescribeTopicRefreshRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh you want to describe.
-
#refresh_id ⇒ String
The ID of the refresh, which is performed when the topic is created or updated.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh you want to describe.
18362 18363 18364 18365 18366 18367 18368 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18362 class DescribeTopicRefreshRequest < Struct.new( :aws_account_id, :topic_id, :refresh_id) SENSITIVE = [] include Aws::Structure end |
#refresh_id ⇒ String
The ID of the refresh, which is performed when the topic is created or updated.
18362 18363 18364 18365 18366 18367 18368 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18362 class DescribeTopicRefreshRequest < Struct.new( :aws_account_id, :topic_id, :refresh_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
18362 18363 18364 18365 18366 18367 18368 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18362 class DescribeTopicRefreshRequest < Struct.new( :aws_account_id, :topic_id, :refresh_id) SENSITIVE = [] include Aws::Structure end |