Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
21474 21475 21476 21477 21478 21479 21480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21474 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
21474 21475 21476 21477 21478 21479 21480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21474 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
21474 21475 21476 21477 21478 21479 21480 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21474 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |