Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


19713
19714
19715
19716
19717
19718
19719
# File 'lib/aws-sdk-quicksight/types.rb', line 19713

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


19713
19714
19715
19716
19717
19718
19719
# File 'lib/aws-sdk-quicksight/types.rb', line 19713

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


19713
19714
19715
19716
19717
19718
19719
# File 'lib/aws-sdk-quicksight/types.rb', line 19713

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end