Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
19266 19267 19268 19269 19270 19271 19272 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19266 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
19266 19267 19268 19269 19270 19271 19272 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19266 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19266 19267 19268 19269 19270 19271 19272 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19266 class DescribeTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id) SENSITIVE = [] include Aws::Structure end |