Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


16912
16913
16914
16915
16916
16917
16918
# File 'lib/aws-sdk-quicksight/types.rb', line 16912

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


16912
16913
16914
16915
16916
16917
16918
# File 'lib/aws-sdk-quicksight/types.rb', line 16912

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


16912
16913
16914
16915
16916
16917
16918
# File 'lib/aws-sdk-quicksight/types.rb', line 16912

class DescribeTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id)
  SENSITIVE = []
  include Aws::Structure
end