Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19749 19750 19751 19752 19753 19754 19755 19756 19757 19758 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19749 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |