Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_arnString

The Amazon Resource Name (ARN) of the dataset.

Returns:

  • (String)


19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_scheduleTypes::TopicRefreshSchedule

The definition of a refresh schedule.



19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_arnString

The Amazon Resource Name (ARN) of the topic.

Returns:

  • (String)


19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


19564
19565
19566
19567
19568
19569
19570
19571
19572
19573
# File 'lib/aws-sdk-quicksight/types.rb', line 19564

class DescribeTopicRefreshScheduleResponse < Struct.new(
  :topic_id,
  :topic_arn,
  :dataset_arn,
  :refresh_schedule,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end