Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19302 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |