Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
18118 18119 18120 18121 18122 18123 18124 18125 18126 18127 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18118 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |