Class: Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that contains the refresh schedule that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
16948 16949 16950 16951 16952 16953 16954 16955 16956 16957 |
# File 'lib/aws-sdk-quicksight/types.rb', line 16948 class DescribeTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :refresh_schedule, :status, :request_id) SENSITIVE = [] include Aws::Structure end |