Class: Aws::QuickSight::Types::DescribeTopicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
19816 19817 19818 19819 19820 19821 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19816 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19816 19817 19818 19819 19820 19821 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19816 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |