Class: Aws::QuickSight::Types::DescribeTopicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
19799 19800 19801 19802 19803 19804 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19799 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19799 19800 19801 19802 19803 19804 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19799 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |