Class: Aws::QuickSight::Types::DescribeTopicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
19586 19587 19588 19589 19590 19591 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19586 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
19586 19587 19588 19589 19590 19591 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19586 class DescribeTopicRequest < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |