Class: Aws::QuickSight::Types::DescribeTopicResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic ⇒ Types::TopicDetails
The definition of a topic.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ Types::TopicDetails
The definition of a topic.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
18174 18175 18176 18177 18178 18179 18180 18181 18182 18183 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18174 class DescribeTopicResponse < Struct.new( :arn, :topic_id, :topic, :request_id, :status, :custom_instructions) SENSITIVE = [] include Aws::Structure end |