Class: Aws::QuickSight::Types::DescribeTopicV2Request
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeTopicV2Request
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to describe.
-
#topic_id ⇒ String
The ID of the topic that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to describe.
20776 20777 20778 20779 20780 20781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20776 class DescribeTopicV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
20776 20777 20778 20779 20780 20781 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20776 class DescribeTopicV2Request < Struct.new( :aws_account_id, :topic_id) SENSITIVE = [] include Aws::Structure end |