Class: Aws::QuickSight::Types::DescribeTopicV2Response

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the topic.

Returns:

  • (String)


20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_instructionsTypes::CustomInstructions

Instructions that provide additional guidance and context for response generation.



20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#topicTypes::TopicV2Details

The definition of a topic.



20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that you want to describe. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


20811
20812
20813
20814
20815
20816
20817
20818
20819
20820
# File 'lib/aws-sdk-quicksight/types.rb', line 20811

class DescribeTopicV2Response < Struct.new(
  :arn,
  :topic_id,
  :topic,
  :custom_instructions,
  :status,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end