Class: Aws::QuickSight::Types::DescribeUserRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DescribeUserRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in.
-
#namespace ⇒ String
The namespace.
-
#user_name ⇒ String
The name of the user that you want to describe.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
19832 19833 19834 19835 19836 19837 19838 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19832 class DescribeUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace. Currently, you should set this to default.
19832 19833 19834 19835 19836 19837 19838 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19832 class DescribeUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the user that you want to describe.
19832 19833 19834 19835 19836 19837 19838 |
# File 'lib/aws-sdk-quicksight/types.rb', line 19832 class DescribeUserRequest < Struct.new( :user_name, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |