Class: Aws::QuickSight::Types::DescribeUserRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the user is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


17031
17032
17033
17034
17035
17036
17037
# File 'lib/aws-sdk-quicksight/types.rb', line 17031

class DescribeUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace. Currently, you should set this to ‘default`.

Returns:

  • (String)


17031
17032
17033
17034
17035
17036
17037
# File 'lib/aws-sdk-quicksight/types.rb', line 17031

class DescribeUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the user that you want to describe.

Returns:

  • (String)


17031
17032
17033
17034
17035
17036
17037
# File 'lib/aws-sdk-quicksight/types.rb', line 17031

class DescribeUserRequest < Struct.new(
  :user_name,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end