Class: Aws::QuickSight::Types::DestinationTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::DestinationTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Defines a destination table in data preparation that receives the final transformed data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for the destination table.
-
#source ⇒ Types::DestinationTableSource
The source configuration that specifies which transform operation provides data to this destination table.
Instance Attribute Details
#alias ⇒ String
Alias for the destination table.
17156 17157 17158 17159 17160 17161 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17156 class DestinationTable < Struct.new( :alias, :source) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::DestinationTableSource
The source configuration that specifies which transform operation provides data to this destination table.
17156 17157 17158 17159 17160 17161 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17156 class DestinationTable < Struct.new( :alias, :source) SENSITIVE = [] include Aws::Structure end |