Class: Aws::QuickSight::Types::EffectiveLimit
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::EffectiveLimit
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The effective limit for a resource type that applies to a user, considering all applicable profile assignments and inheritance rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit_unit ⇒ String
The unit of measurement for the limit.
-
#limit_value ⇒ Integer
The maximum allowed value for the resource.
-
#profile_id ⇒ String
The identifier of the limits profile that defines this limit.
-
#resource_type ⇒ String
The type of resource that the limit applies to.
-
#source ⇒ String
The source from which this limit was inherited.
Instance Attribute Details
#limit_unit ⇒ String
The unit of measurement for the limit.
22183 22184 22185 22186 22187 22188 22189 22190 22191 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22183 class EffectiveLimit < Struct.new( :resource_type, :limit_value, :limit_unit, :source, :profile_id) SENSITIVE = [] include Aws::Structure end |
#limit_value ⇒ Integer
The maximum allowed value for the resource.
22183 22184 22185 22186 22187 22188 22189 22190 22191 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22183 class EffectiveLimit < Struct.new( :resource_type, :limit_value, :limit_unit, :source, :profile_id) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The identifier of the limits profile that defines this limit.
22183 22184 22185 22186 22187 22188 22189 22190 22191 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22183 class EffectiveLimit < Struct.new( :resource_type, :limit_value, :limit_unit, :source, :profile_id) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource that the limit applies to.
22183 22184 22185 22186 22187 22188 22189 22190 22191 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22183 class EffectiveLimit < Struct.new( :resource_type, :limit_value, :limit_unit, :source, :profile_id) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source from which this limit was inherited. Possible values:
-
DIRECT_USER– The limit comes from a profile directly assigned to the user. -
GROUP– The limit comes from a profile assigned to a group the user belongs to. -
ROLE– The limit comes from a profile assigned to a role the user has. -
ACCOUNT– The limit comes from the account-level default profile. -
SYSTEM_DEFAULT– The limit comes from the built-in system default.
22183 22184 22185 22186 22187 22188 22189 22190 22191 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22183 class EffectiveLimit < Struct.new( :resource_type, :limit_value, :limit_unit, :source, :profile_id) SENSITIVE = [] include Aws::Structure end |