Class: Aws::QuickSight::Types::FMKBParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FMKBParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The connection parameters for a fully managed knowledge base data
source. Provide these parameters in the DataSourceParameters object
when you create or update a data source that uses a fully managed
knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Bedrock knowledge base.
-
#linked_data_source_ids ⇒ Array<String>
The IDs of the linked data sources.
Instance Attribute Details
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Bedrock knowledge base.
20446 20447 20448 20449 20450 20451 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20446 class FMKBParameters < Struct.new( :knowledge_base_arn, :linked_data_source_ids) SENSITIVE = [] include Aws::Structure end |
#linked_data_source_ids ⇒ Array<String>
The IDs of the linked data sources.
20446 20447 20448 20449 20450 20451 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20446 class FMKBParameters < Struct.new( :knowledge_base_arn, :linked_data_source_ids) SENSITIVE = [] include Aws::Structure end |