Class: Aws::QuickSight::Types::FailedSpaceResourceOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FailedSpaceResourceOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A resource operation that failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_message ⇒ String
The error message that describes why the operation failed.
-
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
-
#resource_type ⇒ String
The type of the resource.
Instance Attribute Details
#error_message ⇒ String
The error message that describes why the operation failed.
20036 20037 20038 20039 20040 20041 20042 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20036 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |
#resource_details ⇒ Types::SpaceQuickSightResourceDetails
The details of the resource.
20036 20037 20038 20039 20040 20041 20042 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20036 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource.
20036 20037 20038 20039 20040 20041 20042 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20036 class FailedSpaceResourceOperation < Struct.new( :resource_type, :resource_details, :error_message) SENSITIVE = [] include Aws::Structure end |