Class: Aws::QuickSight::Types::FieldBarSeriesItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FieldBarSeriesItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The field series item configuration of a ‘BarChartVisual`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_id ⇒ String
Field ID of the field for which you are setting the series configuration.
-
#settings ⇒ Types::BarChartSeriesSettings
Options that determine the presentation of bar series associated to the field.
Instance Attribute Details
#field_id ⇒ String
Field ID of the field for which you are setting the series configuration.
17680 17681 17682 17683 17684 17685 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17680 class FieldBarSeriesItem < Struct.new( :field_id, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::BarChartSeriesSettings
Options that determine the presentation of bar series associated to the field.
17680 17681 17682 17683 17684 17685 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17680 class FieldBarSeriesItem < Struct.new( :field_id, :settings) SENSITIVE = [] include Aws::Structure end |