Class: Aws::QuickSight::Types::FilterDropDownControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FilterDropDownControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A control to display a dropdown list with buttons that are used to select a single value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cascading_control_configuration ⇒ Types::CascadingControlConfiguration
The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.
-
#commit_mode ⇒ String
The visibility configuration of the Apply button on a ‘FilterDropDownControl`.
-
#display_options ⇒ Types::DropDownControlDisplayOptions
The display options of the ‘FilterDropDownControl`.
-
#filter_control_id ⇒ String
The ID of the ‘FilterDropDownControl`.
-
#selectable_values ⇒ Types::FilterSelectableValues
A list of selectable values that are used in a control.
-
#source_filter_id ⇒ String
The source filter ID of the ‘FilterDropDownControl`.
-
#title ⇒ String
The title of the ‘FilterDropDownControl`.
-
#type ⇒ String
The type of the ‘FilterDropDownControl`.
Instance Attribute Details
#cascading_control_configuration ⇒ Types::CascadingControlConfiguration
The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#commit_mode ⇒ String
The visibility configuration of the Apply button on a ‘FilterDropDownControl`.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#display_options ⇒ Types::DropDownControlDisplayOptions
The display options of the ‘FilterDropDownControl`.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#filter_control_id ⇒ String
The ID of the ‘FilterDropDownControl`.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#selectable_values ⇒ Types::FilterSelectableValues
A list of selectable values that are used in a control.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#source_filter_id ⇒ String
The source filter ID of the ‘FilterDropDownControl`.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the ‘FilterDropDownControl`.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the ‘FilterDropDownControl`. Choose one of the following options:
-
‘MULTI_SELECT`: The user can select multiple entries from a dropdown menu.
-
‘SINGLE_SELECT`: The user can select a single entry from a dropdown menu.
17874 17875 17876 17877 17878 17879 17880 17881 17882 17883 17884 17885 |
# File 'lib/aws-sdk-quicksight/types.rb', line 17874 class FilterDropDownControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode) SENSITIVE = [] include Aws::Structure end |