Class: Aws::QuickSight::Types::FilterSliderControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FilterSliderControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_options ⇒ Types::SliderControlDisplayOptions
The display options of a control.
-
#filter_control_id ⇒ String
The ID of the ‘FilterSliderControl`.
-
#maximum_value ⇒ Float
The larger value that is displayed at the right of the slider.
-
#minimum_value ⇒ Float
The smaller value that is displayed at the left of the slider.
-
#source_filter_id ⇒ String
The source filter ID of the ‘FilterSliderControl`.
-
#step_size ⇒ Float
The number of increments that the slider bar is divided into.
-
#title ⇒ String
The title of the ‘FilterSliderControl`.
-
#type ⇒ String
The type of the ‘FilterSliderControl`.
Instance Attribute Details
#display_options ⇒ Types::SliderControlDisplayOptions
The display options of a control.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#filter_control_id ⇒ String
The ID of the ‘FilterSliderControl`.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#maximum_value ⇒ Float
The larger value that is displayed at the right of the slider.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#minimum_value ⇒ Float
The smaller value that is displayed at the left of the slider.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#source_filter_id ⇒ String
The source filter ID of the ‘FilterSliderControl`.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#step_size ⇒ Float
The number of increments that the slider bar is divided into.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the ‘FilterSliderControl`.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the ‘FilterSliderControl`. Choose one of the following options:
-
‘SINGLE_POINT`: Filter against(equals) a single data point.
-
‘RANGE`: Filter data that is in a specified range.
18236 18237 18238 18239 18240 18241 18242 18243 18244 18245 18246 18247 |
# File 'lib/aws-sdk-quicksight/types.rb', line 18236 class FilterSliderControl < Struct.new( :filter_control_id, :title, :source_filter_id, :display_options, :type, :maximum_value, :minimum_value, :step_size) SENSITIVE = [] include Aws::Structure end |