Class: Aws::QuickSight::Types::FlowDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The full details of a flow, including its definition specifying the steps.

Constant Summary collapse

SENSITIVE =
[:flow_definition]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#created_byString

The identifier of the principal who created the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#created_timeTime

The time this flow was created.

Returns:

  • (Time)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#descriptionString

The description of the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#flow_definitionHash, ...

The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow’s internal format. The format is subject to change.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#last_updated_byString

The identifier of the last principal who updated the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#last_updated_timeTime

The last time this flow was modified.

Returns:

  • (Time)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#nameString

The display name of the flow.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#publish_stateString

The publish state of the flow. Valid values are ‘DRAFT`, `PUBLISHED`, or `PENDING_APPROVAL`.

Returns:

  • (String)


21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end

#step_aliasesArray<Types::StepAliasMapping>

A list of step alias mappings for the flow.

Returns:



21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
21336
# File 'lib/aws-sdk-quicksight/types.rb', line 21322

class FlowDetail < Struct.new(
  :arn,
  :flow_id,
  :name,
  :description,
  :publish_state,
  :created_time,
  :created_by,
  :last_updated_time,
  :last_updated_by,
  :flow_definition,
  :step_aliases)
  SENSITIVE = [:flow_definition]
  include Aws::Structure
end