Class: Aws::QuickSight::Types::FlowDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FlowDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The full details of a flow, including its definition specifying the steps.
Constant Summary collapse
- SENSITIVE =
[:flow_definition]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
-
#created_by ⇒ String
The identifier of the principal who created the flow.
-
#created_time ⇒ Time
The time this flow was created.
-
#description ⇒ String
The description of the flow.
-
#flow_definition ⇒ Hash, ...
The definition of the flow, specifying the steps and configurations.
-
#flow_id ⇒ String
The unique identifier of the flow.
-
#last_updated_by ⇒ String
The identifier of the last principal who updated the flow.
-
#last_updated_time ⇒ Time
The last time this flow was modified.
-
#name ⇒ String
The display name of the flow.
-
#publish_state ⇒ String
The publish state of the flow.
-
#step_aliases ⇒ Array<Types::StepAliasMapping>
A list of step alias mappings for the flow.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#created_by ⇒ String
The identifier of the principal who created the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#created_time ⇒ Time
The time this flow was created.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#description ⇒ String
The description of the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#flow_definition ⇒ Hash, ...
The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow’s internal format. The format is subject to change.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#last_updated_by ⇒ String
The identifier of the last principal who updated the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#last_updated_time ⇒ Time
The last time this flow was modified.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#name ⇒ String
The display name of the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#publish_state ⇒ String
The publish state of the flow. Valid values are ‘DRAFT`, `PUBLISHED`, or `PENDING_APPROVAL`.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |
#step_aliases ⇒ Array<Types::StepAliasMapping>
A list of step alias mappings for the flow.
21322 21323 21324 21325 21326 21327 21328 21329 21330 21331 21332 21333 21334 21335 21336 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21322 class FlowDetail < Struct.new( :arn, :flow_id, :name, :description, :publish_state, :created_time, :created_by, :last_updated_time, :last_updated_by, :flow_definition, :step_aliases) SENSITIVE = [:flow_definition] include Aws::Structure end |