Class: Aws::QuickSight::Types::FontWeight

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The option that determines the text display weight, or boldness.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The lexical name for the level of boldness of the text display.

Returns:

  • (String)


20412
20413
20414
20415
20416
# File 'lib/aws-sdk-quicksight/types.rb', line 20412

class FontWeight < Struct.new(
  :name)
  SENSITIVE = []
  include Aws::Structure
end