Class: Aws::QuickSight::Types::FreeFormLayoutElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FreeFormLayoutElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An element within a free-form layout.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#background_style ⇒ Types::FreeFormLayoutElementBackgroundStyle
The background style configuration of a free-form layout element.
-
#border_radius ⇒ String
The border radius of a free-form layout element.
-
#border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
-
#element_id ⇒ String
A unique identifier for an element within a free-form layout.
-
#element_type ⇒ String
The type of element.
-
#height ⇒ String
The height of an element within a free-form layout.
-
#loading_animation ⇒ Types::LoadingAnimation
The loading animation configuration of a free-form layout element.
-
#padding ⇒ String
The padding of a free-form layout element.
-
#rendering_rules ⇒ Array<Types::SheetElementRenderingRule>
The rendering rules that determine when an element should be displayed within a free-form layout.
-
#selected_border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
-
#visibility ⇒ String
The visibility of an element within a free-form layout.
-
#width ⇒ String
The width of an element within a free-form layout.
-
#x_axis_location ⇒ String
The x-axis coordinate of the element.
-
#y_axis_location ⇒ String
The y-axis coordinate of the element.
Instance Attribute Details
#background_style ⇒ Types::FreeFormLayoutElementBackgroundStyle
The background style configuration of a free-form layout element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_radius ⇒ String
The border radius of a free-form layout element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_id ⇒ String
A unique identifier for an element within a free-form layout.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_type ⇒ String
The type of element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#height ⇒ String
The height of an element within a free-form layout.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#loading_animation ⇒ Types::LoadingAnimation
The loading animation configuration of a free-form layout element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#padding ⇒ String
The padding of a free-form layout element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#rendering_rules ⇒ Array<Types::SheetElementRenderingRule>
The rendering rules that determine when an element should be displayed within a free-form layout.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#selected_border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element. This border style is used when the element is selected.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
The visibility of an element within a free-form layout.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#width ⇒ String
The width of an element within a free-form layout.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#x_axis_location ⇒ String
The x-axis coordinate of the element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#y_axis_location ⇒ String
The y-axis coordinate of the element.
22472 22473 22474 22475 22476 22477 22478 22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22472 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |