Class: Aws::QuickSight::Types::FreeFormLayoutElement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An element within a free-form layout.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#background_styleTypes::FreeFormLayoutElementBackgroundStyle

The background style configuration of a free-form layout element.



22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#border_radiusString

The border radius of a free-form layout element.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#border_styleTypes::FreeFormLayoutElementBorderStyle

The border style configuration of a free-form layout element.



22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#element_idString

A unique identifier for an element within a free-form layout.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#element_typeString

The type of element.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#heightString

The height of an element within a free-form layout.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#loading_animationTypes::LoadingAnimation

The loading animation configuration of a free-form layout element.



22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#paddingString

The padding of a free-form layout element.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#rendering_rulesArray<Types::SheetElementRenderingRule>

The rendering rules that determine when an element should be displayed within a free-form layout.



22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#selected_border_styleTypes::FreeFormLayoutElementBorderStyle

The border style configuration of a free-form layout element. This border style is used when the element is selected.



22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#visibilityString

The visibility of an element within a free-form layout.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#widthString

The width of an element within a free-form layout.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#x_axis_locationString

The x-axis coordinate of the element.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end

#y_axis_locationString

The y-axis coordinate of the element.

Returns:

  • (String)


22187
22188
22189
22190
22191
22192
22193
22194
22195
22196
22197
22198
22199
22200
22201
22202
22203
22204
# File 'lib/aws-sdk-quicksight/types.rb', line 22187

class FreeFormLayoutElement < Struct.new(
  :element_id,
  :element_type,
  :x_axis_location,
  :y_axis_location,
  :width,
  :height,
  :visibility,
  :rendering_rules,
  :border_style,
  :selected_border_style,
  :background_style,
  :loading_animation,
  :border_radius,
  :padding)
  SENSITIVE = []
  include Aws::Structure
end