Class: Aws::QuickSight::Types::FreeFormLayoutElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::FreeFormLayoutElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An element within a free-form layout.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#background_style ⇒ Types::FreeFormLayoutElementBackgroundStyle
The background style configuration of a free-form layout element.
-
#border_radius ⇒ String
The border radius of a free-form layout element.
-
#border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
-
#element_id ⇒ String
A unique identifier for an element within a free-form layout.
-
#element_type ⇒ String
The type of element.
-
#height ⇒ String
The height of an element within a free-form layout.
-
#loading_animation ⇒ Types::LoadingAnimation
The loading animation configuration of a free-form layout element.
-
#padding ⇒ String
The padding of a free-form layout element.
-
#rendering_rules ⇒ Array<Types::SheetElementRenderingRule>
The rendering rules that determine when an element should be displayed within a free-form layout.
-
#selected_border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
-
#visibility ⇒ String
The visibility of an element within a free-form layout.
-
#width ⇒ String
The width of an element within a free-form layout.
-
#x_axis_location ⇒ String
The x-axis coordinate of the element.
-
#y_axis_location ⇒ String
The y-axis coordinate of the element.
Instance Attribute Details
#background_style ⇒ Types::FreeFormLayoutElementBackgroundStyle
The background style configuration of a free-form layout element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_radius ⇒ String
The border radius of a free-form layout element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_id ⇒ String
A unique identifier for an element within a free-form layout.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_type ⇒ String
The type of element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#height ⇒ String
The height of an element within a free-form layout.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#loading_animation ⇒ Types::LoadingAnimation
The loading animation configuration of a free-form layout element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#padding ⇒ String
The padding of a free-form layout element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#rendering_rules ⇒ Array<Types::SheetElementRenderingRule>
The rendering rules that determine when an element should be displayed within a free-form layout.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#selected_border_style ⇒ Types::FreeFormLayoutElementBorderStyle
The border style configuration of a free-form layout element. This border style is used when the element is selected.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
The visibility of an element within a free-form layout.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#width ⇒ String
The width of an element within a free-form layout.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#x_axis_location ⇒ String
The x-axis coordinate of the element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#y_axis_location ⇒ String
The y-axis coordinate of the element.
20756 20757 20758 20759 20760 20761 20762 20763 20764 20765 20766 20767 20768 20769 20770 20771 20772 20773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20756 class FreeFormLayoutElement < Struct.new( :element_id, :element_type, :x_axis_location, :y_axis_location, :width, :height, :visibility, :rendering_rules, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |