Class: Aws::QuickSight::Types::GenerativeAuthoringConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GenerativeAuthoringConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The generative BI authoring settings of an embedded Quick Sight console.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
The generative BI authoring settings of an embedded Quick Sight console.
Instance Attribute Details
#enabled ⇒ Boolean
The generative BI authoring settings of an embedded Quick Sight console.
20234 20235 20236 20237 20238 |
# File 'lib/aws-sdk-quicksight/types.rb', line 20234 class GenerativeAuthoringConfigurations < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |