Class: Aws::QuickSight::Types::GeocodePreferenceValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GeocodePreferenceValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
GeocodePreferenceValue is a union - when making an API calls you must set exactly one of the members.
Note:
GeocodePreferenceValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GeocodePreferenceValue corresponding to the set member.
The preference value for the geocode preference.
Direct Known Subclasses
Defined Under Namespace
Classes: Coordinate, GeocoderHierarchy, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#coordinate ⇒ Types::Coordinate
The preference coordinate for the geocode preference.
-
#geocoder_hierarchy ⇒ Types::GeocoderHierarchy
The preference hierarchy for the geocode preference.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#coordinate ⇒ Types::Coordinate
The preference coordinate for the geocode preference.
23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23103 class GeocodePreferenceValue < Struct.new( :geocoder_hierarchy, :coordinate, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GeocoderHierarchy < GeocodePreferenceValue; end class Coordinate < GeocodePreferenceValue; end class Unknown < GeocodePreferenceValue; end end |
#geocoder_hierarchy ⇒ Types::GeocoderHierarchy
The preference hierarchy for the geocode preference.
23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23103 class GeocodePreferenceValue < Struct.new( :geocoder_hierarchy, :coordinate, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GeocoderHierarchy < GeocodePreferenceValue; end class Coordinate < GeocodePreferenceValue; end class Unknown < GeocodePreferenceValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
23103 23104 23105 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23103 def unknown @unknown end |