Class: Aws::QuickSight::Types::GeocodePreferenceValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Note:

GeocodePreferenceValue is a union - when making an API calls you must set exactly one of the members.

Note:

GeocodePreferenceValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GeocodePreferenceValue corresponding to the set member.

The preference value for the geocode preference.

Direct Known Subclasses

Coordinate, GeocoderHierarchy, Unknown

Defined Under Namespace

Classes: Coordinate, GeocoderHierarchy, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#coordinateTypes::Coordinate

The preference coordinate for the geocode preference.

Returns:



20299
20300
20301
20302
20303
20304
20305
20306
20307
20308
20309
20310
# File 'lib/aws-sdk-quicksight/types.rb', line 20299

class GeocodePreferenceValue < Struct.new(
  :geocoder_hierarchy,
  :coordinate,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GeocoderHierarchy < GeocodePreferenceValue; end
  class Coordinate < GeocodePreferenceValue; end
  class Unknown < GeocodePreferenceValue; end
end

#geocoder_hierarchyTypes::GeocoderHierarchy

The preference hierarchy for the geocode preference.



20299
20300
20301
20302
20303
20304
20305
20306
20307
20308
20309
20310
# File 'lib/aws-sdk-quicksight/types.rb', line 20299

class GeocodePreferenceValue < Struct.new(
  :geocoder_hierarchy,
  :coordinate,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GeocoderHierarchy < GeocodePreferenceValue; end
  class Coordinate < GeocodePreferenceValue; end
  class Unknown < GeocodePreferenceValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



20299
20300
20301
# File 'lib/aws-sdk-quicksight/types.rb', line 20299

def unknown
  @unknown
end