Class: Aws::QuickSight::Types::GeospatialCircleSymbolStyle
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GeospatialCircleSymbolStyle
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The properties for a circle symbol style.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#circle_radius ⇒ Types::GeospatialCircleRadius
The radius of the circle.
-
#fill_color ⇒ Types::GeospatialColor
The color and opacity values for the fill color.
-
#stroke_color ⇒ Types::GeospatialColor
The color and opacity values for the stroke color.
-
#stroke_width ⇒ Types::GeospatialLineWidth
The width of the stroke (border).
Instance Attribute Details
#circle_radius ⇒ Types::GeospatialCircleRadius
The radius of the circle.
23472 23473 23474 23475 23476 23477 23478 23479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23472 class GeospatialCircleSymbolStyle < Struct.new( :fill_color, :stroke_color, :stroke_width, :circle_radius) SENSITIVE = [] include Aws::Structure end |
#fill_color ⇒ Types::GeospatialColor
The color and opacity values for the fill color.
23472 23473 23474 23475 23476 23477 23478 23479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23472 class GeospatialCircleSymbolStyle < Struct.new( :fill_color, :stroke_color, :stroke_width, :circle_radius) SENSITIVE = [] include Aws::Structure end |
#stroke_color ⇒ Types::GeospatialColor
The color and opacity values for the stroke color.
23472 23473 23474 23475 23476 23477 23478 23479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23472 class GeospatialCircleSymbolStyle < Struct.new( :fill_color, :stroke_color, :stroke_width, :circle_radius) SENSITIVE = [] include Aws::Structure end |
#stroke_width ⇒ Types::GeospatialLineWidth
The width of the stroke (border).
23472 23473 23474 23475 23476 23477 23478 23479 |
# File 'lib/aws-sdk-quicksight/types.rb', line 23472 class GeospatialCircleSymbolStyle < Struct.new( :fill_color, :stroke_color, :stroke_width, :circle_radius) SENSITIVE = [] include Aws::Structure end |