Class: Aws::QuickSight::Types::GeospatialPolygonSymbolStyle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The polygon symbol style for a polygon layer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fill_colorTypes::GeospatialColor

The color and opacity values for the fill color.



23698
23699
23700
23701
23702
23703
23704
# File 'lib/aws-sdk-quicksight/types.rb', line 23698

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end

#stroke_colorTypes::GeospatialColor

The color and opacity values for the stroke color.



23698
23699
23700
23701
23702
23703
23704
# File 'lib/aws-sdk-quicksight/types.rb', line 23698

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end

#stroke_widthTypes::GeospatialLineWidth

The width of the border stroke.



23698
23699
23700
23701
23702
23703
23704
# File 'lib/aws-sdk-quicksight/types.rb', line 23698

class GeospatialPolygonSymbolStyle < Struct.new(
  :fill_color,
  :stroke_color,
  :stroke_width)
  SENSITIVE = []
  include Aws::Structure
end