Class: Aws::QuickSight::Types::GetFlowMetadataInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the flow that you are getting metadata for.

Returns:

  • (String)


22498
22499
22500
22501
22502
22503
# File 'lib/aws-sdk-quicksight/types.rb', line 22498

class GetFlowMetadataInput < Struct.new(
  :aws_account_id,
  :flow_id)
  SENSITIVE = []
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow.

Returns:

  • (String)


22498
22499
22500
22501
22502
22503
# File 'lib/aws-sdk-quicksight/types.rb', line 22498

class GetFlowMetadataInput < Struct.new(
  :aws_account_id,
  :flow_id)
  SENSITIVE = []
  include Aws::Structure
end