Class: Aws::QuickSight::Types::GetFlowMetadataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetFlowMetadataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are getting metadata for.
-
#flow_id ⇒ String
The unique identifier of the flow.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are getting metadata for.
21347 21348 21349 21350 21351 21352 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21347 class GetFlowMetadataInput < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow.
21347 21348 21349 21350 21351 21352 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21347 class GetFlowMetadataInput < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |