Class: Aws::QuickSight::Types::GetFlowPermissionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetFlowPermissionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are getting permissions for.
-
#flow_id ⇒ String
The unique identifier of the flow to get permissions from.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are getting permissions for.
21428 21429 21430 21431 21432 21433 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21428 class GetFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow to get permissions from.
21428 21429 21430 21431 21432 21433 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21428 class GetFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id) SENSITIVE = [] include Aws::Structure end |