Class: Aws::QuickSight::Types::GetIdentityContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetIdentityContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
///////////////////////// /////////////////////////
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in.
-
#context_region ⇒ String
The region in which the context is to be used.
-
#namespace ⇒ String
The namespace of the user that you want to get identity context for.
-
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
-
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in. Currently, you use the ID for the Amazon Web Services account that contains your Quick Sight account.
22756 22757 22758 22759 22760 22761 22762 22763 22764 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22756 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at, :context_region) SENSITIVE = [] include Aws::Structure end |
#context_region ⇒ String
The region in which the context is to be used. Use this parameter to obtain an identity context for cross-region use.
The specified region must meet the following conditions:
-
The region must be in the same Amazon Web Services partition as the region you are calling from. Cross-partition requests are not supported. For example, you cannot specify a region in the ‘aws-cn` partition when calling from a region in the `aws` partition.
-
It must be a valid Amazon QuickSight supported region.
-
The calling customer account must be enabled in the specified context region.
-
This parameter is not supported when calling from an opt-in region.
22756 22757 22758 22759 22760 22761 22762 22763 22764 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22756 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at, :context_region) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the user that you want to get identity context for. This parameter is required when the UserIdentifier is specified using Email or UserName.
22756 22757 22758 22759 22760 22761 22762 22763 22764 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22756 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at, :context_region) SENSITIVE = [] include Aws::Structure end |
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
22756 22757 22758 22759 22760 22761 22762 22763 22764 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22756 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at, :context_region) SENSITIVE = [] include Aws::Structure end |
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
22756 22757 22758 22759 22760 22761 22762 22763 22764 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22756 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at, :context_region) SENSITIVE = [] include Aws::Structure end |