Class: Aws::QuickSight::Types::GetIdentityContextRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

///////////////////////// /////////////////////////

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in. Currently, you use the ID for the Amazon Web Services account that contains your Quick Sight account.

Returns:

  • (String)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-quicksight/types.rb', line 22645

class GetIdentityContextRequest < Struct.new(
  :aws_account_id,
  :user_identifier,
  :namespace,
  :session_expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the user that you want to get identity context for. This parameter is required when the UserIdentifier is specified using Email or UserName.

Returns:

  • (String)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-quicksight/types.rb', line 22645

class GetIdentityContextRequest < Struct.new(
  :aws_account_id,
  :user_identifier,
  :namespace,
  :session_expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#session_expires_atTime

The timestamp at which the session will expire.

Returns:

  • (Time)


22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-quicksight/types.rb', line 22645

class GetIdentityContextRequest < Struct.new(
  :aws_account_id,
  :user_identifier,
  :namespace,
  :session_expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#user_identifierTypes::UserIdentifier

The identifier for the user whose identity context you want to retrieve.



22645
22646
22647
22648
22649
22650
22651
22652
# File 'lib/aws-sdk-quicksight/types.rb', line 22645

class GetIdentityContextRequest < Struct.new(
  :aws_account_id,
  :user_identifier,
  :namespace,
  :session_expires_at)
  SENSITIVE = []
  include Aws::Structure
end