Class: Aws::QuickSight::Types::GetIdentityContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetIdentityContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
///////////////////////// /////////////////////////
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in.
-
#namespace ⇒ String
The namespace of the user that you want to get identity context for.
-
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
-
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in. Currently, you use the ID for the Amazon Web Services account that contains your Quick Sight account.
22645 22646 22647 22648 22649 22650 22651 22652 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22645 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the user that you want to get identity context for. This parameter is required when the UserIdentifier is specified using Email or UserName.
22645 22646 22647 22648 22649 22650 22651 22652 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22645 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
22645 22646 22647 22648 22649 22650 22651 22652 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22645 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
22645 22646 22647 22648 22649 22650 22651 22652 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22645 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |