Class: Aws::QuickSight::Types::GetIdentityContextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetIdentityContextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
///////////////////////// /////////////////////////
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in.
-
#namespace ⇒ String
The namespace of the user that you want to get identity context for.
-
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
-
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the user whose identity context you want to retrieve is in. Currently, you use the ID for the Amazon Web Services account that contains your Quick Sight account.
21494 21495 21496 21497 21498 21499 21500 21501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21494 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the user that you want to get identity context for. This parameter is required when the UserIdentifier is specified using Email or UserName.
21494 21495 21496 21497 21498 21499 21500 21501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21494 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#session_expires_at ⇒ Time
The timestamp at which the session will expire.
21494 21495 21496 21497 21498 21499 21500 21501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21494 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |
#user_identifier ⇒ Types::UserIdentifier
The identifier for the user whose identity context you want to retrieve.
21494 21495 21496 21497 21498 21499 21500 21501 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21494 class GetIdentityContextRequest < Struct.new( :aws_account_id, :user_identifier, :namespace, :session_expires_at) SENSITIVE = [] include Aws::Structure end |