Class: Aws::QuickSight::Types::GetIdentityContextResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextString

The identity context information for the user. This is an identity token that should be used as the ContextAssertion parameter in the STS AssumeRole API call to obtain identity enhanced Amazon Web Services credentials.

Returns:

  • (String)


25601
25602
25603
25604
25605
25606
25607
# File 'lib/aws-sdk-quicksight/types.rb', line 25601

class GetIdentityContextResponse < Struct.new(
  :status,
  :request_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


25601
25602
25603
25604
25605
25606
25607
# File 'lib/aws-sdk-quicksight/types.rb', line 25601

class GetIdentityContextResponse < Struct.new(
  :status,
  :request_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


25601
25602
25603
25604
25605
25606
25607
# File 'lib/aws-sdk-quicksight/types.rb', line 25601

class GetIdentityContextResponse < Struct.new(
  :status,
  :request_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end