Class: Aws::QuickSight::Types::GetIdentityContextResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetIdentityContextResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ String
The identity context information for the user.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#context ⇒ String
The identity context information for the user. This is an identity token that should be used as the ContextAssertion parameter in the STS AssumeRole API call to obtain identity enhanced Amazon Web Services credentials.
24634 24635 24636 24637 24638 24639 24640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24634 class GetIdentityContextResponse < Struct.new( :status, :request_id, :context) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
24634 24635 24636 24637 24638 24639 24640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24634 class GetIdentityContextResponse < Struct.new( :status, :request_id, :context) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
24634 24635 24636 24637 24638 24639 24640 |
# File 'lib/aws-sdk-quicksight/types.rb', line 24634 class GetIdentityContextResponse < Struct.new( :status, :request_id, :context) SENSITIVE = [] include Aws::Structure end |