Class: Aws::QuickSight::Types::GetSessionEmbedUrlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GetSessionEmbedUrlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account associated with your Amazon Quick Sight subscription.
-
#entry_point ⇒ String
The URL you use to access the embedded session.
-
#session_lifetime_in_minutes ⇒ Integer
How many minutes the session is valid.
-
#user_arn ⇒ String
The Amazon Quick Suite user’s Amazon Resource Name (ARN), for use with ‘QUICKSIGHT` identity type.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account associated with your Amazon Quick Sight subscription.
21581 21582 21583 21584 21585 21586 21587 21588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21581 class GetSessionEmbedUrlRequest < Struct.new( :aws_account_id, :entry_point, :session_lifetime_in_minutes, :user_arn) SENSITIVE = [] include Aws::Structure end |
#entry_point ⇒ String
The URL you use to access the embedded session. The entry point URL is constrained to the following paths:
-
‘/start`
-
‘/start/analyses`
-
‘/start/dashboards`
-
‘/start/favorites`
-
‘/dashboards/DashboardId ` - where `DashboardId` is the actual ID key from the Amazon Quick Sight console URL of the dashboard
-
‘/analyses/AnalysisId ` - where `AnalysisId` is the actual ID key from the Amazon Quick Sight console URL of the analysis
21581 21582 21583 21584 21585 21586 21587 21588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21581 class GetSessionEmbedUrlRequest < Struct.new( :aws_account_id, :entry_point, :session_lifetime_in_minutes, :user_arn) SENSITIVE = [] include Aws::Structure end |
#session_lifetime_in_minutes ⇒ Integer
How many minutes the session is valid. The session lifetime must be 15-600 minutes.
21581 21582 21583 21584 21585 21586 21587 21588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21581 class GetSessionEmbedUrlRequest < Struct.new( :aws_account_id, :entry_point, :session_lifetime_in_minutes, :user_arn) SENSITIVE = [] include Aws::Structure end |
#user_arn ⇒ String
The Amazon Quick Suite user’s Amazon Resource Name (ARN), for use with ‘QUICKSIGHT` identity type. You can use this for any type of Amazon Quick Suite users in your account (readers, authors, or admins). They need to be authenticated as one of the following:
-
Active Directory (AD) users or group members
-
Invited nonfederated users
-
IAM users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation
Omit this parameter for users in the third group, IAM users and IAM role-based sessions.
21581 21582 21583 21584 21585 21586 21587 21588 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21581 class GetSessionEmbedUrlRequest < Struct.new( :aws_account_id, :entry_point, :session_lifetime_in_minutes, :user_arn) SENSITIVE = [] include Aws::Structure end |