Class: Aws::QuickSight::Types::Governance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Contains the governance configuration for a custom permissions profile. When governance controls are defined for a category, any capabilities in that category not explicitly set to ALLOW in Capabilities are denied. Even newly added capabilities in the category are implicitly disabled when Amazon Quick releases them.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_category_effectsHash<String,String>

A map of DefaultCategoryEffects.

Returns:

  • (Hash<String,String>)


25747
25748
25749
25750
25751
# File 'lib/aws-sdk-quicksight/types.rb', line 25747

class Governance < Struct.new(
  :default_category_effects)
  SENSITIVE = []
  include Aws::Structure
end