Class: Aws::QuickSight::Types::GridLayoutElement
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::GridLayoutElement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An element within a grid layout.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#background_style ⇒ Types::GridLayoutElementBackgroundStyle
The background style configuration of a grid layout element.
-
#border_radius ⇒ String
The border radius of a grid layout element.
-
#border_style ⇒ Types::GridLayoutElementBorderStyle
The border style configuration of a grid layout element.
-
#column_index ⇒ Integer
The column index for the upper left corner of an element.
-
#column_span ⇒ Integer
The width of a grid element expressed as a number of grid columns.
-
#element_id ⇒ String
A unique identifier for an element within a grid layout.
-
#element_type ⇒ String
The type of element.
-
#loading_animation ⇒ Types::LoadingAnimation
The configuration of loading animation in free-form layout.
-
#padding ⇒ String
The padding of a grid layout element.
-
#row_index ⇒ Integer
The row index for the upper left corner of an element.
-
#row_span ⇒ Integer
The height of a grid element expressed as a number of grid rows.
-
#selected_border_style ⇒ Types::GridLayoutElementBorderStyle
The border style configuration of a grid layout element.
Instance Attribute Details
#background_style ⇒ Types::GridLayoutElementBackgroundStyle
The background style configuration of a grid layout element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_radius ⇒ String
The border radius of a grid layout element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#border_style ⇒ Types::GridLayoutElementBorderStyle
The border style configuration of a grid layout element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#column_index ⇒ Integer
The column index for the upper left corner of an element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#column_span ⇒ Integer
The width of a grid element expressed as a number of grid columns.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_id ⇒ String
A unique identifier for an element within a grid layout.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#element_type ⇒ String
The type of element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#loading_animation ⇒ Types::LoadingAnimation
The configuration of loading animation in free-form layout.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#padding ⇒ String
The padding of a grid layout element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#row_index ⇒ Integer
The row index for the upper left corner of an element.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#row_span ⇒ Integer
The height of a grid element expressed as a number of grid rows.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |
#selected_border_style ⇒ Types::GridLayoutElementBorderStyle
The border style configuration of a grid layout element. This border style is used when the element is selected.
21764 21765 21766 21767 21768 21769 21770 21771 21772 21773 21774 21775 21776 21777 21778 21779 |
# File 'lib/aws-sdk-quicksight/types.rb', line 21764 class GridLayoutElement < Struct.new( :element_id, :element_type, :column_index, :column_span, :row_index, :row_span, :border_style, :selected_border_style, :background_style, :loading_animation, :border_radius, :padding) SENSITIVE = [] include Aws::Structure end |