Class: Aws::QuickSight::Types::IAMConnectionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Authentication metadata for IAM-based connections, used for first-party Amazon Web Services service integrations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#role_arnString

The Amazon Resource Name (ARN) of the IAM role to assume for authentication with Amazon Web Services services. This IAM role should be in the same account as Quick Sight.

Returns:

  • (String)


25431
25432
25433
25434
25435
# File 'lib/aws-sdk-quicksight/types.rb', line 25431

class IAMConnectionMetadata < Struct.new(
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end