Class: Aws::QuickSight::Types::IAMConnectionMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::IAMConnectionMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Authentication metadata for IAM-based connections, used for first-party Amazon Web Services service integrations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to assume for authentication with Amazon Web Services services.
Instance Attribute Details
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to assume for authentication with Amazon Web Services services. This IAM role should be in the same account as Quick Sight.
25192 25193 25194 25195 25196 |
# File 'lib/aws-sdk-quicksight/types.rb', line 25192 class IAMConnectionMetadata < Struct.new( :role_arn) SENSITIVE = [] include Aws::Structure end |