Class: Aws::QuickSight::Types::ImportTableOperationSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ImportTableOperationSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Specifies the source table and column mappings for an import table operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_id_mappings ⇒ Array<Types::DataSetColumnIdMapping>
The mappings between source column identifiers and target column identifiers during the import.
-
#source_table_id ⇒ String
The identifier of the source table to import data from.
Instance Attribute Details
#column_id_mappings ⇒ Array<Types::DataSetColumnIdMapping>
The mappings between source column identifiers and target column identifiers during the import.
22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22767 class ImportTableOperationSource < Struct.new( :source_table_id, :column_id_mappings) SENSITIVE = [] include Aws::Structure end |
#source_table_id ⇒ String
The identifier of the source table to import data from.
22767 22768 22769 22770 22771 22772 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22767 class ImportTableOperationSource < Struct.new( :source_table_id, :column_id_mappings) SENSITIVE = [] include Aws::Structure end |