Class: Aws::QuickSight::Types::JoinOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::JoinOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A transform operation that combines data from two sources based on specified join conditions.
Constant Summary collapse
- SENSITIVE =
[:on_clause]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for this operation.
-
#left_operand ⇒ Types::TransformOperationSource
The left operand for the join operation.
-
#left_operand_properties ⇒ Types::JoinOperandProperties
Properties that control how the left operand’s columns are handled in the join result.
-
#on_clause ⇒ String
The join condition that specifies how to match rows between the left and right operands.
-
#right_operand ⇒ Types::TransformOperationSource
The right operand for the join operation.
-
#right_operand_properties ⇒ Types::JoinOperandProperties
Properties that control how the right operand’s columns are handled in the join result.
-
#type ⇒ String
The type of join to perform, such as ‘INNER`, `LEFT`, `RIGHT`, or `OUTER`.
Instance Attribute Details
#alias ⇒ String
Alias for this operation.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#left_operand ⇒ Types::TransformOperationSource
The left operand for the join operation.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#left_operand_properties ⇒ Types::JoinOperandProperties
Properties that control how the left operand’s columns are handled in the join result.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#on_clause ⇒ String
The join condition that specifies how to match rows between the left and right operands.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#right_operand ⇒ Types::TransformOperationSource
The right operand for the join operation.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#right_operand_properties ⇒ Types::JoinOperandProperties
Properties that control how the right operand’s columns are handled in the join result.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |
#type ⇒ String
The type of join to perform, such as ‘INNER`, `LEFT`, `RIGHT`, or `OUTER`.
22763 22764 22765 22766 22767 22768 22769 22770 22771 22772 22773 |
# File 'lib/aws-sdk-quicksight/types.rb', line 22763 class JoinOperation < Struct.new( :alias, :left_operand, :right_operand, :type, :on_clause, :left_operand_properties, :right_operand_properties) SENSITIVE = [:on_clause] include Aws::Structure end |