Class: Aws::QuickSight::Types::KbTemplateConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::KbTemplateConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The template configuration for a knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template ⇒ Hash, ...
The template document that defines the knowledge base behavior.
Instance Attribute Details
#template ⇒ Hash, ...
The template document that defines the knowledge base behavior.
26656 26657 26658 26659 26660 |
# File 'lib/aws-sdk-quicksight/types.rb', line 26656 class KbTemplateConfiguration < Struct.new( :template) SENSITIVE = [] include Aws::Structure end |