Class: Aws::QuickSight::Types::KnowledgeBase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A knowledge base resource that provides data from connected sources for AI-powered experiences in Amazon QuickSight.

Constant Summary collapse

SENSITIVE =
[:knowledge_base_configuration, :primary_owner_username]

Instance Attribute Summary collapse

Instance Attribute Details

#access_control_configurationTypes::AccessControlConfiguration

The access control configuration for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#created_atTime

The date and time that the knowledge base was created.

Returns:

  • (Time)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#data_source_arnString

The ARN of the data source associated with the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#descriptionString

The description of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#document_countInteger

The number of documents in the knowledge base.

Returns:

  • (Integer)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#first_completed_ingestion_summaryTypes::KnowledgeBaseIngestionSummary

A summary of the first completed ingestion for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#first_incomplete_ingestion_summaryTypes::KnowledgeBaseIngestionSummary

A summary of the first incomplete ingestion for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#is_email_notification_opted_for_ingestion_failuresBoolean

Specifies whether email notifications are enabled for ingestion failures.

Returns:

  • (Boolean)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#knowledge_base_arnString

The Amazon Resource Name (ARN) of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseConfiguration

The configuration settings for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#knowledge_base_size_bytesInteger

The size of the knowledge base in bytes.

Returns:

  • (Integer)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#latest_ingestion_summaryTypes::KnowledgeBaseIngestionSummary

A summary of the most recent ingestion for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#media_extraction_configurationTypes::MediaExtractionConfiguration

The media extraction configuration for the knowledge base.



28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#nameString

The name of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#primary_owner_arnString

The ARN of the primary owner of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#primary_owner_usernameString

The username of the primary owner of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#statusString

The status of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#typeString

The type of the knowledge base.

Returns:

  • (String)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end

#updated_atTime

The date and time that the knowledge base was last updated.

Returns:

  • (Time)


28071
28072
28073
28074
28075
28076
28077
28078
28079
28080
28081
28082
28083
28084
28085
28086
28087
28088
28089
28090
28091
28092
28093
28094
# File 'lib/aws-sdk-quicksight/types.rb', line 28071

class KnowledgeBase < Struct.new(
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :status,
  :data_source_arn,
  :knowledge_base_configuration,
  :media_extraction_configuration,
  :access_control_configuration,
  :type,
  :created_at,
  :updated_at,
  :description,
  :is_email_notification_opted_for_ingestion_failures,
  :first_completed_ingestion_summary,
  :first_incomplete_ingestion_summary,
  :latest_ingestion_summary,
  :knowledge_base_size_bytes,
  :document_count,
  :primary_owner_arn,
  :primary_owner_username)
  SENSITIVE = [:knowledge_base_configuration, :primary_owner_username]
  include Aws::Structure
end