Class: Aws::QuickSight::Types::KnowledgeBaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::KnowledgeBaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration settings for a knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template_configuration ⇒ Types::KbTemplateConfiguration
The template configuration that defines how the data source connector crawls and indexes data for the knowledge base.
Instance Attribute Details
#template_configuration ⇒ Types::KbTemplateConfiguration
The template configuration that defines how the data source
connector crawls and indexes data for the knowledge base. The
template structure varies by connector type. See
KbTemplateConfiguration for connector-specific details.
29199 29200 29201 29202 29203 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29199 class KnowledgeBaseConfiguration < Struct.new( :template_configuration) SENSITIVE = [] include Aws::Structure end |