Class: Aws::QuickSight::Types::LimitsProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::LimitsProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A limits profile that defines resource usage limits for Amazon Quick Sight users. Limits profiles can be assigned to users, groups, or roles to control resource consumption.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that contains the limits profile.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the limits profile.
-
#created_at ⇒ Time
The date and time that the limits profile was created.
-
#description ⇒ String
The description of the limits profile.
-
#profile_id ⇒ String
The unique identifier for the limits profile.
-
#profile_name ⇒ String
The display name of the limits profile.
-
#resource_limits ⇒ Hash<String,Types::ProfileLimitValue>
A map of resource types to their limit values.
-
#updated_at ⇒ Time
The date and time that the limits profile was last updated.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that contains the limits profile.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the limits profile.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the limits profile was created.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the limits profile.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The unique identifier for the limits profile.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#profile_name ⇒ String
The display name of the limits profile.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#resource_limits ⇒ Hash<String,Types::ProfileLimitValue>
A map of resource types to their limit values.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the limits profile was last updated.
29696 29697 29698 29699 29700 29701 29702 29703 29704 29705 29706 29707 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29696 class LimitsProfile < Struct.new( :profile_id, :arn, :account_id, :profile_name, :description, :resource_limits, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |