Class: Aws::QuickSight::Types::LineChartLineStyleSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::LineChartLineStyleSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Line styles options for a line series in LineChartVisual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#line_interpolation ⇒ String
Interpolation style for line series.
-
#line_style ⇒ String
Line style for line series.
-
#line_visibility ⇒ String
Configuration option that determines whether to show the line for the series.
-
#line_width ⇒ String
Width that determines the line thickness.
Instance Attribute Details
#line_interpolation ⇒ String
Interpolation style for line series.
-
LINEAR: Show as default, linear style. -
SMOOTH: Show as a smooth curve. -
STEPPED: Show steps in line.
27491 27492 27493 27494 27495 27496 27497 27498 |
# File 'lib/aws-sdk-quicksight/types.rb', line 27491 class LineChartLineStyleSettings < Struct.new( :line_visibility, :line_interpolation, :line_style, :line_width) SENSITIVE = [] include Aws::Structure end |
#line_style ⇒ String
Line style for line series.
-
SOLID: Show as a solid line. -
DOTTED: Show as a dotted line. -
DASHED: Show as a dashed line.
27491 27492 27493 27494 27495 27496 27497 27498 |
# File 'lib/aws-sdk-quicksight/types.rb', line 27491 class LineChartLineStyleSettings < Struct.new( :line_visibility, :line_interpolation, :line_style, :line_width) SENSITIVE = [] include Aws::Structure end |
#line_visibility ⇒ String
Configuration option that determines whether to show the line for the series.
27491 27492 27493 27494 27495 27496 27497 27498 |
# File 'lib/aws-sdk-quicksight/types.rb', line 27491 class LineChartLineStyleSettings < Struct.new( :line_visibility, :line_interpolation, :line_style, :line_width) SENSITIVE = [] include Aws::Structure end |
#line_width ⇒ String
Width that determines the line thickness.
27491 27492 27493 27494 27495 27496 27497 27498 |
# File 'lib/aws-sdk-quicksight/types.rb', line 27491 class LineChartLineStyleSettings < Struct.new( :line_visibility, :line_interpolation, :line_style, :line_width) SENSITIVE = [] include Aws::Structure end |