Class: Aws::QuickSight::Types::MarginStyle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The display options for margins around the outside edge of sheets.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#showBoolean

This Boolean value controls whether to display sheet margins.

Returns:

  • (Boolean)


26851
26852
26853
26854
26855
# File 'lib/aws-sdk-quicksight/types.rb', line 26851

class MarginStyle < Struct.new(
  :show)
  SENSITIVE = []
  include Aws::Structure
end