Class: Aws::QuickSight::Types::NamedEntityDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::NamedEntityDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that represents a named entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
The name of the entity.
-
#is_hidden ⇒ Boolean
A Boolean value that indicates whether the named entity definition is hidden.
-
#metric ⇒ Types::NamedEntityDefinitionMetric
The definition of a metric.
-
#presentation_order ⇒ Integer
The presentation order of the named entity definition.
-
#property_name ⇒ String
The property name to be used for the named entity.
-
#property_role ⇒ String
The property role.
-
#property_usage ⇒ String
The property usage.
-
#rank_order ⇒ Integer
The rank order of the named entity definition.
Instance Attribute Details
#field_name ⇒ String
The name of the entity.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#is_hidden ⇒ Boolean
A Boolean value that indicates whether the named entity definition is hidden.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ Types::NamedEntityDefinitionMetric
The definition of a metric.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#presentation_order ⇒ Integer
The presentation order of the named entity definition.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#property_name ⇒ String
The property name to be used for the named entity.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#property_role ⇒ String
The property role. Valid values for this structure are PRIMARY and
ID.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#property_usage ⇒ String
The property usage. Valid values for this structure are INHERIT,
DIMENSION, and MEASURE.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |
#rank_order ⇒ Integer
The rank order of the named entity definition.
31960 31961 31962 31963 31964 31965 31966 31967 31968 31969 31970 31971 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31960 class NamedEntityDefinition < Struct.new( :field_name, :property_name, :property_role, :property_usage, :metric, :rank_order, :presentation_order, :is_hidden) SENSITIVE = [] include Aws::Structure end |