Class: Aws::QuickSight::Types::OAuthClientApplication
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::OAuthClientApplication
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
An OAuth client application that is used to authenticate connections to a data source through an OAuth identity provider.
Constant Summary collapse
- SENSITIVE =
[:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the OAuthClientApplication.
-
#created_time ⇒ Time
The time that the OAuthClientApplication was created.
-
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used with.
-
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
-
#last_updated_time ⇒ Time
The time that the OAuthClientApplication was last updated.
-
#name ⇒ String
The display name of the OAuthClientApplication.
-
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
-
#o_auth_client_application_id ⇒ String
The ID of the OAuthClientApplication.
-
#o_auth_client_authentication_type ⇒ String
The OAuth client authentication type used by the OAuthClientApplication.
-
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
-
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the OAuthClientApplication.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#created_time ⇒ Time
The time that the OAuthClientApplication was created.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used
with. Valid values are SNOWFLAKE.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#last_updated_time ⇒ Time
The time that the OAuthClientApplication was last updated.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#name ⇒ String
The display name of the OAuthClientApplication.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_client_application_id ⇒ String
The ID of the OAuthClientApplication. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_client_authentication_type ⇒ String
The OAuth client authentication type used by the
OAuthClientApplication. Valid values are TOKEN.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31614 class OAuthClientApplication < Struct.new( :o_auth_client_application_id, :name, :o_auth_client_authentication_type, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties, :created_time, :last_updated_time, :arn) SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |