Class: Aws::QuickSight::Types::OAuthClientApplication

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

An OAuth client application that is used to authenticate connections to a data source through an OAuth identity provider.

Constant Summary collapse

SENSITIVE =
[:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the OAuthClientApplication.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#created_timeTime

The time that the OAuthClientApplication was created.

Returns:

  • (Time)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#data_source_typeString

The type of data source that the OAuthClientApplication is used with. Valid values are ‘SNOWFLAKE`.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#identity_provider_vpc_connection_propertiesTypes::VpcConnectionProperties

VPC connection properties.



29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#last_updated_timeTime

The time that the OAuthClientApplication was last updated.

Returns:

  • (Time)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#nameString

The display name of the OAuthClientApplication.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_authorization_endpoint_urlString

The authorization endpoint URL of the identity provider that is used to obtain authorization codes.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_client_application_idString

The ID of the OAuthClientApplication. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_client_authentication_typeString

The OAuth client authentication type used by the OAuthClientApplication. Valid values are ‘TOKEN`.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_scopesString

The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_token_endpoint_urlString

The token endpoint URL of the identity provider that is used to obtain access tokens.

Returns:

  • (String)


29528
29529
29530
29531
29532
29533
29534
29535
29536
29537
29538
29539
29540
29541
29542
# File 'lib/aws-sdk-quicksight/types.rb', line 29528

class OAuthClientApplication < Struct.new(
  :o_auth_client_application_id,
  :name,
  :o_auth_client_authentication_type,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties,
  :created_time,
  :last_updated_time,
  :arn)
  SENSITIVE = [:o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end