Class: Aws::QuickSight::Types::OracleParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::OracleParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The parameters for Oracle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database ⇒ String
The database.
-
#host ⇒ String
An Oracle host.
-
#port ⇒ Integer
The port.
-
#use_service_name ⇒ Boolean
A Boolean value that indicates whether the
Databaseuses a service name or an SID.
Instance Attribute Details
#database ⇒ String
The database.
32937 32938 32939 32940 32941 32942 32943 32944 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32937 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#host ⇒ String
An Oracle host.
32937 32938 32939 32940 32941 32942 32943 32944 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32937 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port.
32937 32938 32939 32940 32941 32942 32943 32944 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32937 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |
#use_service_name ⇒ Boolean
A Boolean value that indicates whether the Database uses a service
name or an SID. If this value is left blank, the default value is
SID. If this value is set to false, the value is SID.
32937 32938 32939 32940 32941 32942 32943 32944 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32937 class OracleParameters < Struct.new( :host, :port, :database, :use_service_name) SENSITIVE = [] include Aws::Structure end |