Class: Aws::QuickSight::Types::ParameterDropDownControl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A control to display a dropdown list with buttons that are used to select a single value.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cascading_control_configurationTypes::CascadingControlConfiguration

The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.



30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#commit_modeString

The visibility configuration of the Apply button on a ‘ParameterDropDownControl`.

Returns:

  • (String)


30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#control_sort_configurationsArray<Types::ControlSortConfiguration>

The sort configuration for the values displayed in the control. Only one sort configuration can be applied per control.



30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#control_title_format_textTypes::ControlTitleFormatText

The title text format configuration for the control.



30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#display_optionsTypes::DropDownControlDisplayOptions

The display options of a control.



30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_control_idString

The ID of the ‘ParameterDropDownControl`.

Returns:

  • (String)


30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#selectable_valuesTypes::ParameterSelectableValues

A list of selectable values that are used in a control.



30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#source_parameter_nameString

The source parameter name of the ‘ParameterDropDownControl`.

Returns:

  • (String)


30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the ‘ParameterDropDownControl`.

Returns:

  • (String)


30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type parameter name of the ‘ParameterDropDownControl`.

Returns:

  • (String)


30068
30069
30070
30071
30072
30073
30074
30075
30076
30077
30078
30079
30080
30081
# File 'lib/aws-sdk-quicksight/types.rb', line 30068

class ParameterDropDownControl < Struct.new(
  :parameter_control_id,
  :title,
  :source_parameter_name,
  :display_options,
  :type,
  :selectable_values,
  :cascading_control_configuration,
  :commit_mode,
  :control_sort_configurations,
  :control_title_format_text)
  SENSITIVE = []
  include Aws::Structure
end