Class: Aws::QuickSight::Types::ParameterDropDownControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ParameterDropDownControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A control to display a dropdown list with buttons that are used to select a single value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cascading_control_configuration ⇒ Types::CascadingControlConfiguration
The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.
-
#commit_mode ⇒ String
The visibility configuration of the Apply button on a ‘ParameterDropDownControl`.
-
#control_sort_configurations ⇒ Array<Types::ControlSortConfiguration>
The sort configuration for the values displayed in the control.
-
#display_options ⇒ Types::DropDownControlDisplayOptions
The display options of a control.
-
#parameter_control_id ⇒ String
The ID of the ‘ParameterDropDownControl`.
-
#selectable_values ⇒ Types::ParameterSelectableValues
A list of selectable values that are used in a control.
-
#source_parameter_name ⇒ String
The source parameter name of the ‘ParameterDropDownControl`.
-
#title ⇒ String
The title of the ‘ParameterDropDownControl`.
-
#type ⇒ String
The type parameter name of the ‘ParameterDropDownControl`.
Instance Attribute Details
#cascading_control_configuration ⇒ Types::CascadingControlConfiguration
The values that are displayed in a control can be configured to only show values that are valid based on what’s selected in other controls.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#commit_mode ⇒ String
The visibility configuration of the Apply button on a ‘ParameterDropDownControl`.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#control_sort_configurations ⇒ Array<Types::ControlSortConfiguration>
The sort configuration for the values displayed in the control. Only one sort configuration can be applied per control.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#display_options ⇒ Types::DropDownControlDisplayOptions
The display options of a control.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#parameter_control_id ⇒ String
The ID of the ‘ParameterDropDownControl`.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#selectable_values ⇒ Types::ParameterSelectableValues
A list of selectable values that are used in a control.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#source_parameter_name ⇒ String
The source parameter name of the ‘ParameterDropDownControl`.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the ‘ParameterDropDownControl`.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type parameter name of the ‘ParameterDropDownControl`.
29419 29420 29421 29422 29423 29424 29425 29426 29427 29428 29429 29430 29431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 29419 class ParameterDropDownControl < Struct.new( :parameter_control_id, :title, :source_parameter_name, :display_options, :type, :selectable_values, :cascading_control_configuration, :commit_mode, :control_sort_configurations) SENSITIVE = [] include Aws::Structure end |