Class: Aws::QuickSight::Types::PivotTableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The configuration for a ‘PivotTableVisual`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_customization_visual_optionsTypes::DashboardCustomizationVisualOptions

The options that define customizations available to dashboard readers for a specific visual



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_optionsTypes::PivotTableFieldOptions

The field options for a pivot table visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_wellsTypes::PivotTableFieldWells

The field wells of the visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#interactionsTypes::VisualInteractionOptions

The general visual interactions setup for a visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#paginated_report_optionsTypes::PivotTablePaginatedReportOptions

The paginated report options for a pivot table visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_configurationTypes::PivotTableSortConfiguration

The sort configuration for a ‘PivotTableVisual`.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#table_optionsTypes::PivotTableOptions

The table options for a pivot table visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#tooltipTypes::TooltipOptions

The display options for the visual tooltip.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#total_optionsTypes::PivotTableTotalOptions

The total options for a pivot table visual.



31024
31025
31026
31027
31028
31029
31030
31031
31032
31033
31034
31035
31036
# File 'lib/aws-sdk-quicksight/types.rb', line 31024

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end