Class: Aws::QuickSight::Types::PivotTableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The configuration for a ‘PivotTableVisual`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_customization_visual_optionsTypes::DashboardCustomizationVisualOptions

The options that define customizations available to dashboard readers for a specific visual



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_optionsTypes::PivotTableFieldOptions

The field options for a pivot table visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#field_wellsTypes::PivotTableFieldWells

The field wells of the visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#interactionsTypes::VisualInteractionOptions

The general visual interactions setup for a visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#paginated_report_optionsTypes::PivotTablePaginatedReportOptions

The paginated report options for a pivot table visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#sort_configurationTypes::PivotTableSortConfiguration

The sort configuration for a ‘PivotTableVisual`.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#table_optionsTypes::PivotTableOptions

The table options for a pivot table visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#tooltipTypes::TooltipOptions

The display options for the visual tooltip.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end

#total_optionsTypes::PivotTableTotalOptions

The total options for a pivot table visual.



30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
# File 'lib/aws-sdk-quicksight/types.rb', line 30504

class PivotTableConfiguration < Struct.new(
  :field_wells,
  :sort_configuration,
  :table_options,
  :total_options,
  :field_options,
  :paginated_report_options,
  :tooltip,
  :dashboard_customization_visual_options,
  :interactions)
  SENSITIVE = []
  include Aws::Structure
end