Class: Aws::QuickSight::Types::PivotTableOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PivotTableOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The table options for a pivot table visual.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cell_style ⇒ Types::TableCellStyle
The table cell style of cells.
-
#collapsed_row_dimensions_visibility ⇒ String
The visibility setting of a pivot table's collapsed row dimension fields.
-
#column_header_style ⇒ Types::TableCellStyle
The table cell style of the column header.
-
#column_names_visibility ⇒ String
The visibility of the column names.
-
#default_cell_width ⇒ String
The default cell width of the pivot table.
-
#metric_placement ⇒ String
The metric placement (row, column) options.
-
#row_alternate_color_options ⇒ Types::RowAlternateColorOptions
The row alternate color options (widget status, row alternate colors).
-
#row_field_names_style ⇒ Types::TableCellStyle
The table cell style of row field names.
-
#row_header_style ⇒ Types::TableCellStyle
The table cell style of the row headers.
-
#rows_label_options ⇒ Types::PivotTableRowsLabelOptions
The options for the label that is located above the row headers.
-
#rows_layout ⇒ String
The layout for the row dimension headers of a pivot table.
-
#single_metric_visibility ⇒ String
The visibility of the single metric options.
-
#toggle_buttons_visibility ⇒ String
Determines the visibility of the pivot table.
Instance Attribute Details
#cell_style ⇒ Types::TableCellStyle
The table cell style of cells.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#collapsed_row_dimensions_visibility ⇒ String
The visibility setting of a pivot table's collapsed row dimension
fields. If the value of this structure is HIDDEN, all collapsed
columns in a pivot table are automatically hidden. The default value
is VISIBLE.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#column_header_style ⇒ Types::TableCellStyle
The table cell style of the column header.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#column_names_visibility ⇒ String
The visibility of the column names.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#default_cell_width ⇒ String
The default cell width of the pivot table.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#metric_placement ⇒ String
The metric placement (row, column) options.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#row_alternate_color_options ⇒ Types::RowAlternateColorOptions
The row alternate color options (widget status, row alternate colors).
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#row_field_names_style ⇒ Types::TableCellStyle
The table cell style of row field names.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#row_header_style ⇒ Types::TableCellStyle
The table cell style of the row headers.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#rows_label_options ⇒ Types::PivotTableRowsLabelOptions
The options for the label that is located above the row headers.
This option is only applicable when RowsLayout is set to
HIERARCHY.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#rows_layout ⇒ String
The layout for the row dimension headers of a pivot table. Choose one of the following options.
-
TABULAR: (Default) Each row field is displayed in a separate column. -
HIERARCHY: All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#single_metric_visibility ⇒ String
The visibility of the single metric options.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |
#toggle_buttons_visibility ⇒ String
Determines the visibility of the pivot table.
33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 33448 33449 33450 33451 33452 33453 33454 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33438 class PivotTableOptions < Struct.new( :metric_placement, :single_metric_visibility, :column_names_visibility, :toggle_buttons_visibility, :column_header_style, :row_header_style, :cell_style, :row_field_names_style, :row_alternate_color_options, :collapsed_row_dimensions_visibility, :rows_layout, :rows_label_options, :default_cell_width) SENSITIVE = [] include Aws::Structure end |