Class: Aws::QuickSight::Types::PivotTableOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The table options for a pivot table visual.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cell_styleTypes::TableCellStyle

The table cell style of cells.



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#collapsed_row_dimensions_visibilityString

The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is HIDDEN, all collapsed columns in a pivot table are automatically hidden. The default value is VISIBLE.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#column_header_styleTypes::TableCellStyle

The table cell style of the column header.



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#column_names_visibilityString

The visibility of the column names.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#default_cell_widthString

The default cell width of the pivot table.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#metric_placementString

The metric placement (row, column) options.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#row_alternate_color_optionsTypes::RowAlternateColorOptions

The row alternate color options (widget status, row alternate colors).



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#row_field_names_styleTypes::TableCellStyle

The table cell style of row field names.



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#row_header_styleTypes::TableCellStyle

The table cell style of the row headers.



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#rows_label_optionsTypes::PivotTableRowsLabelOptions

The options for the label that is located above the row headers. This option is only applicable when RowsLayout is set to HIERARCHY.



33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#rows_layoutString

The layout for the row dimension headers of a pivot table. Choose one of the following options.

  • TABULAR: (Default) Each row field is displayed in a separate column.

  • HIERARCHY: All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#single_metric_visibilityString

The visibility of the single metric options.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end

#toggle_buttons_visibilityString

Determines the visibility of the pivot table.

Returns:

  • (String)


33375
33376
33377
33378
33379
33380
33381
33382
33383
33384
33385
33386
33387
33388
33389
33390
33391
# File 'lib/aws-sdk-quicksight/types.rb', line 33375

class PivotTableOptions < Struct.new(
  :metric_placement,
  :single_metric_visibility,
  :column_names_visibility,
  :toggle_buttons_visibility,
  :column_header_style,
  :row_header_style,
  :cell_style,
  :row_field_names_style,
  :row_alternate_color_options,
  :collapsed_row_dimensions_visibility,
  :rows_layout,
  :rows_label_options,
  :default_cell_width)
  SENSITIVE = []
  include Aws::Structure
end