Class: Aws::QuickSight::Types::PluginVisual

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A flexible visualization type that allows engineers to create new custom charts in Quick Sight.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::VisualCustomAction>

The list of custom actions that are configured for a visual.

Returns:



30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#chart_configurationTypes::PluginVisualConfiguration

A description of the plugin field wells and their persisted properties.



30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#plugin_arnString

The Amazon Resource Name (ARN) that reflects the plugin and version.

Returns:

  • (String)


30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#subtitleTypes::VisualSubtitleLabelOptions

The subtitle label options for a visual.



30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#titleTypes::VisualTitleLabelOptions

The title label options for a visual.



30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_content_alt_textString

The alt text for the visual.

Returns:

  • (String)


30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end

#visual_idString

The ID of the visual that you want to use.

Returns:

  • (String)


30871
30872
30873
30874
30875
30876
30877
30878
30879
30880
30881
# File 'lib/aws-sdk-quicksight/types.rb', line 30871

class PluginVisual < Struct.new(
  :visual_id,
  :plugin_arn,
  :title,
  :subtitle,
  :chart_configuration,
  :actions,
  :visual_content_alt_text)
  SENSITIVE = []
  include Aws::Structure
end