Class: Aws::QuickSight::Types::PredefinedHierarchy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#columnsArray<Types::ColumnIdentifier>

The list of columns that define the predefined hierarchy.

Returns:



31078
31079
31080
31081
31082
31083
31084
# File 'lib/aws-sdk-quicksight/types.rb', line 31078

class PredefinedHierarchy < Struct.new(
  :hierarchy_id,
  :columns,
  :drill_down_filters)
  SENSITIVE = []
  include Aws::Structure
end

#drill_down_filtersArray<Types::DrillDownFilter>

The option that determines the drill down filters for the predefined hierarchy.

Returns:



31078
31079
31080
31081
31082
31083
31084
# File 'lib/aws-sdk-quicksight/types.rb', line 31078

class PredefinedHierarchy < Struct.new(
  :hierarchy_id,
  :columns,
  :drill_down_filters)
  SENSITIVE = []
  include Aws::Structure
end

#hierarchy_idString

The hierarchy ID of the predefined hierarchy.

Returns:

  • (String)


31078
31079
31080
31081
31082
31083
31084
# File 'lib/aws-sdk-quicksight/types.rb', line 31078

class PredefinedHierarchy < Struct.new(
  :hierarchy_id,
  :columns,
  :drill_down_filters)
  SENSITIVE = []
  include Aws::Structure
end