Class: Aws::QuickSight::Types::PredefinedHierarchy
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::PredefinedHierarchy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#columns ⇒ Array<Types::ColumnIdentifier>
The list of columns that define the predefined hierarchy.
-
#drill_down_filters ⇒ Array<Types::DrillDownFilter>
The option that determines the drill down filters for the predefined hierarchy.
-
#hierarchy_id ⇒ String
The hierarchy ID of the predefined hierarchy.
Instance Attribute Details
#columns ⇒ Array<Types::ColumnIdentifier>
The list of columns that define the predefined hierarchy.
31078 31079 31080 31081 31082 31083 31084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31078 class PredefinedHierarchy < Struct.new( :hierarchy_id, :columns, :drill_down_filters) SENSITIVE = [] include Aws::Structure end |
#drill_down_filters ⇒ Array<Types::DrillDownFilter>
The option that determines the drill down filters for the predefined hierarchy.
31078 31079 31080 31081 31082 31083 31084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31078 class PredefinedHierarchy < Struct.new( :hierarchy_id, :columns, :drill_down_filters) SENSITIVE = [] include Aws::Structure end |
#hierarchy_id ⇒ String
The hierarchy ID of the predefined hierarchy.
31078 31079 31080 31081 31082 31083 31084 |
# File 'lib/aws-sdk-quicksight/types.rb', line 31078 class PredefinedHierarchy < Struct.new( :hierarchy_id, :columns, :drill_down_filters) SENSITIVE = [] include Aws::Structure end |