Class: Aws::QuickSight::Types::RecentSnapshotsConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The recent snapshots configuration for an embedded Quick Sight dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

The recent snapshots configuration for an embedded Quick Sight dashboard.

Returns:

  • (Boolean)


32282
32283
32284
32285
32286
# File 'lib/aws-sdk-quicksight/types.rb', line 32282

class RecentSnapshotsConfigurations < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end