Class: Aws::QuickSight::Types::RedshiftIAMParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::RedshiftIAMParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that grants Quick Sight access to your cluster and make a call to the ‘redshift:GetClusterCredentials` API. For more information on the `redshift:GetClusterCredentials` API, see [ `GetClusterCredentials` ][1].
[1]: docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_create_database_user ⇒ Boolean
Automatically creates a database user.
-
#database_groups ⇒ Array<String>
A list of groups whose permissions will be granted to Quick Sight to access the cluster.
-
#database_user ⇒ String
The user whose permissions and group memberships will be used by Quick Sight to access the cluster.
-
#role_arn ⇒ String
Use the ‘RoleArn` structure to allow Quick Sight to call `redshift:GetClusterCredentials` on your cluster.
Instance Attribute Details
#auto_create_database_user ⇒ Boolean
Automatically creates a database user. If your database doesn’t have a ‘DatabaseUser`, set this parameter to `True`. If there is no `DatabaseUser`, Quick Sight can’t connect to your cluster. The ‘RoleArn` that you use for this operation must grant access to `redshift:CreateClusterUser` to successfully create the user.
30827 30828 30829 30830 30831 30832 30833 30834 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30827 class RedshiftIAMParameters < Struct.new( :role_arn, :database_user, :database_groups, :auto_create_database_user) SENSITIVE = [] include Aws::Structure end |
#database_groups ⇒ Array<String>
A list of groups whose permissions will be granted to Quick Sight to access the cluster. These permissions are combined with the permissions granted to Quick Sight by the ‘DatabaseUser`. If you choose to include this parameter, the `RoleArn` must grant access to `redshift:JoinGroup`.
30827 30828 30829 30830 30831 30832 30833 30834 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30827 class RedshiftIAMParameters < Struct.new( :role_arn, :database_user, :database_groups, :auto_create_database_user) SENSITIVE = [] include Aws::Structure end |
#database_user ⇒ String
The user whose permissions and group memberships will be used by Quick Sight to access the cluster. If this user already exists in your database, Amazon Quick Sight is granted the same permissions that the user has. If the user doesn’t exist, set the value of ‘AutoCreateDatabaseUser` to `True` to create a new user with PUBLIC permissions.
30827 30828 30829 30830 30831 30832 30833 30834 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30827 class RedshiftIAMParameters < Struct.new( :role_arn, :database_user, :database_groups, :auto_create_database_user) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
Use the ‘RoleArn` structure to allow Quick Sight to call `redshift:GetClusterCredentials` on your cluster. The calling principal must have `iam:PassRole` access to pass the role to Quick Sight. The role’s trust policy must allow the Quick Sight service principal to assume the role.
30827 30828 30829 30830 30831 30832 30833 30834 |
# File 'lib/aws-sdk-quicksight/types.rb', line 30827 class RedshiftIAMParameters < Struct.new( :role_arn, :database_user, :database_groups, :auto_create_database_user) SENSITIVE = [] include Aws::Structure end |