Class: Aws::QuickSight::Types::RefreshFrequency

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies the interval between each scheduled refresh of a dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#intervalString

The interval between scheduled refreshes. Valid values are as follows:

  • ‘MINUTE15`: The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.

  • ‘MINUTE30`:The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.

  • ‘HOURLY`: The dataset refreshes every hour. This interval can only be used for one schedule per dataset.

  • ‘DAILY`: The dataset refreshes every day.

  • ‘WEEKLY`: The dataset refreshes every week.

  • ‘MONTHLY`: The dataset refreshes every month.

Returns:

  • (String)


31202
31203
31204
31205
31206
31207
31208
31209
# File 'lib/aws-sdk-quicksight/types.rb', line 31202

class RefreshFrequency < Struct.new(
  :interval,
  :refresh_on_day,
  :timezone,
  :time_of_the_day)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_on_dayTypes::ScheduleRefreshOnEntity

The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.



31202
31203
31204
31205
31206
31207
31208
31209
# File 'lib/aws-sdk-quicksight/types.rb', line 31202

class RefreshFrequency < Struct.new(
  :interval,
  :refresh_on_day,
  :timezone,
  :time_of_the_day)
  SENSITIVE = []
  include Aws::Structure
end

#time_of_the_dayString

The time of day that you want the datset to refresh. This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.

Returns:

  • (String)


31202
31203
31204
31205
31206
31207
31208
31209
# File 'lib/aws-sdk-quicksight/types.rb', line 31202

class RefreshFrequency < Struct.new(
  :interval,
  :refresh_on_day,
  :timezone,
  :time_of_the_day)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The timezone that you want the refresh schedule to use. The timezone ID must match a corresponding ID found on ‘java.util.time.getAvailableIDs()`.

Returns:

  • (String)


31202
31203
31204
31205
31206
31207
31208
31209
# File 'lib/aws-sdk-quicksight/types.rb', line 31202

class RefreshFrequency < Struct.new(
  :interval,
  :refresh_on_day,
  :timezone,
  :time_of_the_day)
  SENSITIVE = []
  include Aws::Structure
end