Class: Aws::QuickSight::Types::SchedulesConfigurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SchedulesConfigurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The schedules configuration for an embedded Quick Sight dashboard.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
The schedules configuration for an embedded Quick Sight dashboard.
Instance Attribute Details
#enabled ⇒ Boolean
The schedules configuration for an embedded Quick Sight dashboard.
32975 32976 32977 32978 32979 |
# File 'lib/aws-sdk-quicksight/types.rb', line 32975 class SchedulesConfigurations < Struct.new( :enabled) SENSITIVE = [] include Aws::Structure end |