Class: Aws::QuickSight::Types::SearchActionConnectorsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchActionConnectorsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_connector_summaries ⇒ Array<Types::ActionConnectorSummary>
A list of action connector summaries that match the search criteria.
-
#next_token ⇒ String
A pagination token to retrieve the next set of results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status code of the request.
Instance Attribute Details
#action_connector_summaries ⇒ Array<Types::ActionConnectorSummary>
A list of action connector summaries that match the search criteria.
34279 34280 34281 34282 34283 34284 34285 34286 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34279 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to retrieve the next set of results. If null, there are no more results to retrieve.
34279 34280 34281 34282 34283 34284 34285 34286 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34279 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
34279 34280 34281 34282 34283 34284 34285 34286 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34279 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status code of the request.
34279 34280 34281 34282 34283 34284 34285 34286 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34279 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |