Class: Aws::QuickSight::Types::SearchActionConnectorsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchActionConnectorsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_connector_summaries ⇒ Array<Types::ActionConnectorSummary>
A list of action connector summaries that match the search criteria.
-
#next_token ⇒ String
A pagination token to retrieve the next set of results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status code of the request.
Instance Attribute Details
#action_connector_summaries ⇒ Array<Types::ActionConnectorSummary>
A list of action connector summaries that match the search criteria.
33050 33051 33052 33053 33054 33055 33056 33057 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33050 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to retrieve the next set of results. If null, there are no more results to retrieve.
33050 33051 33052 33053 33054 33055 33056 33057 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33050 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
33050 33051 33052 33053 33054 33055 33056 33057 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33050 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status code of the request.
33050 33051 33052 33053 33054 33055 33056 33057 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33050 class SearchActionConnectorsResponse < Struct.new( :next_token, :request_id, :status, :action_connector_summaries) SENSITIVE = [] include Aws::Structure end |