Class: Aws::QuickSight::Types::SearchAppsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchAppsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_summary_list ⇒ Array<Types::AppSummary>
A list of app summaries that match the search criteria.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
Instance Attribute Details
#app_summary_list ⇒ Array<Types::AppSummary>
A list of app summaries that match the search criteria.
39878 39879 39880 39881 39882 39883 39884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39878 class SearchAppsResponse < Struct.new( :app_summary_list, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
39878 39879 39880 39881 39882 39883 39884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39878 class SearchAppsResponse < Struct.new( :app_summary_list, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
39878 39879 39880 39881 39882 39883 39884 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39878 class SearchAppsResponse < Struct.new( :app_summary_list, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |