Class: Aws::QuickSight::Types::SearchFlowsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where you are searching for flows from.

Returns:

  • (String)


33359
33360
33361
33362
33363
33364
33365
33366
# File 'lib/aws-sdk-quicksight/types.rb', line 33359

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::SearchFlowsFilter>

The filters applied to the search when searching for flows in the Amazon Web Services account.

Returns:



33359
33360
33361
33362
33363
33364
33365
33366
# File 'lib/aws-sdk-quicksight/types.rb', line 33359

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned per request.

Returns:

  • (Integer)


33359
33360
33361
33362
33363
33364
33365
33366
# File 'lib/aws-sdk-quicksight/types.rb', line 33359

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to request the next set of results, or null if you want to retrieve the first set.

Returns:

  • (String)


33359
33360
33361
33362
33363
33364
33365
33366
# File 'lib/aws-sdk-quicksight/types.rb', line 33359

class SearchFlowsInput < Struct.new(
  :aws_account_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end