Class: Aws::QuickSight::Types::SearchFlowsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchFlowsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_summary_list ⇒ Array<Types::FlowSummary>
The list of flows found against the search.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#flow_summary_list ⇒ Array<Types::FlowSummary>
The list of flows found against the search.
34616 34617 34618 34619 34620 34621 34622 34623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34616 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
34616 34617 34618 34619 34620 34621 34622 34623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34616 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
34616 34617 34618 34619 34620 34621 34622 34623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34616 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
34616 34617 34618 34619 34620 34621 34622 34623 |
# File 'lib/aws-sdk-quicksight/types.rb', line 34616 class SearchFlowsOutput < Struct.new( :flow_summary_list, :next_token, :request_id, :status) SENSITIVE = [] include Aws::Structure end |