Class: Aws::QuickSight::Types::SearchGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


33482
33483
33484
33485
33486
33487
33488
33489
33490
# File 'lib/aws-sdk-quicksight/types.rb', line 33482

class SearchGroupsRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :namespace,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::GroupSearchFilter>

The structure for the search filters that you want to apply to your search.

Returns:



33482
33483
33484
33485
33486
33487
33488
33489
33490
# File 'lib/aws-sdk-quicksight/types.rb', line 33482

class SearchGroupsRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :namespace,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return from this request.

Returns:

  • (Integer)


33482
33483
33484
33485
33486
33487
33488
33489
33490
# File 'lib/aws-sdk-quicksight/types.rb', line 33482

class SearchGroupsRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :namespace,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace that you want to search.

Returns:

  • (String)


33482
33483
33484
33485
33486
33487
33488
33489
33490
# File 'lib/aws-sdk-quicksight/types.rb', line 33482

class SearchGroupsRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :namespace,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token that can be used in a subsequent request.

Returns:

  • (String)


33482
33483
33484
33485
33486
33487
33488
33489
33490
# File 'lib/aws-sdk-quicksight/types.rb', line 33482

class SearchGroupsRequest < Struct.new(
  :aws_account_id,
  :next_token,
  :max_results,
  :namespace,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end