Class: Aws::QuickSight::Types::SearchGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#filters ⇒ Array<Types::GroupSearchFilter>
The structure for the search filters that you want to apply to your search.
-
#max_results ⇒ Integer
The maximum number of results to return from this request.
-
#namespace ⇒ String
The namespace that you want to search.
-
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
33482 33483 33484 33485 33486 33487 33488 33489 33490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33482 class SearchGroupsRequest < Struct.new( :aws_account_id, :next_token, :max_results, :namespace, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::GroupSearchFilter>
The structure for the search filters that you want to apply to your search.
33482 33483 33484 33485 33486 33487 33488 33489 33490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33482 class SearchGroupsRequest < Struct.new( :aws_account_id, :next_token, :max_results, :namespace, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return from this request.
33482 33483 33484 33485 33486 33487 33488 33489 33490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33482 class SearchGroupsRequest < Struct.new( :aws_account_id, :next_token, :max_results, :namespace, :filters) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that you want to search.
33482 33483 33484 33485 33486 33487 33488 33489 33490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33482 class SearchGroupsRequest < Struct.new( :aws_account_id, :next_token, :max_results, :namespace, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token that can be used in a subsequent request.
33482 33483 33484 33485 33486 33487 33488 33489 33490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33482 class SearchGroupsRequest < Struct.new( :aws_account_id, :next_token, :max_results, :namespace, :filters) SENSITIVE = [] include Aws::Structure end |