Class: Aws::QuickSight::Types::SearchSpacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchSpacesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the spaces.
-
#filters ⇒ Array<Types::SpaceQuicksightSearchFilter>
The filters to apply to the search.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the spaces.
36608 36609 36610 36611 36612 36613 36614 36615 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36608 class SearchSpacesRequest < Struct.new( :aws_account_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::SpaceQuicksightSearchFilter>
The filters to apply to the search.
36608 36609 36610 36611 36612 36613 36614 36615 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36608 class SearchSpacesRequest < Struct.new( :aws_account_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
36608 36609 36610 36611 36612 36613 36614 36615 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36608 class SearchSpacesRequest < Struct.new( :aws_account_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
36608 36609 36610 36611 36612 36613 36614 36615 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36608 class SearchSpacesRequest < Struct.new( :aws_account_id, :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |