Class: Aws::QuickSight::Types::SearchSpacesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of results, or null if there are no more results.

Returns:

  • (String)


37407
37408
37409
37410
37411
37412
37413
37414
37415
# File 'lib/aws-sdk-quicksight/types.rb', line 37407

class SearchSpacesResponse < Struct.new(
  :space_id,
  :space_arn,
  :space_summaries,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


37407
37408
37409
37410
37411
37412
37413
37414
37415
# File 'lib/aws-sdk-quicksight/types.rb', line 37407

class SearchSpacesResponse < Struct.new(
  :space_id,
  :space_arn,
  :space_summaries,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#space_arnString

The ARN of the space.

Returns:

  • (String)


37407
37408
37409
37410
37411
37412
37413
37414
37415
# File 'lib/aws-sdk-quicksight/types.rb', line 37407

class SearchSpacesResponse < Struct.new(
  :space_id,
  :space_arn,
  :space_summaries,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#space_idString

The ID of the space.

Returns:

  • (String)


37407
37408
37409
37410
37411
37412
37413
37414
37415
# File 'lib/aws-sdk-quicksight/types.rb', line 37407

class SearchSpacesResponse < Struct.new(
  :space_id,
  :space_arn,
  :space_summaries,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#space_summariesArray<Types::SpaceSummary>

A list of space summaries that match the search criteria.

Returns:



37407
37408
37409
37410
37411
37412
37413
37414
37415
# File 'lib/aws-sdk-quicksight/types.rb', line 37407

class SearchSpacesResponse < Struct.new(
  :space_id,
  :space_arn,
  :space_summaries,
  :next_token,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end