Class: Aws::QuickSight::Types::SearchSpacesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchSpacesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#space_arn ⇒ String
The ARN of the space.
-
#space_id ⇒ String
The ID of the space.
-
#space_summaries ⇒ Array<Types::SpaceSummary>
A list of space summaries that match the search criteria.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
36640 36641 36642 36643 36644 36645 36646 36647 36648 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36640 class SearchSpacesResponse < Struct.new( :space_id, :space_arn, :space_summaries, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
36640 36641 36642 36643 36644 36645 36646 36647 36648 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36640 class SearchSpacesResponse < Struct.new( :space_id, :space_arn, :space_summaries, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#space_arn ⇒ String
The ARN of the space.
36640 36641 36642 36643 36644 36645 36646 36647 36648 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36640 class SearchSpacesResponse < Struct.new( :space_id, :space_arn, :space_summaries, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space.
36640 36641 36642 36643 36644 36645 36646 36647 36648 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36640 class SearchSpacesResponse < Struct.new( :space_id, :space_arn, :space_summaries, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |
#space_summaries ⇒ Array<Types::SpaceSummary>
A list of space summaries that match the search criteria.
36640 36641 36642 36643 36644 36645 36646 36647 36648 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36640 class SearchSpacesResponse < Struct.new( :space_id, :space_arn, :space_summaries, :next_token, :request_id) SENSITIVE = [] include Aws::Structure end |