Class: Aws::QuickSight::Types::SearchTopicsV2Response
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SearchTopicsV2Response
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_summary_list ⇒ Array<Types::TopicV2Summary>
A list of topic summaries that is returned by the search topic request.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of results, or null if there are no more results.
38953 38954 38955 38956 38957 38958 38959 38960 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38953 class SearchTopicsV2Response < Struct.new( :topic_summary_list, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
38953 38954 38955 38956 38957 38958 38959 38960 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38953 class SearchTopicsV2Response < Struct.new( :topic_summary_list, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
38953 38954 38955 38956 38957 38958 38959 38960 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38953 class SearchTopicsV2Response < Struct.new( :topic_summary_list, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_summary_list ⇒ Array<Types::TopicV2Summary>
A list of topic summaries that is returned by the search topic request.
38953 38954 38955 38956 38957 38958 38959 38960 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38953 class SearchTopicsV2Response < Struct.new( :topic_summary_list, :next_token, :status, :request_id) SENSITIVE = [] include Aws::Structure end |