Class: Aws::QuickSight::Types::SemanticModelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SemanticModelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Configuration for the semantic model that defines how prepared data is structured for analysis and reporting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#semantic_metadata ⇒ Array<Types::DataSetSemanticMetadata>
The dataset-level semantic metadata, including a description and custom instructions.
-
#table_map ⇒ Hash<String,Types::SemanticTable>
A map of semantic tables that define the analytical structure.
Instance Attribute Details
#semantic_metadata ⇒ Array<Types::DataSetSemanticMetadata>
The dataset-level semantic metadata, including a description and custom instructions.
35420 35421 35422 35423 35424 35425 |
# File 'lib/aws-sdk-quicksight/types.rb', line 35420 class SemanticModelConfiguration < Struct.new( :table_map, :semantic_metadata) SENSITIVE = [] include Aws::Structure end |
#table_map ⇒ Hash<String,Types::SemanticTable>
A map of semantic tables that define the analytical structure.
35420 35421 35422 35423 35424 35425 |
# File 'lib/aws-sdk-quicksight/types.rb', line 35420 class SemanticModelConfiguration < Struct.new( :table_map, :semantic_metadata) SENSITIVE = [] include Aws::Structure end |