Class: Aws::QuickSight::Types::SemanticModelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SemanticModelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Configuration for the semantic model that defines how prepared data is structured for analysis and reporting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#table_map ⇒ Hash<String,Types::SemanticTable>
A map of semantic tables that define the analytical structure.
Instance Attribute Details
#table_map ⇒ Hash<String,Types::SemanticTable>
A map of semantic tables that define the analytical structure.
35113 35114 35115 35116 35117 |
# File 'lib/aws-sdk-quicksight/types.rb', line 35113 class SemanticModelConfiguration < Struct.new( :table_map) SENSITIVE = [] include Aws::Structure end |