Class: Aws::QuickSight::Types::SemanticModelConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Configuration for the semantic model that defines how prepared data is structured for analysis and reporting.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#table_mapHash<String,Types::SemanticTable>

A map of semantic tables that define the analytical structure.

Returns:



33862
33863
33864
33865
33866
# File 'lib/aws-sdk-quicksight/types.rb', line 33862

class SemanticModelConfiguration < Struct.new(
  :table_map)
  SENSITIVE = []
  include Aws::Structure
end