Class: Aws::QuickSight::Types::SemanticTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SemanticTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A semantic table that represents the final analytical structure of the data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for the semantic table.
-
#destination_table_id ⇒ String
The identifier of the destination table from data preparation that provides data to this semantic table.
-
#row_level_permission_configuration ⇒ Types::RowLevelPermissionConfiguration
Configuration for row level security that control data access for this semantic table.
Instance Attribute Details
#alias ⇒ String
Alias for the semantic table.
33887 33888 33889 33890 33891 33892 33893 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33887 class SemanticTable < Struct.new( :alias, :destination_table_id, :row_level_permission_configuration) SENSITIVE = [] include Aws::Structure end |
#destination_table_id ⇒ String
The identifier of the destination table from data preparation that provides data to this semantic table.
33887 33888 33889 33890 33891 33892 33893 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33887 class SemanticTable < Struct.new( :alias, :destination_table_id, :row_level_permission_configuration) SENSITIVE = [] include Aws::Structure end |
#row_level_permission_configuration ⇒ Types::RowLevelPermissionConfiguration
Configuration for row level security that control data access for this semantic table.
33887 33888 33889 33890 33891 33892 33893 |
# File 'lib/aws-sdk-quicksight/types.rb', line 33887 class SemanticTable < Struct.new( :alias, :destination_table_id, :row_level_permission_configuration) SENSITIVE = [] include Aws::Structure end |