Class: Aws::QuickSight::Types::Sheet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A sheet, which is an object that contains a set of visuals that are viewed together on one page in Quick Sight. Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#imagesArray<Types::SheetImage>

A list of images on a sheet.

Returns:



35338
35339
35340
35341
35342
35343
35344
# File 'lib/aws-sdk-quicksight/types.rb', line 35338

class Sheet < Struct.new(
  :sheet_id,
  :name,
  :images)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a sheet. This name is displayed on the sheet’s tab in the Quick Sight console.

Returns:

  • (String)


35338
35339
35340
35341
35342
35343
35344
# File 'lib/aws-sdk-quicksight/types.rb', line 35338

class Sheet < Struct.new(
  :sheet_id,
  :name,
  :images)
  SENSITIVE = []
  include Aws::Structure
end

#sheet_idString

The unique identifier associated with a sheet.

Returns:

  • (String)


35338
35339
35340
35341
35342
35343
35344
# File 'lib/aws-sdk-quicksight/types.rb', line 35338

class Sheet < Struct.new(
  :sheet_id,
  :name,
  :images)
  SENSITIVE = []
  include Aws::Structure
end