Class: Aws::QuickSight::Types::SnapshotJobS3Result
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SnapshotJobS3Result
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The Amazon S3 result from the snapshot job. The result includes the
DestinationConfiguration and the Amazon S3 Uri. If an error occured
during the job, the result returns information on the error.
Constant Summary collapse
- SENSITIVE =
[:s3_uri]
Instance Attribute Summary collapse
-
#error_info ⇒ Array<Types::SnapshotJobResultErrorInfo>
An array of error records that describe any failures that occur while the dashboard snapshot job runs.
-
#s3_destination_configuration ⇒ Types::SnapshotS3DestinationConfiguration
A list of Amazon S3 bucket configurations that are provided when you make a
StartDashboardSnapshotJobAPI call. -
#s3_uri ⇒ String
The Amazon S3 Uri.
Instance Attribute Details
#error_info ⇒ Array<Types::SnapshotJobResultErrorInfo>
An array of error records that describe any failures that occur while the dashboard snapshot job runs.
39418 39419 39420 39421 39422 39423 39424 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39418 class SnapshotJobS3Result < Struct.new( :s3_destination_configuration, :s3_uri, :error_info) SENSITIVE = [:s3_uri] include Aws::Structure end |
#s3_destination_configuration ⇒ Types::SnapshotS3DestinationConfiguration
A list of Amazon S3 bucket configurations that are provided when you
make a StartDashboardSnapshotJob API call.
39418 39419 39420 39421 39422 39423 39424 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39418 class SnapshotJobS3Result < Struct.new( :s3_destination_configuration, :s3_uri, :error_info) SENSITIVE = [:s3_uri] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 Uri.
39418 39419 39420 39421 39422 39423 39424 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39418 class SnapshotJobS3Result < Struct.new( :s3_destination_configuration, :s3_uri, :error_info) SENSITIVE = [:s3_uri] include Aws::Structure end |