Class: Aws::QuickSight::Types::SourceTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A source table that provides initial data from either a physical table or parent dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_setTypes::ParentDataSet

A parent dataset that serves as the data source instead of a physical table.



35132
35133
35134
35135
35136
35137
# File 'lib/aws-sdk-quicksight/types.rb', line 35132

class SourceTable < Struct.new(
  :physical_table_id,
  :data_set)
  SENSITIVE = []
  include Aws::Structure
end

#physical_table_idString

The identifier of the physical table that serves as the data source.

Returns:

  • (String)


35132
35133
35134
35135
35136
35137
# File 'lib/aws-sdk-quicksight/types.rb', line 35132

class SourceTable < Struct.new(
  :physical_table_id,
  :data_set)
  SENSITIVE = []
  include Aws::Structure
end