Class: Aws::QuickSight::Types::SpaceContributor
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SpaceContributor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A contributor to an Amazon QuickSight space.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#percentage ⇒ Float
The percentage of total contributions made by the user.
-
#raw_file_size_bytes ⇒ Integer
The raw file size in bytes contributed by the user.
-
#user_name ⇒ String
The user name of the contributor.
Instance Attribute Details
#percentage ⇒ Float
The percentage of total contributions made by the user.
39156 39157 39158 39159 39160 39161 39162 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39156 class SpaceContributor < Struct.new( :user_name, :raw_file_size_bytes, :percentage) SENSITIVE = [] include Aws::Structure end |
#raw_file_size_bytes ⇒ Integer
The raw file size in bytes contributed by the user.
39156 39157 39158 39159 39160 39161 39162 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39156 class SpaceContributor < Struct.new( :user_name, :raw_file_size_bytes, :percentage) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The user name of the contributor.
39156 39157 39158 39159 39160 39161 39162 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39156 class SpaceContributor < Struct.new( :user_name, :raw_file_size_bytes, :percentage) SENSITIVE = [] include Aws::Structure end |