Class: Aws::QuickSight::Types::SpaceQuickSightResourceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SpaceQuickSightResourceDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
SpaceQuickSightResourceDetails is a union - when making an API calls you must set exactly one of the members.
Note:
SpaceQuickSightResourceDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SpaceQuickSightResourceDetails corresponding to the set member.
The details of a QuickSight resource in a space.
Direct Known Subclasses
Defined Under Namespace
Classes: ResourceArn, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the QuickSight resource.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the QuickSight resource.
39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39249 class SpaceQuickSightResourceDetails < Struct.new( :resource_arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ResourceArn < SpaceQuickSightResourceDetails; end class Unknown < SpaceQuickSightResourceDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
39249 39250 39251 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39249 def unknown @unknown end |