Class: Aws::QuickSight::Types::SparklinesOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::SparklinesOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options for sparklines in a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_points_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
-
#field_id ⇒ String
The field ID of the value column that the sparkline is applied to.
-
#line_color ⇒ String
The color of the sparkline line.
-
#line_interpolation ⇒ String
The interpolation style for the sparkline line.
-
#max_value_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
-
#min_value_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
-
#visual_type ⇒ String
The type of the sparkline.
-
#x_axis_field ⇒ Types::DimensionField
The dimension type field.
-
#y_axis_behavior ⇒ String
Determines whether the Y axis is shared across all sparklines or independent for each sparkline.
Instance Attribute Details
#all_points_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#field_id ⇒ String
The field ID of the value column that the sparkline is applied to.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#line_color ⇒ String
The color of the sparkline line.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#line_interpolation ⇒ String
The interpolation style for the sparkline line.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#max_value_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#min_value_marker ⇒ Types::LineChartMarkerStyleSettings
Marker styles options for a line series in ‘LineChartVisual`.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#visual_type ⇒ String
The type of the sparkline. Valid values are ‘LINE` and `AREA_LINE`.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#x_axis_field ⇒ Types::DimensionField
The dimension type field.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |
#y_axis_behavior ⇒ String
Determines whether the Y axis is shared across all sparklines or independent for each sparkline.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 |
# File 'lib/aws-sdk-quicksight/types.rb', line 36531 class SparklinesOptions < Struct.new( :field_id, :x_axis_field, :y_axis_behavior, :visual_type, :line_color, :line_interpolation, :all_points_marker, :max_value_marker, :min_value_marker) SENSITIVE = [] include Aws::Structure end |