Class: Aws::QuickSight::Types::StartAssetBundleExportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::StartAssetBundleExportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_bundle_export_job_id ⇒ String
The ID of the job.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to export assets from.
-
#cloud_formation_override_property_configuration ⇒ Types::AssetBundleCloudFormationOverridePropertyConfiguration
An optional collection of structures that generate CloudFormation parameters to override the existing resource property values when the resource is exported to a new CloudFormation template.
-
#export_format ⇒ String
The export data format.
-
#include_all_dependencies ⇒ Boolean
A Boolean that determines whether all dependencies of each resource ARN are recursively exported with the job.
-
#include_folder_members ⇒ String
A setting that indicates whether you want to include folder assets.
-
#include_folder_memberships ⇒ Boolean
A Boolean that determines if the exported asset carries over information about the folders that the asset is a member of.
-
#include_permissions ⇒ Boolean
A Boolean that determines whether all permissions for each resource ARN are exported with the job.
-
#include_tags ⇒ Boolean
A Boolean that determines whether all tags for each resource ARN are exported with the job.
-
#resource_arns ⇒ Array<String>
An array of resource ARNs to export.
-
#validation_strategy ⇒ Types::AssetBundleExportJobValidationStrategy
An optional parameter that determines which validation strategy to use for the export job.
Instance Attribute Details
#asset_bundle_export_job_id ⇒ String
The ID of the job. This ID is unique while the job is running. After the job is completed, you can reuse this ID for another job.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to export assets from.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#cloud_formation_override_property_configuration ⇒ Types::AssetBundleCloudFormationOverridePropertyConfiguration
An optional collection of structures that generate CloudFormation parameters to override the existing resource property values when the resource is exported to a new CloudFormation template.
Use this field if the ExportFormat field of a
StartAssetBundleExportJobRequest API call is set to
CLOUDFORMATION_JSON.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#export_format ⇒ String
The export data format.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#include_all_dependencies ⇒ Boolean
A Boolean that determines whether all dependencies of each resource
ARN are recursively exported with the job. For example, say you
provided a Dashboard ARN to the ResourceArns parameter. If you set
IncludeAllDependencies to TRUE, any theme, dataset, and data
source resource that is a dependency of the dashboard is also
exported.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#include_folder_members ⇒ String
A setting that indicates whether you want to include folder assets. You can also use this setting to recusrsively include all subfolders of an exported folder.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#include_folder_memberships ⇒ Boolean
A Boolean that determines if the exported asset carries over information about the folders that the asset is a member of.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#include_permissions ⇒ Boolean
A Boolean that determines whether all permissions for each resource
ARN are exported with the job. If you set IncludePermissions to
TRUE, any permissions associated with each resource are exported.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#include_tags ⇒ Boolean
A Boolean that determines whether all tags for each resource ARN are
exported with the job. If you set IncludeTags to TRUE, any tags
associated with each resource are exported.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
An array of resource ARNs to export. The following resources are supported.
-
Analysis -
Dashboard -
DataSet -
DataSource -
RefreshSchedule -
Theme -
VPCConnection
The API caller must have the necessary permissions in their IAM role to access each resource before the resources can be exported.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |
#validation_strategy ⇒ Types::AssetBundleExportJobValidationStrategy
An optional parameter that determines which validation strategy to
use for the export job. If StrictModeForAllResources is set to
TRUE, strict validation for every error is enforced. If it is set
to FALSE, validation is skipped for specific UI errors that are
shown as warnings. The default value for StrictModeForAllResources
is FALSE.
40030 40031 40032 40033 40034 40035 40036 40037 40038 40039 40040 40041 40042 40043 40044 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40030 class StartAssetBundleExportJobRequest < Struct.new( :aws_account_id, :asset_bundle_export_job_id, :resource_arns, :include_all_dependencies, :export_format, :cloud_formation_override_property_configuration, :include_permissions, :include_tags, :validation_strategy, :include_folder_memberships, :include_folder_members) SENSITIVE = [] include Aws::Structure end |