Class: Aws::QuickSight::Types::StartAssetBundleImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::StartAssetBundleImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_bundle_import_job_id ⇒ String
The ID of the job.
-
#asset_bundle_import_source ⇒ Types::AssetBundleImportSource
The source of the asset bundle zip file that contains the data that you want to import.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to import assets into.
-
#failure_action ⇒ String
The failure action for the import job.
-
#override_parameters ⇒ Types::AssetBundleImportJobOverrideParameters
Optional overrides that are applied to the resource configuration before import.
-
#override_permissions ⇒ Types::AssetBundleImportJobOverridePermissions
Optional permission overrides that are applied to the resource configuration before import.
-
#override_tags ⇒ Types::AssetBundleImportJobOverrideTags
Optional tag overrides that are applied to the resource configuration before import.
-
#override_validation_strategy ⇒ Types::AssetBundleImportJobOverrideValidationStrategy
An optional validation strategy override for all analyses and dashboards that is applied to the resource configuration before import.
Instance Attribute Details
#asset_bundle_import_job_id ⇒ String
The ID of the job. This ID is unique while the job is running. After the job is completed, you can reuse this ID for another job.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#asset_bundle_import_source ⇒ Types::AssetBundleImportSource
The source of the asset bundle zip file that contains the data that
you want to import. The file must be in QUICKSIGHT_JSON format.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to import assets into.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#failure_action ⇒ String
The failure action for the import job.
If you choose ROLLBACK, failed import jobs will attempt to undo
any asset changes caused by the failed job.
If you choose DO_NOTHING, failed import jobs will not attempt to
roll back any asset changes caused by the failed job, possibly
keeping the Amazon Quick Sight account in an inconsistent state.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#override_parameters ⇒ Types::AssetBundleImportJobOverrideParameters
Optional overrides that are applied to the resource configuration before import.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#override_permissions ⇒ Types::AssetBundleImportJobOverridePermissions
Optional permission overrides that are applied to the resource configuration before import.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#override_tags ⇒ Types::AssetBundleImportJobOverrideTags
Optional tag overrides that are applied to the resource configuration before import.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |
#override_validation_strategy ⇒ Types::AssetBundleImportJobOverrideValidationStrategy
An optional validation strategy override for all analyses and dashboards that is applied to the resource configuration before import.
39822 39823 39824 39825 39826 39827 39828 39829 39830 39831 39832 39833 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39822 class StartAssetBundleImportJobRequest < Struct.new( :aws_account_id, :asset_bundle_import_job_id, :asset_bundle_import_source, :override_parameters, :failure_action, :override_permissions, :override_tags, :override_validation_strategy) SENSITIVE = [] include Aws::Structure end |