Class: Aws::QuickSight::Types::StartAssetBundleImportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_bundle_import_job_idString

The ID of the job. This ID is unique while the job is running. After the job is completed, you can reuse this ID for another job.

Returns:

  • (String)


39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#asset_bundle_import_sourceTypes::AssetBundleImportSource

The source of the asset bundle zip file that contains the data that you want to import. The file must be in ‘QUICKSIGHT_JSON` format.



39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account to import assets into.

Returns:

  • (String)


39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#failure_actionString

The failure action for the import job.

If you choose ‘ROLLBACK`, failed import jobs will attempt to undo any asset changes caused by the failed job.

If you choose ‘DO_NOTHING`, failed import jobs will not attempt to roll back any asset changes caused by the failed job, possibly keeping the Amazon Quick Sight account in an inconsistent state.

Returns:

  • (String)


39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#override_parametersTypes::AssetBundleImportJobOverrideParameters

Optional overrides that are applied to the resource configuration before import.



39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#override_permissionsTypes::AssetBundleImportJobOverridePermissions

Optional permission overrides that are applied to the resource configuration before import.



39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#override_tagsTypes::AssetBundleImportJobOverrideTags

Optional tag overrides that are applied to the resource configuration before import.



39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#override_validation_strategyTypes::AssetBundleImportJobOverrideValidationStrategy

An optional validation strategy override for all analyses and dashboards that is applied to the resource configuration before import.



39017
39018
39019
39020
39021
39022
39023
39024
39025
39026
39027
39028
# File 'lib/aws-sdk-quicksight/types.rb', line 39017

class StartAssetBundleImportJobRequest < Struct.new(
  :aws_account_id,
  :asset_bundle_import_job_id,
  :asset_bundle_import_source,
  :override_parameters,
  :failure_action,
  :override_permissions,
  :override_tags,
  :override_validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end