Class: Aws::QuickSight::Types::StartAutomationJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:input_payload]

Instance Attribute Summary collapse

Instance Attribute Details

#automation_group_idString

The ID of the automation group that contains the automation to run.

Returns:

  • (String)


36890
36891
36892
36893
36894
36895
36896
36897
# File 'lib/aws-sdk-quicksight/types.rb', line 36890

class StartAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :input_payload)
  SENSITIVE = [:input_payload]
  include Aws::Structure
end

#automation_idString

The ID of the automation to run.

Returns:

  • (String)


36890
36891
36892
36893
36894
36895
36896
36897
# File 'lib/aws-sdk-quicksight/types.rb', line 36890

class StartAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :input_payload)
  SENSITIVE = [:input_payload]
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the automation.

Returns:

  • (String)


36890
36891
36892
36893
36894
36895
36896
36897
# File 'lib/aws-sdk-quicksight/types.rb', line 36890

class StartAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :input_payload)
  SENSITIVE = [:input_payload]
  include Aws::Structure
end

#input_payloadString

The input payload for the automation job, provided as a JSON string.

Returns:

  • (String)


36890
36891
36892
36893
36894
36895
36896
36897
# File 'lib/aws-sdk-quicksight/types.rb', line 36890

class StartAutomationJobRequest < Struct.new(
  :aws_account_id,
  :automation_group_id,
  :automation_id,
  :input_payload)
  SENSITIVE = [:input_payload]
  include Aws::Structure
end