Class: Aws::QuickSight::Types::StartDashboardSnapshotJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.

Returns:

  • (String)


35548
35549
35550
35551
35552
35553
35554
35555
35556
# File 'lib/aws-sdk-quicksight/types.rb', line 35548

class StartDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id,
  :user_configuration,
  :snapshot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_idString

The ID of the dashboard that you want to start a snapshot job for.

Returns:

  • (String)


35548
35549
35550
35551
35552
35553
35554
35555
35556
# File 'lib/aws-sdk-quicksight/types.rb', line 35548

class StartDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id,
  :user_configuration,
  :snapshot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_configurationTypes::SnapshotConfiguration

A structure that describes the configuration of the dashboard snapshot.



35548
35549
35550
35551
35552
35553
35554
35555
35556
# File 'lib/aws-sdk-quicksight/types.rb', line 35548

class StartDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id,
  :user_configuration,
  :snapshot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_job_idString

An ID for the dashboard snapshot job. This ID is unique to the dashboard while the job is running. This ID can be used to poll the status of a job with a ‘DescribeDashboardSnapshotJob` while the job runs. You can reuse this ID for another job 24 hours after the current job is completed.

Returns:

  • (String)


35548
35549
35550
35551
35552
35553
35554
35555
35556
# File 'lib/aws-sdk-quicksight/types.rb', line 35548

class StartDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id,
  :user_configuration,
  :snapshot_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#user_configurationTypes::SnapshotUserConfiguration

A structure that contains information about the users that the dashboard snapshot is generated for. The users can be either anonymous users or registered users. Anonymous users cannot be used together with registered users.

When using identity-enhanced session credentials, set the UserConfiguration request attribute to null. Otherwise, the request will be invalid.



35548
35549
35550
35551
35552
35553
35554
35555
35556
# File 'lib/aws-sdk-quicksight/types.rb', line 35548

class StartDashboardSnapshotJobRequest < Struct.new(
  :aws_account_id,
  :dashboard_id,
  :snapshot_job_id,
  :user_configuration,
  :snapshot_configuration)
  SENSITIVE = []
  include Aws::Structure
end