Class: Aws::QuickSight::Types::StartDashboardSnapshotJobScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::StartDashboardSnapshotJobScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
-
#dashboard_id ⇒ String
The ID of the dashboard that you want to start a snapshot job schedule for.
-
#schedule_id ⇒ String
The ID of the schedule that you want to start a snapshot job schedule for.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that the dashboard snapshot job is executed in.
39972 39973 39974 39975 39976 39977 39978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39972 class StartDashboardSnapshotJobScheduleRequest < Struct.new( :aws_account_id, :dashboard_id, :schedule_id) SENSITIVE = [] include Aws::Structure end |
#dashboard_id ⇒ String
The ID of the dashboard that you want to start a snapshot job schedule for.
39972 39973 39974 39975 39976 39977 39978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39972 class StartDashboardSnapshotJobScheduleRequest < Struct.new( :aws_account_id, :dashboard_id, :schedule_id) SENSITIVE = [] include Aws::Structure end |
#schedule_id ⇒ String
The ID of the schedule that you want to start a snapshot job schedule for. The schedule ID can be found in the Amazon Quick Sight console in the Schedules pane of the dashboard that the schedule is configured for.
39972 39973 39974 39975 39976 39977 39978 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39972 class StartDashboardSnapshotJobScheduleRequest < Struct.new( :aws_account_id, :dashboard_id, :schedule_id) SENSITIVE = [] include Aws::Structure end |