Class: Aws::QuickSight::Types::TableInlineVisualization
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TableInlineVisualization
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The inline visualization of a specific type to display within a chart.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_bars ⇒ Types::DataBarsOptions
The configuration of the inline visualization of the data bars within a chart.
-
#sparklines ⇒ Types::SparklinesOptions
The configuration of the inline visualization of the sparklines within a chart.
Instance Attribute Details
#data_bars ⇒ Types::DataBarsOptions
The configuration of the inline visualization of the data bars within a chart.
37823 37824 37825 37826 37827 37828 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37823 class TableInlineVisualization < Struct.new( :data_bars, :sparklines) SENSITIVE = [] include Aws::Structure end |
#sparklines ⇒ Types::SparklinesOptions
The configuration of the inline visualization of the sparklines within a chart.
37823 37824 37825 37826 37827 37828 |
# File 'lib/aws-sdk-quicksight/types.rb', line 37823 class TableInlineVisualization < Struct.new( :data_bars, :sparklines) SENSITIVE = [] include Aws::Structure end |