Class: Aws::QuickSight::Types::TemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The template summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A summary of a template.
-
#created_time ⇒ Time
The last time that this template was created.
-
#last_updated_time ⇒ Time
The last time that this template was updated.
-
#latest_version_number ⇒ Integer
A structure containing a list of version numbers for the template summary.
-
#name ⇒ String
A display name for the template.
-
#template_id ⇒ String
The ID of the template.
Instance Attribute Details
#arn ⇒ String
A summary of a template.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The last time that this template was created.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The last time that this template was updated.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#latest_version_number ⇒ Integer
A structure containing a list of version numbers for the template summary.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A display name for the template.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID of the template. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
41689 41690 41691 41692 41693 41694 41695 41696 41697 41698 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41689 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |