Class: Aws::QuickSight::Types::TemplateSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The template summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

A summary of a template.

Returns:

  • (String)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The last time that this template was created.

Returns:

  • (Time)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The last time that this template was updated.

Returns:

  • (Time)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_numberInteger

A structure containing a list of version numbers for the template summary.

Returns:

  • (Integer)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A display name for the template.

Returns:

  • (String)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

The ID of the template. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


38486
38487
38488
38489
38490
38491
38492
38493
38494
38495
# File 'lib/aws-sdk-quicksight/types.rb', line 38486

class TemplateSummary < Struct.new(
  :arn,
  :template_id,
  :name,
  :latest_version_number,
  :created_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end