Class: Aws::QuickSight::Types::TemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The template summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A summary of a template.
-
#created_time ⇒ Time
The last time that this template was created.
-
#last_updated_time ⇒ Time
The last time that this template was updated.
-
#latest_version_number ⇒ Integer
A structure containing a list of version numbers for the template summary.
-
#name ⇒ String
A display name for the template.
-
#template_id ⇒ String
The ID of the template.
Instance Attribute Details
#arn ⇒ String
A summary of a template.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The last time that this template was created.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The last time that this template was updated.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#latest_version_number ⇒ Integer
A structure containing a list of version numbers for the template summary.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A display name for the template.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The ID of the template. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 |
# File 'lib/aws-sdk-quicksight/types.rb', line 38486 class TemplateSummary < Struct.new( :arn, :template_id, :name, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |