Class: Aws::QuickSight::Types::TemplateVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A version of a template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timeTime

The time that this template version was created.

Returns:

  • (Time)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_configurationsArray<Types::DataSetConfiguration>

Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.

Returns:



41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the template.

Returns:

  • (String)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::TemplateError>

Errors associated with this template version.

Returns:



41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#sheetsArray<Types::Sheet>

A list of the associated sheets with the unique identifier and name of each sheet.

Returns:



41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#source_entity_arnString

The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.

Returns:

  • (String)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status that is associated with the template.

  • CREATION_IN_PROGRESS

  • CREATION_SUCCESSFUL

  • CREATION_FAILED

  • UPDATE_IN_PROGRESS

  • UPDATE_SUCCESSFUL

  • UPDATE_FAILED

  • DELETED

Returns:

  • (String)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#theme_arnString

The ARN of the theme associated with this version of the template.

Returns:

  • (String)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end

#version_numberInteger

The version number of the template version.

Returns:

  • (Integer)


41730
41731
41732
41733
41734
41735
41736
41737
41738
41739
41740
41741
41742
# File 'lib/aws-sdk-quicksight/types.rb', line 41730

class TemplateVersion < Struct.new(
  :created_time,
  :errors,
  :version_number,
  :status,
  :data_set_configurations,
  :description,
  :source_entity_arn,
  :theme_arn,
  :sheets)
  SENSITIVE = []
  include Aws::Structure
end