Class: Aws::QuickSight::Types::TemplateVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TemplateVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A version of a template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_time ⇒ Time
The time that this template version was created.
-
#data_set_configurations ⇒ Array<Types::DataSetConfiguration>
Schema of the dataset identified by the placeholder.
-
#description ⇒ String
The description of the template.
-
#errors ⇒ Array<Types::TemplateError>
Errors associated with this template version.
-
#sheets ⇒ Array<Types::Sheet>
A list of the associated sheets with the unique identifier and name of each sheet.
-
#source_entity_arn ⇒ String
The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
-
#status ⇒ String
The status that is associated with the template.
-
#theme_arn ⇒ String
The ARN of the theme associated with this version of the template.
-
#version_number ⇒ Integer
The version number of the template version.
Instance Attribute Details
#created_time ⇒ Time
The time that this template version was created.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#data_set_configurations ⇒ Array<Types::DataSetConfiguration>
Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the template.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::TemplateError>
Errors associated with this template version.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#sheets ⇒ Array<Types::Sheet>
A list of the associated sheets with the unique identifier and name of each sheet.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#source_entity_arn ⇒ String
The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status that is associated with the template.
-
‘CREATION_IN_PROGRESS`
-
‘CREATION_SUCCESSFUL`
-
‘CREATION_FAILED`
-
‘UPDATE_IN_PROGRESS`
-
‘UPDATE_SUCCESSFUL`
-
‘UPDATE_FAILED`
-
‘DELETED`
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#theme_arn ⇒ String
The ARN of the theme associated with this version of the template.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version number of the template version.
39119 39120 39121 39122 39123 39124 39125 39126 39127 39128 39129 39130 39131 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39119 class TemplateVersion < Struct.new( :created_time, :errors, :version_number, :status, :data_set_configurations, :description, :source_entity_arn, :theme_arn, :sheets) SENSITIVE = [] include Aws::Structure end |