Class: Aws::QuickSight::Types::ThemeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ThemeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The theme summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
-
#created_time ⇒ Time
The date and time that this theme was created.
-
#last_updated_time ⇒ Time
The last date and time that this theme was updated.
-
#latest_version_number ⇒ Integer
The latest version number for the theme.
-
#name ⇒ String
the display name for the theme.
-
#theme_id ⇒ String
The ID of the theme.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The date and time that this theme was created.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The last date and time that this theme was updated.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#latest_version_number ⇒ Integer
The latest version number for the theme.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
the display name for the theme.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#theme_id ⇒ String
The ID of the theme. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
41047 41048 41049 41050 41051 41052 41053 41054 41055 41056 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41047 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |