Class: Aws::QuickSight::Types::ThemeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ThemeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The theme summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
-
#created_time ⇒ Time
The date and time that this theme was created.
-
#last_updated_time ⇒ Time
The last date and time that this theme was updated.
-
#latest_version_number ⇒ Integer
The latest version number for the theme.
-
#name ⇒ String
the display name for the theme.
-
#theme_id ⇒ String
The ID of the theme.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the resource.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The date and time that this theme was created.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The last date and time that this theme was updated.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#latest_version_number ⇒ Integer
The latest version number for the theme.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
the display name for the theme.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#theme_id ⇒ String
The ID of the theme. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
39003 39004 39005 39006 39007 39008 39009 39010 39011 39012 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39003 class ThemeSummary < Struct.new( :arn, :name, :theme_id, :latest_version_number, :created_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |