Class: Aws::QuickSight::Types::ThousandSeparatorOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ThousandSeparatorOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The options that determine the thousands separator configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grouping_style ⇒ String
Determines the way numbers are styled to accommodate different readability standards.
-
#symbol ⇒ String
Determines the thousands separator symbol.
-
#visibility ⇒ String
Determines the visibility of the thousands separator.
Instance Attribute Details
#grouping_style ⇒ String
Determines the way numbers are styled to accommodate different
readability standards. The DEFAULT value uses the standard
international grouping system and groups numbers by the thousands.
The LAKHS value uses the Indian numbering system and groups
numbers by lakhs and crores.
41968 41969 41970 41971 41972 41973 41974 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41968 class ThousandSeparatorOptions < Struct.new( :symbol, :visibility, :grouping_style) SENSITIVE = [] include Aws::Structure end |
#symbol ⇒ String
Determines the thousands separator symbol.
41968 41969 41970 41971 41972 41973 41974 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41968 class ThousandSeparatorOptions < Struct.new( :symbol, :visibility, :grouping_style) SENSITIVE = [] include Aws::Structure end |
#visibility ⇒ String
Determines the visibility of the thousands separator.
41968 41969 41970 41971 41972 41973 41974 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41968 class ThousandSeparatorOptions < Struct.new( :symbol, :visibility, :grouping_style) SENSITIVE = [] include Aws::Structure end |