Class: Aws::QuickSight::Types::ThresholdAlertsConfigurations

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The threshold alerts configuration for an embedded Quick Sight dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

The threshold alerts configuration for an embedded Quick Sight dashboard.

Returns:

  • (Boolean)


38961
38962
38963
38964
38965
# File 'lib/aws-sdk-quicksight/types.rb', line 38961

class ThresholdAlertsConfigurations < Struct.new(
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end