Class: Aws::QuickSight::Types::TopicCalculatedField
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicCalculatedField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that represents a calculated field.
Constant Summary collapse
- SENSITIVE =
[:expression]
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The default aggregation.
-
#allowed_aggregations ⇒ Array<String>
The list of aggregation types that are allowed for the calculated field.
-
#calculated_field_description ⇒ String
The calculated field description.
-
#calculated_field_name ⇒ String
The calculated field name.
-
#calculated_field_synonyms ⇒ Array<String>
The other names or aliases for the calculated field.
-
#cell_value_synonyms ⇒ Array<Types::CellValueSynonym>
The other names or aliases for the calculated field cell value.
-
#column_data_role ⇒ String
The column data role for a calculated field.
-
#comparative_order ⇒ Types::ComparativeOrder
The order in which data is displayed for the calculated field when it’s used in a comparative context.
-
#default_formatting ⇒ Types::DefaultFormatting
The default formatting definition.
-
#disable_indexing ⇒ Boolean
A Boolean value that indicates if a calculated field is visible in the autocomplete.
-
#expression ⇒ String
The calculated field expression.
-
#is_included_in_topic ⇒ Boolean
A boolean value that indicates if a calculated field is included in the topic.
-
#never_aggregate_in_filter ⇒ Boolean
A Boolean value that indicates whether to never aggregate calculated field in filters.
-
#non_additive ⇒ Boolean
The non additive for the table style target.
-
#not_allowed_aggregations ⇒ Array<String>
The list of aggregation types that are not allowed for the calculated field.
-
#semantic_type ⇒ Types::SemanticType
The semantic type.
-
#time_granularity ⇒ String
The level of time precision that is used to aggregate ‘DateTime` values.
Instance Attribute Details
#aggregation ⇒ String
The default aggregation. Valid values for this structure are ‘SUM`, `MAX`, `MIN`, `COUNT`, `DISTINCT_COUNT`, and `AVERAGE`.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#allowed_aggregations ⇒ Array<String>
The list of aggregation types that are allowed for the calculated field. Valid values for this structure are ‘COUNT`, `DISTINCT_COUNT`, `MIN`, `MAX`, `MEDIAN`, `SUM`, `AVERAGE`, `STDEV`, `STDEVP`, `VAR`, `VARP`, and `PERCENTILE`.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#calculated_field_description ⇒ String
The calculated field description.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#calculated_field_name ⇒ String
The calculated field name.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#calculated_field_synonyms ⇒ Array<String>
The other names or aliases for the calculated field.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#cell_value_synonyms ⇒ Array<Types::CellValueSynonym>
The other names or aliases for the calculated field cell value.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#column_data_role ⇒ String
The column data role for a calculated field. Valid values for this structure are ‘DIMENSION` and `MEASURE`.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#comparative_order ⇒ Types::ComparativeOrder
The order in which data is displayed for the calculated field when it’s used in a comparative context.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#default_formatting ⇒ Types::DefaultFormatting
The default formatting definition.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#disable_indexing ⇒ Boolean
A Boolean value that indicates if a calculated field is visible in the autocomplete.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#expression ⇒ String
The calculated field expression.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#is_included_in_topic ⇒ Boolean
A boolean value that indicates if a calculated field is included in the topic.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#never_aggregate_in_filter ⇒ Boolean
A Boolean value that indicates whether to never aggregate calculated field in filters.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#non_additive ⇒ Boolean
The non additive for the table style target.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#not_allowed_aggregations ⇒ Array<String>
The list of aggregation types that are not allowed for the calculated field. Valid values for this structure are ‘COUNT`, `DISTINCT_COUNT`, `MIN`, `MAX`, `MEDIAN`, `SUM`, `AVERAGE`, `STDEV`, `STDEVP`, `VAR`, `VARP`, and `PERCENTILE`.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#semantic_type ⇒ Types::SemanticType
The semantic type.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |
#time_granularity ⇒ String
The level of time precision that is used to aggregate ‘DateTime` values.
42581 42582 42583 42584 42585 42586 42587 42588 42589 42590 42591 42592 42593 42594 42595 42596 42597 42598 42599 42600 42601 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42581 class TopicCalculatedField < Struct.new( :calculated_field_name, :calculated_field_description, :expression, :calculated_field_synonyms, :is_included_in_topic, :disable_indexing, :column_data_role, :time_granularity, :default_formatting, :aggregation, :comparative_order, :semantic_type, :allowed_aggregations, :not_allowed_aggregations, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [:expression] include Aws::Structure end |