Class: Aws::QuickSight::Types::TopicColumn

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Represents a column in a dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregationString

The type of aggregation that is performed on the column data when it's queried.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_aggregationsArray<String>

The list of aggregation types that are allowed for the column. Valid values for this structure are COUNT, DISTINCT_COUNT, MIN, MAX, MEDIAN, SUM, AVERAGE, STDEV, STDEVP, VAR, VARP, and PERCENTILE.

Returns:

  • (Array<String>)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#cell_value_synonymsArray<Types::CellValueSynonym>

The other names or aliases for the column cell value.

Returns:



43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#column_data_roleString

The role of the column in the data. Valid values are DIMENSION and MEASURE.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#column_descriptionString

A description of the column and its contents.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#column_friendly_nameString

A user-friendly name for the column.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#column_nameString

The name of the column.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#column_synonymsArray<String>

The other names or aliases for the column.

Returns:

  • (Array<String>)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#comparative_orderTypes::ComparativeOrder

The order in which data is displayed for the column when it's used in a comparative context.



43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#default_formattingTypes::DefaultFormatting

The default formatting used for values in the column.



43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#disable_indexingBoolean

A Boolean value that indicates whether the column shows in the autocomplete functionality.

Returns:

  • (Boolean)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#is_included_in_topicBoolean

A Boolean value that indicates whether the column is included in the query results.

Returns:

  • (Boolean)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#never_aggregate_in_filterBoolean

A Boolean value that indicates whether to aggregate the column data when it's used in a filter context.

Returns:

  • (Boolean)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#non_additiveBoolean

The non additive value for the column.

Returns:

  • (Boolean)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#not_allowed_aggregationsArray<String>

The list of aggregation types that are not allowed for the column. Valid values for this structure are COUNT, DISTINCT_COUNT, MIN, MAX, MEDIAN, SUM, AVERAGE, STDEV, STDEVP, VAR, VARP, and PERCENTILE.

Returns:

  • (Array<String>)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#semantic_typeTypes::SemanticType

The semantic type of data contained in the column.

Returns:



43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end

#time_granularityString

The level of time precision that is used to aggregate DateTime values.

Returns:

  • (String)


43085
43086
43087
43088
43089
43090
43091
43092
43093
43094
43095
43096
43097
43098
43099
43100
43101
43102
43103
43104
43105
# File 'lib/aws-sdk-quicksight/types.rb', line 43085

class TopicColumn < Struct.new(
  :column_name,
  :column_friendly_name,
  :column_description,
  :column_synonyms,
  :column_data_role,
  :aggregation,
  :is_included_in_topic,
  :disable_indexing,
  :comparative_order,
  :semantic_type,
  :time_granularity,
  :allowed_aggregations,
  :not_allowed_aggregations,
  :default_formatting,
  :never_aggregate_in_filter,
  :cell_value_synonyms,
  :non_additive)
  SENSITIVE = []
  include Aws::Structure
end