Class: Aws::QuickSight::Types::TopicColumn
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicColumn
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Represents a column in a dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The type of aggregation that is performed on the column data when it’s queried.
-
#allowed_aggregations ⇒ Array<String>
The list of aggregation types that are allowed for the column.
-
#cell_value_synonyms ⇒ Array<Types::CellValueSynonym>
The other names or aliases for the column cell value.
-
#column_data_role ⇒ String
The role of the column in the data.
-
#column_description ⇒ String
A description of the column and its contents.
-
#column_friendly_name ⇒ String
A user-friendly name for the column.
-
#column_name ⇒ String
The name of the column.
-
#column_synonyms ⇒ Array<String>
The other names or aliases for the column.
-
#comparative_order ⇒ Types::ComparativeOrder
The order in which data is displayed for the column when it’s used in a comparative context.
-
#default_formatting ⇒ Types::DefaultFormatting
The default formatting used for values in the column.
-
#disable_indexing ⇒ Boolean
A Boolean value that indicates whether the column shows in the autocomplete functionality.
-
#is_included_in_topic ⇒ Boolean
A Boolean value that indicates whether the column is included in the query results.
-
#never_aggregate_in_filter ⇒ Boolean
A Boolean value that indicates whether to aggregate the column data when it’s used in a filter context.
-
#non_additive ⇒ Boolean
The non additive value for the column.
-
#not_allowed_aggregations ⇒ Array<String>
The list of aggregation types that are not allowed for the column.
-
#semantic_type ⇒ Types::SemanticType
The semantic type of data contained in the column.
-
#time_granularity ⇒ String
The level of time precision that is used to aggregate ‘DateTime` values.
Instance Attribute Details
#aggregation ⇒ String
The type of aggregation that is performed on the column data when it’s queried.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#allowed_aggregations ⇒ Array<String>
The list of aggregation types that are allowed for the column. Valid values for this structure are ‘COUNT`, `DISTINCT_COUNT`, `MIN`, `MAX`, `MEDIAN`, `SUM`, `AVERAGE`, `STDEV`, `STDEVP`, `VAR`, `VARP`, and `PERCENTILE`.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#cell_value_synonyms ⇒ Array<Types::CellValueSynonym>
The other names or aliases for the column cell value.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#column_data_role ⇒ String
The role of the column in the data. Valid values are ‘DIMENSION` and `MEASURE`.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#column_description ⇒ String
A description of the column and its contents.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#column_friendly_name ⇒ String
A user-friendly name for the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#column_name ⇒ String
The name of the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#column_synonyms ⇒ Array<String>
The other names or aliases for the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#comparative_order ⇒ Types::ComparativeOrder
The order in which data is displayed for the column when it’s used in a comparative context.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#default_formatting ⇒ Types::DefaultFormatting
The default formatting used for values in the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#disable_indexing ⇒ Boolean
A Boolean value that indicates whether the column shows in the autocomplete functionality.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#is_included_in_topic ⇒ Boolean
A Boolean value that indicates whether the column is included in the query results.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#never_aggregate_in_filter ⇒ Boolean
A Boolean value that indicates whether to aggregate the column data when it’s used in a filter context.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#non_additive ⇒ Boolean
The non additive value for the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#not_allowed_aggregations ⇒ Array<String>
The list of aggregation types that are not allowed for the column. Valid values for this structure are ‘COUNT`, `DISTINCT_COUNT`, `MIN`, `MAX`, `MEDIAN`, `SUM`, `AVERAGE`, `STDEV`, `STDEVP`, `VAR`, `VARP`, and `PERCENTILE`.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#semantic_type ⇒ Types::SemanticType
The semantic type of data contained in the column.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |
#time_granularity ⇒ String
The level of time precision that is used to aggregate ‘DateTime` values.
39760 39761 39762 39763 39764 39765 39766 39767 39768 39769 39770 39771 39772 39773 39774 39775 39776 39777 39778 39779 39780 |
# File 'lib/aws-sdk-quicksight/types.rb', line 39760 class TopicColumn < Struct.new( :column_name, :column_friendly_name, :column_description, :column_synonyms, :column_data_role, :aggregation, :is_included_in_topic, :disable_indexing, :comparative_order, :semantic_type, :time_granularity, :allowed_aggregations, :not_allowed_aggregations, :default_formatting, :never_aggregate_in_filter, :cell_value_synonyms, :non_additive) SENSITIVE = [] include Aws::Structure end |