Class: Aws::QuickSight::Types::TopicNamedEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that represents a named entity.

Constant Summary collapse

SENSITIVE =
[:entity_description, :entity_synonyms]

Instance Attribute Summary collapse

Instance Attribute Details

#definitionArray<Types::NamedEntityDefinition>

The definition of a named entity.

Returns:



44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_descriptionString

The description of the named entity.

Returns:

  • (String)


44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_nameString

The name of the named entity.

Returns:

  • (String)


44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#entity_synonymsArray<String>

The other names or aliases for the named entity.

Returns:

  • (Array<String>)


44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#presentation_orderInteger

The presentation order of the named entity.

Returns:

  • (Integer)


44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#rank_orderInteger

The rank order of the named entity.

Returns:

  • (Integer)


44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#semantic_entity_typeTypes::SemanticEntityType

The type of named entity that a topic represents.



44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end

#sortArray<Types::NamedEntitySort>

The sort configuration of the named entity.

Returns:



44866
44867
44868
44869
44870
44871
44872
44873
44874
44875
44876
44877
# File 'lib/aws-sdk-quicksight/types.rb', line 44866

class TopicNamedEntity < Struct.new(
  :entity_name,
  :entity_description,
  :entity_synonyms,
  :semantic_entity_type,
  :definition,
  :sort,
  :rank_order,
  :presentation_order)
  SENSITIVE = [:entity_description, :entity_synonyms]
  include Aws::Structure
end