Class: Aws::QuickSight::Types::TopicNamedEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicNamedEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that represents a named entity.
Constant Summary collapse
- SENSITIVE =
[:entity_description, :entity_synonyms]
Instance Attribute Summary collapse
-
#definition ⇒ Array<Types::NamedEntityDefinition>
The definition of a named entity.
-
#entity_description ⇒ String
The description of the named entity.
-
#entity_name ⇒ String
The name of the named entity.
-
#entity_synonyms ⇒ Array<String>
The other names or aliases for the named entity.
-
#presentation_order ⇒ Integer
The presentation order of the named entity.
-
#rank_order ⇒ Integer
The rank order of the named entity.
-
#semantic_entity_type ⇒ Types::SemanticEntityType
The type of named entity that a topic represents.
-
#sort ⇒ Array<Types::NamedEntitySort>
The sort configuration of the named entity.
Instance Attribute Details
#definition ⇒ Array<Types::NamedEntityDefinition>
The definition of a named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#entity_description ⇒ String
The description of the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#entity_name ⇒ String
The name of the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#entity_synonyms ⇒ Array<String>
The other names or aliases for the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#presentation_order ⇒ Integer
The presentation order of the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#rank_order ⇒ Integer
The rank order of the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#semantic_entity_type ⇒ Types::SemanticEntityType
The type of named entity that a topic represents.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |
#sort ⇒ Array<Types::NamedEntitySort>
The sort configuration of the named entity.
44866 44867 44868 44869 44870 44871 44872 44873 44874 44875 44876 44877 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44866 class TopicNamedEntity < Struct.new( :entity_name, :entity_description, :entity_synonyms, :semantic_entity_type, :definition, :sort, :rank_order, :presentation_order) SENSITIVE = [:entity_description, :entity_synonyms] include Aws::Structure end |