Class: Aws::QuickSight::Types::TopicV2DataSetRelationEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicV2DataSetRelationEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that represents an endpoint of a data set relation of a topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_names ⇒ Array<String>
The names of the columns that are used in the data set relation.
-
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the data set at this endpoint of the relation.
Instance Attribute Details
#column_names ⇒ Array<String>
The names of the columns that are used in the data set relation.
46930 46931 46932 46933 46934 46935 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46930 class TopicV2DataSetRelationEndpoint < Struct.new( :data_set_arn, :column_names) SENSITIVE = [] include Aws::Structure end |
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the data set at this endpoint of the relation.
46930 46931 46932 46933 46934 46935 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46930 class TopicV2DataSetRelationEndpoint < Struct.new( :data_set_arn, :column_names) SENSITIVE = [] include Aws::Structure end |