Class: Aws::QuickSight::Types::TopicV2DataSetRelationEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A structure that represents an endpoint of a data set relation of a topic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_namesArray<String>

The names of the columns that are used in the data set relation.

Returns:

  • (Array<String>)


45362
45363
45364
45365
45366
45367
# File 'lib/aws-sdk-quicksight/types.rb', line 45362

class TopicV2DataSetRelationEndpoint < Struct.new(
  :data_set_arn,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_arnString

The Amazon Resource Name (ARN) of the data set at this endpoint of the relation.

Returns:

  • (String)


45362
45363
45364
45365
45366
45367
# File 'lib/aws-sdk-quicksight/types.rb', line 45362

class TopicV2DataSetRelationEndpoint < Struct.new(
  :data_set_arn,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end