Class: Aws::QuickSight::Types::TopicV2DataSetRelationEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::TopicV2DataSetRelationEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A structure that represents an endpoint of a data set relation of a topic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_names ⇒ Array<String>
The names of the columns that are used in the data set relation.
-
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the data set at this endpoint of the relation.
Instance Attribute Details
#column_names ⇒ Array<String>
The names of the columns that are used in the data set relation.
45362 45363 45364 45365 45366 45367 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45362 class TopicV2DataSetRelationEndpoint < Struct.new( :data_set_arn, :column_names) SENSITIVE = [] include Aws::Structure end |
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the data set at this endpoint of the relation.
45362 45363 45364 45365 45366 45367 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45362 class TopicV2DataSetRelationEndpoint < Struct.new( :data_set_arn, :column_names) SENSITIVE = [] include Aws::Structure end |