Class: Aws::QuickSight::Types::TransformOperationSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Specifies the source of data for a transform operation, including the source operation and column mappings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_id_mappingsArray<Types::DataSetColumnIdMapping>

The mappings between source column identifiers and target column identifiers for this transformation.

Returns:



40860
40861
40862
40863
40864
40865
# File 'lib/aws-sdk-quicksight/types.rb', line 40860

class TransformOperationSource < Struct.new(
  :transform_operation_id,
  :column_id_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#transform_operation_idString

The identifier of the transform operation that provides input data.

Returns:

  • (String)


40860
40861
40862
40863
40864
40865
# File 'lib/aws-sdk-quicksight/types.rb', line 40860

class TransformOperationSource < Struct.new(
  :transform_operation_id,
  :column_id_mappings)
  SENSITIVE = []
  include Aws::Structure
end