Class: Aws::QuickSight::Types::TransformStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A step in data preparation that performs a specific operation on the data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregate_stepTypes::AggregateOperation

A transform step that groups data and applies aggregation functions to calculate summary values.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#append_stepTypes::AppendOperation

A transform step that combines rows from multiple sources by stacking them vertically.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#cast_column_types_stepTypes::CastColumnTypesOperation

A transform step that changes the data types of one or more columns.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#create_columns_stepTypes::CreateColumnsOperation

A transform operation that creates calculated columns. Columns created in one such operation form a lexical closure.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#filters_stepTypes::FiltersOperation

A transform step that applies filter conditions.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#import_table_stepTypes::ImportTableOperation

A transform step that brings data from a source table.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#join_stepTypes::JoinOperation

A transform step that combines data from two sources based on specified join conditions.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#pivot_stepTypes::PivotOperation

A transform step that converts row values into columns to reshape the data structure.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#project_stepTypes::ProjectOperation

A transform operation that projects columns. Operations that come after a projection can only refer to projected columns.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#rename_columns_stepTypes::RenameColumnsOperation

A transform step that changes the names of one or more columns.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end

#unpivot_stepTypes::UnpivotOperation

A transform step that converts columns into rows to normalize the data structure.



39440
39441
39442
39443
39444
39445
39446
39447
39448
39449
39450
39451
39452
39453
39454
# File 'lib/aws-sdk-quicksight/types.rb', line 39440

class TransformStep < Struct.new(
  :import_table_step,
  :project_step,
  :filters_step,
  :create_columns_step,
  :rename_columns_step,
  :cast_column_types_step,
  :join_step,
  :aggregate_step,
  :pivot_step,
  :unpivot_step,
  :append_step)
  SENSITIVE = []
  include Aws::Structure
end