Class: Aws::QuickSight::Types::UnpivotOperation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A transform operation that converts columns into rows, normalizing the data structure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

Alias for this operation.

Returns:

  • (String)


39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#columns_to_unpivotArray<Types::ColumnToUnpivot>

The list of columns to unpivot from the source data.

Returns:



39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::TransformOperationSource

The source transform operation that provides input data for unpivoting.



39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#unpivoted_label_column_idString

A unique identifier for the new column that will contain the unpivoted column names.

Returns:

  • (String)


39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#unpivoted_label_column_nameString

The name for the new column that will contain the unpivoted column names.

Returns:

  • (String)


39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#unpivoted_value_column_idString

A unique identifier for the new column that will contain the unpivoted values.

Returns:

  • (String)


39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end

#unpivoted_value_column_nameString

The name for the new column that will contain the unpivoted values.

Returns:

  • (String)


39986
39987
39988
39989
39990
39991
39992
39993
39994
39995
39996
# File 'lib/aws-sdk-quicksight/types.rb', line 39986

class UnpivotOperation < Struct.new(
  :alias,
  :source,
  :columns_to_unpivot,
  :unpivoted_label_column_name,
  :unpivoted_label_column_id,
  :unpivoted_value_column_name,
  :unpivoted_value_column_id)
  SENSITIVE = []
  include Aws::Structure
end