Class: Aws::QuickSight::Types::UnsupportedPricingPlanException
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UnsupportedPricingPlanException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
This error indicates that you are calling an embedding operation in Amazon Quick Sight without the required pricing plan on your Amazon Web Services account. Before you can use embedding for anonymous users, a Quick Suite administrator needs to add capacity pricing to Quick Sight. You can do this on the Manage Quick Suite page.
After capacity pricing is added, you can use the GetDashboardEmbedUrl API operation with the --identity-type ANONYMOUS option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#request_id ⇒ String
The Amazon Web Services request ID for this request.
Instance Attribute Details
#message ⇒ String
44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44830 class UnsupportedPricingPlanException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this request.
44830 44831 44832 44833 44834 44835 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44830 class UnsupportedPricingPlanException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |