Class: Aws::QuickSight::Types::UnsupportedPricingPlanException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

This error indicates that you are calling an embedding operation in Amazon Quick Sight without the required pricing plan on your Amazon Web Services account. Before you can use embedding for anonymous users, a Quick Suite administrator needs to add capacity pricing to Quick Sight. You can do this on the **Manage Quick Suite** page.

After capacity pricing is added, you can use the ‘ GetDashboardEmbedUrl ` API operation with the `–identity-type ANONYMOUS` option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


40017
40018
40019
40020
40021
40022
# File 'lib/aws-sdk-quicksight/types.rb', line 40017

class UnsupportedPricingPlanException < Struct.new(
  :message,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this request.

Returns:

  • (String)


40017
40018
40019
40020
40021
40022
# File 'lib/aws-sdk-quicksight/types.rb', line 40017

class UnsupportedPricingPlanException < Struct.new(
  :message,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end