Class: Aws::QuickSight::Types::UnsupportedUserEditionException
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UnsupportedUserEditionException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
This error indicates that you are calling an operation on an Amazon Quick Suite subscription where the edition doesn’t include support for that operation. Amazon Quick Suite currently has Standard Edition and Enterprise Edition. Not every operation and capability is available in every edition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#request_id ⇒ String
The Amazon Web Services request ID for this request.
Instance Attribute Details
#message ⇒ String
42241 42242 42243 42244 42245 42246 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42241 class UnsupportedUserEditionException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this request.
42241 42242 42243 42244 42245 42246 |
# File 'lib/aws-sdk-quicksight/types.rb', line 42241 class UnsupportedUserEditionException < Struct.new( :message, :request_id) SENSITIVE = [] include Aws::Structure end |