Class: Aws::QuickSight::Types::UpdateAccountSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that contains the Quick Sight settings that you want to list.

Returns:

  • (String)


45042
45043
45044
45045
45046
45047
45048
45049
# File 'lib/aws-sdk-quicksight/types.rb', line 45042

class UpdateAccountSettingsRequest < Struct.new(
  :aws_account_id,
  :default_namespace,
  :notification_email,
  :termination_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#default_namespaceString

The default namespace for this Amazon Web Services account. Currently, the default is default. IAM users that register for the first time with Amazon Quick Sight provide an email address that becomes associated with the default namespace.

Returns:

  • (String)


45042
45043
45044
45045
45046
45047
45048
45049
# File 'lib/aws-sdk-quicksight/types.rb', line 45042

class UpdateAccountSettingsRequest < Struct.new(
  :aws_account_id,
  :default_namespace,
  :notification_email,
  :termination_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#notification_emailString

The email address that you want Quick Sight to send notifications to regarding your Amazon Web Services account or Quick Sight subscription.

Returns:

  • (String)


45042
45043
45044
45045
45046
45047
45048
45049
# File 'lib/aws-sdk-quicksight/types.rb', line 45042

class UpdateAccountSettingsRequest < Struct.new(
  :aws_account_id,
  :default_namespace,
  :notification_email,
  :termination_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#termination_protection_enabledBoolean

A boolean value that determines whether or not an Quick Sight account can be deleted. A True value doesn't allow the account to be deleted and results in an error message if a user tries to make a DeleteAccountSubscription request. A False value will allow the account to be deleted.

Returns:

  • (Boolean)


45042
45043
45044
45045
45046
45047
45048
45049
# File 'lib/aws-sdk-quicksight/types.rb', line 45042

class UpdateAccountSettingsRequest < Struct.new(
  :aws_account_id,
  :default_namespace,
  :notification_email,
  :termination_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end