Class: Aws::QuickSight::Types::UpdateAccountSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAccountSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the Quick Sight settings that you want to list.
-
#default_namespace ⇒ String
The default namespace for this Amazon Web Services account.
-
#notification_email ⇒ String
The email address that you want Quick Sight to send notifications to regarding your Amazon Web Services account or Quick Sight subscription.
-
#termination_protection_enabled ⇒ Boolean
A boolean value that determines whether or not an Quick Sight account can be deleted.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that contains the Quick Sight settings that you want to list.
44704 44705 44706 44707 44708 44709 44710 44711 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44704 class UpdateAccountSettingsRequest < Struct.new( :aws_account_id, :default_namespace, :notification_email, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#default_namespace ⇒ String
The default namespace for this Amazon Web Services account. Currently, the default is ‘default`. IAM users that register for the first time with Amazon Quick Sight provide an email address that becomes associated with the default namespace.
44704 44705 44706 44707 44708 44709 44710 44711 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44704 class UpdateAccountSettingsRequest < Struct.new( :aws_account_id, :default_namespace, :notification_email, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#notification_email ⇒ String
The email address that you want Quick Sight to send notifications to regarding your Amazon Web Services account or Quick Sight subscription.
44704 44705 44706 44707 44708 44709 44710 44711 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44704 class UpdateAccountSettingsRequest < Struct.new( :aws_account_id, :default_namespace, :notification_email, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#termination_protection_enabled ⇒ Boolean
A boolean value that determines whether or not an Quick Sight account can be deleted. A ‘True` value doesn’t allow the account to be deleted and results in an error message if a user tries to make a ‘DeleteAccountSubscription` request. A `False` value will allow the account to be deleted.
44704 44705 44706 44707 44708 44709 44710 44711 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44704 class UpdateAccountSettingsRequest < Struct.new( :aws_account_id, :default_namespace, :notification_email, :termination_protection_enabled) SENSITIVE = [] include Aws::Structure end |