Class: Aws::QuickSight::Types::UpdateActionConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateActionConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#action_connector_id ⇒ String
The unique identifier of the action connector to update.
-
#authentication_config ⇒ Types::AuthConfig
The updated authentication configuration for connecting to the external service.
-
#aws_account_id ⇒ String
The Amazon Web Services account ID that contains the action connector to update.
-
#description ⇒ String
The updated description of the action connector.
-
#name ⇒ String
The new name for the action connector.
-
#vpc_connection_arn ⇒ String
The updated ARN of the VPC connection to use for secure connectivity.
Instance Attribute Details
#action_connector_id ⇒ String
The unique identifier of the action connector to update.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#authentication_config ⇒ Types::AuthConfig
The updated authentication configuration for connecting to the external service.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#aws_account_id ⇒ String
The Amazon Web Services account ID that contains the action connector to update.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The updated description of the action connector.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The new name for the action connector.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |
#vpc_connection_arn ⇒ String
The updated ARN of the VPC connection to use for secure connectivity.
41830 41831 41832 41833 41834 41835 41836 41837 41838 41839 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41830 class UpdateActionConnectorRequest < Struct.new( :aws_account_id, :action_connector_id, :name, :authentication_config, :description, :vpc_connection_arn) SENSITIVE = [:name, :description] include Aws::Structure end |