Class: Aws::QuickSight::Types::UpdateAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:starter_prompts, :welcome_message, :custom_prompt_input]
Instance Attribute Summary collapse
-
#action_connectors_to_add ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
-
#action_connectors_to_remove ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to detach from the agent.
-
#agent_id ⇒ String
The unique identifier for the agent to update.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
-
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
-
#description ⇒ String
A description of the agent.
-
#icon_id ⇒ String
The icon identifier for the agent.
-
#name ⇒ String
The name of the agent.
-
#spaces_to_add ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
-
#spaces_to_remove ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to detach from the agent.
-
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
-
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
Instance Attribute Details
#action_connectors_to_add ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#action_connectors_to_remove ⇒ Array<String>
The Amazon Resource Names (ARNs) of the action connectors to detach from the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier for the agent to update.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#custom_prompt_input ⇒ Types::CustomPromptInput
The custom prompt configuration for the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#description ⇒ String
A description of the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#icon_id ⇒ String
The icon identifier for the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#name ⇒ String
The name of the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#spaces_to_add ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to attach to the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#spaces_to_remove ⇒ Array<String>
The Amazon Resource Names (ARNs) of the spaces to detach from the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#starter_prompts ⇒ Array<String>
A list of starter prompts that are displayed to users when they begin interacting with the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |
#welcome_message ⇒ String
The welcome message that is displayed when a user starts a conversation with the agent.
45341 45342 45343 45344 45345 45346 45347 45348 45349 45350 45351 45352 45353 45354 45355 45356 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45341 class UpdateAgentRequest < Struct.new( :agent_id, :aws_account_id, :name, :description, :icon_id, :starter_prompts, :welcome_message, :custom_prompt_input, :spaces_to_add, :spaces_to_remove, :action_connectors_to_add, :action_connectors_to_remove) SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input] include Aws::Structure end |