Class: Aws::QuickSight::Types::UpdateAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:starter_prompts, :welcome_message, :custom_prompt_input]

Instance Attribute Summary collapse

Instance Attribute Details

#action_connectors_to_addArray<String>

The Amazon Resource Names (ARNs) of the action connectors to attach to the agent.

Returns:

  • (Array<String>)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#action_connectors_to_removeArray<String>

The Amazon Resource Names (ARNs) of the action connectors to detach from the agent.

Returns:

  • (Array<String>)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#agent_idString

The unique identifier for the agent to update.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the agent.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#custom_prompt_inputTypes::CustomPromptInput

The custom prompt configuration for the agent.



44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#descriptionString

A description of the agent.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#icon_idString

The icon identifier for the agent.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#nameString

The name of the agent.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#spaces_to_addArray<String>

The Amazon Resource Names (ARNs) of the spaces to attach to the agent.

Returns:

  • (Array<String>)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#spaces_to_removeArray<String>

The Amazon Resource Names (ARNs) of the spaces to detach from the agent.

Returns:

  • (Array<String>)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#starter_promptsArray<String>

A list of starter prompts that are displayed to users when they begin interacting with the agent.

Returns:

  • (Array<String>)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end

#welcome_messageString

The welcome message that is displayed when a user starts a conversation with the agent.

Returns:

  • (String)


44208
44209
44210
44211
44212
44213
44214
44215
44216
44217
44218
44219
44220
44221
44222
44223
# File 'lib/aws-sdk-quicksight/types.rb', line 44208

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :aws_account_id,
  :name,
  :description,
  :icon_id,
  :starter_prompts,
  :welcome_message,
  :custom_prompt_input,
  :spaces_to_add,
  :spaces_to_remove,
  :action_connectors_to_add,
  :action_connectors_to_remove)
  SENSITIVE = [:starter_prompts, :welcome_message, :custom_prompt_input]
  include Aws::Structure
end