Class: Aws::QuickSight::Types::UpdateAgentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_idString

The unique identifier for the agent.

Returns:

  • (String)


44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#agent_statusString

The status of the agent.

Returns:

  • (String)


44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the agent.

Returns:

  • (String)


44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#failed_to_add_action_connectorsArray<Types::FailedToUpdateAssociation>

A list of per-ARN failures from the action connectors that were requested to be added.



44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#failed_to_add_spacesArray<Types::FailedToUpdateAssociation>

A list of per-ARN failures from the spaces that were requested to be added.



44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#failed_to_remove_action_connectorsArray<Types::FailedToUpdateAssociation>

A list of per-ARN failures from the action connectors that were requested to be removed.



44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#failed_to_remove_spacesArray<Types::FailedToUpdateAssociation>

A list of per-ARN failures from the spaces that were requested to be removed.



44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


44263
44264
44265
44266
44267
44268
44269
44270
44271
44272
44273
44274
# File 'lib/aws-sdk-quicksight/types.rb', line 44263

class UpdateAgentResponse < Struct.new(
  :arn,
  :agent_id,
  :agent_status,
  :failed_to_add_spaces,
  :failed_to_remove_spaces,
  :failed_to_add_action_connectors,
  :failed_to_remove_action_connectors,
  :request_id)
  SENSITIVE = []
  include Aws::Structure
end