Class: Aws::QuickSight::Types::UpdateAnalysisPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateAnalysisPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_id ⇒ String
The ID of the analysis whose permissions you're updating.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis whose permissions you're updating.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the permissions to add and the principal to add them to.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the permissions to remove and the principal to remove them from.
Instance Attribute Details
#analysis_id ⇒ String
The ID of the analysis whose permissions you're updating. The ID is part of the analysis URL.
45467 45468 45469 45470 45471 45472 45473 45474 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45467 class UpdateAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the analysis whose permissions you're updating. You must be using the Amazon Web Services account that the analysis is in.
45467 45468 45469 45470 45471 45472 45473 45474 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45467 class UpdateAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the permissions to add and the principal to add them to.
45467 45468 45469 45470 45471 45472 45473 45474 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45467 class UpdateAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
A structure that describes the permissions to remove and the principal to remove them from.
45467 45468 45469 45470 45471 45472 45473 45474 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45467 class UpdateAnalysisPermissionsRequest < Struct.new( :aws_account_id, :analysis_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |