Class: Aws::QuickSight::Types::UpdateAnalysisPermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The ID of the analysis whose permissions you’re updating. The ID is part of the analysis URL.

Returns:

  • (String)


42615
42616
42617
42618
42619
42620
42621
42622
# File 'lib/aws-sdk-quicksight/types.rb', line 42615

class UpdateAnalysisPermissionsRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the analysis whose permissions you’re updating. You must be using the Amazon Web Services account that the analysis is in.

Returns:

  • (String)


42615
42616
42617
42618
42619
42620
42621
42622
# File 'lib/aws-sdk-quicksight/types.rb', line 42615

class UpdateAnalysisPermissionsRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#grant_permissionsArray<Types::ResourcePermission>

A structure that describes the permissions to add and the principal to add them to.

Returns:



42615
42616
42617
42618
42619
42620
42621
42622
# File 'lib/aws-sdk-quicksight/types.rb', line 42615

class UpdateAnalysisPermissionsRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_permissionsArray<Types::ResourcePermission>

A structure that describes the permissions to remove and the principal to remove them from.

Returns:



42615
42616
42617
42618
42619
42620
42621
42622
# File 'lib/aws-sdk-quicksight/types.rb', line 42615

class UpdateAnalysisPermissionsRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end