Class: Aws::QuickSight::Types::UpdateAnalysisRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analysis_idString

The ID for the analysis that you're updating. This ID displays in the URL of the analysis.

Returns:

  • (String)


46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#aws_account_idString

The ID of the Amazon Web Services account that contains the analysis that you're updating.

Returns:

  • (String)


46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#definitionTypes::AnalysisDefinition

The definition of an analysis.

A definition is the data model of all features in a Dashboard, Template, or Analysis.



46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive name for the analysis that you're updating. This name displays for the analysis in the Amazon Quick Sight console.

Returns:

  • (String)


46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::Parameters

The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.

Returns:



46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#source_entityTypes::AnalysisSourceEntity

A source entity to use for the analysis that you're updating. This metadata structure contains details that describe a source template and one or more datasets or topics.



46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#theme_arnString

The Amazon Resource Name (ARN) for the theme to apply to the analysis that you're creating. To see the theme in the Amazon Quick Sight console, make sure that you have access to it.

Returns:

  • (String)


46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end

#validation_strategyTypes::ValidationStrategy

The option to relax the validation needed to update an analysis with definition objects. This skips the validation step for specific errors.



46927
46928
46929
46930
46931
46932
46933
46934
46935
46936
46937
46938
# File 'lib/aws-sdk-quicksight/types.rb', line 46927

class UpdateAnalysisRequest < Struct.new(
  :aws_account_id,
  :analysis_id,
  :name,
  :parameters,
  :source_entity,
  :theme_arn,
  :definition,
  :validation_strategy)
  SENSITIVE = []
  include Aws::Structure
end