Class: Aws::QuickSight::Types::UpdateApplicationWithTokenExchangeGrantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateApplicationWithTokenExchangeGrantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to be updated with a token exchange grant.
-
#namespace ⇒ String
The namespace of the Quick Suite application.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account to be updated with a token exchange grant.
40559 40560 40561 40562 40563 40564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40559 class UpdateApplicationWithTokenExchangeGrantRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the Quick Suite application.
40559 40560 40561 40562 40563 40564 |
# File 'lib/aws-sdk-quicksight/types.rb', line 40559 class UpdateApplicationWithTokenExchangeGrantRequest < Struct.new( :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |