Class: Aws::QuickSight::Types::UpdateCustomPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateCustomPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the custom permissions profile that you want to update.
-
#capabilities ⇒ Types::Capabilities
A set of actions to include in the custom permissions profile.
-
#custom_permissions_name ⇒ String
The name of the custom permissions profile that you want to update.
-
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the custom permissions profile that you want to update.
45778 45779 45780 45781 45782 45783 45784 45785 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45778 class UpdateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::Capabilities
A set of actions to include in the custom permissions profile.
45778 45779 45780 45781 45782 45783 45784 45785 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45778 class UpdateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The name of the custom permissions profile that you want to update.
45778 45779 45780 45781 45782 45783 45784 45785 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45778 class UpdateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |
#governance ⇒ Types::Governance
The governance configuration for the custom permissions profile. The
UpdateCustomPermissions operation replaces all existing
Capabilities and Governance values. If you omit this parameter,
Amazon Quick removes governance from the profile and the existing
custom permission behavior applies.
45778 45779 45780 45781 45782 45783 45784 45785 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45778 class UpdateCustomPermissionsRequest < Struct.new( :aws_account_id, :custom_permissions_name, :capabilities, :governance) SENSITIVE = [] include Aws::Structure end |