Class: Aws::QuickSight::Types::UpdateDataSetPermissionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_set_arnString

The Amazon Resource Name (ARN) of the dataset.

Returns:

  • (String)


45815
45816
45817
45818
45819
45820
45821
45822
# File 'lib/aws-sdk-quicksight/types.rb', line 45815

class UpdateDataSetPermissionsResponse < Struct.new(
  :data_set_arn,
  :data_set_id,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#data_set_idString

The ID for the dataset whose permissions you want to update. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


45815
45816
45817
45818
45819
45820
45821
45822
# File 'lib/aws-sdk-quicksight/types.rb', line 45815

class UpdateDataSetPermissionsResponse < Struct.new(
  :data_set_arn,
  :data_set_id,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The Amazon Web Services request ID for this operation.

Returns:

  • (String)


45815
45816
45817
45818
45819
45820
45821
45822
# File 'lib/aws-sdk-quicksight/types.rb', line 45815

class UpdateDataSetPermissionsResponse < Struct.new(
  :data_set_arn,
  :data_set_id,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusInteger

The HTTP status of the request.

Returns:

  • (Integer)


45815
45816
45817
45818
45819
45820
45821
45822
# File 'lib/aws-sdk-quicksight/types.rb', line 45815

class UpdateDataSetPermissionsResponse < Struct.new(
  :data_set_arn,
  :data_set_id,
  :request_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end