Class: Aws::QuickSight::Types::UpdateDataSetPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateDataSetPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset whose permissions you want to update.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
43364 43365 43366 43367 43368 43369 43370 43371 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43364 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset whose permissions you want to update. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
43364 43365 43366 43367 43368 43369 43370 43371 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43364 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
43364 43365 43366 43367 43368 43369 43370 43371 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43364 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
43364 43365 43366 43367 43368 43369 43370 43371 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43364 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |