Class: Aws::QuickSight::Types::UpdateDataSetPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateDataSetPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#data_set_id ⇒ String
The ID for the dataset whose permissions you want to update.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#data_set_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
41162 41163 41164 41165 41166 41167 41168 41169 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41162 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The ID for the dataset whose permissions you want to update. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
41162 41163 41164 41165 41166 41167 41168 41169 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41162 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
41162 41163 41164 41165 41166 41167 41168 41169 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41162 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
41162 41163 41164 41165 41166 41167 41168 41169 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41162 class UpdateDataSetPermissionsResponse < Struct.new( :data_set_arn, :data_set_id, :request_id, :status) SENSITIVE = [] include Aws::Structure end |