Class: Aws::QuickSight::Types::UpdateDataSourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateDataSourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:credentials]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#credentials ⇒ Types::DataSourceCredentials
The credentials that Amazon Quick Sight that uses to connect to your underlying source.
-
#data_source_id ⇒ String
The ID of the data source.
-
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Amazon Quick Sight uses to connect to your underlying source.
-
#name ⇒ String
A display name for the data source.
-
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Amazon Quick Sight connects to your underlying source.
-
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
Use this parameter only when you want Amazon Quick Sight to use a VPC connection when connecting to your underlying source.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#credentials ⇒ Types::DataSourceCredentials
The credentials that Amazon Quick Sight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#data_source_parameters ⇒ Types::DataSourceParameters
The parameters that Amazon Quick Sight uses to connect to your underlying source.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#name ⇒ String
A display name for the data source.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#ssl_properties ⇒ Types::SslProperties
Secure Socket Layer (SSL) properties that apply when Amazon Quick Sight connects to your underlying source.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |
#vpc_connection_properties ⇒ Types::VpcConnectionProperties
Use this parameter only when you want Amazon Quick Sight to use a VPC connection when connecting to your underlying source.
43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43049 class UpdateDataSourceRequest < Struct.new( :aws_account_id, :data_source_id, :name, :data_source_parameters, :credentials, :vpc_connection_properties, :ssl_properties) SENSITIVE = [:credentials] include Aws::Structure end |