Class: Aws::QuickSight::Types::UpdateFlowPermissionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the flow you are updating permissions against.

Returns:

  • (String)


41518
41519
41520
41521
41522
41523
41524
41525
# File 'lib/aws-sdk-quicksight/types.rb', line 41518

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow to update permissions for.

Returns:

  • (String)


41518
41519
41520
41521
41522
41523
41524
41525
# File 'lib/aws-sdk-quicksight/types.rb', line 41518

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#grant_permissionsArray<Types::Permission>

The permissions that you want to grant on this flow.

Returns:



41518
41519
41520
41521
41522
41523
41524
41525
# File 'lib/aws-sdk-quicksight/types.rb', line 41518

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_permissionsArray<Types::Permission>

The permissions that you want to revoke from this flow.

Returns:



41518
41519
41520
41521
41522
41523
41524
41525
# File 'lib/aws-sdk-quicksight/types.rb', line 41518

class UpdateFlowPermissionsInput < Struct.new(
  :aws_account_id,
  :flow_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end