Class: Aws::QuickSight::Types::UpdateFlowPermissionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateFlowPermissionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow you are updating permissions against.
-
#flow_id ⇒ String
The unique identifier of the flow to update permissions for.
-
#grant_permissions ⇒ Array<Types::Permission>
The permissions that you want to grant on this flow.
-
#revoke_permissions ⇒ Array<Types::Permission>
The permissions that you want to revoke from this flow.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow you are updating permissions against.
41518 41519 41520 41521 41522 41523 41524 41525 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41518 class UpdateFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow to update permissions for.
41518 41519 41520 41521 41522 41523 41524 41525 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41518 class UpdateFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::Permission>
The permissions that you want to grant on this flow.
41518 41519 41520 41521 41522 41523 41524 41525 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41518 class UpdateFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::Permission>
The permissions that you want to revoke from this flow.
41518 41519 41520 41521 41522 41523 41524 41525 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41518 class UpdateFlowPermissionsInput < Struct.new( :aws_account_id, :flow_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |