Class: Aws::QuickSight::Types::UpdateFlowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateFlowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:flow_definition]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are updating.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
Updated description for the flow.
-
#flow_definition ⇒ Hash, ...
The definition of the flow, specifying the steps and configurations.
-
#flow_id ⇒ String
The unique identifier of the flow to update.
-
#name ⇒ String
Updated display name for the flow.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the flow that you are updating.
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |
#description ⇒ String
Updated description for the flow. Omit to preserve the existing description.
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |
#flow_definition ⇒ Hash, ...
The definition of the flow, specifying the steps and configurations. This is the flow definition in Quick Flow’s internal format. The format is subject to change. When provided, all existing steps are replaced. Omit to preserve the existing definition.
<note markdown=“1”> Always derive or depend on the flow definition from the ‘DescribeFlow` operation to ensure you are working with the latest format.
</note>
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |
#flow_id ⇒ String
The unique identifier of the flow to update.
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |
#name ⇒ String
Updated display name for the flow. Omit to preserve the existing name.
46255 46256 46257 46258 46259 46260 46261 46262 46263 46264 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46255 class UpdateFlowRequest < Struct.new( :aws_account_id, :flow_id, :name, :description, :flow_definition, :client_token) SENSITIVE = [:flow_definition] include Aws::Structure end |