Class: Aws::QuickSight::Types::UpdateGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in.
-
#description ⇒ String
The description for the group that you want to update.
-
#group_name ⇒ String
The name of the group that you want to update.
-
#namespace ⇒ String
The namespace of the group that you want to update.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.
45658 45659 45660 45661 45662 45663 45664 45665 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45658 class UpdateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the group that you want to update.
45658 45659 45660 45661 45662 45663 45664 45665 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45658 class UpdateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the group that you want to update.
45658 45659 45660 45661 45662 45663 45664 45665 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45658 class UpdateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the group that you want to update.
45658 45659 45660 45661 45662 45663 45664 45665 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45658 class UpdateGroupRequest < Struct.new( :group_name, :description, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |