Class: Aws::QuickSight::Types::UpdateGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID for the Amazon Web Services account that the group is in. Currently, you use the ID for the Amazon Web Services account that contains your Amazon Quick Sight account.

Returns:

  • (String)


43175
43176
43177
43178
43179
43180
43181
43182
# File 'lib/aws-sdk-quicksight/types.rb', line 43175

class UpdateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for the group that you want to update.

Returns:

  • (String)


43175
43176
43177
43178
43179
43180
43181
43182
# File 'lib/aws-sdk-quicksight/types.rb', line 43175

class UpdateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#group_nameString

The name of the group that you want to update.

Returns:

  • (String)


43175
43176
43177
43178
43179
43180
43181
43182
# File 'lib/aws-sdk-quicksight/types.rb', line 43175

class UpdateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the group that you want to update.

Returns:

  • (String)


43175
43176
43177
43178
43179
43180
43181
43182
# File 'lib/aws-sdk-quicksight/types.rb', line 43175

class UpdateGroupRequest < Struct.new(
  :group_name,
  :description,
  :aws_account_id,
  :namespace)
  SENSITIVE = []
  include Aws::Structure
end