Class: Aws::QuickSight::Types::UpdateIAMPolicyAssignmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateIAMPolicyAssignmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assignment_name ⇒ String
The name of the assignment, also called a rule.
-
#assignment_status ⇒ String
The status of the assignment.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the IAM policy assignment.
-
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that you want to assign the policy to.
-
#namespace ⇒ String
The namespace of the assignment.
-
#policy_arn ⇒ String
The ARN for the IAM policy to apply to the Amazon Quick Sight users and groups specified in this assignment.
Instance Attribute Details
#assignment_name ⇒ String
The name of the assignment, also called a rule. The name must be unique within the Amazon Web Services account.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |
#assignment_status ⇒ String
The status of the assignment. Possible values are as follows:
-
‘ENABLED` - Anything specified in this assignment is used when creating the data source.
-
‘DISABLED` - This assignment isn’t used when creating the data source.
-
‘DRAFT` - This assignment is an unfinished draft and isn’t used when creating the data source.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the IAM policy assignment.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that you want to assign the policy to.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the assignment.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The ARN for the IAM policy to apply to the Amazon Quick Sight users and groups specified in this assignment.
41762 41763 41764 41765 41766 41767 41768 41769 41770 41771 |
# File 'lib/aws-sdk-quicksight/types.rb', line 41762 class UpdateIAMPolicyAssignmentRequest < Struct.new( :aws_account_id, :assignment_name, :namespace, :assignment_status, :policy_arn, :identities) SENSITIVE = [] include Aws::Structure end |