Class: Aws::QuickSight::Types::UpdateIAMPolicyAssignmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateIAMPolicyAssignmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assignment_id ⇒ String
The ID of the assignment.
-
#assignment_name ⇒ String
The name of the assignment or rule.
-
#assignment_status ⇒ String
The status of the assignment.
-
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that the IAM policy is assigned to.
-
#policy_arn ⇒ String
The ARN for the IAM policy applied to the Amazon Quick Sight users and groups specified in this assignment.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
Instance Attribute Details
#assignment_id ⇒ String
The ID of the assignment.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#assignment_name ⇒ String
The name of the assignment or rule.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#assignment_status ⇒ String
The status of the assignment. Possible values are as follows:
-
‘ENABLED` - Anything specified in this assignment is used when creating the data source.
-
‘DISABLED` - This assignment isn’t used when creating the data source.
-
‘DRAFT` - This assignment is an unfinished draft and isn’t used when creating the data source.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#identities ⇒ Hash<String,Array<String>>
The Amazon Quick Sight users, groups, or both that the IAM policy is assigned to.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#policy_arn ⇒ String
The ARN for the IAM policy applied to the Amazon Quick Sight users and groups specified in this assignment.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
43297 43298 43299 43300 43301 43302 43303 43304 43305 43306 43307 |
# File 'lib/aws-sdk-quicksight/types.rb', line 43297 class UpdateIAMPolicyAssignmentResponse < Struct.new( :assignment_name, :assignment_id, :policy_arn, :identities, :assignment_status, :request_id, :status) SENSITIVE = [] include Aws::Structure end |