Class: Aws::QuickSight::Types::UpdateKnowledgeBasePermissionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the knowledge base.

Returns:

  • (String)


46725
46726
46727
46728
46729
46730
46731
46732
# File 'lib/aws-sdk-quicksight/types.rb', line 46725

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#grant_permissionsArray<Types::ResourcePermission>

The resource permissions that you want to grant on the knowledge base.

Returns:



46725
46726
46727
46728
46729
46730
46731
46732
# File 'lib/aws-sdk-quicksight/types.rb', line 46725

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier for the knowledge base.

Returns:

  • (String)


46725
46726
46727
46728
46729
46730
46731
46732
# File 'lib/aws-sdk-quicksight/types.rb', line 46725

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end

#revoke_permissionsArray<Types::ResourcePermission>

The resource permissions that you want to revoke from the knowledge base.

Returns:



46725
46726
46727
46728
46729
46730
46731
46732
# File 'lib/aws-sdk-quicksight/types.rb', line 46725

class UpdateKnowledgeBasePermissionsRequest < Struct.new(
  :aws_account_id,
  :knowledge_base_id,
  :grant_permissions,
  :revoke_permissions)
  SENSITIVE = []
  include Aws::Structure
end