Class: Aws::QuickSight::Types::UpdateOAuthClientApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateOAuthClientApplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID.
-
#client_id ⇒ String
The client ID of the OAuth application that is registered with the identity provider.
-
#client_secret ⇒ String
The client secret of the OAuth application that is registered with the identity provider.
-
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used with.
-
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
-
#name ⇒ String
The display name for the OAuthClientApplication.
-
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
-
#o_auth_client_application_id ⇒ String
The ID of the OAuthClientApplication that you want to update.
-
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
-
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#client_id ⇒ String
The client ID of the OAuth application that is registered with the identity provider.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#client_secret ⇒ String
The client secret of the OAuth application that is registered with the identity provider.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#data_source_type ⇒ String
The type of data source that the OAuthClientApplication is used with. Valid values are ‘SNOWFLAKE`.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#identity_provider_vpc_connection_properties ⇒ Types::VpcConnectionProperties
VPC connection properties.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#name ⇒ String
The display name for the OAuthClientApplication.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_authorization_endpoint_url ⇒ String
The authorization endpoint URL of the identity provider that is used to obtain authorization codes.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_client_application_id ⇒ String
The ID of the OAuthClientApplication that you want to update.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_scopes ⇒ String
The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |
#o_auth_token_endpoint_url ⇒ String
The token endpoint URL of the identity provider that is used to obtain access tokens.
46814 46815 46816 46817 46818 46819 46820 46821 46822 46823 46824 46825 46826 46827 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46814 class UpdateOAuthClientApplicationRequest < Struct.new( :aws_account_id, :o_auth_client_application_id, :name, :client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url, :o_auth_scopes, :data_source_type, :identity_provider_vpc_connection_properties) SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url] include Aws::Structure end |