Class: Aws::QuickSight::Types::UpdateOAuthClientApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account ID.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#client_idString

The client ID of the OAuth application that is registered with the identity provider.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#client_secretString

The client secret of the OAuth application that is registered with the identity provider.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#data_source_typeString

The type of data source that the OAuthClientApplication is used with. Valid values are ‘SNOWFLAKE`.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#identity_provider_vpc_connection_propertiesTypes::VpcConnectionProperties

VPC connection properties.



44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#nameString

The display name for the OAuthClientApplication.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_authorization_endpoint_urlString

The authorization endpoint URL of the identity provider that is used to obtain authorization codes.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_client_application_idString

The ID of the OAuthClientApplication that you want to update.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_scopesString

The OAuth scopes that are requested when the OAuthClientApplication obtains an access token from the identity provider.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end

#o_auth_token_endpoint_urlString

The token endpoint URL of the identity provider that is used to obtain access tokens.

Returns:

  • (String)


44221
44222
44223
44224
44225
44226
44227
44228
44229
44230
44231
44232
44233
44234
# File 'lib/aws-sdk-quicksight/types.rb', line 44221

class UpdateOAuthClientApplicationRequest < Struct.new(
  :aws_account_id,
  :o_auth_client_application_id,
  :name,
  :client_id,
  :client_secret,
  :o_auth_token_endpoint_url,
  :o_auth_authorization_endpoint_url,
  :o_auth_scopes,
  :data_source_type,
  :identity_provider_vpc_connection_properties)
  SENSITIVE = [:client_id, :client_secret, :o_auth_token_endpoint_url, :o_auth_authorization_endpoint_url]
  include Aws::Structure
end