Class: Aws::QuickSight::Types::UpdateRoleCustomPermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateRoleCustomPermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in.
-
#custom_permissions_name ⇒ String
The name of the custom permission that you want to update the role with.
-
#namespace ⇒ String
The namespace that contains the role that you want to update.
-
#role ⇒ String
The name of role tht you want to update.
Instance Attribute Details
#aws_account_id ⇒ String
The ID for the Amazon Web Services account that you want to create a group in. The Amazon Web Services account ID that you provide must be the same Amazon Web Services account that contains your Amazon Quick Sight account.
47543 47544 47545 47546 47547 47548 47549 47550 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47543 class UpdateRoleCustomPermissionRequest < Struct.new( :custom_permissions_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#custom_permissions_name ⇒ String
The name of the custom permission that you want to update the role with.
47543 47544 47545 47546 47547 47548 47549 47550 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47543 class UpdateRoleCustomPermissionRequest < Struct.new( :custom_permissions_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace that contains the role that you want to update.
47543 47544 47545 47546 47547 47548 47549 47550 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47543 class UpdateRoleCustomPermissionRequest < Struct.new( :custom_permissions_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name of role tht you want to update.
47543 47544 47545 47546 47547 47548 47549 47550 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47543 class UpdateRoleCustomPermissionRequest < Struct.new( :custom_permissions_name, :role, :aws_account_id, :namespace) SENSITIVE = [] include Aws::Structure end |