Class: Aws::QuickSight::Types::UpdateSpaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the space.

Returns:

  • (String)


46456
46457
46458
46459
46460
46461
46462
46463
# File 'lib/aws-sdk-quicksight/types.rb', line 46456

class UpdateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A new description for the space.

Returns:

  • (String)


46456
46457
46458
46459
46460
46461
46462
46463
# File 'lib/aws-sdk-quicksight/types.rb', line 46456

class UpdateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

A new display name for the space.

Returns:

  • (String)


46456
46457
46458
46459
46460
46461
46462
46463
# File 'lib/aws-sdk-quicksight/types.rb', line 46456

class UpdateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#space_idString

The ID of the space that you want to update.

Returns:

  • (String)


46456
46457
46458
46459
46460
46461
46462
46463
# File 'lib/aws-sdk-quicksight/types.rb', line 46456

class UpdateSpaceRequest < Struct.new(
  :aws_account_id,
  :space_id,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end