Class: Aws::QuickSight::Types::UpdateSpaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateSpaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#description ⇒ String
A new description for the space.
-
#name ⇒ String
A new display name for the space.
-
#space_id ⇒ String
The ID of the space that you want to update.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
46456 46457 46458 46459 46460 46461 46462 46463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46456 class UpdateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A new description for the space.
46456 46457 46458 46459 46460 46461 46462 46463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46456 class UpdateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
A new display name for the space.
46456 46457 46458 46459 46460 46461 46462 46463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46456 class UpdateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to update.
46456 46457 46458 46459 46460 46461 46462 46463 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46456 class UpdateSpaceRequest < Struct.new( :aws_account_id, :space_id, :name, :description) SENSITIVE = [:description] include Aws::Structure end |