Class: Aws::QuickSight::Types::UpdateSpaceResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateSpaceResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_resources ⇒ Array<Types::SpaceResourceOperation>
A list of resources to add to the space.
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
-
#remove_resources ⇒ Array<Types::SpaceResourceOperation>
A list of resources to remove from the space.
-
#space_id ⇒ String
The ID of the space that you want to update resources for.
Instance Attribute Details
#add_resources ⇒ Array<Types::SpaceResourceOperation>
A list of resources to add to the space.
46483 46484 46485 46486 46487 46488 46489 46490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46483 class UpdateSpaceResourcesRequest < Struct.new( :aws_account_id, :space_id, :add_resources, :remove_resources) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the space.
46483 46484 46485 46486 46487 46488 46489 46490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46483 class UpdateSpaceResourcesRequest < Struct.new( :aws_account_id, :space_id, :add_resources, :remove_resources) SENSITIVE = [] include Aws::Structure end |
#remove_resources ⇒ Array<Types::SpaceResourceOperation>
A list of resources to remove from the space.
46483 46484 46485 46486 46487 46488 46489 46490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46483 class UpdateSpaceResourcesRequest < Struct.new( :aws_account_id, :space_id, :add_resources, :remove_resources) SENSITIVE = [] include Aws::Structure end |
#space_id ⇒ String
The ID of the space that you want to update resources for.
46483 46484 46485 46486 46487 46488 46489 46490 |
# File 'lib/aws-sdk-quicksight/types.rb', line 46483 class UpdateSpaceResourcesRequest < Struct.new( :aws_account_id, :space_id, :add_resources, :remove_resources) SENSITIVE = [] include Aws::Structure end |