Class: Aws::QuickSight::Types::UpdateTopicPermissionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicPermissionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update the permissions for.
-
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant to the topic.
-
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update the permissions for.
44230 44231 44232 44233 44234 44235 44236 44237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44230 class UpdateTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#grant_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to grant to the topic.
44230 44231 44232 44233 44234 44235 44236 44237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44230 class UpdateTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#revoke_permissions ⇒ Array<Types::ResourcePermission>
The resource permissions that you want to revoke from the topic.
44230 44231 44232 44233 44234 44235 44236 44237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44230 class UpdateTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
44230 44231 44232 44233 44234 44235 44236 44237 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44230 class UpdateTopicPermissionsRequest < Struct.new( :aws_account_id, :topic_id, :grant_permissions, :revoke_permissions) SENSITIVE = [] include Aws::Structure end |