Class: Aws::QuickSight::Types::UpdateTopicPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the topic.
48317 48318 48319 48320 48321 48322 48323 48324 48325 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48317 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
48317 48318 48319 48320 48321 48322 48323 48324 48325 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48317 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
48317 48318 48319 48320 48321 48322 48323 48324 48325 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48317 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
48317 48318 48319 48320 48321 48322 48323 48324 48325 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48317 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
48317 48318 48319 48320 48321 48322 48323 48324 48325 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48317 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |