Class: Aws::QuickSight::Types::UpdateTopicPermissionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicPermissionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the topic.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#permissions ⇒ Array<Types::ResourcePermission>
A list of resource permissions on the topic.
45077 45078 45079 45080 45081 45082 45083 45084 45085 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45077 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
45077 45078 45079 45080 45081 45082 45083 45084 45085 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45077 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
45077 45078 45079 45080 45081 45082 45083 45084 45085 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45077 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
45077 45078 45079 45080 45081 45082 45083 45084 45085 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45077 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
45077 45078 45079 45080 45081 45082 45083 45084 45085 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45077 class UpdateTopicPermissionsResponse < Struct.new( :topic_id, :topic_arn, :permissions, :status, :request_id) SENSITIVE = [] include Aws::Structure end |