Class: Aws::QuickSight::Types::UpdateTopicRefreshScheduleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want to update.

Returns:

  • (String)


48275
48276
48277
48278
48279
48280
48281
48282
# File 'lib/aws-sdk-quicksight/types.rb', line 48275

class UpdateTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id,
  :refresh_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_idString

The ID of the dataset.

Returns:

  • (String)


48275
48276
48277
48278
48279
48280
48281
48282
# File 'lib/aws-sdk-quicksight/types.rb', line 48275

class UpdateTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id,
  :refresh_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_scheduleTypes::TopicRefreshSchedule

The definition of a refresh schedule.



48275
48276
48277
48278
48279
48280
48281
48282
# File 'lib/aws-sdk-quicksight/types.rb', line 48275

class UpdateTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id,
  :refresh_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


48275
48276
48277
48278
48279
48280
48281
48282
# File 'lib/aws-sdk-quicksight/types.rb', line 48275

class UpdateTopicRefreshScheduleRequest < Struct.new(
  :aws_account_id,
  :topic_id,
  :dataset_id,
  :refresh_schedule)
  SENSITIVE = []
  include Aws::Structure
end