Class: Aws::QuickSight::Types::UpdateTopicRefreshScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicRefreshScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want to update.
-
#dataset_id ⇒ String
The ID of the dataset.
-
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic whose refresh schedule you want to update.
45107 45108 45109 45110 45111 45112 45113 45114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45107 class UpdateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#dataset_id ⇒ String
The ID of the dataset.
45107 45108 45109 45110 45111 45112 45113 45114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45107 class UpdateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#refresh_schedule ⇒ Types::TopicRefreshSchedule
The definition of a refresh schedule.
45107 45108 45109 45110 45111 45112 45113 45114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45107 class UpdateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
45107 45108 45109 45110 45111 45112 45113 45114 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45107 class UpdateTopicRefreshScheduleRequest < Struct.new( :aws_account_id, :topic_id, :dataset_id, :refresh_schedule) SENSITIVE = [] include Aws::Structure end |