Class: Aws::QuickSight::Types::UpdateTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
48283 48284 48285 48286 48287 48288 48289 48290 48291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48283 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
48283 48284 48285 48286 48287 48288 48289 48290 48291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48283 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
48283 48284 48285 48286 48287 48288 48289 48290 48291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48283 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
48283 48284 48285 48286 48287 48288 48289 48290 48291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48283 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
48283 48284 48285 48286 48287 48288 48289 48290 48291 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48283 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |