Class: Aws::QuickSight::Types::UpdateTopicRefreshScheduleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicRefreshScheduleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset.
44675 44676 44677 44678 44679 44680 44681 44682 44683 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44675 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
44675 44676 44677 44678 44679 44680 44681 44682 44683 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44675 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
44675 44676 44677 44678 44679 44680 44681 44682 44683 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44675 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
44675 44676 44677 44678 44679 44680 44681 44682 44683 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44675 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
44675 44676 44677 44678 44679 44680 44681 44682 44683 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44675 class UpdateTopicRefreshScheduleResponse < Struct.new( :topic_id, :topic_arn, :dataset_arn, :status, :request_id) SENSITIVE = [] include Aws::Structure end |