Class: Aws::QuickSight::Types::UpdateTopicRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update.
-
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
-
#topic ⇒ Types::TopicDetails
The definition of the topic that you want to update.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account that contains the topic that you want to update.
45169 45170 45171 45172 45173 45174 45175 45176 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45169 class UpdateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#custom_instructions ⇒ Types::CustomInstructions
Custom instructions for the topic.
45169 45170 45171 45172 45173 45174 45175 45176 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45169 class UpdateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic ⇒ Types::TopicDetails
The definition of the topic that you want to update.
45169 45170 45171 45172 45173 45174 45175 45176 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45169 class UpdateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :custom_instructions) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
45169 45170 45171 45172 45173 45174 45175 45176 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45169 class UpdateTopicRequest < Struct.new( :aws_account_id, :topic_id, :topic, :custom_instructions) SENSITIVE = [] include Aws::Structure end |