Class: Aws::QuickSight::Types::UpdateTopicResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
48441 48442 48443 48444 48445 48446 48447 48448 48449 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48441 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
48441 48442 48443 48444 48445 48446 48447 48448 48449 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48441 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
48441 48442 48443 48444 48445 48446 48447 48448 48449 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48441 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
48441 48442 48443 48444 48445 48446 48447 48448 48449 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48441 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
48441 48442 48443 48444 48445 48446 48447 48448 48449 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48441 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |