Class: Aws::QuickSight::Types::UpdateTopicResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateTopicResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
-
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
-
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
-
#status ⇒ Integer
The HTTP status of the request.
-
#topic_id ⇒ String
The ID of the topic that you want to modify.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the topic.
47122 47123 47124 47125 47126 47127 47128 47129 47130 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47122 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#refresh_arn ⇒ String
The Amazon Resource Name (ARN) of the topic refresh.
47122 47123 47124 47125 47126 47127 47128 47129 47130 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47122 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The Amazon Web Services request ID for this operation.
47122 47123 47124 47125 47126 47127 47128 47129 47130 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47122 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Integer
The HTTP status of the request.
47122 47123 47124 47125 47126 47127 47128 47129 47130 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47122 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |
#topic_id ⇒ String
The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.
47122 47123 47124 47125 47126 47127 47128 47129 47130 |
# File 'lib/aws-sdk-quicksight/types.rb', line 47122 class UpdateTopicResponse < Struct.new( :topic_id, :arn, :refresh_arn, :request_id, :status) SENSITIVE = [] include Aws::Structure end |