Class: Aws::QuickSight::Types::UpdateTopicV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account that contains the topic that you want to update.

Returns:

  • (String)


49913
49914
49915
49916
49917
49918
49919
49920
49921
# File 'lib/aws-sdk-quicksight/types.rb', line 49913

class UpdateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions,
  :publish_option)
  SENSITIVE = []
  include Aws::Structure
end

#custom_instructionsTypes::CustomInstructions

Instructions that provide additional guidance and context for response generation.



49913
49914
49915
49916
49917
49918
49919
49920
49921
# File 'lib/aws-sdk-quicksight/types.rb', line 49913

class UpdateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions,
  :publish_option)
  SENSITIVE = []
  include Aws::Structure
end

#publish_optionString

The publish option for the topic that you want to update.

Returns:

  • (String)


49913
49914
49915
49916
49917
49918
49919
49920
49921
# File 'lib/aws-sdk-quicksight/types.rb', line 49913

class UpdateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions,
  :publish_option)
  SENSITIVE = []
  include Aws::Structure
end

#topicTypes::TopicV2Details

The definition of the topic that you want to update.



49913
49914
49915
49916
49917
49918
49919
49920
49921
# File 'lib/aws-sdk-quicksight/types.rb', line 49913

class UpdateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions,
  :publish_option)
  SENSITIVE = []
  include Aws::Structure
end

#topic_idString

The ID of the topic that you want to modify. This ID is unique per Amazon Web Services Region for each Amazon Web Services account.

Returns:

  • (String)


49913
49914
49915
49916
49917
49918
49919
49920
49921
# File 'lib/aws-sdk-quicksight/types.rb', line 49913

class UpdateTopicV2Request < Struct.new(
  :aws_account_id,
  :topic_id,
  :topic,
  :custom_instructions,
  :publish_option)
  SENSITIVE = []
  include Aws::Structure
end