Class: Aws::QuickSight::Types::UpdateVPCConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UpdateVPCConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID of the account that contains the VPC connection that you want to update.
-
#dns_resolvers ⇒ Array<String>
A list of IP addresses of DNS resolver endpoints for the VPC connection.
-
#name ⇒ String
The display name for the VPC connection.
-
#role_arn ⇒ String
An IAM role associated with the VPC connection.
-
#security_group_ids ⇒ Array<String>
A list of security group IDs for the VPC connection.
-
#subnet_ids ⇒ Array<String>
A list of subnet IDs for the VPC connection.
-
#vpc_connection_id ⇒ String
The ID of the VPC connection that you’re updating.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID of the account that contains the VPC connection that you want to update.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#dns_resolvers ⇒ Array<String>
A list of IP addresses of DNS resolver endpoints for the VPC connection.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The display name for the VPC connection.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
An IAM role associated with the VPC connection.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
A list of security group IDs for the VPC connection.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
A list of subnet IDs for the VPC connection.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_connection_id ⇒ String
The ID of the VPC connection that you’re updating. This ID is a unique identifier for each Amazon Web Services Region in an Amazon Web Services account.
44814 44815 44816 44817 44818 44819 44820 44821 44822 44823 44824 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44814 class UpdateVPCConnectionRequest < Struct.new( :aws_account_id, :vpc_connection_id, :name, :subnet_ids, :security_group_ids, :dns_resolvers, :role_arn) SENSITIVE = [] include Aws::Structure end |