Class: Aws::QuickSight::Types::User

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

A registered user of Quick Sight.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activeBoolean

The active status of user. When you create an Quick Sight user that’s not an IAM user or an Active Directory user, that user is inactive until they sign in and provide a password.

Returns:

  • (Boolean)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) for the user.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_permissions_nameString

The custom permissions profile associated with this user.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#emailString

The user’s email address.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#external_login_federation_provider_typeString

The type of supported external login provider that provides identity to let the user federate into Quick Sight with an associated IAM role. The type can be one of the following.

  • ‘COGNITO`: Amazon Cognito. The provider URL is cognito-identity.amazonaws.com.

  • ‘CUSTOM_OIDC`: Custom OpenID Connect (OIDC) provider.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#external_login_federation_provider_urlString

The URL of the external login provider.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#external_login_idString

The identity ID for the user in the external login provider.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#identity_typeString

The type of identity authentication used by the user.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The principal ID of the user.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The Quick Sight role for the user. The user role can be one of the following:.

  • ‘READER`: A user who has read-only access to dashboards.

  • ‘AUTHOR`: A user who can create data sources, datasets, analyses, and dashboards.

  • ‘ADMIN`: A user who is an author, who can also manage Amazon Quick Sight settings.

  • ‘READER_PRO`: Reader Pro adds Generative BI capabilities to the Reader role. Reader Pros have access to Amazon Q in Quick Sight, can build stories with Amazon Q, and can generate executive summaries from dashboards.

  • ‘AUTHOR_PRO`: Author Pro adds Generative BI capabilities to the Author role. Author Pros can author dashboards with natural language with Amazon Q, build stories with Amazon Q, create Topics for Q&amp;A, and generate executive summaries from dashboards.

  • ‘ADMIN_PRO`: Admin Pros are Author Pros who can also manage Quick Sight administrative settings. Admin Pro users are billed at Author Pro pricing.

  • ‘RESTRICTED_READER`: This role isn’t currently available for use.

  • ‘RESTRICTED_AUTHOR`: This role isn’t currently available for use.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The user’s user name. This value is required if you are registering a user that will be managed in Quick Sight. In the output, the value for ‘UserName` is `N/A` when the value for `IdentityType` is `IAM` and the corresponding IAM user is deleted.

Returns:

  • (String)


43330
43331
43332
43333
43334
43335
43336
43337
43338
43339
43340
43341
43342
43343
43344
# File 'lib/aws-sdk-quicksight/types.rb', line 43330

class User < Struct.new(
  :arn,
  :user_name,
  :email,
  :role,
  :identity_type,
  :active,
  :principal_id,
  :custom_permissions_name,
  :external_login_federation_provider_type,
  :external_login_federation_provider_url,
  :external_login_id)
  SENSITIVE = []
  include Aws::Structure
end