Class: Aws::QuickSight::Types::UserIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UserIdentifier
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Note:
UserIdentifier is a union - when making an API calls you must set exactly one of the members.
A structure that contains information to identify a user.
Defined Under Namespace
Classes: Email, Unknown, UserArn, UserName
Constant Summary collapse
- SENSITIVE =
[:user_name, :email]
Instance Attribute Summary collapse
-
#email ⇒ String
The email address of the user that you want to get identity context for.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user_arn ⇒ String
The Amazon Resource Name (ARN) of the user that you want to get identity context for.
-
#user_name ⇒ String
The name of the user that you want to get identity context for.
Instance Attribute Details
#email ⇒ String
The email address of the user that you want to get identity context for.
50418 50419 50420 50421 50422 50423 50424 50425 50426 50427 50428 50429 50430 50431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50418 class UserIdentifier < Struct.new( :user_name, :email, :user_arn, :unknown) SENSITIVE = [:user_name, :email] include Aws::Structure include Aws::Structure::Union class UserName < UserIdentifier; end class Email < UserIdentifier; end class UserArn < UserIdentifier; end class Unknown < UserIdentifier; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
50418 50419 50420 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50418 def unknown @unknown end |
#user_arn ⇒ String
The Amazon Resource Name (ARN) of the user that you want to get identity context for.
50418 50419 50420 50421 50422 50423 50424 50425 50426 50427 50428 50429 50430 50431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50418 class UserIdentifier < Struct.new( :user_name, :email, :user_arn, :unknown) SENSITIVE = [:user_name, :email] include Aws::Structure include Aws::Structure::Union class UserName < UserIdentifier; end class Email < UserIdentifier; end class UserArn < UserIdentifier; end class Unknown < UserIdentifier; end end |
#user_name ⇒ String
The name of the user that you want to get identity context for.
50418 50419 50420 50421 50422 50423 50424 50425 50426 50427 50428 50429 50430 50431 |
# File 'lib/aws-sdk-quicksight/types.rb', line 50418 class UserIdentifier < Struct.new( :user_name, :email, :user_arn, :unknown) SENSITIVE = [:user_name, :email] include Aws::Structure include Aws::Structure::Union class UserName < UserIdentifier; end class Email < UserIdentifier; end class UserArn < UserIdentifier; end class Unknown < UserIdentifier; end end |