Class: Aws::QuickSight::Types::UserIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

Note:

UserIdentifier is a union - when making an API calls you must set exactly one of the members.

A structure that contains information to identify a user.

Direct Known Subclasses

Email, Unknown, UserArn, UserName

Defined Under Namespace

Classes: Email, Unknown, UserArn, UserName

Constant Summary collapse

SENSITIVE =
[:user_name, :email]

Instance Attribute Summary collapse

Instance Attribute Details

#emailString

The email address of the user that you want to get identity context for.

Returns:

  • (String)


45003
45004
45005
45006
45007
45008
45009
45010
45011
45012
45013
45014
45015
45016
# File 'lib/aws-sdk-quicksight/types.rb', line 45003

class UserIdentifier < Struct.new(
  :user_name,
  :email,
  :user_arn,
  :unknown)
  SENSITIVE = [:user_name, :email]
  include Aws::Structure
  include Aws::Structure::Union

  class UserName < UserIdentifier; end
  class Email < UserIdentifier; end
  class UserArn < UserIdentifier; end
  class Unknown < UserIdentifier; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



45003
45004
45005
# File 'lib/aws-sdk-quicksight/types.rb', line 45003

def unknown
  @unknown
end

#user_arnString

The Amazon Resource Name (ARN) of the user that you want to get identity context for.

Returns:

  • (String)


45003
45004
45005
45006
45007
45008
45009
45010
45011
45012
45013
45014
45015
45016
# File 'lib/aws-sdk-quicksight/types.rb', line 45003

class UserIdentifier < Struct.new(
  :user_name,
  :email,
  :user_arn,
  :unknown)
  SENSITIVE = [:user_name, :email]
  include Aws::Structure
  include Aws::Structure::Union

  class UserName < UserIdentifier; end
  class Email < UserIdentifier; end
  class UserArn < UserIdentifier; end
  class Unknown < UserIdentifier; end
end

#user_nameString

The name of the user that you want to get identity context for.

Returns:

  • (String)


45003
45004
45005
45006
45007
45008
45009
45010
45011
45012
45013
45014
45015
45016
# File 'lib/aws-sdk-quicksight/types.rb', line 45003

class UserIdentifier < Struct.new(
  :user_name,
  :email,
  :user_arn,
  :unknown)
  SENSITIVE = [:user_name, :email]
  include Aws::Structure
  include Aws::Structure::Union

  class UserName < UserIdentifier; end
  class Email < UserIdentifier; end
  class UserArn < UserIdentifier; end
  class Unknown < UserIdentifier; end
end