Class: Aws::QuickSight::Types::UserIndexCapacity
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::UserIndexCapacity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
A summary of a user’s index capacity consumption.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email ⇒ String
The email address of the user.
-
#kb_count ⇒ Integer
The number of knowledge bases owned by the user.
-
#role ⇒ String
The role of the user.
-
#space_count ⇒ Integer
The number of spaces owned by the user.
-
#total_capacity_bytes ⇒ Integer
The total index capacity consumed by the user in bytes.
-
#total_kb_capacity_bytes ⇒ Integer
The total index capacity consumed by the user’s knowledge bases in bytes.
-
#total_space_capacity_bytes ⇒ Integer
The total index capacity consumed by the user’s spaces in bytes.
-
#user_arn ⇒ String
The ARN of the user.
-
#user_name ⇒ String
The username of the user.
Instance Attribute Details
#email ⇒ String
The email address of the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#kb_count ⇒ Integer
The number of knowledge bases owned by the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role of the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#space_count ⇒ Integer
The number of spaces owned by the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#total_capacity_bytes ⇒ Integer
The total index capacity consumed by the user in bytes.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#total_kb_capacity_bytes ⇒ Integer
The total index capacity consumed by the user’s knowledge bases in bytes.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#total_space_capacity_bytes ⇒ Integer
The total index capacity consumed by the user’s spaces in bytes.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#user_arn ⇒ String
The ARN of the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The username of the user.
48484 48485 48486 48487 48488 48489 48490 48491 48492 48493 48494 48495 48496 |
# File 'lib/aws-sdk-quicksight/types.rb', line 48484 class UserIndexCapacity < Struct.new( :user_arn, :user_name, :email, :role, :total_capacity_bytes, :total_kb_capacity_bytes, :total_space_capacity_bytes, :kb_count, :space_count) SENSITIVE = [] include Aws::Structure end |