Class: Aws::QuickSight::Types::ValueColumnConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::ValueColumnConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
Configuration for how to handle value columns in pivot operations, including aggregation settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_function ⇒ Types::DataPrepAggregationFunction
The aggregation function to apply when multiple values map to the same pivoted cell.
Instance Attribute Details
#aggregation_function ⇒ Types::DataPrepAggregationFunction
The aggregation function to apply when multiple values map to the same pivoted cell.
45039 45040 45041 45042 45043 |
# File 'lib/aws-sdk-quicksight/types.rb', line 45039 class ValueColumnConfiguration < Struct.new( :aggregation_function) SENSITIVE = [] include Aws::Structure end |