Class: Aws::QuickSight::Types::VisualMessageConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-quicksight/types.rb

Overview

The configuration for a customizable message displayed on a visual. Supports parameter substitution in text fields.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description text of the message that is displayed on the visual.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

#description_visibilityString

Specifies whether the description of the message is displayed.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specifies whether the custom message is displayed on the visual. When set to true, the custom message appears in place of the default message. When set to false or omitted, the default message is displayed.

Returns:

  • (Boolean)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

The display text of the hyperlink that is shown in the message.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

The destination URL of the hyperlink that is shown in the message. Only valid http, https, and mailto URLs are supported.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

Specifies whether the hyperlink in the message is displayed.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title text of the message that is displayed on the visual.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end

#title_visibilityString

Specifies whether the title of the message is displayed.

Returns:

  • (String)


51258
51259
51260
51261
51262
51263
51264
51265
51266
51267
51268
51269
# File 'lib/aws-sdk-quicksight/types.rb', line 51258

class VisualMessageConfiguration < Struct.new(
  :enabled,
  :title,
  :title_visibility,
  :description,
  :description_visibility,
  :link_text,
  :link_url,
  :link_visibility)
  SENSITIVE = []
  include Aws::Structure
end