Class: Aws::QuickSight::Types::VisualMessageConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::VisualMessageConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The configuration for a customizable message displayed on a visual. Supports parameter substitution in text fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description text of the message that is displayed on the visual.
-
#description_visibility ⇒ String
Specifies whether the description of the message is displayed.
-
#enabled ⇒ Boolean
Specifies whether the custom message is displayed on the visual.
-
#link_text ⇒ String
The display text of the hyperlink that is shown in the message.
-
#link_url ⇒ String
The destination URL of the hyperlink that is shown in the message.
-
#link_visibility ⇒ String
Specifies whether the hyperlink in the message is displayed.
-
#title ⇒ String
The title text of the message that is displayed on the visual.
-
#title_visibility ⇒ String
Specifies whether the title of the message is displayed.
Instance Attribute Details
#description ⇒ String
The description text of the message that is displayed on the visual.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#description_visibility ⇒ String
Specifies whether the description of the message is displayed.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Specifies whether the custom message is displayed on the visual.
When set to true, the custom message appears in place of the
default message. When set to false or omitted, the default message
is displayed.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#link_text ⇒ String
The display text of the hyperlink that is shown in the message.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#link_url ⇒ String
The destination URL of the hyperlink that is shown in the message.
Only valid http, https, and mailto URLs are supported.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#link_visibility ⇒ String
Specifies whether the hyperlink in the message is displayed.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title text of the message that is displayed on the visual.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |
#title_visibility ⇒ String
Specifies whether the title of the message is displayed.
51258 51259 51260 51261 51262 51263 51264 51265 51266 51267 51268 51269 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51258 class VisualMessageConfiguration < Struct.new( :enabled, :title, :title_visibility, :description, :description_visibility, :link_text, :link_url, :link_visibility) SENSITIVE = [] include Aws::Structure end |