Class: Aws::QuickSight::Types::VisualMessages
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::VisualMessages
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The messages that are displayed on a visual under specific conditions, such as when the visual returns no data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#no_data_message ⇒ Types::VisualMessageConfiguration
The message that is displayed on a visual when there is no data to display.
Instance Attribute Details
#no_data_message ⇒ Types::VisualMessageConfiguration
The message that is displayed on a visual when there is no data to display.
51281 51282 51283 51284 51285 |
# File 'lib/aws-sdk-quicksight/types.rb', line 51281 class VisualMessages < Struct.new( :no_data_message) SENSITIVE = [] include Aws::Structure end |