Class: Aws::QuickSight::Types::WebProxyCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::QuickSight::Types::WebProxyCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-quicksight/types.rb
Overview
The credentials for authenticating with a web proxy server.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#web_proxy_password ⇒ String
The password for authenticating with the web proxy server.
-
#web_proxy_username ⇒ String
The username for authenticating with the web proxy server.
Instance Attribute Details
#web_proxy_password ⇒ String
The password for authenticating with the web proxy server.
44492 44493 44494 44495 44496 44497 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44492 class WebProxyCredentials < Struct.new( :web_proxy_username, :web_proxy_password) SENSITIVE = [] include Aws::Structure end |
#web_proxy_username ⇒ String
The username for authenticating with the web proxy server.
44492 44493 44494 44495 44496 44497 |
# File 'lib/aws-sdk-quicksight/types.rb', line 44492 class WebProxyCredentials < Struct.new( :web_proxy_username, :web_proxy_password) SENSITIVE = [] include Aws::Structure end |